@@ -2,8 +2,8 @@
 #define SNDLIB_H
 
 #define SNDLIB_VERSION 21
-#define SNDLIB_REVISION 0
-#define SNDLIB_DATE "27-July-09"
+#define SNDLIB_REVISION 2
+#define SNDLIB_DATE "11-Dec-09"
 
 #include <mus-config.h>
 
@@ -27,7 +27,7 @@
 #endif
 
 
-#if MUS_WINDOZE
+#if HAVE_WINDOZE
   /* I got these from gmp.h */
   #if defined (__GNUC__)
     #define MUS_EXPORT  __declspec(__dllexport__)
@@ -49,7 +49,7 @@
   #endif
 #endif
 
-#if (SIZEOF_SSIZE_T == SIZEOF_INT) && (!MUS_MAC_OSX)
+#if (SIZEOF_SSIZE_T == SIZEOF_INT) && (!HAVE_OSX)
   #define SSIZE_TD "%d"
 #else
   #define SSIZE_TD "%ld"
@@ -239,19 +239,7 @@ enum {MUS_UNKNOWN, MUS_BSHORT, MUS_MULAW, MUS_BYTE, MUS_BFLOAT, MUS_BINT, MUS_AL
 #define MUS_AUDIO_DEVICE(n) ((n) & 0xffff)
 
 
-enum {MUS_AUDIO_DEFAULT, MUS_AUDIO_DUPLEX_DEFAULT, MUS_AUDIO_ADAT_IN, MUS_AUDIO_AES_IN, MUS_AUDIO_LINE_OUT,
-      MUS_AUDIO_LINE_IN, MUS_AUDIO_MICROPHONE, MUS_AUDIO_SPEAKERS, MUS_AUDIO_DIGITAL_IN, MUS_AUDIO_DIGITAL_OUT,
-      MUS_AUDIO_DAC_OUT, MUS_AUDIO_ADAT_OUT, MUS_AUDIO_AES_OUT, MUS_AUDIO_DAC_FILTER, MUS_AUDIO_MIXER,
-      MUS_AUDIO_LINE1, MUS_AUDIO_LINE2, MUS_AUDIO_LINE3, MUS_AUDIO_AUX_INPUT, MUS_AUDIO_CD,
-      MUS_AUDIO_AUX_OUTPUT, MUS_AUDIO_SPDIF_IN, MUS_AUDIO_SPDIF_OUT, MUS_AUDIO_AMP, MUS_AUDIO_SRATE,
-      MUS_AUDIO_CHANNEL, MUS_AUDIO_FORMAT, MUS_AUDIO_IMIX, MUS_AUDIO_IGAIN, MUS_AUDIO_RECLEV,
-      MUS_AUDIO_PCM, MUS_AUDIO_PCM2, MUS_AUDIO_OGAIN, MUS_AUDIO_LINE, MUS_AUDIO_SYNTH,
-      MUS_AUDIO_BASS, MUS_AUDIO_TREBLE, MUS_AUDIO_PORT, MUS_AUDIO_SAMPLES_PER_CHANNEL,
-      MUS_AUDIO_DIRECTION
-};
-/* Snd's recorder uses MUS_AUDIO_DIRECTION to find the size of this list */
-
-
+#define MUS_AUDIO_DEFAULT 0
 #define MUS_ERROR -1
 
 enum {MUS_NO_ERROR, MUS_NO_FREQUENCY, MUS_NO_PHASE, MUS_NO_GEN, MUS_NO_LENGTH,
@@ -266,13 +254,11 @@ enum {MUS_NO_ERROR, MUS_NO_FREQUENCY, MUS_NO_PHASE, MUS_NO_GEN, MUS_NO_LENGTH,
 
       MUS_AUDIO_CHANNELS_NOT_AVAILABLE, MUS_AUDIO_SRATE_NOT_AVAILABLE, MUS_AUDIO_FORMAT_NOT_AVAILABLE,
       MUS_AUDIO_NO_INPUT_AVAILABLE, MUS_AUDIO_CONFIGURATION_NOT_AVAILABLE, 
-      MUS_AUDIO_NO_LINES_AVAILABLE, MUS_AUDIO_WRITE_ERROR, MUS_AUDIO_SIZE_NOT_AVAILABLE, MUS_AUDIO_DEVICE_NOT_AVAILABLE,
-      MUS_AUDIO_CANT_CLOSE, MUS_AUDIO_CANT_OPEN, MUS_AUDIO_READ_ERROR, MUS_AUDIO_AMP_NOT_AVAILABLE,
+      MUS_AUDIO_WRITE_ERROR, MUS_AUDIO_SIZE_NOT_AVAILABLE, MUS_AUDIO_DEVICE_NOT_AVAILABLE,
+      MUS_AUDIO_CANT_CLOSE, MUS_AUDIO_CANT_OPEN, MUS_AUDIO_READ_ERROR, 
       MUS_AUDIO_CANT_WRITE, MUS_AUDIO_CANT_READ, MUS_AUDIO_NO_READ_PERMISSION,
 
       MUS_CANT_CLOSE_FILE, MUS_ARG_OUT_OF_RANGE, MUS_WRONG_TYPE_ARG,
-      MUS_MIDI_OPEN_ERROR, MUS_MIDI_READ_ERROR, MUS_MIDI_WRITE_ERROR, MUS_MIDI_CLOSE_ERROR, MUS_MIDI_INIT_ERROR, MUS_MIDI_MISC_ERROR,
-
       MUS_NO_CHANNELS, MUS_NO_HOP, MUS_NO_WIDTH, MUS_NO_FILE_NAME, MUS_NO_RAMP, MUS_NO_RUN, 
       MUS_NO_INCREMENT, MUS_NO_OFFSET,
       MUS_NO_XCOEFF, MUS_NO_YCOEFF, MUS_NO_XCOEFFS, MUS_NO_YCOEFFS, MUS_NO_RESET, MUS_BAD_SIZE, MUS_CANT_CONVERT,
@@ -282,7 +268,7 @@ enum {MUS_NO_ERROR, MUS_NO_FREQUENCY, MUS_NO_PHASE, MUS_NO_GEN, MUS_NO_LENGTH,
 /* keep this list in sync with mus_error_names in sound.c and snd-test.scm|rb */
 
 
-#if MUS_WINDOZE
+#if HAVE_WINDOZE
   #ifdef FOPEN
     #undef FOPEN
   #endif
@@ -430,20 +416,14 @@ MUS_EXPORT int mus_float_array_to_file(const char *filename, mus_float_t *ddata,
 #define MUS_OSS_API 1
 #define MUS_JACK_API 2
 
-MUS_EXPORT bool mus_audio_device_p(int n);
-MUS_EXPORT void mus_audio_describe(void);
-MUS_EXPORT char *mus_audio_report(void);
+MUS_EXPORT char *mus_audio_describe(void);
 MUS_EXPORT int mus_audio_open_output(int dev, int srate, int chans, int format, int size);
 MUS_EXPORT int mus_audio_open_input(int dev, int srate, int chans, int format, int size);
 MUS_EXPORT int mus_audio_write(int line, char *buf, int bytes);
 MUS_EXPORT int mus_audio_close(int line);
 MUS_EXPORT int mus_audio_read(int line, char *buf, int bytes);
-
 MUS_EXPORT int mus_audio_write_buffers(int line, int frames, int chans, mus_sample_t **bufs, int output_format, bool clipped);
 MUS_EXPORT int mus_audio_read_buffers(int line, int frames, int chans, mus_sample_t **bufs, int input_format);
-
-MUS_EXPORT int mus_audio_mixer_read(int dev, int field, int chan, float *val);
-MUS_EXPORT int mus_audio_mixer_write(int dev, int field, int chan, float *val);
 MUS_EXPORT int mus_audio_initialize(void);
 
 #if HAVE_OSS || HAVE_ALSA
@@ -465,17 +445,11 @@ MUS_EXPORT int mus_audio_initialize(void);
 #endif
 
 MUS_EXPORT int mus_audio_systems(void);
-MUS_EXPORT char *mus_audio_system_name(int sys);
 MUS_EXPORT char *mus_audio_moniker(void);
 MUS_EXPORT int mus_audio_compatible_format(int dev);
 
-#if MUS_SUN
-  MUS_EXPORT void mus_sun_set_outputs(int speakers, int headphones, int line_out);
-#endif
-
-#if MUS_NETBSD
-  MUS_EXPORT void mus_netbsd_set_outputs(int speakers, int headphones, int line_out);
-#endif
+int mus_audio_device_channels(int dev);
+int mus_audio_device_format(int dev);
 
 #if (!HAVE_STRERROR)
   MUS_EXPORT char *strerror(int errnum);
@@ -563,7 +537,7 @@ MUS_EXPORT mus_float_t mus_run_evaluate_ptree_1f1v1b2f(struct ptree *pt, mus_flo
 MUS_EXPORT mus_float_t mus_run_evaluate_ptreec(struct ptree *pt, mus_float_t arg, XEN object, bool dir, int type);
 MUS_EXPORT int mus_run_xen_to_run_type(XEN val);
 
-#if HAVE_S7
+#if HAVE_SCHEME
 MUS_EXPORT struct ptree *mus_run_form_to_ptree_1_b_without_env(XEN code);
 MUS_EXPORT mus_float_t mus_run_evaluate_ptree_0f2f(struct ptree *pt);
 MUS_EXPORT struct ptree *mus_run_form_to_ptree_0_f(XEN code);
@@ -633,19 +607,6 @@ typedef void mus_header_write_hook_t(const char *filename);
 MUS_EXPORT mus_header_write_hook_t *mus_header_write_set_hook(mus_header_write_hook_t *new_hook);
 
 
-/* -------- midi.c -------- */
-MUS_EXPORT int mus_midi_open_read(const char *name);
-MUS_EXPORT int mus_midi_open_write(const char *name);
-MUS_EXPORT int mus_midi_close(int line);
-MUS_EXPORT int mus_midi_read(int line, unsigned char *buffer, int bytes);
-MUS_EXPORT int mus_midi_write(int line, unsigned char *buffer, int bytes);
-MUS_EXPORT const char *mus_midi_device_name(int sysdev);
-MUS_EXPORT char *mus_midi_describe(void);
-#if HAVE_EXTENSION_LANGUAGE
-  MUS_EXPORT void mus_midi_init(void);
-#endif
-
-
 #if HAVE_PTHREADS
   MUS_EXPORT void mus_thread_restore_error_handler(void);
   MUS_EXPORT mus_error_handler_t *mus_thread_get_previous_error_handler(void);
