@@ -8,14 +8,13 @@
 ;;; 3-Nov-08: I changed some of the instrument names to avoid collisions with animals.scm (prepended "b-")
 
 
-(use-modules (ice-9 optargs) (ice-9 format))
 (provide 'snd-bird.scm)
 
 ;;; translated (semi-automatically) from a Sambox note list to bird.clm, then bird.scm
 
 (if (and (not (provided? 'snd-ws.scm)) 
 	 (not (provided? 'sndlib-ws.scm)))
-    (load-from-path "ws.scm"))
+    (load "ws.scm"))
 
 (definstrument (bigbird start dur frequency freqskew amplitude freq-envelope amp-envelope partials)
   "(bigbird start dur frequency freqskew amplitude freq-envelope amp-envelope partials)"
@@ -28,11 +27,10 @@
 	 (end (+ beg len)))
     (ws-interrupt?)
     (run
-     (lambda ()
-       (do ((i beg (+ 1 i)))
-	   ((= i end))
-	 (outa i (* (env amp-env)
-		    (polyshape os 1.0 (env gls-env)))))))))
+     (do ((i beg (+ 1 i)))
+	 ((= i end))
+       (outa i (* (env amp-env)
+		  (polyshape os 1.0 (env gls-env))))))))
 
 (definstrument (bird start dur frequency freqskew amplitude freq-envelope amp-envelope)
   "(bird start dur frequency freqskew amplitude freq-envelope amp-envelope)"
@@ -44,11 +42,10 @@
 	 (end (+ beg len)))
     (ws-interrupt?)
     (run
-     (lambda ()
-       (do ((i beg (+ 1 i)))
-	   ((= i end))
-	 (outa i (* (env amp-env)
-		    (oscil os (env gls-env)))))))))
+     (do ((i beg (+ 1 i)))
+	 ((= i end))
+       (outa i (* (env amp-env)
+		  (oscil os (env gls-env))))))))
   
 (define main-amp '(.00 .00 .25 1.00 .60 .70 .75 1.00 1.00 .0))
 (define bird-tap '(.00 .00 .01 1.00 .99 1.00 1.00 .0))
