@@ -2,7 +2,7 @@
 
 # Author: Michael Scholz <mi-scholz@users.sourceforge.net>
 # Created: Wed Oct 14 23:02:57 CEST 2009
-# Changed: Wed Oct 28 22:37:22 CET 2009
+# Changed: Thu Apr 15 13:32:46 CEST 2010
 
 # Commentary:
 #
@@ -451,8 +451,6 @@ if provided? :snd
   Sort_files_by_date = 2
   Sort_files_by_size = 4
   Sort_files_by_entry = -1
-  alias mus_audio_sun_outputs           mus_sun_set_outputs
-  alias set_oss_buffers                 mus_oss_set_buffers
   alias mus_audio_set_oss_buffers       mus_oss_set_buffers
   unless defined? mus_file_data_clipped
     alias mus_file_data_clipped         mus_clipping
@@ -536,23 +534,6 @@ if provided? :snd
   end
   alias sine_summation  nrxysin
   alias sine_summation? nrxysin?
-
-  if provided?(:snd_nogui)
-    def x_bounds(*args)
-      []
-    end
-    
-    def y_bounds(*args)
-      []
-    end
-    def set_x_bounds(bounds, *args)
-      bounds
-    end
-    
-    def set_y_bounds(bounds, *args)
-      bounds
-    end
-  end
 end
 
 # enum("foo", :bar, "FOO_BAR")
@@ -2056,7 +2037,7 @@ def install_eval_hooks(file, retval, input, hook, &reset_cursor)
   reset_cursor.nil? or reset_cursor.call
   $exit_hook.add_hook!(file) do | | prompt.reset end
   hook.add_hook!(file) do |line|
-    eval_line << line << "\n"
+    eval_line = eval_line + line + "\n"
     eval_level += Snd_eval.count_level(line)
     if eval_level.negative?
       eval_level = 0
@@ -2293,16 +2274,17 @@ end
 
 def verbose_message_string(stack_p, remark, *args)
   fmt_remark = format("\n%s", remark)
-  args.to_a.car = String(args.to_a.car)
-  str = if args.length < 2
-          args.car
+  str = if args.null?
+          ""
+        elsif args.length == 1
+          String(args.car)
         else
           format(*args)
         end
   str = if str.split(/\n/).length > 1
           str.split(/\n/).join(fmt_remark)
         else
-          format("%s%s", remark, args.car)
+          format("%s%s", remark, str)
         end
   if $!
     str += format("[%s] %s (%s)", rb_error_to_mus_tag.inspect, snd_error_to_message, $!.class)
@@ -2346,11 +2328,13 @@ def clm_message(*args)
         else
           format(*args)
         end
-  if provided?(:snd)
-    clm_print("\n%s", msg)
-     unless provided?(:snd_nogui)
-       $stdout.print(msg, "\n")
-     end
+  if provided? :snd
+    if provided? :snd_nogui
+      clm_print("%s\n", msg)
+    else
+      clm_print("\n%s", msg)
+    end
+    nil
   else
     $stdout.print(msg, "\n")
   end
@@ -2359,14 +2343,7 @@ end
 # like clm_print(*args), in emacs it prepends msg with a comment sign
 
 def message(*args)
-  msg = if args.null?
-          ""
-        elsif args.length == 1
-          String(args.car)
-        else
-          format(*args)
-        end
-  clm_message(verbose_message_string(false, "# ", msg))
+  clm_message(verbose_message_string(false, "# ", *args))
 end
 
 # debug(var1, var2) --> #<DEBUG: ClassName: value1, ClassName: value2>
@@ -2385,7 +2362,7 @@ def debug_trace(*args)
   clm_message(verbose_message_string(true, "# "))
 end
 
-if provided? :snd then set_snd_input(:snd) end
+if provided?(:snd) then set_snd_input(:snd) end
 
 class Snd
   class << Snd
@@ -2430,6 +2407,10 @@ class Snd
     end
 
     def message(*args)
+      clm_message(verbose_message_string(false, "# ", *args))
+    end
+
+    def display(*args)
       msg = if args.null?
               ""
             elsif args.length == 1
@@ -2437,15 +2418,12 @@ class Snd
             else
               format(*args)
             end
-      clm_message(verbose_message_string(false, "# ", msg))
-    end
-
-    def display(*args)
-      args[0] = String(args[0])
-      msg = format(*args)
       if snd_input == :snd
-        snd_print("\n" + msg)
-        if $VERBOSE then $stdout.print(msg, "\n") end
+        if provided? :snd_nogui
+          clm_print("%s\n", msg)
+        else
+          clm_print("\n%s", msg)
+        end
         nil
       else
         $stdout.print(msg, "\n")
@@ -2472,12 +2450,13 @@ class Snd
     end
 
     def debug(*args)
-      fmt = ""
-      args.each do |arg|
-        fmt += format("%s: %s", arg.class, arg.inspect)
-        fmt += ", "
+      if args.null?
+        Snd.message("#<DEBUG>")
+      elsif args.length == 1
+        Snd.message("#<DEBUG: %s>", String(args.car))
+      else
+        Snd.message("#<DEBUG: %s>", format(*args))
       end
-      Snd.message("#<DEBUG: %s>", fmt.chomp(", "))
     end
 
     def debug_trace(*args)
@@ -2687,7 +2666,7 @@ def snd_error_to_message
                                 0
                               end)
           else
-            format(str.strip, *if string?(s = str.slice!(str.index("[")..str.index("]")))
+            format(str.strip, if string?(s = str.slice!(str.index("[")..str.index("]")))
                                 eval(s)
                               else
                                 [0] * len
