@@ -1,6 +1,6 @@
 ;;; various envelope functions
 ;;;
-;;; envelope-interp (x env :optional (base 1.0)) -> value of env at x (base controls connecting segment type)
+;;; envelope-interp (x env (base 1.0)) -> value of env at x (base controls connecting segment type)
 ;;; window-envelope (beg end env) -> portion of env lying between x axis values beg and end
 ;;; map-envelopes (func env1 env2) maps func over the breakpoints in env1 and env2 returning a new envelope
 ;;;   multiply-envelopes (env1 env2) multiplies break-points of env1 and env2 returning a new envelope
@@ -8,25 +8,23 @@
 ;;; max-envelope (env) -> max y value in env, min-envelope
 ;;; integrate-envelope (env) -> area under env
 ;;; envelope-last-x (env) -> max x axis break point position
-;;; stretch-envelope env old-attack new-attack :optional old-decay new-decay -> divseg-like envelope mangler
-;;; scale-envelope (env scaler :optional offset) scales y axis values by 'scaler' and optionally adds 'offset'
+;;; stretch-envelope env old-attack new-attack old-decay new-decay -> divseg-like envelope mangler
+;;; scale-envelope (env scaler offset) scales y axis values by 'scaler' and optionally adds 'offset'
 ;;; reverse-envelope (env) reverses the breakpoints in 'env'
 ;;; concatenate-envelopes (:rest envs) concatenates its arguments into a new envelope
-;;; repeat-envelope env repeats :optional (reflected #f) (normalized #f) repeats an envelope
+;;; repeat-envelope env repeats (reflected #f) (normalized #f) repeats an envelope
 ;;; power-env: generator for extended envelopes (each segment has its own base)
 ;;; envelope-exp: interpolate segments into envelope to give exponential curves
 ;;; rms-envelope
 ;;; normalize-envelope
 ;;; simplify-envelope
 
-(use-modules (ice-9 format) (ice-9 optargs))
-
 (provide 'snd-env.scm)
 
 ;;; -------- envelope-interp
 
-(define* (envelope-interp x env :optional base)   ;env is list of x y breakpoint pairs, interpolate at x returning y
-  "(envelope-interp x env :optional (base 1.0)) -> value of env at x; base controls connecting segment 
+(define* (envelope-interp x env base)   ;env is list of x y breakpoint pairs, interpolate at x returning y
+  "(envelope-interp x env (base 1.0)) -> value of env at x; base controls connecting segment 
 type: (envelope-interp .3 '(0 0 .5 1 1 0) -> .6"
   (cond ((null? env) 0.0)		;no data -- return 0.0
 	((or (<= x (car env))	        ;we're sitting on x val (or if < we blew it)
@@ -58,7 +56,7 @@ end: (window-envelope 1.0 3.0 '(0.0 0.0 5.0 1.0)) -> '(1.0 0.2 3.0 0.6)"
   (let ((nenv '())
 	(lasty (if env (cadr env) 0.0))
 	(len (length env)))
-    (call-with-current-continuation
+    (call-with-exit
      (lambda (return-early)               
        (do ((i 0 (+ i 2)))
 	   ((>= i len))
@@ -181,7 +179,7 @@ envelope: (multiply-envelopes '(0 0 2 .5) '(0 0 1 2 2 1)) -> '(0 0 0.5 0.5 1.0 0
 
 (define (stretch-envelope . args)
 
-  "(stretch-envelope env old-attack new-attack :optional old-decay new-decay) takes 'env' and 
+  "(stretch-envelope env old-attack new-attack old-decay new-decay) takes 'env' and 
 returns a new envelope based on it but with the attack and optionally decay portions stretched 
 or squeezed; 'old-attack' is the original x axis attack end point, 'new-attack' is where that 
 section should end in the new envelope.  Similarly for 'old-decay' and 'new-decay'.  This mimics 
@@ -259,8 +257,8 @@ divseg in early versions of CLM and its antecedents in Sambox and Mus10 (linen).
     
 ;;; -------- scale-envelope
 
-(define* (scale-envelope e scl :optional (offset 0))
-  "(scale-envelope env scaler :optional (offset 0)) scales y axis values by 'scaler' and optionally adds 'offset'"
+(define* (scale-envelope e scl (offset 0))
+  "(scale-envelope env scaler (offset 0)) scales y axis values by 'scaler' and optionally adds 'offset'"
   (if (null? e)
       '()
       (append (list (car e) (+ offset (* scl (cadr e))))
@@ -314,8 +312,8 @@ divseg in early versions of CLM and its antecedents in Sambox and Mus10 (linen).
     (reverse ne)))
 
 
-(define* (repeat-envelope ur-env repeats :optional (reflected #f) (normalized #f))
-    "(repeat-envelope env repeats :optional (reflected #f) (normalized #f)) repeats 'env' 'repeats' 
+(define* (repeat-envelope ur-env repeats (reflected #f) (normalized #f))
+    "(repeat-envelope env repeats (reflected #f) (normalized #f)) repeats 'env' 'repeats' 
 times.  (repeat-envelope '(0 0 100 1) 2) -> (0 0 100 1 101 0 201 1). 
 If the final y value is different from the first y value, a quick ramp is 
 inserted between repeats. 'normalized' causes the new envelope's x axis 
@@ -364,7 +362,7 @@ repetition to be in reverse."
 ;;;
 ;;; (this could also be done using multi-expt-env (based on env-any) in generators.scm)
 
-(if (not (provided? 'snd-ws.scm)) (load-from-path "ws.scm"))
+(if (not (provided? 'snd-ws.scm)) (load "ws.scm"))
 
 (def-clm-struct penv (envs #f :type clm-vector) (total-envs 0 :type int) (current-env 0 :type int) (current-pass 0 :type int))
 
@@ -378,7 +376,7 @@ repetition to be in reverse."
 	    (set! (penv-current-pass pe) (- (length (vector-ref (penv-envs pe) (penv-current-env pe))) 1)))))
     val))
 
-(define* (make-power-env envelope :key (scaler 1.0) (offset 0.0) duration)
+(define* (make-power-env envelope (scaler 1.0) (offset 0.0) duration)
   (let* ((len (- (floor (/ (length envelope) 3)) 1))
 	 (pe (make-penv :envs (make-vector len)
 			:total-envs len
@@ -399,7 +397,7 @@ repetition to be in reverse."
     (set! (penv-current-pass pe) (- (length (vector-ref (penv-envs pe) 0)) 1))
     pe))
 
-(define* (power-env-channel pe :optional (beg 0) dur snd chn edpos (edname "power-env-channel"))
+(define* (power-env-channel pe (beg 0) dur snd chn edpos (edname "power-env-channel"))
   ;; split into successive calls on env-channel
   (let ((curbeg beg)) ; sample number
     (as-one-edit
@@ -415,8 +413,8 @@ repetition to be in reverse."
 
 ;;; here's a simpler version that takes the breakpoint list, rather than the power-env structure:
 
-(define* (powenv-channel envelope :optional (beg 0) dur snd chn edpos)
-  "(powenv-channel envelope :optional (beg 0) dur snd chn edpos) returns an envelope with a separate base for \
+(define* (powenv-channel envelope (beg 0) dur snd chn edpos)
+  "(powenv-channel envelope (beg 0) dur snd chn edpos) returns an envelope with a separate base for \
 each segment: (powenv-channel '(0 0 .325  1 1 32.0 2 0 32.0))"
   (let* ((curbeg beg)
 	 (fulldur (or dur (frames snd chn edpos)))
@@ -454,14 +452,14 @@ each segment: (powenv-channel '(0 0 .325  1 1 32.0 2 0 32.0))"
 ;;; power applies to whole envelope,
 ;;; xgrid is how fine a solution to sample our new envelope with.
 
-(define* (envelope-exp e :optional (power 1.0) (xgrid 100))
-  "(envelope-exp e :optional (power 1.0) (xgrid 100)) approximates an exponential curve connecting the breakpoints"
+(define* (envelope-exp e (power 1.0) (xgrid 100))
+  "(envelope-exp e (power 1.0) (xgrid 100)) approximates an exponential curve connecting the breakpoints"
   (let* ((mn (min-envelope e))
-	 (largest-diff (exact->inexact (- (max-envelope e) mn)))
+	 (largest-diff (* 1.0 (- (max-envelope e) mn)))
 	 (x-min (car e))
 	 (len (length e))
 	 (x-max (list-ref e (- len 2)))
-	 (x-incr (exact->inexact (/ (- x-max x-min) xgrid)))
+	 (x-incr (* 1.0 (/ (- x-max x-min) xgrid)))
 	 (new-e '()))
     (do ((x x-min (+ x x-incr)))
 	((>= x x-max))
@@ -478,8 +476,8 @@ each segment: (powenv-channel '(0 0 .325  1 1 32.0 2 0 32.0))"
 
 ;;; rms-envelope
 
-(define* (rms-envelope file :key (beg 0.0) (dur #f) (rfreq 30.0) (db #f))
-  "(rms-envelope file :key (beg 0.0) (dur #f) (rfreq 30.0) (db #f)) returns an envelope of RMS values in 'file'"
+(define* (rms-envelope file (beg 0.0) (dur #f) (rfreq 30.0) (db #f))
+  "(rms-envelope file (beg 0.0) (dur #f) (rfreq 30.0) (db #f)) returns an envelope of RMS values in 'file'"
   ;; based on rmsenv.ins by Bret Battey
   (let* ((e '())
 	 (incr (/ 1.0 rfreq))
@@ -487,7 +485,7 @@ each segment: (powenv-channel '(0 0 .325  1 1 32.0 2 0 32.0))"
 	 (incrsamps (round (* incr fsr)))
 	 (start (round (* beg fsr)))
 	 (reader (make-sampler start file))
-	 (end (if dur (min (inexact->exact (+ start (round (* fsr dur))))
+	 (end (if dur (min (* 1.0 (+ start (round (* fsr dur))))
 			   (mus-sound-frames file))
 		  (mus-sound-frames file)))
 	 (rms (make-moving-average incrsamps))) ; this could use make-moving-rms from dsp.scm
@@ -499,7 +497,7 @@ each segment: (powenv-channel '(0 0 .325  1 1 32.0 2 0 32.0))"
 	    ((= j incrsamps))
 	  (let ((val (reader)))
 	    (set! rms-val (moving-average rms (* val val)))))
-	(set! e (cons (exact->inexact (/ i fsr)) e))
+	(set! e (cons (* 1.0 (/ i fsr)) e))
 	(set! rms-val (sqrt rms-val))
 	(if db 
 	    (if (< rms-val .00001)
@@ -508,7 +506,7 @@ each segment: (powenv-channel '(0 0 .325  1 1 32.0 2 0 32.0))"
 	    (set! e (cons rms-val e)))))))
 
 
-(define* (normalize-envelope env :optional (new-max 1.0))
+(define* (normalize-envelope env (new-max 1.0))
   (define (abs-max-envelope-1 e mx)
     (if (null? e)
 	mx
@@ -521,7 +519,7 @@ each segment: (powenv-channel '(0 0 .325  1 1 32.0 2 0 32.0))"
 ;;;
 ;;; this is not very good...
 
-(define* (simplify-envelope env :optional (ygrid 10) (xgrid 100))
+(define* (simplify-envelope env (ygrid 10) (xgrid 100))
 
   ;; grid = how fine a fluctuation we will allow.
   ;; the smaller the grid, the less likely a given bump will get through
