@@ -8,11 +8,8 @@
 ;;; (play-with-envs snd) sets channel amps during playback from the associated enved envelopes
 ;;; (play-panned snd) pans a mono sound following its enved envelope into a stereo sound
 
-(use-modules (ice-9 format))
 (provide 'snd-enved.scm)
 
-(if (not (provided? 'snd-extensions.scm)) (load-from-path "extensions.scm"))
-
 (define channel-envelope
   (make-procedure-with-setter
 
@@ -177,14 +174,14 @@
 ;;;
 ;;; some examples of using this envelope editor
 
-(define* (play-with-envs :optional (sound #f))
+(define* (play-with-envs (sound #f))
   "(play-with-envs snd) sets channel amps during playback from the associated enved envelopes"
   (let ((chans (channels sound)))
     (do ((chan 0 (+ 1 chan)))
 	((= chan chans))
       (let ((player (make-player sound chan))
 	    (e (make-env (channel-envelope sound chan) 
-			 :length (floor (exact->inexact (/ (frames sound chan) (dac-size)))))))
+			 :length (floor (/ (frames sound chan) (dac-size))))))
 	(add-player player 0 -1 -1 (lambda (reason) (reset-hook! play-hook)))
 	(add-hook! play-hook (lambda (fr)
 			       ;; if fr (dac buffer size in frames) is not dac-size, we should do something debonair
