@@ -9,11 +9,10 @@
 ;;;   returns a violin function
 ;;; fm-violin takes the value returned by make-fm-violin and returns a new sample each time it is called
 
-(use-modules (ice-9 optargs))
 (provide 'snd-fmv.scm)
 
 (define make-fm-violin 
-  (lambda* (frequency amplitude :key
+  (lambda* (frequency amplitude
 	    (fm-index 1.0)
 	    (amp-env #f)
 	    (periodic-vibrato-rate 5.0) 
@@ -36,10 +35,9 @@
 	    (fm1-index #f) 
 	    (fm2-index #f) 
 	    (fm3-index #f)
-	    (base 1.0)
-	    :allow-other-keys)
+	    (base 1.0))
 
-"(make-fm-violin frequency amplitude :key 
+"(make-fm-violin frequency amplitude 
   (fm-index 1.0) (amp-env #f) (periodic-vibrato-rate 5.0) 
   (random-vibrato-rate 16.0) (periodic-vibrato-amplitude 0.0025) 
   (random-vibrato-amplitude 0.005) (noise-amount 0.0) 
@@ -158,8 +156,8 @@ fm-violin takes the value returned by make-fm-violin and returns a new sample ea
       (vct->channel data beg dur))))
 |#
 
-(define* (fm-violin-ins startime dur freq amp :key (degree #f) (reverb-amount 0.0) (distance 1.0) :allow-other-keys :rest args)
-  "(fm-violin-ins startime dur freq amp :key (degree #f) (reverb-amount 0.0) (distance 1.0) :allow-other-keys :rest args) 
+(define* (fm-violin-ins startime dur freq amp (degree #f) (reverb-amount 0.0) (distance 1.0) :rest args)
+  "(fm-violin-ins startime dur freq amp (degree #f) (reverb-amount 0.0) (distance 1.0) :rest args) 
 calls the fm-violin with the given args and mixes the results into the current sound"
     (let* ((beg (floor (* startime (srate))))
 	   (len (floor (* dur (srate))))
