@@ -34,12 +34,10 @@
 
 ;;; Code:
 
-(use-modules (ice-9 format) (ice-9 optargs))
 (provide 'snd-freeverb.scm)
-(if (not (provided? 'snd-ws.scm)) (load-from-path "ws.scm"))
+(if (not (provided? 'snd-ws.scm)) (load "ws.scm"))
 
 (definstrument (freeverb
-		   :key
 		   (room-decay 0.5)
 		   (damping 0.5)
 		   (global 0.3)
@@ -54,7 +52,7 @@
 		   (stereo-spread 23)
 		   (verbose #f))
   (let* ((startime 0.0)
-	 (dur (+ 1.0 (mus-sound-duration (file-name *reverb*))))
+	 (dur (+ 1.0 (mus-sound-duration (mus-file-name *reverb*))))
 	 (beg (seconds->samples startime))
 	 (end (cadr (times->samples startime dur)))
 	 (out-chans (channels *output*))
@@ -85,7 +83,7 @@
 	(format #t ";;; freeverb: ~d input channels, ~d output channels~%" in-chans out-chans))
     (if (and (> in-chans 1)
 	     (not (= in-chans out-chans)))
-	(snd-error "input must be mono or input channels must equal output channels"))
+	(error "input must be mono or input channels must equal output channels"))
     (if (not (mixer? output-mixer))
 	(if (vector? output-mixer)
 	    (do ((i 0 (+ 1 i)))
@@ -137,42 +135,41 @@
 	(let* ((tuning (list-ref allpasstuning i))
 	       (len (floor (* srate-scale tuning))))
 	  (if (odd? c)
-	      (set! len (+ len (floor (inexact->exact (* srate-scale stereo-spread))))))
+	      (set! len (+ len (floor (* srate-scale stereo-spread)))))
 	  (vector-set! allpasses (+ (* c numallpasses) i)
 		       (make-all-pass :size len :feedforward -1 :feedback 0.5)))))
     (ws-interrupt?)
     (run
-     (lambda ()
-       (do ((i beg (+ 1 i)))
-	   ((= i end))
-	 (declare (predelays clm-vector) (allpasses clm-vector) (fcombs clm-vector))
-	 (file->frame *reverb* i f-in)
-	 (if (> in-chans 1)
+     (do ((i beg (+ 1 i)))
+	 ((= i end))
+       (declare (predelays clm-vector) (allpasses clm-vector) (fcombs clm-vector))
+       (file->frame *reverb* i f-in)
+       (if (> in-chans 1)
+	   (do ((c 0 (+ 1 c)))
+	       ((= c out-chans))
+	     (frame-set! f-in c (delay (vector-ref predelays c) (frame-ref f-in c)))
+	     (frame-set! f-out c 0.0)
+	     (do ((j 0 (+ 1 j)))
+		 ((= j numcombs))
+	       (let ((ctr (+ (* c numcombs) j)))
+		 (frame-set! f-out c (+ (frame-ref f-out c)
+					(filtered-comb (vector-ref fcombs ctr) (frame-ref f-in 0)))))))
+	   (begin
+	     (frame-set! f-in 0 (delay (vector-ref predelays 0) (frame-ref f-in 0)))
 	     (do ((c 0 (+ 1 c)))
 		 ((= c out-chans))
-	       (frame-set! f-in c (delay (vector-ref predelays c) (frame-ref f-in c)))
 	       (frame-set! f-out c 0.0)
 	       (do ((j 0 (+ 1 j)))
 		   ((= j numcombs))
 		 (let ((ctr (+ (* c numcombs) j)))
 		   (frame-set! f-out c (+ (frame-ref f-out c)
-					  (filtered-comb (vector-ref fcombs ctr) (frame-ref f-in 0)))))))
-	     (begin
-	       (frame-set! f-in 0 (delay (vector-ref predelays 0) (frame-ref f-in 0)))
-	       (do ((c 0 (+ 1 c)))
-		   ((= c out-chans))
-		 (frame-set! f-out c 0.0)
-		 (do ((j 0 (+ 1 j)))
-		     ((= j numcombs))
-		   (let ((ctr (+ (* c numcombs) j)))
-		     (frame-set! f-out c (+ (frame-ref f-out c)
-					    (filtered-comb (vector-ref fcombs ctr) (frame-ref f-in 0)))))))))
-	 (do ((c 0 (+ 1 c)))
-	     ((= c out-chans))
-	   (do ((j 0 (+ 1 j)))
-	       ((= j numallpasses))
-	     (frame-set! f-out c (all-pass (vector-ref allpasses (+ (* c numallpasses) j))
-					   (frame-ref f-out c)))))
-	 (frame->file *output* i (frame->frame f-out out-mix out-buf)))))))
+					  (filtered-comb (vector-ref fcombs ctr) (frame-ref f-in 0)))))))))
+       (do ((c 0 (+ 1 c)))
+	   ((= c out-chans))
+	 (do ((j 0 (+ 1 j)))
+	     ((= j numallpasses))
+	   (frame-set! f-out c (all-pass (vector-ref allpasses (+ (* c numallpasses) j))
+					 (frame-ref f-out c)))))
+       (frame->file *output* i (frame->frame f-out out-mix out-buf))))))
 
 ;; freeverb.scm ends here
