@@ -1,6 +1,5 @@
 ;;; examples of mark-related functions
 
-(use-modules (ice-9 format) (ice-9 common-list))
 (provide 'snd-marks.scm)
 
 ;;; Contents:
@@ -18,7 +17,6 @@
 ;;;     define-selection-via-marks selects the portion between two marks
 ;;;     snap-mark-to-beat forces dragged mark to end up on a beat
 ;;;     mark-explode splits a sound into a bunch of sounds based on mark placements
-;;;     mark-property implements property lists for marks
 ;;;     save-mark-properties sets up an after-save-state-hook function to save any mark-properties
 ;;;     mark-click-info is a mark-click-hook function that describes a mark and its properties
 
@@ -227,7 +225,7 @@
 
 ;;; -------- report-mark-names causes mark names to be posted in the minibuffer as a sound is played
 
-(if (not (provided? 'snd-hooks.scm)) (load-from-path "hooks.scm"))
+(if (not (provided? 'snd-hooks.scm)) (load "hooks.scm"))
 
 (define (report-mark-names)
   "(report-mark-names) causes mark names to be printed as they are passed while playing"
@@ -236,6 +234,7 @@
 	       (let* ((marklist (marks snd 0))
 		      (samplist (map mark-sample marklist))
 		      (samp 0))
+
 		 (define (report-mark-names-play-hook size)
 		   (set! samp (+ samp size))
 		   (if (and (not (null? samplist))
@@ -244,10 +243,11 @@
 			 (report-in-minibuffer (mark-name (car marklist)) snd)
 			 (set! marklist (cdr marklist))
 			 (set! samplist (cdr samplist)))))
+
 		 (define (report-mark-names-stop-playing-hook snd)
 		   (report-in-minibuffer "" snd)
-		   (remove-local-hook! play-hook report-mark-names-play-hook)
-		   (remove-local-hook! stop-playing-hook report-mark-names-stop-playing-hook))
+		   (remove-hook! play-hook report-mark-names-play-hook)
+		   (remove-hook! stop-playing-hook report-mark-names-stop-playing-hook))
 		 
 		 (add-hook! stop-playing-hook report-mark-names-stop-playing-hook)
 		 (add-hook! play-hook report-mark-names-play-hook)
@@ -344,8 +344,8 @@
 ;;;
 ;;; write out each section of a file between marks as a separate file
 
-(define* (mark-explode :optional (htype mus-next) (dformat mus-bfloat))
-  "(mark-explode :optional header-type data-format) splits a sound into a bunch of sounds based on mark placements"
+(define* (mark-explode (htype mus-next) (dformat mus-bfloat))
+  "(mark-explode header-type data-format) splits a sound into a bunch of sounds based on mark placements"
   (let ((start 0)
 	(file-ctr 0)
 	(snd (or (selected-sound) (car (sounds)))))
@@ -369,45 +369,22 @@
     (update-time-graph snd)))
 
 
-;;; -------- mark property lists
-
-(define mark-property
-  (make-procedure-with-setter
-   (lambda (key id)
-     "(mark-property key mark) returns the value associated with 'key' in the given mark's property list, or #f"
-     (if (mark? id)
-	 (let ((data (assoc key (mark-properties id))))
-	   (if data
-	       (cdr data)
-	       #f))
-	 (throw 'no-such-mark (list "mark-property" id))))
-   (lambda (key id new-val)
-     (if (mark? id)
-	 (let ((old-val (assoc key (mark-properties id))))
-	   (if old-val
-	       (set-cdr! old-val new-val)
-	       (set! (mark-properties id) (cons (cons key new-val) (mark-properties id))))
-	   new-val)
-	 (throw 'no-such-mark (list "set! mark-property" id))))))
+;;; -------- save mark property lists
 
 (define (save-mark-properties)
   "(save-mark-properties) sets up an after-save-state-hook function to save any mark-properties"
 
   (define (open-appending filename)
-    (if (provided? 'snd-guile)
-	(open filename (logior O_RDWR O_APPEND))
-	(open-output-file filename "a")))
+    (open-output-file filename "a"))
 
   (define (close-appending fd)
-    (if (provided? 'snd-guile)
-	(close fd)
-	(close-output-port fd)))
+    (close-output-port fd))
 
   (add-hook! after-save-state-hook 
     (lambda (filename)
       (let ((fd (open-appending filename)))
 	(format fd "~%~%;;; from remember-mark-properties in marks.scm~%")
-	(format fd "(if (not (defined? 'mark-property)) (load-from-path \"marks.scm\"))~%")
+	(format fd "(if (not (defined? 'mark-property)) (load \"marks.scm\"))~%")
 	(for-each 
 	 (lambda (snd-m)
 	   (for-each 
@@ -464,7 +441,7 @@
 	      (lambda args #f))))
 
 (define (marks->string sndf)
-  (let ((str (format #f "(if (not (provided? 'snd-marks.scm)) (load-from-path \"marks.scm\"))~%(let ((m #f))~%"))
+  (let ((str (format #f "(if (not (provided? 'snd-marks.scm)) (load \"marks.scm\"))~%(let ((m #f))~%"))
 	(chan 0))
     (for-each
      (lambda (chan-marks)
