@@ -32,10 +32,9 @@
 ;;
 ;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
 
-(use-modules (ice-9 format) (ice-9 optargs))
 (provide 'snd-maxf.scm)
-(if (not (provided? 'snd-ws.scm)) (load-from-path "ws.scm"))
-;;; (if (not (provided? 'snd-jcrev.scm)) (load-from-path "jcrev.scm"))
+(if (not (provided? 'snd-ws.scm)) (load "ws.scm"))
+;;; (if (not (provided? 'snd-jcrev.scm)) (load "jcrev.scm"))
 
 (define *locsig-type* mus-interp-sinusoidal)
 
@@ -82,7 +81,7 @@
      (set! (mvm-pp2 b) (/ (* 2.0 pi ffreq) (mus-srate)))
      (set! (mvm-pp3 b) (* (mvm-pp2 b) famp))))
 
-(define* (maxfilter file beg :key
+(define* (maxfilter file beg
 		    (att 1.0)
 		    (numf 1)
 		    (freqfactor 1.0)
@@ -91,7 +90,7 @@
 		    (degree (random 90.0))
 		    (distance 1.0)
 		    (reverb-amount 0.2))
-  "(maxfilter file beg :key (att 1.0) (numf 1) (freqfactor 1.0)
+  "(maxfilter file beg (att 1.0) (numf 1) (freqfactor 1.0)
             (amplitude 1.0) (amp-env '(0 1 100 1))
             (degree (random 90.0)) (distance 1.0) (reverb-amount 0.2))
 
@@ -308,34 +307,33 @@ the desired phase.
 	   (snd-msg "Please leave default or enter [1] [2] [4] [9] [12] [13]~%")
 	   (set! numf 1)))
     (run
-     (lambda ()
-       (do ((i beg (+ 1 i)))
-	   ((= i end))
-	 (let ((outvalA (* att (readin rdA)))
-	       (add-fl 0))
-	   (do ((j 0 (+ 1 j)))
-	       ((= j numf))
-	     (cond ((= numf 1)
-		    (set-coeffs formfil (array-ref state-0 j 0)
-				(array-ref state-0 j 1) (array-ref state-0 j 2)))
-		   ((= numf 2)
-		    (set-coeffs formfil (array-ref state-5 j 0)
-				(array-ref state-5 j 1) (array-ref state-5 j 2)))
-		   ((= numf 4)
-		    (set-coeffs formfil (array-ref state-4 j 0)
-				(array-ref state-4 j 1) (array-ref state-4 j 2)))
-		   ((= numf 9)
-		    (set-coeffs formfil (array-ref state-2 j 0)
-				(array-ref state-2 j 1) (array-ref state-2 j 2)))
-		   ((= numf 12)
-		    (set-coeffs formfil (array-ref state-1 j 0)
-				(array-ref state-1 j 1) (array-ref state-1 j 2)))
-		   ((= numf 13)
-		    (set-coeffs formfil (array-ref state-3 j 0)
-				(array-ref state-3 j 1) (array-ref state-3 j 2))))
-	     (let ((filsig (mvmfilt formfil outvalA)))
-	       (set! add-fl (+ add-fl filsig))))
-	   (locsig loc i (* (env ampf) add-fl))))))))
+     (do ((i beg (+ 1 i)))
+	 ((= i end))
+       (let ((outvalA (* att (readin rdA)))
+	     (add-fl 0))
+	 (do ((j 0 (+ 1 j)))
+	     ((= j numf))
+	   (cond ((= numf 1)
+		  (set-coeffs formfil (array-ref state-0 j 0)
+			      (array-ref state-0 j 1) (array-ref state-0 j 2)))
+		 ((= numf 2)
+		  (set-coeffs formfil (array-ref state-5 j 0)
+			      (array-ref state-5 j 1) (array-ref state-5 j 2)))
+		 ((= numf 4)
+		  (set-coeffs formfil (array-ref state-4 j 0)
+			      (array-ref state-4 j 1) (array-ref state-4 j 2)))
+		 ((= numf 9)
+		  (set-coeffs formfil (array-ref state-2 j 0)
+			      (array-ref state-2 j 1) (array-ref state-2 j 2)))
+		 ((= numf 12)
+		  (set-coeffs formfil (array-ref state-1 j 0)
+			      (array-ref state-1 j 1) (array-ref state-1 j 2)))
+		 ((= numf 13)
+		  (set-coeffs formfil (array-ref state-3 j 0)
+			      (array-ref state-3 j 1) (array-ref state-3 j 2))))
+	   (let ((filsig (mvmfilt formfil outvalA)))
+	     (set! add-fl (+ add-fl filsig))))
+	 (locsig loc i (* (env ampf) add-fl)))))))
 
 ;; (let* ((ifile "dog.snd")
 ;;        (ofile "gmax_dog.snd")
