@@ -6,15 +6,12 @@
 ;;; (find-mix sample snd chn) returns the mix at the given sample, or #f
 ;;; (mix-maxamp mix) maxamp of mix
 ;;;
-;;; mix-property associates a property list with a mix
 ;;; mix-click-sets-amp sets up hook functions so that mix click zeros amps, then subsequent click resets to the before-zero value
 ;;; check-mix-tags tries to move mix tags around to avoid collisions
 
 
-(use-modules (ice-9 common-list))
 (provide 'snd-mix.scm)
 
-
 (define (tree-for-each func tree)
   "(tree-for-each func tree) applies func to every leaf of 'tree'"
   (cond ((null? tree) '())
@@ -53,8 +50,8 @@
         (mixes)))))
 
 
-(define* (find-mix sample :optional snd chn)
-  "(find-mix sample :optional snd chn) returns the mix at the given sample, or #f"
+(define* (find-mix sample snd chn)
+  "(find-mix sample snd chn) returns the mix at the given sample, or #f"
   (let ((mix-list (mixes (or snd (selected-sound) (car (sounds))) (or chn (selected-channel snd) 0))))
     (call-with-exit
      (lambda (found-it)
@@ -148,28 +145,6 @@ All mixes sync'd to it are also moved the same number of samples. (remove-hook!
 
 
 
-;;; --------- mix-property
-
-(define mix-property
-  (make-procedure-with-setter
-   (lambda (key id)
-     "(mix-property key mix) returns the value associated with 'key' in the given mix's property list, or #f"
-     (if (mix? id)
-	 (let ((data (assoc key (mix-properties id))))
-	   (if data
-	       (cdr data)
-	       #f))
-	 (throw 'no-such-mix (list "mix-property" id))))
-   (lambda (key id new-val)
-     (if (mix? id)
-	 (let ((old-val (assoc key (mix-properties id))))
-	   (if old-val
-	       (set-cdr! old-val new-val)
-	       (set! (mix-properties id) (cons (cons key new-val) (mix-properties id))))
-	   new-val)
-	 (throw 'no-such-mix (list "set! mix-property" id))))))
-
-
 ;;; -------- mix-click-sets-amp
 
 (define (mix-click-sets-amp)
@@ -200,9 +175,9 @@ All mixes sync'd to it are also moved the same number of samples. (remove-hook!
 			   (format #f "~A" n))
 		       (mix-sync n)
 		       (mix-position n)
-		       (exact->inexact (/ (mix-position n) (srate (car (mix-home n)))))
+		       (* 1.0 (/ (mix-position n) (srate (car (mix-home n)))))
 		       (frames n)
-		       (exact->inexact (/ (frames n) (srate (car (mix-home n)))))
+		       (* 1.0 (/ (frames n) (srate (car (mix-home n)))))
 		       (short-file-name (car (mix-home n))) 
 		       (cadr (mix-home n))
 		       (mix-amp n)
@@ -373,7 +348,7 @@ last end of the mixes in 'mix-list'"
       (mus-sound-close-output fd (* (mus-bytes-per-sample mus-out-format) (length data))))))
 
 
-(if (not (provided? 'snd-env.scm)) (load-from-path "env.scm"))
+(if (not (provided? 'snd-env.scm)) (load "env.scm"))
 
 (define (env-mixes mix-list overall-amp-env)
   "(env-mixes mix-list amp-env) applies 'amp-env' as a global amplitude envelope to the mixes in 'mix-list'"
@@ -397,9 +372,9 @@ last end of the mixes in 'mix-list'"
 	mix-list)))))
   
 
-(define* (sync-all-mixes :optional (new-sync 1))
+(define* (sync-all-mixes (new-sync 1))
   ;; a replacement for set-all-tracks in snd-8
-  "(sync-all-mixes :optional (new-sync 1)) sets the mix-sync field of every active mix to new-sync"
+  "(sync-all-mixes (new-sync 1)) sets the mix-sync field of every active mix to new-sync"
   (for-each
    (lambda (snd-m)
      (for-each
@@ -438,7 +413,10 @@ last end of the mixes in 'mix-list'"
     (play (lambda ()
 	    (while (and (not (null? sorted-mixes))
 			(= now (mix-position (car sorted-mixes))))
-	      (play-mix (car sorted-mixes))
+	      (play (let ((mx (car sorted-mixes)))
+		      (if (integer? mx)
+			  (integer->mix mx)
+			  mx)))
 	      (set! sorted-mixes (cdr sorted-mixes)))
 	    (set! now (+ 1 now))
 	    (if (null? sorted-mixes)
@@ -448,9 +426,9 @@ last end of the mixes in 'mix-list'"
 
 ;;; -------- pan-mix --------
 
-(define* (pan-mix name beg pan :optional snd (chn 0) auto-delete)
+(define* (pan-mix name beg pan snd (chn 0) auto-delete)
 
-  "(pan-mix file start pan-env :optional snd (chn 0) (auto-delete #f)) mixes 'file' into the sound 'snd'
+  "(pan-mix file start pan-env snd (chn 0) (auto-delete #f)) mixes 'file' into the sound 'snd'
 starting at 'start' (in samples) using 'pan-env' to decide how to split the sound between the output channels (0: all chan 0, 1: all chan 1).
 So, (pan-mix \"oboe.snd\" 0 '(0 0 1 1)) goes from all chan 0 to all chan 1.
 'auto-delete' determines whether the in-coming file should be treated as a temporary file and deleted when the mix
@@ -541,9 +519,9 @@ panning operation."
 		       #f)))))))))
 
 
-(define* (pan-mix-selection beg pan :optional snd chn)
+(define* (pan-mix-selection beg pan snd chn)
 
-  "(pan-mix-selection start pan-env :optional snd chn) mixes the current selection  into the sound 'snd'
+  "(pan-mix-selection start pan-env snd chn) mixes the current selection  into the sound 'snd'
 starting at 'start' (in samples) using 'pan-env' to pan (0: all chan 0, 1: all chan 1)."
 
   (if (not (selection?))
@@ -551,9 +529,9 @@ starting at 'start' (in samples) using 'pan-env' to pan (0: all chan 0, 1: all c
       (pan-mix (save-selection (snd-tempnam)) beg pan snd chn #t)))
 
 
-(define* (pan-mix-region reg beg pan :optional snd chn)
+(define* (pan-mix-region reg beg pan snd chn)
 
-  "(pan-mix-region reg start pan-env :optional snd chn) mixes the given region into the sound 'snd' 
+  "(pan-mix-region reg start pan-env snd chn) mixes the given region into the sound 'snd' 
 starting at 'start' (in samples) using 'pan-env' to pan (0: all chan 0, 1: all chan 1)."
 
   (if (not (region? reg))
@@ -561,9 +539,9 @@ starting at 'start' (in samples) using 'pan-env' to pan (0: all chan 0, 1: all c
       (pan-mix (save-region reg (snd-tempnam)) beg pan snd chn #t)))
 
 
-(define* (pan-mix-vct v beg pan :optional snd chn)
+(define* (pan-mix-vct v beg pan snd chn)
 
-  "(pan-mix-vct v start pan-env :optional snd chn) mixes the vct data into the sound 'snd' 
+  "(pan-mix-vct v start pan-env snd chn) mixes the vct data into the sound 'snd' 
 starting at 'start' (in samples) using 'pan-env' to pan (0: all chan 0, 1: all chan 1)."
 
   (let* ((temp-file (snd-tempnam))
@@ -576,8 +554,8 @@ starting at 'start' (in samples) using 'pan-env' to pan (0: all chan 0, 1: all c
 
 ;;; -------- delay-channel-mixes
 
-(define* (delay-channel-mixes beg dur :optional snd chn)
-  "(delay-channel-mixes beg dur :optional snd chn) adds dur (which can be negative) to the \
+(define* (delay-channel-mixes beg dur snd chn)
+  "(delay-channel-mixes beg dur snd chn) adds dur (which can be negative) to the \
 begin time of each mix that starts after beg in the given channel"
   (for-each
    (lambda (m)
@@ -591,7 +569,7 @@ begin time of each mix that starts after beg in the given channel"
 ;;; -------- check-mix-tags
 
 (define* (check-mix-tags snd chn)
-  "(check-mix-tags :optional snd chn) tries to move mix tags around to avoid collisions"
+  "(check-mix-tags snd chn) tries to move mix tags around to avoid collisions"
   (if (not snd)
       (for-each check-mix-tags (sounds))
       (if (not chn)
