@@ -12,10 +12,8 @@
 ;;;   changed 11-Jul-06 to use array-interp
 
 (provide 'snd-moog.scm)
-(if (not (provided? 'snd-env.scm)) (load-from-path "env.scm"))
-(if (not (provided? 'snd-ws.scm)) (load-from-path "ws.scm"))
-
-(use-modules (ice-9 optargs) (ice-9 format))
+(if (not (provided? 'snd-env.scm)) (load "env.scm"))
+(if (not (provided? 'snd-ws.scm)) (load "ws.scm"))
 
 (define moog-gaintable (vct 0.999969 0.990082 0.980347 0.970764 0.961304 0.951996 0.94281 0.933777 0.924866 0.916077 
 			    0.90741 0.898865 0.890442 0.882141  0.873962 0.865906 0.857941 0.850067 0.842346 0.834686
@@ -114,4 +112,3 @@
 
 ;;; (define gen (make-moog-filter 500.0 .1))
 ;;; (map-channel (lambda (y) (moog-filter gen y)))
-;;; (run (lambda () (moog-filter gen 1.0)))
