@@ -1,6 +1,6 @@
 ;; this file loads the music symbol glyphs in cmn-glyphs.lisp (from the cmn package),
 ;;; each function in that package becomes a Scheme function of the form:
-;;;   name :optional x y size style snd chn ax
+;;;   name x y size style snd chn ax
 ;;;   style: #t for lines, #f (default) for filled polygon
 ;;;
 ;;; although Snd based here, all this file needs externally are draw-lines, draw-dot, and fill-polygon
@@ -25,11 +25,11 @@
 		     (len (length vect)))
 		(do ((i 0 (+ 1 i)))
 		    ((= i len))
-		  (vector-set! vals (+ start i) (vector-ref vect i)))
+		  (set! (vals (+ start i)) (vect i)))
 		(set-vals (cdr vects) (+ start len) vals))
 	      (if (car vects)
 		  (begin
-		    (vector-set! vals start (car vects))
+		    (set! (vals start) (car vects))
 		    (set-vals (cdr vects) (+ start 1) vals))
 		  (set-vals (cdr vects) start vals)))))
     (set-vals args 0 (make-vector (total-length args 0)))))
@@ -45,13 +45,13 @@
 	 (ay (- y3 (+ y0 cy by)))
 	 (incr (/ 1.0 n))
 	 (pts (make-vector (* 2 (+ n 1)))))
-    (vector-set! pts 0 x0)
-    (vector-set! pts 1 y0)
+    (set! (pts 0) x0)
+    (set! (pts 1) y0)
     (do ((i 0 (+ 1 i))
 	 (val incr (+ val incr)))
 	((> i n) pts)
-      (vector-set! pts (* i 2) (floor (+ x0 (* val (+ cx (* val (+ bx (* val ax))))))))
-      (vector-set! pts (+ (* i 2) 1) (floor (+ y0 (* val (+ cy (* val (+ by (* val ay)))))))))))
+      (set! (pts (* i 2)) (floor (+ x0 (* val (+ cx (* val (+ bx (* val ax))))))))
+      (set! (pts (+ (* i 2) 1)) (floor (+ y0 (* val (+ cy (* val (+ by (* val ay)))))))))))
 
 ;; pass our Snd context into the graphics procedures (there's probably a cleaner way)
 (define ps-snd 0)
@@ -95,8 +95,8 @@
   
 (define (lineto score x y)
   (let ((v (make-vector 2)))
-    (vector-set! v 0 (->x x))
-    (vector-set! v 1 (->y y))
+    (set! (v 0) (->x x))
+    (set! (v 1) (->y y))
     (set! curx x)
     (set! cury y)
     (set! pathlist (cons v pathlist))
@@ -106,8 +106,8 @@
   (let ((v (make-vector 2)))
     (set! curx (+ curx x))
     (set! cury (+ cury y))
-    (vector-set! v 0 (->x curx))
-    (vector-set! v 1 (->y cury))
+    (set! (v 0) (->x curx))
+    (set! (v 1) (->y cury))
     (set! pathlist (cons v pathlist))
     #f))
 
@@ -135,9 +135,7 @@
 	    ps-snd ps-chn ps-ax))
 
 (define old-defvar defvar)
-(if (not (provided? 'snd-s7))
-    (set! defvar define)
-    (defmacro defvar (name value) `(define ,name ,value)))
+(defmacro defvar (name value) `(define ,name ,value))
 
 (define-macro (setf a b) `(set! ,a ,b))
 
@@ -168,22 +166,20 @@
 
 ;(define comment
 ;  (make-procedure-with-setter
-;   (lambda* (:optional (scr #f) (msg 0))
-;     "(comment :optional (scr #f) (msg 0)) tries to make musglyph.scm safe for comments"
+;   (lambda* ((scr #f) (msg 0))
+;     "(comment (scr #f) (msg 0)) tries to make musglyph.scm safe for comments"
 ;     (if (or (number? msg)
 ;	     (not scr))
 ;	 (sound-comment scr)))
-;   (lambda* (snd :optional (val #f))
+;   (lambda* (snd (val #f))
 ;     (if (not val)
 ;	 (apply (setter sound-comment) (list #f snd))
 ;	 (apply (setter sound-comment) (list snd val))))))
 
 ;(load "loop.scm") ; Rick's loop implementation (cm/src/loop.scm)
-(if (not (provided? 'snd-s7))
-    (define progn begin)
-    (defmacro progn args `(begin ,@args)))
+(defmacro progn args `(begin ,@args))
 
-(load-from-path "cmn-glyphs.lisp")
+(load "cmn-glyphs.lisp")
 
 (set! defvar old-defvar)
 ;(set! declare old-declare)
