@@ -7,20 +7,19 @@
 ;;; Comments not otherwise noted are taken from noise.ins!
 
 ;; Included functions:
-;; (attack-point duration attack decay :optional (total-x 100.0))
+;; (attack-point duration attack decay (total-x 100.0))
 ;; (fm-noise ...)
-;; (make-fm-noise len freq :key ...)
+;; (make-fm-noise len freq ...)
 
 ;;; The "noise" instrument (useful for Oceanic Music):
 
-(use-modules (ice-9 format) (ice-9 optargs))
 (provide 'snd-noise.scm)
-(if (not (provided? 'snd-ws.scm)) (load-from-path "ws.scm"))
-(if (not (provided? 'snd-env.scm)) (load-from-path "env.scm"))
+(if (not (provided? 'snd-ws.scm)) (load "ws.scm"))
+(if (not (provided? 'snd-env.scm)) (load "env.scm"))
 
 (define *locsig-type* mus-interp-sinusoidal)
 
-(define* (attack-point duration attack decay :optional (total-x 100.0))
+(define* (attack-point duration attack decay (total-x 100.0))
   (* total-x (/ (if (= 0.0 attack)
 		    (if (= 0.0 decay)
 			(/ duration 4)
@@ -31,7 +30,7 @@
 (definstrument (fm-noise startime dur freq0 amp ampfun ampat ampdc
 		   freq1 glissfun freqat freqdc rfreq0 rfreq1 rfreqfun rfreqat rfreqdc
 		   dev0 dev1 devfun devat devdc
-		   :key (degree 0.0)
+		   (degree 0.0)
 		   (distance 1.0)
 		   (reverb-amount 0.005))
   
@@ -96,13 +95,12 @@
 			    :duration dur :scaler (hz->radians (- rfreq1 rfreq0)))))
     (ws-interrupt?)
     (run
-     (lambda ()
-       (do ((i beg (+ 1 i)))
-	   ((= i end))
-	 (locsig loc i (* (env amp-f)
-			  (oscil carrier (+ (env freq-f)
-					    (* (+ dev-0 (env dev-f)) 
-					       (rand modulator (env rfreq-f))))))))))))
+     (do ((i beg (+ 1 i)))
+	 ((= i end))
+       (locsig loc i (* (env amp-f)
+			(oscil carrier (+ (env freq-f)
+					  (* (+ dev-0 (env dev-f)) 
+					     (rand modulator (env rfreq-f)))))))))))
 
 ;; (let* ((ofile "test.snd")
 ;;        (snd (find-sound ofile)))
@@ -117,7 +115,7 @@
 ;;; And here is a generator-like instrument, see make-fm-violin in
 ;;; fmv.scm. [MS]
 
-(define* (make-fm-noise len freq :key
+(define* (make-fm-noise len freq
 			(amp 0.25)
 			(ampfun '(0 0 25 1 75 1 100 0))
 			(ampat 0.1)
@@ -139,7 +137,7 @@
 			(degree (random 90.0))
 			(distance 1.0)
 			(reverb-amount 0.005))
-  (let* ((dur (/ len (inexact->exact (srate))))
+  (let* ((dur (/ len (floor (srate))))
 	 (amp-attack (attack-point dur ampat ampdc))
 	 (amp-decay (- 100.0 (attack-point dur ampdc ampat)))
 	 (freq-attack (attack-point dur freqat freqdc))
