@@ -1,5 +1,3 @@
-(use-modules (ice-9 optargs) (ice-9 format))
-
 (provide 'snd-numerics.scm)
 
 ;;; random stuff I needed at one time or another while goofing around...
@@ -8,8 +6,8 @@
 (define factorial
   (let* ((num-factorials 128)
 	 (factorials (let ((temp (make-vector num-factorials 0)))
-		       (vector-set! temp 0 1) ; is this correct?
-		       (vector-set! temp 1 1)
+		       (set! (temp 0) 1) ; is this correct?
+		       (set! (temp 1) 1)
 		       temp)))
     (lambda (n)
       (if (> n num-factorials)
@@ -19,10 +17,10 @@
 	    (set! factorials (make-vector num-factorials 0))
 	    (do ((i 0 (+ 1 i)))
 		((= i old-num))
-	      (vector-set! factorials i (vector-ref old-facts i)))))
-      (if (zero? (vector-ref factorials n))
-	  (vector-set! factorials n (* n (factorial (- n 1)))))
-      (vector-ref factorials n))))
+	      (set! (factorials i) (old-facts i)))))
+      (if (zero? (factorials n))
+	  (set! (factorials n) (* n (factorial (- n 1)))))
+      (factorials n))))
 
 (define (binomial-direct n m) ; "n-choose-m" might be a better name (there are much better ways to compute this -- see below)
   (/ (factorial n)
@@ -83,22 +81,22 @@
 (define (legendre-polynomial a x) ; sum of weighted polynomials (m=0)
   (let ((n (- (length a) 1)))
     (if (= n 0) 
-	(vector-ref a 0)
+	(a 0)
 	(let* ((r x)
 	       (s 1.0)
 	       (h 0.0)
-	       (sum (vector-ref a 0)))
+	       (sum (a 0)))
 	  (do ((k 1 (+ 1 k)))
 	      ((= k n))
 	    (set! h r)
-	    (set! sum (+ sum (* r (vector-ref a k))))
+	    (set! sum (+ sum (* r (a k))))
 	    (set! r (/ (- (* r x (+ (* 2 k) 1))  (* s k)) (+ k 1)))
 	    (set! s h))
-	  (+ sum (* r (vector-ref a n)))))))
+	  (+ sum (* r (a n)))))))
 
 (define (legendre n x)
   (legendre-polynomial (let ((v (make-vector (+ 1 n) 0.0)))
-			 (vector-set! v n 1.0)
+			 (set! (v n) 1.0)
 			 v)
 		       x))
 
@@ -125,7 +123,7 @@
 |#
 
 
-(define* (gegenbauer n x :optional (alpha 0.0))
+(define* (gegenbauer n x (alpha 0.0))
   (if (< alpha -0.5) (set! alpha -0.5))
   (if (= n 0)
       1.0
@@ -163,72 +161,72 @@
 |#
 
 
-(define* (chebyshev-polynomial a x :optional (kind 1))
+(define* (chebyshev-polynomial a x (kind 1))
   (let ((n (- (length a) 1)))
     (if (= n 0) 
-	(vector-ref a 0)
+	(a 0)
 	(let* ((r (* kind x))
 	       (s 1.0)
 	       (h 0.0)
-	       (sum (vector-ref a 0)))
+	       (sum (a 0)))
 	  (do ((k 1 (+ 1 k)))
 	      ((= k n))
 	    (set! h r)
-	    (set! sum (+ sum (* r (vector-ref a k))))
+	    (set! sum (+ sum (* r (a k))))
 	    (set! r (- (* 2 r x) s))
 	    (set! s h))
-	  (+ sum (* r (vector-ref a n)))))))
+	  (+ sum (* r (a n)))))))
 
-(define* (chebyshev n x :optional (kind 1))
+(define* (chebyshev n x (kind 1))
   (let ((a (make-vector (+ 1 n) 0.0)))
-    (vector-set! a n 1.0)
+    (set! (a n) 1.0)
     (chebyshev-polynomial a x kind)))
 
 
 (define (hermite-polynomial a x)
   (let ((n (- (length a) 1)))
     (if (= n 0) 
-	(vector-ref a 0)
+	(a 0)
 	(let* ((r (* 2 x))
 	       (s 1.0)
 	       (h 0.0)
-	       (sum (vector-ref a 0)))
+	       (sum (a 0)))
 	  (do ((k 1 (+ 1 k))
 	       (k2 2 (+ k2 2)))
 	      ((= k n))
 	    (set! h r)
-	    (set! sum (+ sum (* r (vector-ref a k))))
+	    (set! sum (+ sum (* r (a k))))
 	    (set! r (- (* 2 r x) (* k2 s)))
 	    (set! s h))
-	  (+ sum (* r (vector-ref a n)))))))
+	  (+ sum (* r (a n)))))))
 
 (define* (hermite n x)
   (let ((a (make-vector (+ 1 n) 0.0)))
-    (vector-set! a n 1.0)
+    (set! (a n) 1.0)
     (hermite-polynomial a x)))
 
 
-(define* (laguerre-polynomial a x :optional (alpha 0.0))
+(define* (laguerre-polynomial a x (alpha 0.0))
   (let ((n (- (length a) 1)))
     (if (= n 0) 
-	(vector-ref a 0)
+	(a 0)
 	(let* ((r (- (+ alpha 1.0) x))
 	       (s 1.0)
 	       (h 0.0)
-	       (sum (vector-ref a 0)))
+	       (sum (a 0)))
 	  (do ((k 1 (+ 1 k)))
 	      ((= k n))
 	    (set! h r)
-	    (set! sum (+ sum (* r (vector-ref a k))))
+	    (set! sum (+ sum (* r (a k))))
 	    (set! r (/ (- (* r (- (+ (* 2 k) 1 alpha) x)) 
 			  (* s (+ k alpha)))
 		       (+ k 1)))
 	    (set! s h))
-	  (+ sum (* r (vector-ref a n)))))))
+	  (+ sum (* r (a n)))))))
 
-(define* (laguerre n x :optional (alpha 0.0))
+(define* (laguerre n x (alpha 0.0))
   (let ((a (make-vector (+ 1 n) 0.0)))
-    (vector-set! a n 1.0)
+    (set! (a n) 1.0)
     (laguerre-polynomial a x alpha)))
 
 
@@ -242,10 +240,10 @@
 ;;; (automorph 0.0+1.0i 0 0 1) rotates 90 degrees (so 4 times = identity)
 ;;; most cases won't work right because we're assuming real output and so on
 
-(define* (automorph a b c d :optional snd chn)
+(define* (automorph a b c d snd chn)
   (let* ((len (frames snd chn))
 	 (pow2 (ceiling (/ (log len) (log 2))))
-	 (fftlen (inexact->exact (expt 2 pow2)))
+	 (fftlen (floor (expt 2 pow2)))
 	 (fftscale (/ 1.0 fftlen))
 	 (rl (channel->vct 0 fftlen snd chn))
 	 (im (make-vct fftlen)))
@@ -253,25 +251,25 @@
     (vct-scale! rl fftscale)
     (vct-scale! im fftscale)
     ;; handle 0 case by itself
-    (let* ((c1 (make-rectangular (vct-ref rl 0) (vct-ref im 0)))
+    (let* ((c1 (make-rectangular (rl 0) (im 0)))
 	   (val (/ (+ (* a c1) b)
 		   (+ (* c c1) d)))
 	   (rval (real-part val))
 	   (ival (imag-part val)))
-      (vct-set! rl 0 rval)
-      (vct-set! im 0 ival))
+      (set! (rl 0) rval)
+      (set! (im 0) ival))
     (do ((i 1 (+ i 1))
 	 (k (- fftlen 1) (- k 1)))
 	((= i (/ fftlen 2)))
-      (let* ((c1 (make-rectangular (vct-ref rl i) (vct-ref im i)))
+      (let* ((c1 (make-rectangular (rl i) (im i)))
 	     (val (/ (+ (* a c1) b)      ; (az + b) / (cz + d)
 		     (+ (* c c1) d)))
 	     (rval (real-part val))
 	     (ival (imag-part val)))
-	(vct-set! rl i rval)
-	(vct-set! im i ival)
-	(vct-set! rl k rval)
-	(vct-set! im k (- ival))))
+	(set! (rl i) rval)
+	(set! (im i) ival)
+	(set! (rl k) rval)
+	(set! (im k) (- ival))))
     (fft rl im -1)
     (vct->channel rl 0 len snd chn #f (format #f "automorph ~A ~A ~A ~A" a b c d))))
 |#
@@ -398,11 +396,11 @@
 					  -23749461029/870 0 8615841276005/14322 0)))
 			(do ((i 0 (+ i 1)))
 			    ((= i 30))
-			  (vector-set! v i (vector-ref vals i)))
+			  (set! (v i) (vals i)))
 			v)))
     (lambda (n)
-      (if (number? (vector-ref saved-values n))
-	  (vector-ref saved-values n)
+      (if (number? (saved-values n))
+	  (saved-values n)
 	  (let ((value (if (odd? n) 
 			   0.0
 			   (let ((sum2 0.0)
@@ -419,7 +417,7 @@
 			     (/ (* 2.0 sum2 (factorial n)
 				   (if (= (modulo n 4) 0) -1 1))
 				(expt (* 2.0 pi) n))))))
-	    (vector-set! saved-values n value)
+	    (set! (saved-values n) value)
 	    value)))))
 
 (define (bernoulli-poly n x)
@@ -691,10 +689,10 @@
 	(if (= tp1 0)
 	    (begin
 	      (set! tp1 1)
-	      (vector-set! tp 0 1.0)
+	      (set! (tp 0) 1.0)
 	      (do ((i 1 (+ i 1)))
 		  ((= i ntp))
-		(vector-set! tp i (* 2.0 (vector-ref tp (- i 1)))))))
+		(set! (tp i) (* 2.0 (tp (- i 1)))))))
 	
 	(if (= ak 1.0)
 	    0.0
@@ -703,11 +701,11 @@
 	      (do ((i 0 (+ i 1)))
 		  ((or (not (= pl -1)) 
 		       (= i ntp)))
-		(if (> (vector-ref tp i) p)
+		(if (> (tp i) p)
 		    (set! pl i)))
 	      
 	      (if (= pl -1) (set! pl ntp))
-	      (let ((pt (vector-ref tp (- pl 1)))
+	      (let ((pt (tp (- pl 1)))
 		    (p1 p)
 		    (r 1.0))
 		;;  Perform binary exponentiation algorithm modulo ak.
@@ -792,7 +790,7 @@
 
 ;;; --------------------------------------------------------------------------------
 
-(define* (sin-nx-peak n :optional (error 1e-12))
+(define* (sin-nx-peak n (error 1e-12))
   ;; return the min peak amp and its location for sin(x)+sin(nx+a)
   (let* ((size (* n 100))
 	 (incr (/ (* 2 pi) size))
