@@ -1,6 +1,5 @@
 ;;; a software oscilloscope using the standard Snd channel display interface
 
-(use-modules (ice-9 format) (ice-9 optargs))
 (provide 'snd-oscope.scm)
 
 (define audio-srate 44100) ; graph's sampling rate
@@ -51,30 +50,7 @@
   (set! oscope-power (not oscope-power))
   (if oscope-power
       (begin
-	(set! oscope-input-port (mus-audio-open-input mus-audio-microphone audio-srate 1 mus-lshort 512))
-	(if (= oscope-input-port -1)
-	    ;; ask card what it wants
-	    (let ((vals (make-vct 32))
-		  (chans 1)
-		  (bytes 512))
-	      (mus-audio-mixer-read mus-audio-line-in mus-audio-format 32 vals)
-	      (let ((fmt (inexact->exact (vct-ref vals 1))))
-		(mus-audio-mixer-read mus-audio-line-in mus-audio-channel 32 vals)
-		(set! chans (inexact->exact (vct-ref vals 0)))
-		(let ((err (mus-audio-mixer-read mus-audio-line-in mus-audio-samples-per-channel 2 vals)))
-		  (if (not (= err -1))
-		      (set! oscope-input-frames (inexact->exact (vct-ref vals 0))))
-		  (let* ((bps (mus-bytes-per-sample fmt)))
-		    (set! bytes (* bps oscope-input-frames chans))
-		    (set! oscope-input-port (catch #t
-					 (lambda ()
-					   (mus-audio-open-input mus-audio-line-in audio-srate chans fmt bytes))
-					 (lambda args -1)))
-		    (if (not (= oscope-input-port -1))
-			(begin
-			  (if (or (not (= (channels oscope-input-data) chans))
-				  (not (= (sound-data-length oscope-input-data) oscope-input-frames)))
-			      (set! oscope-input-data (make-sound-data chans oscope-input-frames))))))))))
+	(set! oscope-input-port (mus-audio-open-input 0 audio-srate 1 mus-lshort 512))
 	(if (not (= oscope-input-port -1))
 	    (begin
 	      (do ()
@@ -111,7 +87,7 @@
     (set! cycle-length size)
     (set! cycle-start 0)
     (if (< cycle-length old-length)
-	(do ((i cycle-length (1+ i)))
+	(do ((i cycle-length (+ 1 i)))
 	    ((>= i old-length))
 	  (sound-data-set! oscope-graph-data 0 i 0.0)))
     (set! oscope-frozen old-frozen)
@@ -246,7 +222,7 @@
 	      (gtk_widget_show scale)
 	      (gtk_box_pack_start (GTK_BOX mainform) label #f #f 0)
 	      (gtk_widget_show label)
-	      (g_signal_connect adj "value_changed" (lambda (w d) (cycle-func (inexact->exact (gtk_adjustment_get_value (GTK_ADJUSTMENT adj)))) #f))
+	      (g_signal_connect adj "value_changed" (lambda (w d) (cycle-func (floor (gtk_adjustment_get_value (GTK_ADJUSTMENT adj)))) #f))
 	      (set! (right-sample oscope-graph 0) cycle-length)
 	      (set! (max-transform-peaks oscope-graph 0) 10)
 	      (g_signal_connect freeze-button "toggled" (lambda (w d) (freeze-func) #f))
