@@ -1,6 +1,6 @@
 ;;; playing-related examples previously scattered around at random
 ;;;
-;;; play-sound :optional func -- play current sound, calling (func data) on each buffer if func is passed
+;;; play-sound func -- play current sound, calling (func data) on each buffer if func is passed
 ;;; play-often, play-until-c-g -- play sound n times or until c-g
 ;;; play-region-forever -- play region over and over until C-g typed
 ;;; loop-between-marks -- play while looping continuously between two movable marks
@@ -11,19 +11,17 @@
 
 ;;; see also play-syncd-marks and play-between-marks in marks.scm
 
-
-(use-modules (ice-9 format) (ice-9 optargs))
 (provide 'snd-play.scm)
 
 
-(define* (samples->sound-data :optional (beg 0) num snd chn obj pos (sd-chan 0))
+(define* (samples->sound-data (beg 0) num snd chn obj pos (sd-chan 0))
   (vct->sound-data 
    (channel->vct beg num snd chn pos) 
    (or obj (make-sound-data 1 (or num (frames snd chn))))
    sd-chan))
 
 
-(define* (open-play-output :optional out-chans out-srate out-format out-bufsize)
+(define* (open-play-output out-chans out-srate out-format out-bufsize)
   ;; returns (list audio-fd chans frames)
   (let* ((outchans (or out-chans 1))
 	 (cur-srate (or out-srate (and (not (null? (sounds))) (srate)) 22050))
@@ -38,34 +36,18 @@
 		(add-hook! mus-error-hook (lambda (typ msg) #t)))
 	    (let ((val (catch #t
 			      (lambda ()
-				(mus-audio-open-output mus-audio-default cur-srate outchans frm outbytes))
+				(mus-audio-open-output 0 cur-srate outchans frm outbytes))
 			      (lambda args -1)))) ; -1 returned in case of error
 	      (if no-error 
 		  (reset-hook! mus-error-hook))
 	      val))))
-    (if (= audio-fd -1)
-	;; ask card what it wants -- ALSA with some cards, for example, insists on 10 (virtual) channels and mus-lintn data!
-	(let ((vals (make-vct 32)))
-	  (mus-audio-mixer-read mus-audio-default mus-audio-format 32 vals)
-	  (let ((fmt (inexact->exact (vct-ref vals 1))))
-	    (mus-audio-mixer-read mus-audio-default mus-audio-channel 32 vals)
-	    (set! outchans (inexact->exact (vct-ref vals 0)))
-	    (let ((err (mus-audio-mixer-read mus-audio-default mus-audio-samples-per-channel 2 vals)))
-	      (if (not (= err -1))
-		  (set! pframes (inexact->exact (vct-ref vals 0))))
-	      (let* ((bps (mus-bytes-per-sample fmt)))
-		(set! outbytes (* bps pframes outchans))
-		(set! audio-fd (catch #t
-				      (lambda ()
-					(mus-audio-open-output mus-audio-default cur-srate outchans fmt outbytes))
-				      (lambda args -1))))))))
     (if (not (= audio-fd -1))
 	(set! (dac-size) outbytes))
     (list audio-fd outchans pframes)))
 
 
-(define* (play-sound :optional func)
-  "(play-sound :optional func) plays the currently selected sound, calling func on each data buffer, if func exists"
+(define* (play-sound func)
+  "(play-sound func) plays the currently selected sound, calling func on each data buffer, if func exists"
   (if (not (null? (sounds)))
       (let* ((filechans (chans))
 	     (audio-info (open-play-output filechans (srate) #f 256))
@@ -133,14 +115,17 @@
 
 ;;; -------- play region over and over until C-g typed
 
-(define (play-region-forever reg)
+(define (play-region-forever reg1)
   "(play-region-forever reg) plays region 'reg' until you interrupt it via C-g"
-  (define (play-region-again reason)
-    (if (and (not (c-g?))  ; be extra careful (probably superfluous)
-	     (= reason 0)) ; 0=play completed normally
-	(play-region reg #f play-region-again)))
-  (play-region reg #f play-region-again))
 
+  (let ((reg (if (integer? reg1) (integer->region reg1) reg1)))
+
+    (define (play-region-again reason)
+      (if (and (not (c-g?))  ; be extra careful (probably superfluous)
+	       (= reason 0)) ; 0=play completed normally
+	  (play reg :wait #f :stop play-region-again)))
+
+    (play reg :wait #f :stop play-region-again)))
 
 ;(bind-key #\p 0 (lambda (n) "play region forever" (play-region-forever (list-ref (regions) (max 0 n)))))
 
@@ -156,7 +141,7 @@
 	 (all-data (samples->sound-data)) ; for simplicity, just grab all the data
 	 (audio-data (make-sound-data 1 bufsize))
 	 (bytes (* bufsize 2)) ; mus-audio-write handles the translation to short (and takes frames, not bytes as 3rd arg)
-	 (audio-fd (mus-audio-open-output mus-audio-default (srate) 1 mus-lshort bytes)))
+	 (audio-fd (mus-audio-open-output 0 (srate) 1 mus-lshort bytes)))
     (if (not (= audio-fd -1))
 	(do ()
 	    ((c-g?) 
@@ -213,13 +198,13 @@ read, even if not playing.  'files' is a list of files to be played."
 	       (pframes (make-vector files-len 0))
 	       (current-file 0)
 	       (reading #t)
-	       (out-port (mus-audio-open-output mus-audio-default srate chans mus-lshort (* bufsize 2))))
+	       (out-port (mus-audio-open-output 0 srate chans mus-lshort (* bufsize 2))))
 	  (if (< out-port 0)
 	      (format #t "can't open audio port! ~A" out-port)
 	      (begin
 		(do ((i 0 (+ 1 i)))
 		    ((= i files-len))
-		  (vector-set! pframes i (frames (list-ref files i))))
+		  (set! (pframes i) (frames (list-ref files i))))
 		(catch #t
 		       (lambda ()
 			 (while reading
@@ -228,9 +213,9 @@ read, even if not playing.  'files' is a list of files to be played."
 				      (let* ((ramp-down 1.0)
 					     (ramp (/ 1.0 bufsize))
 					     (current (list-ref readers current-file))
-					     (current-loc (vector-ref locs current-file))
+					     (current-loc (locs current-file))
 					     (next (list-ref readers next-file))
-					     (next-loc (vector-ref locs next-file))
+					     (next-loc (locs next-file))
 					     (downs (channels current))
 					     (ups (channels next))
 					     (up (make-frame ups))
@@ -252,13 +237,13 @@ read, even if not playing.  'files' is a list of files to be played."
 					(if read-even-when-not-playing
 					    (do ((i 0 (+ 1 i)))
 						((= i files-len))
-					      (vector-set! locs i (+ (vector-ref locs i) bufsize)))
+					      (set! (locs i) (+ (locs i) bufsize)))
 					    (begin
-					      (vector-set! locs current-file (+ (vector-ref locs current-file) bufsize))
-					      (vector-set! locs next-file (+ (vector-ref locs next-file) bufsize))))
+					      (set! (locs current-file) (+ (locs current-file) bufsize))
+					      (set! (locs next-file) (+ (locs next-file) bufsize))))
 					(set! current-file next-file))
 				      (let* ((current (list-ref readers current-file))
-					     (current-loc (vector-ref locs current-file))
+					     (current-loc (locs current-file))
 					     (ons (channels current))
 					     (on (make-frame ons)))
 					(do ((i 0 (+ 1 i)))
@@ -270,15 +255,15 @@ read, even if not playing.  'files' is a list of files to be played."
 					(if read-even-when-not-playing
 					    (do ((i 0 (+ 1 i)))
 						((= i files-len))
-					      (vector-set! locs i (+ (vector-ref locs i) bufsize)))
-					    (vector-set! locs current-file (+ (vector-ref locs current-file) bufsize)))))
+					      (set! (locs i) (+ (locs i) bufsize)))
+					    (set! (locs current-file) (+ (locs current-file) bufsize)))))
 				  (mus-audio-write out-port data bufsize)
 				  (set! reading (and (not (c-g?))
 						     (letrec ((any-data-left 
 							       (lambda (f)
 								 (if (= f files-len)
 								     #f
-								     (or (< (vector-ref locs f) (vector-ref pframes f))
+								     (or (< (locs f) (pframes f))
 									 (any-data-left (+ 1 f)))))))
 						       (any-data-left 0)))))))
 		       (lambda args (begin (snd-print (format #f "error ~A" args)) (car args))))
@@ -321,7 +306,7 @@ amp: (play-with-amps 0 1.0 0.5) plays channel 2 of stereo sound at half amplitud
   (let* ((len 22050)
 	 (osc (make-oscil freq)))
     (play (lambda ()
-	    (set! len (1- len))
+	    (set! len (- len 1))
 	    (if (<= len 0)
 		#f
 		(* amp (oscil osc)))))))
@@ -335,16 +320,16 @@ amp: (play-with-amps 0 1.0 0.5) plays channel 2 of stereo sound at half amplitud
 	 (amps (make-vector num-oscs)))
     (do ((i 0 (+ 1 i)))
 	((= i num-oscs))
-      (vector-set! oscs i (make-oscil (car (list-ref freqs-and-amps i))))
-      (vector-set! amps i (cadr (list-ref freqs-and-amps i))))
+      (set! (oscs i) (make-oscil (car (list-ref freqs-and-amps i))))
+      (set! (amps i) (cadr (list-ref freqs-and-amps i))))
     (play (lambda ()
-	    (set! len (1- len))
+	    (set! len (- len 1))
 	    (if (<= len 0)
 		#f
 		(let ((sum 0.0))
 		  (do ((i 0 (+ 1 i)))
 		      ((= i num-oscs))
-		    (set! sum (+ sum (* (vector-ref amps i) (oscil (vector-ref oscs i))))))
+		    (set! sum (+ sum (* (amps i) (oscil (oscs i))))))
 		  sum))))))
 
 ;(play-sines '((425 .05) (450 .01) (470 .01) (546 .02) (667 .01) (789 .034) (910 .032)))
