@@ -11,7 +11,6 @@
 ;;;    (change-listener-popup-color new-color) to change its color
 ;;; a popup menu is also added to each edit history pane to display the "spreadsheet" edit-list->function menu
 
-(use-modules (ice-9 common-list) (ice-9 format))
 (provide 'snd-popup.scm)
 
 (if (not (provided? 'xm))
@@ -90,7 +89,7 @@
 		    (change-label w "Stop")
 		    (set! stop-widget w)
 		    (set! stopping #t)
-		    (play-selection)))))
+		    (play (selection))))))
       (list "Loop play"      xmPushButtonWidgetClass every-menu ; play over and over
 	    (lambda (w c i) 
 	      (define (stop-playing-selection)
@@ -104,7 +103,7 @@
 		(if (and (not (c-g?))
 			 (= reason 0)
 			 stopping1)
-		    (play-selection #f play-selection-again)
+		    (play (selection) :wait #f :stop play-selection-again)
 		    (stop-playing-selection)))
 	      (if stopping1
 		  (begin
@@ -114,7 +113,7 @@
 		    (change-label w "Stop!")
 		    (set! stop-widget1 w) ; needs to be separate from Play case since we're stopping/restarting deliberately
 		    (set! stopping1 #t)
-		    (play-selection #f play-selection-again)))))
+		    (play (selection) :wait #f :stop play-selection-again)))))
       (list "Delete"    xmPushButtonWidgetClass every-menu (lambda (w c i) (delete-selection)))
       (list "Zero"      xmPushButtonWidgetClass every-menu (lambda (w c i) (scale-selection-by 0.0)))
       (list "Crop"      xmPushButtonWidgetClass every-menu
@@ -169,9 +168,9 @@
 		(info-dialog 
 		 "Selection info"
 		 (format #f "start ~A, ~,3F~%end: ~A, ~,3F~%duration: ~A, ~,3F~%chans: ~D~%maxamp: ~,3F"
-			 beg (exact->inexact (/ beg (srate)))
-			 (+ beg len) (exact->inexact (/ (+ beg len) (srate)))
-			 len (exact->inexact (/ len (srate)))
+			 beg (* 1.0 (/ beg (srate)))
+			 (+ beg len) (* 1.0 (/ (+ beg len) (srate)))
+			 len (* 1.0 (/ len (srate)))
 			 (selection-chans)
 			 (selection-maxamp))))))
       (list "Apply controls" xmPushButtonWidgetClass every-menu (lambda (w c i) (apply-controls (selected-sound) 2))) ; 2=selection
@@ -194,43 +193,6 @@
 	(stopping #f)
 	(stop-widget #f))
 
-    (define (vector-print v)
-      (if (< (length v) 3)
-	  (object->string v)
-	  (let ((str (format #f "'#(~A" (vector-ref v 0))))
-	    (do ((i 1 (+ 1 i)))
-		((= i 3))
-	      (set! str (string-append str " " (object->string (vector-ref v i)))))
-	    (string-append str " ...)"))))
-
-    (define (display-properties props)
-      ;; there's no way to tell Guile's format that enormous vectors should not be printed in full
-      ;; so we search for them here and handle them ourselves
-      (let ((str ""))
-	(for-each
-	 (lambda (pr)
-	   (let ((property (car pr))
-		 (value (cdr pr)))
-	     (set! str (string-append str (string #\newline) "    " (object->string property) ": "))
-	     (if (vector? value)
-		 (set! str (string-append str (vector-print value)))
-		 (if (list? value)
-		     (let ((prev #f))
-		       (set! str (string-append str "'("))
-		       (for-each
-			(lambda (v)
-			  (if prev 
-			      (set! str (string-append str " "))
-			      (set! prev #t))
-			  (if (vector? v)
-			      (set! str (string-append str (vector-print v)))
-			      (set! str (string-append str (object->string v)))))
-			value)
-		       (set! str (string-append str ")")))
-		     (set! str (string-append str (object->string value)))))))
-	 props)
-	str))
-
     (add-hook! stop-playing-hook
 	       (lambda (snd) 
 		 (if stopping
@@ -346,7 +308,7 @@
 			(srate snd)
 			(mus-header-type-name (header-type snd))
 			(mus-data-format-name (data-format snd))
-			(exact->inexact (/ (frames snd graph-popup-chn) (srate snd)))
+			(* 1.0 (/ (frames snd graph-popup-chn) (srate snd)))
 			(maxamp snd #t)
 			(if (comment snd)
 			    (format #f "  comment: \"~A\"~%" (comment snd))
@@ -359,8 +321,7 @@
 			    (format #f "  sounds: ~{~{~%     ~S start: ~A, loop: ~A ~A~}~}" (soundfont-info))
 			    "")
 			(if (not (null? (sound-properties snd)))
-			    (format #f "  properties: ~A"
-				    (display-properties (sound-properties snd)))
+			    (format #f "  properties: ~A" (sound-properties snd))
 			    "")
 			(let ((chan-str ""))
 			  (do ((i 0 (+ 1 i)))
@@ -368,8 +329,7 @@
 			    (if (not (null? (channel-properties snd i)))
 				(set! chan-str 
 				      (string-append chan-str
-						     (format #f "~%  chan ~D properties: ~A" 
-							     i (display-properties (channel-properties snd i)))))))
+						     (format #f "~%  chan ~D properties: ~A" i (channel-properties snd i))))))
 			  chan-str)
 			)))))
       (list "Add mark"           xmPushButtonWidgetClass every-menu 
@@ -925,7 +885,7 @@ color name, an xm Pixel, a snd color, or a list of rgb values (as in Snd's make-
 (define (add-listener-popup)
   (let* ((listener (or (list-ref (main-widgets) 4)
 		       (begin
-			 (show-listener)
+			 (set! (show-listener) #t) ; create it?
 			 (set! (show-listener) #f)
 			 (list-ref (main-widgets) 4))))
 	 (every-menu (list XmNbackground (highlight-color)))
