@@ -1,18 +1,17 @@
 ;;; this is a translation to Snd (from CLM's prc-toolkit95.lisp)
 ;;;  of Perry Cook's Physical Modelling Toolkit.
 
-(use-modules (ice-9 optargs) (ice-9 format))
 (provide 'snd-prc95.scm)
-(if (not (provided? 'snd-ws.scm)) (load-from-path "ws.scm"))
+(if (not (provided? 'snd-ws.scm)) (load "ws.scm"))
 
 
-(define* (make-reed :key (offset 0.6) (slope -0.8))
+(define* (make-reed (offset 0.6) (slope -0.8))
   (vct offset slope))
 
 (define (reedtable r sample)
   (min 1.0 (+ (vct-ref r 0) (* (vct-ref r 1) sample))))
 
-(define* (make-bowtable :key (offset 0.0) (slope 1.0))
+(define* (make-bowtable (offset 0.0) (slope 1.0))
   (vct offset slope))
 
 (define (bowtable b sample)
@@ -21,10 +20,10 @@
 (define (jettable sample) 
   (max -1.0 (min 1.0 (* sample (- (* sample sample) 1.0)))))
 
-(define* (make-onezero :key (gain 0.5) (zerocoeff 1.0))
+(define* (make-onezero (gain 0.5) (zerocoeff 1.0))
   (make-one-zero gain (* gain zerocoeff)))
 
-(define* (make-onep :key (polecoeff 0.9))
+(define* (make-onep (polecoeff 0.9))
   (make-one-pole (- 1.0 polecoeff) (- polecoeff)))
 
 (define (set-pole p val) 
@@ -93,11 +92,10 @@
 				      (* maxa (- 1.0 (random 2.0)))))))
     (ws-interrupt?)
     (run
-     (lambda ()
-       (do ((i start (+ 1 i)))
-	   ((= i end))
-	 (set! dout (delaya delayline (one-zero filter dout)))
-	 (outa i (* amplitude dout)))))))
+     (do ((i start (+ 1 i)))
+	 ((= i end))
+       (set! dout (delaya delayline (one-zero filter dout)))
+       (outa i (* amplitude dout))))))
 
 
 ;;; freq is off in this one (in prc's original also)
@@ -127,37 +125,36 @@
     (set-gain filt 0.3)
     (ws-interrupt?)
     (run
-     (lambda ()
-       (do ((i st (+ 1 i)))
-	   ((= i end))
-	 (let* ((bridgerefl 0.0)
-		(nutrefl 0.0) 
-		(veldiff 0.0) 
-		(stringvel 0.0) 
-		(bowtemp 0.0))
-	   (if bowing
-	       (if (not (= maxvelocity bowvelocity))
-		   (if (< bowvelocity maxvelocity)
-		       (set! bowvelocity (+ bowvelocity attackrate))
-		       (set! bowvelocity (- bowvelocity attackrate))))
-	       (if (> bowvelocity 0.0) 
-		   (set! bowvelocity (- bowvelocity attackrate))))
-	   (set! bowtemp (* 0.3 bowvelocity))
-	   (let ((filt-output (one-pole filt bridgeout)))
-	     (set! bridgerefl (- filt-output))
-	     (set! nutrefl (- neckout))
-	     (set! stringvel (+ bridgerefl nutrefl))
-	     (set! veldiff (- bowtemp stringvel))
-	     (set! veldiff (* veldiff (bowtable bowtab veldiff)))
-	     (set! neckout (delayl neckdelay (+ bridgerefl veldiff)))
-	     (set! bridgeout (delayl bridgedelay (+ nutrefl veldiff)))
-	     (let ((result (* amplitude 10.0 filt-output)))
-	       (if (= ctr release)
-		   (begin
-		     (set! bowing #f)
-		     (set! attackrate .0005)))
-	       (set! ctr (+ ctr 1))
-	       (outa i result)))))))))
+     (do ((i st (+ 1 i)))
+	 ((= i end))
+       (let* ((bridgerefl 0.0)
+	      (nutrefl 0.0) 
+	      (veldiff 0.0) 
+	      (stringvel 0.0) 
+	      (bowtemp 0.0))
+	 (if bowing
+	     (if (not (= maxvelocity bowvelocity))
+		 (if (< bowvelocity maxvelocity)
+		     (set! bowvelocity (+ bowvelocity attackrate))
+		     (set! bowvelocity (- bowvelocity attackrate))))
+	     (if (> bowvelocity 0.0) 
+		 (set! bowvelocity (- bowvelocity attackrate))))
+	 (set! bowtemp (* 0.3 bowvelocity))
+	 (let ((filt-output (one-pole filt bridgeout)))
+	   (set! bridgerefl (- filt-output))
+	   (set! nutrefl (- neckout))
+	   (set! stringvel (+ bridgerefl nutrefl))
+	   (set! veldiff (- bowtemp stringvel))
+	   (set! veldiff (* veldiff (bowtable bowtab veldiff)))
+	   (set! neckout (delayl neckdelay (+ bridgerefl veldiff)))
+	   (set! bridgeout (delayl bridgedelay (+ nutrefl veldiff)))
+	   (let ((result (* amplitude 10.0 filt-output)))
+	     (if (= ctr release)
+		 (begin
+		   (set! bowing #f)
+		   (set! attackrate .0005)))
+	     (set! ctr (+ ctr 1))
+	     (outa i result))))))))
 
 
 (definstrument (brass beg dur freq amplitude maxa)
@@ -179,27 +176,26 @@
 	 (dout 0.0))
     (ws-interrupt?)
     (run
-     (lambda ()
-       (do ((i st (+ 1 i)))
-	   ((= i end))
-	 (if blowing
-	     (if (not (= maxpressure breathpressure))
-		 (if (< breathpressure maxpressure)
-		     (set! breathpressure (+ breathpressure attackrate))
-		     (set! breathpressure (- breathpressure attackrate))))
-	     (if (> breathpressure 0.0)
-		 (set! breathpressure (- breathpressure attackrate))))
-	 (set! dout (delaya delayline (dc-block dcblocker
-						(lip lipfilter
-						     (* 0.3 breathpressure)
-						     (* 0.9 dout)))))
-	 (let ((result (* amplitude dout)))
-	   (if (= ctr release) 
-	       (begin
-		 (set! blowing #f)
-		 (set! attackrate .0005)))
-	   (set! ctr (+ ctr 1))
-	   (outa i result)))))))
+     (do ((i st (+ 1 i)))
+	 ((= i end))
+       (if blowing
+	   (if (not (= maxpressure breathpressure))
+	       (if (< breathpressure maxpressure)
+		   (set! breathpressure (+ breathpressure attackrate))
+		   (set! breathpressure (- breathpressure attackrate))))
+	   (if (> breathpressure 0.0)
+	       (set! breathpressure (- breathpressure attackrate))))
+       (set! dout (delaya delayline (dc-block dcblocker
+					      (lip lipfilter
+						   (* 0.3 breathpressure)
+						   (* 0.9 dout)))))
+       (let ((result (* amplitude dout)))
+	 (if (= ctr release) 
+	     (begin
+	       (set! blowing #f)
+	       (set! attackrate .0005)))
+	 (set! ctr (+ ctr 1))
+	 (outa i result))))))
 
 
 (definstrument (clarinet beg dur freq amplitude maxa)
@@ -221,30 +217,29 @@
 	 (dlyout 0.0))
     (ws-interrupt?)
     (run
-     (lambda ()
-       (do ((i st (+ 1 i)))
-	   ((= i end))
-	 (let ((pressurediff 0.0))
-	   (if blowing
-	       (if (not (= maxpressure breathpressure))
-		   (if (< breathpressure maxpressure)
-		       (set! breathpressure (+ breathpressure attackrate))
-		       (set! breathpressure (- breathpressure attackrate))))
-	       (if (> breathpressure 0.0)
-		   (set! breathpressure (- breathpressure attackrate))))
-	   (set! pressurediff (- (one-zero filter (* -0.95 dlyout)) breathpressure))
-	   (set! dlyout (delayl delayline 
-				(+ breathpressure 
-				   (* pressurediff 
-				      (reedtable rtable pressurediff)))))
-	   (let ((result (* amplitude dlyout)))
-	     (if (= ctr release)
-		 (begin
-		   (set! blowing #f)
-		   (set! attackrate .0005)))
-	     (set! ctr (+ ctr 1))
-	     (outa i result))))))))
-     
+     (do ((i st (+ 1 i)))
+	 ((= i end))
+       (let ((pressurediff 0.0))
+	 (if blowing
+	     (if (not (= maxpressure breathpressure))
+		 (if (< breathpressure maxpressure)
+		     (set! breathpressure (+ breathpressure attackrate))
+		     (set! breathpressure (- breathpressure attackrate))))
+	     (if (> breathpressure 0.0)
+		 (set! breathpressure (- breathpressure attackrate))))
+	 (set! pressurediff (- (one-zero filter (* -0.95 dlyout)) breathpressure))
+	 (set! dlyout (delayl delayline 
+			      (+ breathpressure 
+				 (* pressurediff 
+				    (reedtable rtable pressurediff)))))
+	 (let ((result (* amplitude dlyout)))
+	   (if (= ctr release)
+	       (begin
+		 (set! blowing #f)
+		 (set! attackrate .0005)))
+	   (set! ctr (+ ctr 1))
+	   (outa i result)))))))
+
 
 (definstrument (flute beg dur freq amplitude maxa)
   (let* ((lowestfreq 100.0)
@@ -273,43 +268,42 @@
     (set-gain filter -1.0)
     (ws-interrupt?)
     (run
-     (lambda ()
-       (do ((i st (+ 1 i)))
-	   ((= i end))
-	 (let ((randpressure (* 0.1 breathpressure (random 1.0)))
-	       (temp 0.0) 
-	       (pressurediff 0.0))
-	   (set! sinphase (+ sinphase 0.0007))		;5 hz vibrato?
-	   (if (> sinphase 6.28) (set! sinphase (- sinphase 6.28)))
-	   (set! randpressure (+ randpressure (* 0.05 breathpressure (sin sinphase))))
-	   (if blowing
-	       (if (not (= maxpressure breathpressure))
-		   (if (< breathpressure maxpressure)
-		       (set! breathpressure (+ breathpressure attackrate))
-		       (set! breathpressure (- breathpressure attackrate))))
-	       (if (> breathpressure 0.0) 
-		   (set! breathpressure (- breathpressure attackrate))))
-	   (set! temp (dc-block dcblocker (one-pole filter boreout)))
-	   (set! pressurediff (+ (jettable 
-				  (delayl jetdelay 
-					  (+ breathpressure 
-					     (- randpressure (* jetrefl temp))))) 
-				 (* endrefl temp)))
-	   (set! boreout (delayl boredelay pressurediff))
-	   (let ((result (* 0.3 amplitude boreout)))
-	     (if (= ctr release)
-		 (begin
-		   (set! blowing #f)
-		   (set! attackrate .0005)))
-	     (set! ctr (+ ctr 1))
-	     (outa i result))))))))
+     (do ((i st (+ 1 i)))
+	 ((= i end))
+       (let ((randpressure (* 0.1 breathpressure (random 1.0)))
+	     (temp 0.0) 
+	     (pressurediff 0.0))
+	 (set! sinphase (+ sinphase 0.0007))		;5 hz vibrato?
+	 (if (> sinphase 6.28) (set! sinphase (- sinphase 6.28)))
+	 (set! randpressure (+ randpressure (* 0.05 breathpressure (sin sinphase))))
+	 (if blowing
+	     (if (not (= maxpressure breathpressure))
+		 (if (< breathpressure maxpressure)
+		     (set! breathpressure (+ breathpressure attackrate))
+		     (set! breathpressure (- breathpressure attackrate))))
+	     (if (> breathpressure 0.0) 
+		 (set! breathpressure (- breathpressure attackrate))))
+	 (set! temp (dc-block dcblocker (one-pole filter boreout)))
+	 (set! pressurediff (+ (jettable 
+				(delayl jetdelay 
+					(+ breathpressure 
+					   (- randpressure (* jetrefl temp))))) 
+			       (* endrefl temp)))
+	 (set! boreout (delayl boredelay pressurediff))
+	 (let ((result (* 0.3 amplitude boreout)))
+	   (if (= ctr release)
+	       (begin
+		 (set! blowing #f)
+		 (set! attackrate .0005)))
+	   (set! ctr (+ ctr 1))
+	   (outa i result)))))))
 
 #|
 (with-sound ()
-  (plucky 0 .3 440 .2 1.0)
-  (bowstr .5 .3 220 .2 1.0)
-  (brass 1 .3 440 .2 1.0)
-  (clarinet 1.5 .3 440 .2 1.0)
-  (flute 2 .3 440 .2 1.0))
+	    (plucky 0 .3 440 .2 1.0)
+	    (bowstr .5 .3 220 .2 1.0)
+	    (brass 1 .3 440 .2 1.0)
+	    (clarinet 1.5 .3 440 .2 1.0)
+	    (flute 2 .3 440 .2 1.0))
 |#
 
