@@ -17,9 +17,8 @@
 ;;; translated from CLM singer.ins
 
 (provide 'snd-singer.scm)
-(if (not (provided? 'snd-ws.scm)) (load-from-path "ws.scm"))
+(if (not (provided? 'snd-ws.scm)) (load "ws.scm"))
 
-(use-modules (ice-9 optargs) (ice-9 format))
 
 (definstrument (singer beg amp data)
   ;; data is a list of lists very similar to the sequence of synthesize calls in Perry's original implementation.
@@ -73,7 +72,7 @@
 			   (v (make-vct len)))
 		      (do ((i 0 (+ 1 i)))
 			  ((= i len))
-			(vct-set! v i (exact->inexact (list-ref (list-ref data i) 5))))
+			(set! (v i) (exact->inexact (list-ref (list-ref data i) 5))))
 		      v))
 	 (frq-env (make-env pfun :duration dur))
 	 (vib-env (make-env vfun :duration dur))
@@ -98,16 +97,16 @@
 	(do ((j i (+ 1 j))
 	     (m 0 (+ 1 m)))
 	    ((= m (length shp)))
-	  (vct-set! shape-data j (list-ref shp m)))))
+	  (set! (shape-data j) (list-ref shp m)))))
 	     
     (do ((k 0 (+ 1 k))
 	 (i 0 (+ i 2)))
 	((= k (length glts)))
       (let ((glt (list-ref glts k)))
-	(vct-set! glot-datai i 0.0)
-	(vct-set! glot-datai (+ 1 i) (car glt))
-	(vct-set! glot-datar i (cadr glt))
-	(vct-set! glot-datar (+ 1 i) (caddr glt))))
+	(set! (glot-datai i) 0.0)
+	(set! (glot-datai (+ 1 i)) (car glt))
+	(set! (glot-datar i) (cadr glt))
+	(set! (glot-datar (+ 1 i)) (caddr glt))))
     (let* ((table-size 1000)		; size of glottis wave-table
 	   (noseposition 3)
 	   (noselength 6)
@@ -197,353 +196,352 @@
 	   (first-tract 1)
 	   (offset -1)
 	   (bg (seconds->samples beg))
-	   (nd (inexact->exact (vct-ref change-times (- (length change-times) 1))))
+	   (nd (floor (change-times (- (length change-times) 1))))
 	   (next-offset bg)
 	   (last-sfd -1)
 	   (last-gfd -1))
       
-      (vct-set! nose-coeffs 0 0.0)
-      (vct-set! nose-coeffs 1 -0.29)
-      (vct-set! nose-coeffs 2 -0.22)
-      (vct-set! nose-coeffs 3 0.0)
-      (vct-set! nose-coeffs 4 0.24)
-      (vct-set! nose-coeffs 5 0.3571)
+      (set! (nose-coeffs 0) 0.0)
+      (set! (nose-coeffs 1) -0.29)
+      (set! (nose-coeffs 2) -0.22)
+      (set! (nose-coeffs 3) 0.0)
+      (set! (nose-coeffs 4) 0.24)
+      (set! (nose-coeffs 5) 0.3571)
 
-      (do ((i 0 (+ 1 i))) ((= i 8)) (vct-set! radii i 1.0))
-      (vct-set! radii 8 0.7)
-      (vct-set! radii 9 -0.5)
-      (do ((i 0 (+ 1 i))) ((= i 8)) (vct-set! target-radii i 1.0))
-      (vct-set! target-radii 8 0.7)
-      (vct-set! target-radii 9 -0.5)
+      (do ((i 0 (+ 1 i))) ((= i 8)) (set! (radii i) 1.0))
+      (set! (radii 8) 0.7)
+      (set! (radii 9) -0.5)
+      (do ((i 0 (+ 1 i))) ((= i 8)) (set! (target-radii i) 1.0))
+      (set! (target-radii 8) 0.7)
+      (set! (target-radii 9) -0.5)
 
-      (do ((i 0 (+ 1 i))) ((= i tractlength+8)) (vct-set! radii-poles i dpole))
-      (vct-set! radii-poles 2 tong-hump-pole)
-      (vct-set! radii-poles 3 tong-hump-pole)
-      (vct-set! radii-poles 4 tong-hump-pole)
-      (vct-set! radii-poles 5 tong-tip-pole)
+      (do ((i 0 (+ 1 i))) ((= i tractlength+8)) (set! (radii-poles i) dpole))
+      (set! (radii-poles 2) tong-hump-pole)
+      (set! (radii-poles 3) tong-hump-pole)
+      (set! (radii-poles 4) tong-hump-pole)
+      (set! (radii-poles 5) tong-tip-pole)
 
-      (do ((i 0 (+ 1 i))) ((= i tractlength+8)) (vct-set! radii-pole-gains i dgain))
-      (vct-set! radii-pole-gains 2 tong-hump-gain)
-      (vct-set! radii-pole-gains 3 tong-hump-gain)
-      (vct-set! radii-pole-gains 4 tong-hump-gain)
-      (vct-set! radii-pole-gains 5 tong-tip-gain)
+      (do ((i 0 (+ 1 i))) ((= i tractlength+8)) (set! (radii-pole-gains i) dgain))
+      (set! (radii-pole-gains 2) tong-hump-gain)
+      (set! (radii-pole-gains 3) tong-hump-gain)
+      (set! (radii-pole-gains 4) tong-hump-gain)
+      (set! (radii-pole-gains 5) tong-tip-gain)
 
       (ws-interrupt?)
       (run
-       (lambda ()
-	 (do ((i bg (+ 1 i)))
-	     ((= i nd))
-	   (if (= i next-offset)
-	       (begin
-		 ;; time to check for new tract shapes, glottal pulse shapes etc.
-		 (set! offset (+ 1 offset))
-		 (set! fnoiseamp (vct-ref noiseamps offset))
-		 (if (= last-sfd -1)
-		     (set! last-sfd 0)
-		     (let ((new-sfd (+ last-sfd 8 tractlength)))
-		       (do ((j last-sfd (+ 1 j))
-			    (k new-sfd (+ 1 k)))
-			   ((= j new-sfd))
-			 (if (> (abs (- (vct-ref shape-data j) (vct-ref shape-data k))) .001)
-			     (set! new-tract 1)))
-		       (set! last-sfd new-sfd)))
-		 (if (= last-gfd -1)
-		     (set! last-gfd 0)
-		     (let ((new-gfd (+ last-gfd 2)))
-		       (set! last-gfd new-gfd)))
-		 (set! next-offset (inexact->exact (vct-ref change-times (+ offset 1))))))
-
-	   (if (not (= new-tract 0))
-	       (begin
-		 (do ((j last-sfd (+ 1 j))
-		      (k 0 (+ 1 k)))
-		     ((= k tractlength+8))
-		   (vct-set! target-radii k (vct-ref shape-data j)))
-		 (if (= first-tract 1)
+       (do ((i bg (+ 1 i)))
+	   ((= i nd))
+	 (if (= i next-offset)
+	     (begin
+	       ;; time to check for new tract shapes, glottal pulse shapes etc.
+	       (set! offset (+ 1 offset))
+	       (set! fnoiseamp (noiseamps offset))
+	       (if (= last-sfd -1)
+		   (set! last-sfd 0)
+		   (let ((new-sfd (+ last-sfd 8 tractlength)))
+		     (do ((j last-sfd (+ 1 j))
+			  (k new-sfd (+ 1 k)))
+			 ((= j new-sfd))
+		       (if (> (abs (- (shape-data j) (shape-data k))) .001)
+			   (set! new-tract 1)))
+		     (set! last-sfd new-sfd)))
+	       (if (= last-gfd -1)
+		   (set! last-gfd 0)
+		   (let ((new-gfd (+ last-gfd 2)))
+		     (set! last-gfd new-gfd)))
+	       (set! next-offset (floor (change-times (+ offset 1))))))
+	 
+	 (if (not (= new-tract 0))
+	     (begin
+	       (do ((j last-sfd (+ 1 j))
+		    (k 0 (+ 1 k)))
+		   ((= k tractlength+8))
+		 (set! (target-radii k) (shape-data j)))
+	       (if (= first-tract 1)
+		   (begin
+		     (do ((k 0 (+ 1 k)))
+			 ((= k tractlength+8))
+		       (set! (radii k) (target-radii k)))))
+	       (set! change-radii 0)
+	       (set! initial-noise-position (radii tractlength+1))
+	       (do ((j 0 (+ 1 j)))
+		   ((= j tractlength+8))
+		 (if (> (abs (- (target-radii j) (radii j))) 0.001)
+		     (set! change-radii 1)))))
+	 
+	 (if (or (= first-tract 1) (not (= change-radii 0)))
+	     (begin
+	       (if (= new-tract 0)
+		   (begin
+		     (do ((j 0 (+ 1 j)))
+			 ((= j tractlength+8))
+		       (set! (radii j) (+ (* (radii j) (radii-poles j))
+					  (* (target-radii j) (radii-pole-gains j)))))))
+	       ;; set tract shape
+	       (set! (temp-arr 0) 1.0)
+	       (do ((j 1 (+ 1 j)))
+		   ((= j tractlength))
+		 (set! (temp-arr j) (* (radii (- j 1)) (radii (- j 1))))
+		 (if (= (temp-arr j) 0.0) 
+		     (set! (temp-arr j) 1e-10)))
+	       (do ((j 1 (+ 1 j)))
+		   ((= j tractlength))
+		 (set! (coeffs j) (/ (- (temp-arr (- j 1)) (temp-arr j))
+				     (+ (temp-arr (- j 1)) (temp-arr j)))))
+	       (set! glot-refl-gain (radii tractlength-1))
+	       (set! lip-refl-gain (radii tractlength))
+	       (set! noise-pos (floor (radii tractlength+1)))
+	       (set! noise-gain (radii (+ tractlength 2)))
+	       (let* ((temp1 (radii (+ tractlength 3)))
+		      (r (radii (+ tractlength 4)))
+		      (t2 (radii (+ tractlength 5)))
+		      (r2 (radii (+ tractlength 6)))
+		      ;; fricative noise generator (set noise angle and radius)
+		      (noise-angle (hz->radians temp1))
+		      (noise-radius r)
+		      (noise-a (* -2.0 (cos (/ noise-angle formant-shift)) noise-radius))
+		      (noise-b (* noise-radius noise-radius))
+		      (noise-angle2 (hz->radians t2))
+		      (noise-radius2 r2)
+		      (noise-a2 (* -2.0 (cos (/ noise-angle2 formant-shift)) noise-radius2))
+		      (noise-b2 (* noise-radius2 noise-radius2)))
+		 (set! (noise-c 0) (+ noise-a noise-a2))
+		 (set! (noise-c 1) (+ noise-b noise-b2 (* noise-a noise-a2)))
+		 (set! (noise-c 2) (+ (* noise-a2 noise-b) (* noise-b2 noise-a)))
+		 (set! (noise-c 3) (* noise-b2 noise-b)))
+	       (set! lip-radius (radii tractlength-2))
+	       (set! velum-pos (radii (+ tractlength 7)))
+	       (let ((leftradius (radii (- noseposition 2)))
+		     (velumradius velum-pos)
+		     (rightradius (radii (- noseposition 1))))
+		 (let ((temp1 0.0) 
+		       (temp 0.0))
+		   ;; nasal tract (set nasal shape)
+		   (set! temp (- rightradius velumradius))
+		   (if (< temp 0.0) (set! temp 0.0))
+		   (set! (alpha 1) (* leftradius leftradius))
+		   (set! (alpha 2) (* temp temp))
+		   (set! (alpha 3) (* velumradius velumradius))
+		   (set! temp1 (/ 2.0 (+ (alpha 1) (alpha 2) (alpha 3))))
+		   (set! (alpha 1) (* (alpha 1) temp1))
+		   (set! (alpha 2) (* (alpha 2) temp1))
+		   (set! (alpha 3) (* (alpha 3) temp1))))))
+	 
+	 (if (not (= new-tract 0))
+	     (begin
+	       (set! new-tract 0)
+	       (set! first-tract 0)
+	       (if (or (< s-noise 1.0) (< fnoiseamp 0.0001))
+		   (set! (target-radii tractlength+1) initial-noise-position))))
+	 (if (not (= new-glot 0))
+	     (begin
+	       (if (= first-glot 0)
+		   (begin
+		     (do ((i 0 (+ 1 i)))
+			 ((> i table-size))
+		       (set! (glot-table2 i) (glot-table i)))))
+	       (let* ((harms (floor (glot-datai (+ last-gfd 1))))
+		      (temp1 0.0)
+		      (temp 0.0)
+		      (a (glot-datar last-gfd))
+		      (b (glot-datar (+ last-gfd 1)))
+		      (a2 (* two-pi a))
+		      (b2 (* two-pi b)))
+		 (vct-fill! sines 0.0)
+		 (vct-fill! cosines 0.0)
+					;(set! (sines 1) 0.0)
+					;(set! (cosines 1) 0.0)
+		 (if (not (= b a))
 		     (begin
-		       (do ((k 0 (+ 1 k)))
-			   ((= k tractlength+8))
-			 (vct-set! radii k (vct-ref target-radii k)))))
-		 (set! change-radii 0)
-		 (set! initial-noise-position (vct-ref radii tractlength+1))
-		 (do ((j 0 (+ 1 j)))
-		     ((= j tractlength+8))
-		   (if (> (abs (- (vct-ref target-radii j) (vct-ref radii j))) 0.001)
-		       (set! change-radii 1)))))
-	   
-	   (if (or (= first-tract 1) (not (= change-radii 0)))
-	       (begin
-		 (if (= new-tract 0)
-		     (begin
-		       (do ((j 0 (+ 1 j)))
-			   ((= j tractlength+8))
-			 (vct-set! radii j (+ (* (vct-ref radii j) (vct-ref radii-poles j))
-					      (* (vct-ref target-radii j) (vct-ref radii-pole-gains j)))))))
-		 ;; set tract shape
-		 (vct-set! temp-arr 0 1.0)
-		 (do ((j 1 (+ 1 j)))
-		     ((= j tractlength))
-		   (vct-set! temp-arr j (* (vct-ref radii (- j 1)) (vct-ref radii (- j 1))))
-		   (if (= (vct-ref temp-arr j) 0.0) 
-		       (vct-set! temp-arr j 1e-10)))
-		 (do ((j 1 (+ 1 j)))
-		     ((= j tractlength))
-		   (vct-set! coeffs j (/ (- (vct-ref temp-arr (- j 1)) (vct-ref temp-arr j))
-					 (+ (vct-ref temp-arr (- j 1)) (vct-ref temp-arr j)))))
-		 (set! glot-refl-gain (vct-ref radii tractlength-1))
-		 (set! lip-refl-gain (vct-ref radii tractlength))
-		 (set! noise-pos (inexact->exact (vct-ref radii tractlength+1)))
-		 (set! noise-gain (vct-ref radii (+ tractlength 2)))
-		 (let* ((temp1 (vct-ref radii (+ tractlength 3)))
-			(r (vct-ref radii (+ tractlength 4)))
-			(t2 (vct-ref radii (+ tractlength 5)))
-			(r2 (vct-ref radii (+ tractlength 6)))
-			;; fricative noise generator (set noise angle and radius)
-			(noise-angle (hz->radians temp1))
-			(noise-radius r)
-			(noise-a (* -2.0 (cos (/ noise-angle formant-shift)) noise-radius))
-			(noise-b (* noise-radius noise-radius))
-			(noise-angle2 (hz->radians t2))
-			(noise-radius2 r2)
-			(noise-a2 (* -2.0 (cos (/ noise-angle2 formant-shift)) noise-radius2))
-			(noise-b2 (* noise-radius2 noise-radius2)))
-		   (vct-set! noise-c 0 (+ noise-a noise-a2))
-		   (vct-set! noise-c 1 (+ noise-b noise-b2 (* noise-a noise-a2)))
-		   (vct-set! noise-c 2 (+ (* noise-a2 noise-b) (* noise-b2 noise-a)))
-		   (vct-set! noise-c 3 (* noise-b2 noise-b)))
-		 (set! lip-radius (vct-ref radii tractlength-2))
-		 (set! velum-pos (vct-ref radii (+ tractlength 7)))
-		 (let ((leftradius (vct-ref radii (- noseposition 2)))
-		       (velumradius velum-pos)
-		       (rightradius (vct-ref radii (- noseposition 1))))
-		   (let ((temp1 0.0) 
-			 (temp 0.0))
-		     ;; nasal tract (set nasal shape)
-		     (set! temp (- rightradius velumradius))
-		     (if (< temp 0.0) (set! temp 0.0))
-		     (vct-set! alpha 1 (* leftradius leftradius))
-		     (vct-set! alpha 2 (* temp temp))
-		     (vct-set! alpha 3 (* velumradius velumradius))
-		     (set! temp1 (/ 2.0 (+ (vct-ref alpha 1) (vct-ref alpha 2) (vct-ref alpha 3))))
-		     (vct-set! alpha 1 (* (vct-ref alpha 1) temp1))
-		     (vct-set! alpha 2 (* (vct-ref alpha 2) temp1))
-		     (vct-set! alpha 3 (* (vct-ref alpha 3) temp1))))))
-	   
-	   (if (not (= new-tract 0))
-	       (begin
-		 (set! new-tract 0)
-		 (set! first-tract 0)
-		 (if (or (< s-noise 1.0) (< fnoiseamp 0.0001))
-		     (vct-set! target-radii tractlength+1 initial-noise-position))))
-	   (if (not (= new-glot 0))
-	       (begin
-		 (if (= first-glot 0)
-		     (begin
-		       (do ((i 0 (+ 1 i)))
-			   ((> i table-size))
-			 (vct-set! glot-table2 i (vct-ref glot-table i)))))
-		 (let* ((harms (inexact->exact (vct-ref glot-datai (+ last-gfd 1))))
-			(temp1 0.0)
-			(temp 0.0)
-			(a (vct-ref glot-datar last-gfd))
-			(b (vct-ref glot-datar (+ last-gfd 1)))
-			(a2 (* two-pi a))
-			(b2 (* two-pi b)))
-		   (vct-fill! sines 0.0)
-		   (vct-fill! cosines 0.0)
-					;(vct-set! sines 1 0.0)
-					;(vct-set! cosines 1 0.0)
+		       (set! temp (/ one-over-two-pi (- b a)))
+		       (set! temp1 (- 1.0 (cos a2)))
+		       (set! (sines 1) (* (+ (cos a2) (* (- (sin a2) (sin b2)) temp)) temp1 one-over-two-pi))
+		       (set! (cosines 1) (* (+ (- (sin a2)) (* (- (cos a2) (cos b2)) temp)) temp1 one-over-two-pi))))
+		 (set! (sines 1) (+ (sines 1) (* (+ 0.75 (- (cos a2)) (* (cos (* 2 a2)) 0.25)) one-over-two-pi)))
+		 (set! (cosines 1) (+ (cosines 1) (- (* (- (sin a2) (* (sin (* 2 a2)) 0.25)) one-over-two-pi) (* a 0.5))))
+		 (do ((k 2 (+ 1 k))
+		      (ka2 (* 2 a2) (+ ka2 a2))
+		      (ka1 a2 (+ ka1 a2))
+		      (ka3 (* 3 a2) (+ ka3 a2)))
+		     ((> k harms))
+					;(set! (sines k) 0.0)
+					;(set! (cosines k) 0.0)
 		   (if (not (= b a))
 		       (begin
-			 (set! temp (/ one-over-two-pi (- b a)))
-			 (set! temp1 (- 1.0 (cos a2)))
-			 (vct-set! sines 1 (* (+ (cos a2) (* (- (sin a2) (sin b2)) temp)) temp1 one-over-two-pi))
-			 (vct-set! cosines 1 (* (+ (- (sin a2)) (* (- (cos a2) (cos b2)) temp)) temp1 one-over-two-pi))))
-		   (vct-set! sines 1 (+ (vct-ref sines 1) (* (+ 0.75 (- (cos a2)) (* (cos (* 2 a2)) 0.25)) one-over-two-pi)))
-		   (vct-set! cosines 1 (+ (vct-ref cosines 1) (- (* (- (sin a2) (* (sin (* 2 a2)) 0.25)) one-over-two-pi) (* a 0.5))))
-		   (do ((k 2 (+ 1 k))
-			(ka2 (* 2 a2) (+ ka2 a2))
-			(ka1 a2 (+ ka1 a2))
-			(ka3 (* 3 a2) (+ ka3 a2)))
+			 (set! temp (/ one-over-two-pi (* (- b a) k)))
+			 (set! (sines k) (* (+ (cos ka2) (* (- (sin ka2) (sin (* k b2))) temp)) (/ temp1 k)))
+			 (set! (cosines k) (* (+ (- (sin ka2)) (* (- (cos ka2) (cos (* k b2))) temp)) (/ temp1 k)))))
+		   (set! (sines k) (+ (sines k) (+ (/ (- 1.0 (cos ka2)) k) (/ (* (- (cos ka1) 1.0) 0.5) (- k 1))
+						   (/ (* (- (cos ka3) 1.0) 0.5) (+ k 1)))))
+		   (set! (sines k) (* (sines k) one-over-two-pi))
+		   (set! (cosines k) (+ (cosines k) (- (/ (sin ka2) k) (/ (* (sin ka1) 0.5) (- k 1)) (/ (* (sin ka3) 0.5) (+ k 1)))))
+		   (set! (cosines k) (* (cosines k) one-over-two-pi)))
+		 (vct-fill! glot-table 0.0)
+		 (do ((j 0 (+ 1 j))
+		      (x 0.0 (+ x two-pi-over-table-size)))
+		     ((> j table-size))
+					;(set! (glot-table j) 0.0)
+		   (do ((k 1 (+ 1 k)))
 		       ((> k harms))
-					;(vct-set! sines k 0.0)
-					;(vct-set! cosines k 0.0)
-		     (if (not (= b a))
-			 (begin
-			   (set! temp (/ one-over-two-pi (* (- b a) k)))
-			   (vct-set! sines k (* (+ (cos ka2) (* (- (sin ka2) (sin (* k b2))) temp)) (/ temp1 k)))
-			   (vct-set! cosines k (* (+ (- (sin ka2)) (* (- (cos ka2) (cos (* k b2))) temp)) (/ temp1 k)))))
-		     (vct-set! sines k (+ (vct-ref sines k) (+ (/ (- 1.0 (cos ka2)) k) (/ (* (- (cos ka1) 1.0) 0.5) (- k 1))
-							       (/ (* (- (cos ka3) 1.0) 0.5) (+ k 1)))))
-		     (vct-set! sines k (* (vct-ref sines k) one-over-two-pi))
-		     (vct-set! cosines k (+ (vct-ref cosines k) (- (/ (sin ka2) k) (/ (* (sin ka1) 0.5) (- k 1)) (/ (* (sin ka3) 0.5) (+ k 1)))))
-		     (vct-set! cosines k (* (vct-ref cosines k) one-over-two-pi)))
-		   (vct-fill! glot-table 0.0)
-		   (do ((j 0 (+ 1 j))
-			(x 0.0 (+ x two-pi-over-table-size)))
-		       ((> j table-size))
-					;(vct-set! glot-table j 0.0)
-		     (do ((k 1 (+ 1 k)))
-			 ((> k harms))
-		       (vct-set! glot-table j (+ (vct-ref glot-table j) (+ (* (vct-ref cosines k) (cos (* k x)))
-									   (* (vct-ref sines k) (sin (* k x)))))))))
-		 (set! s-glot-mix 1.0)
-		 (set! delta (/ 1.0 (- next-offset i)))
-		 (if (not (= first-glot 0))
+		     (set! (glot-table j) (+ (glot-table j) (+ (* (cosines k) (cos (* k x)))
+							       (* (sines k) (sin (* k x)))))))))
+	       (set! s-glot-mix 1.0)
+	       (set! delta (/ 1.0 (- next-offset i)))
+	       (if (not (= first-glot 0))
+		   (begin
+		     (do ((i 0 (+ 1 i)))
+			 ((> i table-size))
+		       (set! (glot-table2 i) (glot-table i)))
+		     (set! first-glot 0)))
+	       (set! new-glot 0)))
+	 
+	 (set! s-glot-mix (- s-glot-mix delta))
+	 (set! s-glot (env glot-env))
+	 (set! s-noise (env noise-env))
+	 (set! pitch (env frq-env))
+	 (set! vibr-amt (env vib-env))
+	 (set! table-increment (* pitch (+ 1.0 (* vibr-amt (oscil vib-osc)) (rand-interp ran-vib)) table-size-over-sampling-rate))
+	 (set! last-lip-out (+ last-lip-in last-tract-plus))
+	 (set! last-lip-refl (* (+ last-lip-in last-tract-plus) lip-refl-gain))
+	 (set! last-lip-in last-tract-plus)
+	 ;; next glot tick
+	 (let ((table1 0.0)
+	       (table2 0.0)
+	       (int-loc 0))
+	   (set! glotsamp (* (dline2 1) glot-refl-gain))
+	   (if (not (= table-increment 0.0))
+	       (begin
+		 (set! table-location (+ table-location table-increment))
+		 (if (>= table-location table-size)
+		     (set! table-location (- table-location table-size)))
+		 (set! int-loc (floor table-location))
+		 (set! table1 (glot-table int-loc))
+		 (set! table2 (glot-table2 int-loc))
+		 (set! glotsamp (+ glotsamp (* s-glot (+ table1 (* s-glot-mix (- table2 table1))))))
+		 ;; glot noise tick
+		 (if (and (not (= (gn-table int-loc) 0.0))
+			  (not (= gn-gain 0.0)))
 		     (begin
-		       (do ((i 0 (+ 1 i)))
-			   ((> i table-size))
-			 (vct-set! glot-table2 i (vct-ref glot-table i)))
-		       (set! first-glot 0)))
-		 (set! new-glot 0)))
-	   
-	   (set! s-glot-mix (- s-glot-mix delta))
-	   (set! s-glot (env glot-env))
-	   (set! s-noise (env noise-env))
-	   (set! pitch (env frq-env))
-	   (set! vibr-amt (env vib-env))
-	   (set! table-increment (* pitch (+ 1.0 (* vibr-amt (oscil vib-osc)) (rand-interp ran-vib)) table-size-over-sampling-rate))
-	   (set! last-lip-out (+ last-lip-in last-tract-plus))
-	   (set! last-lip-refl (* (+ last-lip-in last-tract-plus) lip-refl-gain))
-	   (set! last-lip-in last-tract-plus)
-	   ;; next glot tick
-	   (let ((table1 0.0)
-		 (table2 0.0)
-		 (int-loc 0))
-	     (set! glotsamp (* (vct-ref dline2 1) glot-refl-gain))
-	     (if (not (= table-increment 0.0))
-		 (begin
-		   (set! table-location (+ table-location table-increment))
-		   (if (>= table-location table-size)
-		       (set! table-location (- table-location table-size)))
-		   (set! int-loc (inexact->exact (floor table-location)))
-		   (set! table1 (vct-ref glot-table int-loc))
-		   (set! table2 (vct-ref glot-table2 int-loc))
-		   (set! glotsamp (+ glotsamp (* s-glot (+ table1 (* s-glot-mix (- table2 table1))))))
-		   ;; glot noise tick
-		   (if (and (not (= (vct-ref gn-table int-loc) 0.0))
-			    (not (= gn-gain 0.0)))
-		       (begin
-			 (set! gn-out (- (* gn-gain s-glot (- 1.0 (random 2.0))) ;guessing here about random()
-					 (* (vct-ref gn-coeffs 3) (vct-ref gn-del 3)) 
-					 (* (vct-ref gn-coeffs 2) (vct-ref gn-del 2))
-					 (* (vct-ref gn-coeffs 1) (vct-ref gn-del 1))
-					 (* (vct-ref gn-coeffs 0) (vct-ref gn-del 0))))
-			 (do ((j 3 (- j 1))
-			      (k 2 (- k 1)))
-			     ((< j 1))
-			   (vct-set! gn-del j (vct-ref gn-del k)))
-			 (vct-set! gn-del 0 gn-out)))
-		   (set! glotsamp (+ glotsamp (* gn-out (vct-ref gn-table int-loc)))))))
-	   
-	   ;; next tract tick
-	   (let ((j 0)
-		 (temp1 0.0)
-		 (temp 0.0))
-	     (vct-set! lt 0 (+ (vct-ref dline1 2) (vct-ref dline2 2)))
-	     (vct-set! dline2 1 (+ (vct-ref dline2 2) (* (vct-ref coeffs 1) (- glotsamp (vct-ref dline2 2)))))
-	     (set! temp (+ glotsamp (- (vct-ref dline2 1) (vct-ref dline2 2))))
-	     (do ((j 2 (+ 1 j)))
-		 ((= j noseposition))
-	       (vct-set! dline2 j (+ (vct-ref dline2 (+ j 1)) (* (vct-ref coeffs j) (- (vct-ref dline1 (- j 1)) (vct-ref dline2 (+ j 1))))))
-	       (set! temp1 temp)
-	       (set! temp (+ (vct-ref dline1 (- j 1)) (- (vct-ref dline2 j) (vct-ref dline2 (+ j 1)))))
-	       (vct-set! dline1 (- j 1) temp1))
-	     (set! j noseposition)	;added
-	     ;;next nasal tick
-	     (let ((plussamp (vct-ref dline1 (- j 1)))
-		   (minussamp (vct-ref dline2 (+ j 1)))
-		   (nose-reftemp 0.0))
-	       (if (and (= velum-pos 0.0)
-			(>= time-nose-closed nose-ring-time))
-		   (begin
-		     (set! nose-reftemp (+ (* (vct-ref alpha 1) plussamp) (* (vct-ref alpha 2) minussamp) (* (vct-ref alpha 3) (vct-ref nose2 1))))
-		     (set! nose-last-minus-refl (- nose-reftemp plussamp))
-		     (set! nose-last-plus-refl (- nose-reftemp minussamp)))
-		   (begin
-		     (if (not (= velum-pos 0.0))
-			 (set! time-nose-closed 0)
-			 (set! time-nose-closed (+ time-nose-closed)))
-		     ;; nasal tick
-		     (let* ((nose-t1 0.0)
-			    (nose-temp 0.0)
-			    (nose-reftemp (+ (* (vct-ref alpha 1) plussamp) (* (vct-ref alpha 2) minussamp) (* (vct-ref alpha 3) (vct-ref nose2 1))))
-			    (plus-in (* velum-pos (- nose-reftemp (vct-ref nose2 1)))))
-		       (set! nose-last-minus-refl (- nose-reftemp plussamp))
-		       (set! nose-last-plus-refl (- nose-reftemp minussamp))
-		       (set! nose-reftemp (* (vct-ref nose-coeffs 1) (- plus-in (vct-ref nose2 2))))
-		       (vct-set! nose2 1 (+ (vct-ref nose2 2) nose-reftemp))
-		       (set! nose-temp (+ plus-in nose-reftemp))
-		       (do ((j 2 (+ 1 j)))
-			   ((= j noselength-1))
-			 (set! nose-reftemp (* (vct-ref nose-coeffs j) (- (vct-ref nose1 (- j 1)) (vct-ref nose2 (+ j 1)))))
-			 (vct-set! nose2 j (+ (vct-ref nose2 (+ j 1)) nose-reftemp))
-			 (set! nose-t1 nose-temp)
-			 (set! nose-temp (+ (vct-ref nose1 (- j 1)) nose-reftemp))
-			 (vct-set! nose1 (- j 1) nose-t1))
-		       (set! nose-reftemp (* (vct-ref nose-coeffs noselength-1)
-					     (- (vct-ref nose1 noselength-2) (* nose-last-output 0.25))))
-		       (vct-set! nose2 noselength-1 (+ (* nose-last-output 0.25) nose-reftemp))
-		       (vct-set! nose1 noselength-1 (+ (vct-ref nose1 noselength-2) nose-reftemp))
-		       (vct-set! nose1 noselength-2 nose-temp)
-		       (set! nose-filt1 nose-filt)
-		       (set! nose-filt (vct-ref nose1 noselength-1))
-		       (set! nose-last-output (* (+ nose-filt nose-filt1) 0.5)))))
-	       (vct-set! dline2 j nose-last-minus-refl))
-	     
+		       (set! gn-out (- (* gn-gain s-glot (- 1.0 (random 2.0))) ;guessing here about random()
+				       (* (gn-coeffs 3) (gn-del 3)) 
+				       (* (gn-coeffs 2) (gn-del 2))
+				       (* (gn-coeffs 1) (gn-del 1))
+				       (* (gn-coeffs 0) (gn-del 0))))
+		       (do ((j 3 (- j 1))
+			    (k 2 (- k 1)))
+			   ((< j 1))
+			 (set! (gn-del j) (gn-del k)))
+		       (set! (gn-del 0) gn-out)))
+		 (set! glotsamp (+ glotsamp (* gn-out (gn-table int-loc)))))))
+	 
+	 ;; next tract tick
+	 (let ((j 0)
+	       (temp1 0.0)
+	       (temp 0.0))
+	   (set! (lt 0) (+ (dline1 2) (dline2 2)))
+	   (set! (dline2 1) (+ (dline2 2) (* (coeffs 1) (- glotsamp (dline2 2)))))
+	   (set! temp (+ glotsamp (- (dline2 1) (dline2 2))))
+	   (do ((j 2 (+ 1 j)))
+	       ((= j noseposition))
+	     (set! (dline2 j) (+ (dline2 (+ j 1)) (* (coeffs j) (- (dline1 (- j 1)) (dline2 (+ j 1))))))
 	     (set! temp1 temp)
-	     (set! temp nose-last-plus-refl)
-	     (vct-set! dline1 (- j 1) temp1)
-	     (do ((j (+ noseposition 1) (+ 1 j)))
-		 ((= j tractlength-1))
-	       (vct-set! dline2 j (+ (vct-ref dline2 (+ j 1)) (* (vct-ref coeffs j) (- (vct-ref dline1 (- j 1)) (vct-ref dline2 (+ j 1))))))
-	       (set! temp1 temp)
-	       (set! temp (+ (vct-ref dline1 (- j 1)) (- (vct-ref dline2 j) (vct-ref dline2 (+ j 1)))))
-	       (vct-set! dline1 (- j 1) temp1))
-	     (vct-set! dline2 tractlength-1 (+ last-lip-refl (* (vct-ref coeffs tractlength-1) 
-								(- (vct-ref dline1 tractlength-2) last-lip-refl))))
-	     (vct-set! dline1 tractlength-1 (+ (vct-ref dline1 tractlength-2) 
-					       (- (vct-ref dline2 tractlength-1) last-lip-refl)))
-	     (vct-set! dline1 tractlength-2 temp)
-	     (if (not (= noise-gain 0.0))
+	     (set! temp (+ (dline1 (- j 1)) (- (dline2 j) (dline2 (+ j 1)))))
+	     (set! (dline1 (- j 1)) temp1))
+	   (set! j noseposition)	;added
+	   ;;next nasal tick
+	   (let ((plussamp (dline1 (- j 1)))
+		 (minussamp (dline2 (+ j 1)))
+		 (nose-reftemp 0.0))
+	     (if (and (= velum-pos 0.0)
+		      (>= time-nose-closed nose-ring-time))
 		 (begin
-		   (set! noise-input (- 1.0 (random 2.0))) ;a guess
-		   (do ((j 3 (- j 1))
-			(k 2 (- k 1)))
-		       ((< j 1))
-		     (vct-set! outz j (vct-ref outz k)))
-		   (vct-set! outz 0 noise-output)
-		   (set! noise-output (- noise-input inz2))
-		   (do ((i 0 (+ 1 i)))
-		       ((= i 4))
-		     (set! noise-output (- noise-output (* (vct-ref noise-c i) (vct-ref outz i)))))
-		   (set! inz2 inz1)
-		   (set! inz1 noise-input)
-		   (vct-set! dline1 noise-pos (+ (vct-ref dline1 noise-pos) (* noise-output noise-gain s-noise)))))
-	     (set! last-tract-plus (* (vct-ref dline1 tractlength-1) lip-radius)))
-	   (vct-set! lt 1 (* ltgain (+ (vct-ref lt 0) (* ltcoeff (vct-ref lt 1)))))
-	   (outa i (* amp (+ last-lip-out nose-last-output (vct-ref lt 1))) *output*)
-	   ))))))
+		   (set! nose-reftemp (+ (* (alpha 1) plussamp) (* (alpha 2) minussamp) (* (alpha 3) (nose2 1))))
+		   (set! nose-last-minus-refl (- nose-reftemp plussamp))
+		   (set! nose-last-plus-refl (- nose-reftemp minussamp)))
+		 (begin
+		   (if (not (= velum-pos 0.0))
+		       (set! time-nose-closed 0)
+		       (set! time-nose-closed (+ time-nose-closed)))
+		   ;; nasal tick
+		   (let* ((nose-t1 0.0)
+			  (nose-temp 0.0)
+			  (nose-reftemp (+ (* (alpha 1) plussamp) (* (alpha 2) minussamp) (* (alpha 3) (nose2 1))))
+			  (plus-in (* velum-pos (- nose-reftemp (nose2 1)))))
+		     (set! nose-last-minus-refl (- nose-reftemp plussamp))
+		     (set! nose-last-plus-refl (- nose-reftemp minussamp))
+		     (set! nose-reftemp (* (nose-coeffs 1) (- plus-in (nose2 2))))
+		     (set! (nose2 1) (+ (nose2 2) nose-reftemp))
+		     (set! nose-temp (+ plus-in nose-reftemp))
+		     (do ((j 2 (+ 1 j)))
+			 ((= j noselength-1))
+		       (set! nose-reftemp (* (nose-coeffs j) (- (nose1 (- j 1)) (nose2 (+ j 1)))))
+		       (set! (nose2 j) (+ (nose2 (+ j 1)) nose-reftemp))
+		       (set! nose-t1 nose-temp)
+		       (set! nose-temp (+ (nose1 (- j 1)) nose-reftemp))
+		       (set! (nose1 (- j 1)) nose-t1))
+		     (set! nose-reftemp (* (nose-coeffs noselength-1)
+					   (- (nose1 noselength-2) (* nose-last-output 0.25))))
+		     (set! (nose2 noselength-1) (+ (* nose-last-output 0.25) nose-reftemp))
+		     (set! (nose1 noselength-1) (+ (nose1 noselength-2) nose-reftemp))
+		     (set! (nose1 noselength-2) nose-temp)
+		     (set! nose-filt1 nose-filt)
+		     (set! nose-filt (nose1 noselength-1))
+		     (set! nose-last-output (* (+ nose-filt nose-filt1) 0.5)))))
+	     (set! (dline2 j) nose-last-minus-refl))
+	   
+	   (set! temp1 temp)
+	   (set! temp nose-last-plus-refl)
+	   (set! (dline1 (- j 1)) temp1)
+	   (do ((j (+ noseposition 1) (+ 1 j)))
+	       ((= j tractlength-1))
+	     (set! (dline2 j) (+ (dline2 (+ j 1)) (* (coeffs j) (- (dline1 (- j 1)) (dline2 (+ j 1))))))
+	     (set! temp1 temp)
+	     (set! temp (+ (dline1 (- j 1)) (- (dline2 j) (dline2 (+ j 1)))))
+	     (set! (dline1 (- j 1)) temp1))
+	   (set! (dline2 tractlength-1) (+ last-lip-refl (* (coeffs tractlength-1) 
+							    (- (dline1 tractlength-2) last-lip-refl))))
+	   (set! (dline1 tractlength-1) (+ (dline1 tractlength-2) 
+					   (- (dline2 tractlength-1) last-lip-refl)))
+	   (set! (dline1 tractlength-2) temp)
+	   (if (not (= noise-gain 0.0))
+	       (begin
+		 (set! noise-input (- 1.0 (random 2.0))) ;a guess
+		 (do ((j 3 (- j 1))
+		      (k 2 (- k 1)))
+		     ((< j 1))
+		   (set! (outz j) (outz k)))
+		 (set! (outz 0) noise-output)
+		 (set! noise-output (- noise-input inz2))
+		 (do ((i 0 (+ 1 i)))
+		     ((= i 4))
+		   (set! noise-output (- noise-output (* (noise-c i) (outz i)))))
+		 (set! inz2 inz1)
+		 (set! inz1 noise-input)
+		 (set! (dline1 noise-pos) (+ (dline1 noise-pos) (* noise-output noise-gain s-noise)))))
+	   (set! last-tract-plus (* (dline1 tractlength-1) lip-radius)))
+	 (set! (lt 1) (* ltgain (+ (lt 0) (* ltcoeff (lt 1)))))
+	 (outa i (* amp (+ last-lip-out nose-last-output (lt 1))) *output*)
+	 )))))
 
 #|
 (with-sound () (singer 0 .1 (list (list .4 ehh.shp test.glt 523.0 .8 0.0 .01) (list .6 oo.shp test.glt 523.0 .7 .1 .01))))
 
 (with-sound ()
-(singer 0 .1 (list (list .05 ehh.shp test.glt 523.0 0.8 0.0 .01) 
-		   (list .15 ehh.shp test.glt 523.0 0.8 0.0 .01) 
-		   (list .05 kkk.shp test.glt 523.0 0.0 0.0 .01) 
-		   (list .05 kkk.shp test.glt 523.0 0.0 0.0 .01) 
-		   (list .02 kk+.shp test.glt 523.0 0.0 1.0 .01) 
-		   (list .08 kk+.shp test.glt 523.0 0.0 0.2 .01) 
-		   (list .05 ooo.shp test.glt 523.0 0.8 0.0 .01) 
-		   (list .15 ooo.shp test.glt 523.0 0.8 0.0 .01) 
-		   (list .05 eee.shp test.glt 523.0 0.8 0.0 .01) 
-		   (list .15 eee.shp test.glt 523.0 0.8 0.0 .01) 
-		   (list .05 ehh.shp test.glt 523.0 0.8 0.0 .01) 
-		   (list .15 ehh.shp test.glt 523.0 0.8 0.0 .01) 
-		   (list .05 mmm.shp test.glt 523.0 0.8 0.0 .01) 
-		   (list .15 mmm.shp test.glt 523.0 0.8 0.0 .01) 			      
-		   (list .10 mmm.shp test.glt 523.0 0.0 0.0 .01) )))
+	    (singer 0 .1 (list (list .05 ehh.shp test.glt 523.0 0.8 0.0 .01) 
+			       (list .15 ehh.shp test.glt 523.0 0.8 0.0 .01) 
+			       (list .05 kkk.shp test.glt 523.0 0.0 0.0 .01) 
+			       (list .05 kkk.shp test.glt 523.0 0.0 0.0 .01) 
+			       (list .02 kk+.shp test.glt 523.0 0.0 1.0 .01) 
+			       (list .08 kk+.shp test.glt 523.0 0.0 0.2 .01) 
+			       (list .05 ooo.shp test.glt 523.0 0.8 0.0 .01) 
+			       (list .15 ooo.shp test.glt 523.0 0.8 0.0 .01) 
+			       (list .05 eee.shp test.glt 523.0 0.8 0.0 .01) 
+			       (list .15 eee.shp test.glt 523.0 0.8 0.0 .01) 
+			       (list .05 ehh.shp test.glt 523.0 0.8 0.0 .01) 
+			       (list .15 ehh.shp test.glt 523.0 0.8 0.0 .01) 
+			       (list .05 mmm.shp test.glt 523.0 0.8 0.0 .01) 
+			       (list .15 mmm.shp test.glt 523.0 0.8 0.0 .01) 			      
+			       (list .10 mmm.shp test.glt 523.0 0.0 0.0 .01) )))
 |#
 
 (define test.glt (list 10 .65 .65))
