@@ -9,17 +9,9 @@
   #undef _
 #endif
 
-#if ENABLE_NLS && HAVE_GETTEXT
-  #include "gettext.h"
-  #define _(String) gettext (String)
-  #define gettext_noop(String) String
-  #define N_(String) gettext_noop (String)
-#else
 #define _(String) ((char *)(String))
-  #define N_(String) String
-  #define textdomain(Domain)
-  #define bindtextdomain(Package, Directory)
-#endif
+#define N_(String) String
+/* these are leftover from NLS */
 
 #if (!HAVE_FAM)
   #define FAMRequest int
@@ -61,13 +53,6 @@
 #define POINT_BUFFER_SIZE 8192
 
 #define FILE_BUFFER_SIZE 8192
-/* this shouldn't be too much larger than the average un-peak-env'd time domain window size:
- *   as a read crosses the in-core boundary, it jumps ahead to the next windowful (everything
- *   goes through read_sample, and it doesn't have local knowledge of the caller's intentions).
- *   But that means a subsequent redisplay (normally upon mouse release) has to jump back to
- *   ax->losamp, so at worst each crossing can cost us 1/4 or thereabouts of FILE_BUFFER_SIZE
- *   extra samples read. Not a big deal, but...
- */
 #define MAX_BUFFER_SIZE 65536
 #define MIX_FILE_BUFFER_SIZE 2048
 #define PRINT_BUFFER_SIZE 512
@@ -642,6 +627,14 @@ typedef enum {NO_REQUESTOR, FROM_UPDATE, FROM_VIEW_FILES, FROM_DRAG_AND_DROP, FR
 #define in_set_verbose_cursor(a) ss->Verbose_Cursor = a
 #define DEFAULT_VERBOSE_CURSOR false
 
+#define with_inset_graph(ss) ss->With_Inset_Graph
+#define set_with_inset_graph(a) ss->With_Inset_Graph = a
+#define DEFAULT_WITH_INSET_GRAPH false
+
+#define with_pointer_focus(ss) ss->With_Pointer_Focus
+#define set_with_pointer_focus(a) ss->With_Pointer_Focus = a
+#define DEFAULT_WITH_POINTER_FOCUS false
+
 #define selection_creates_region(ss) ss->Selection_Creates_Region
 #define set_selection_creates_region(a) ss->Selection_Creates_Region = a
 #define DEFAULT_SELECTION_CREATES_REGION true
@@ -706,6 +699,12 @@ typedef enum {NO_REQUESTOR, FROM_UPDATE, FROM_VIEW_FILES, FROM_DRAG_AND_DROP, FR
   #define DEFAULT_LADSPA_DIR NULL
 #endif
 
+#define peak_env_dir(ss) ss->Peak_Env_Dir
+#define set_peak_env_dir(a) ss->Peak_Env_Dir = a
+#ifndef DEFAULT_PEAK_ENV_DIR
+  #define DEFAULT_PEAK_ENV_DIR NULL
+#endif
+
 #define open_file_dialog_directory(ss) ss->Open_File_Dialog_Directory
 #define set_open_file_dialog_directory(a) ss->Open_File_Dialog_Directory = a
 
