@@ -15,6 +15,7 @@ chan_info *make_chan_info(chan_info *cip, int chan, snd_info *sound)
       cp->last_sonogram = NULL;
       cp->last_wavogram = NULL;
       cp->temp_sonogram = NULL;
+      cp->inset_graph = NULL;
 #if HAVE_GL
       cp->gl_fft_list = NO_LIST;
       cp->gl_wavo_list = NO_LIST;
@@ -121,6 +122,8 @@ chan_info *make_chan_info(chan_info *cip, int chan, snd_info *sound)
       free(cp->last_wavogram); 
       cp->last_wavogram = NULL;
     }
+  if (cp->inset_graph)
+    clear_inset_graph(cp);
   cp->active = CHANNEL_INITIALIZED;
   return(cp);
 }
@@ -129,6 +132,7 @@ chan_info *make_chan_info(chan_info *cip, int chan, snd_info *sound)
 static chan_info *free_chan_info(chan_info *cp)
 {
   /* this does not free the associated widgets -- they are merely unmanaged */
+
   cp->active = CHANNEL_INACTIVE;
   /* need an indication right away that this channel is being deleted -- during free_snd_info (close-sound),
    *   an error may occur (an edit list temp file might have vanished for example), and normally Snd
@@ -227,6 +231,9 @@ static chan_info *free_chan_info(chan_info *cp)
       cp->undo_hook = XEN_FALSE;
       cp->undo_hook_loc = NOT_A_GC_LOC;
     }
+  if (cp->inset_graph)
+    clear_inset_graph(cp);
+
   return(cp);  /* pointer is left for possible future re-use */
 }
 
@@ -496,6 +503,9 @@ snd_info *completely_free_snd_info(snd_info *sp)
 	      snd_unprotect_at(cp->properties_loc);
 	      cp->properties_loc = NOT_A_GC_LOC;
 	    }
+	  if (cp->inset_graph)
+	    free_inset_graph(cp);
+
 	  cp->active = CHANNEL_FREED;
 	  free(cp);
 	  /* it's possible to have dangling readers (snd_fd) with pointers to this channel (see note in snd-edits.c under unlist_reader) */
@@ -970,7 +980,9 @@ static int syncd_channels(int sync)
       for (i = 0; i < ss->max_sounds; i++)
 	{
 	  sp = ss->sounds[i];
-	  if ((sp) && (sp->inuse == SOUND_NORMAL) && (sp->sync == sync)) 
+	  if ((sp) && 
+	      (sp->inuse == SOUND_NORMAL) && 
+	      (sp->sync == sync)) 
 	    chans += sp->nchans;
 	}
       return(chans);
@@ -995,7 +1007,9 @@ sync_info *snd_sync(int sync)
       for (i = 0; i < ss->max_sounds; i++)
 	{
 	  sp = ss->sounds[i];
-	  if ((sp) && (sp->inuse == SOUND_NORMAL) && (sp->sync == sync))
+	  if ((sp) && 
+	      (sp->inuse == SOUND_NORMAL) && 
+	      (sp->sync == sync))
 	    for (k = 0; k < sp->nchans; k++, j++)
 	      si->cps[j] = sp->chans[k];
 	}
@@ -1022,7 +1036,7 @@ sync_info *sync_to_chan(chan_info *cp)
 {
   snd_info *sp;
   sp = cp->sound;
-  if (sp->sync)
+  if (sp->sync != 0)
     return(snd_sync(sp->sync));
   return(make_simple_sync(cp, 0));
 }
