@@ -3,6 +3,30 @@
 
 #if (!USE_NO_GUI)
 
+#if USE_MOTIF
+#define XEN_WRAP_PIXEL(Value)        XEN_LIST_2(C_STRING_TO_XEN_SYMBOL("Pixel"), C_TO_XEN_INT((int)Value))
+                                     /* not ulong here! -- messes up the equal? check */
+#define XEN_UNWRAP_PIXEL(Value)      (unsigned long)XEN_TO_C_INT(XEN_CADR(Value))
+#define XEN_PIXEL_P(Value)           (XEN_LIST_P(Value) && (XEN_LIST_LENGTH(Value) >= 2) && (XEN_SYMBOL_P(XEN_CAR(Value))) && \
+                                      (strcmp("Pixel", XEN_SYMBOL_TO_C_STRING(XEN_CAR(Value))) == 0))
+#else
+#if USE_CAIRO
+  #define XEN_WRAP_PIXEL(Value)    XEN_LIST_2(C_STRING_TO_XEN_SYMBOL("color_t"), XEN_WRAP_C_POINTER((unsigned long)Value))
+  #define XEN_UNWRAP_PIXEL(Value)  (color_t)(XEN_UNWRAP_C_POINTER(XEN_CADR(Value)))
+  #define XEN_PIXEL_P(Value)       (XEN_LIST_P(Value) && (XEN_LIST_LENGTH(Value) >= 2) && (XEN_SYMBOL_P(XEN_CAR(Value))) && \
+                                    (strcmp("color_t", XEN_SYMBOL_TO_C_STRING(XEN_CAR(Value))) == 0))
+#else
+  #define XEN_WRAP_PIXEL(Value)    XEN_LIST_2(C_STRING_TO_XEN_SYMBOL("GdkColor_"), XEN_WRAP_C_POINTER((unsigned long)Value))
+  #define XEN_UNWRAP_PIXEL(Value)  (GdkColor*)(XEN_UNWRAP_C_POINTER(XEN_CADR(Value)))
+  #define XEN_PIXEL_P(Value)       (XEN_LIST_P(Value) && (XEN_LIST_LENGTH(Value) >= 2) && (XEN_SYMBOL_P(XEN_CAR(Value))) && \
+                                    (strcmp("GdkColor_", XEN_SYMBOL_TO_C_STRING(XEN_CAR(Value))) == 0))
+#endif
+#endif
+
+/* unfortunately, we can't just make PIXEL into a C type here -- it is called
+ *   XM_PIXEL in xm.c and in that context, it assumes the layout given above.
+ */
+
 /* our "current path" */
 static point_t points[POINT_BUFFER_SIZE];
 static point_t points1[POINT_BUFFER_SIZE];
@@ -38,13 +62,16 @@ void draw_both_grf_points(int dot_size, axis_context *ax, int j, graph_style_t g
       draw_lines(ax, points, j);
       draw_lines(ax, points1, j);
       break;
+
     case GRAPH_DOTS:
       draw_points(ax, points, j, dot_size);
       draw_points(ax, points1, j, dot_size);
       break;
+
     case GRAPH_FILLED:
       fill_two_sided_polygons(ax, points, points1, j);
       break;
+
     case GRAPH_DOTS_AND_LINES:
       if (dot_size > 1)
 	{
@@ -54,6 +81,7 @@ void draw_both_grf_points(int dot_size, axis_context *ax, int j, graph_style_t g
       draw_lines(ax, points, j);
       draw_lines(ax, points1, j);
       break;
+
     case GRAPH_LOLLIPOPS:
       if (dot_size == 1)
 	{
@@ -85,17 +113,21 @@ void draw_grf_points(int dot_size, axis_context *ax, int j, axis_info *ap, mus_f
     default:
       draw_lines(ax, points, j); 
       break;
+
     case GRAPH_DOTS: 
       draw_points(ax, points, j, dot_size); 
       break;
+
     case GRAPH_FILLED: 
       fill_polygons(ax, points, j, grf_y(y0, ap)); 
       break;
+
     case GRAPH_DOTS_AND_LINES: 
       if (dot_size > 1) 
 	draw_points(ax, points, j, dot_size); 
       draw_lines(ax, points, j); 
       break;
+
     case GRAPH_LOLLIPOPS:
       gy0 = grf_y(y0, ap);
       if (dot_size == 1)
@@ -127,8 +159,10 @@ void draw_cursor(chan_info *cp)
 #endif
   axis_info *ap;
   axis_context *ax;
+
   if (!(cp->graph_time_p)) return;
   ap = cp->axis;
+
 #if USE_CAIRO
   ax = ap->ax;
   if (!ax)
@@ -139,15 +173,18 @@ void draw_cursor(chan_info *cp)
     }
   old_color = get_foreground_color(ax);
   set_foreground_color(ax, ss->sgx->cursor_color);
+
   if (ax->cr) cairo_destroy(ax->cr);
   ax->cr = gdk_cairo_create(ax->wn); /* this is needed to force the cursor to be displayed! */
   free_cursor_pix(cp);
+
   if (cp->cx > cp->cursor_size) cx0 = cp->cx - cp->cursor_size;
   if (cp->cy > cp->cursor_size) cy0 = cp->cy - cp->cursor_size;
   csize = 2 * cp->cursor_size + 1;
 #else
   ax = cursor_context(cp);
 #endif
+
   if ((cp->tracking) && (with_tracking_cursor(ss) != DONT_TRACK))
     cur = cp->tracking_cursor_style;
   else cur = cp->cursor_style;
@@ -161,12 +198,20 @@ void draw_cursor(chan_info *cp)
       draw_line(ax, cp->cx, cp->cy - cp->cursor_size, cp->cx, cp->cy + cp->cursor_size);
       draw_line(ax, cp->cx - cp->cursor_size, cp->cy, cp->cx + cp->cursor_size, cp->cy);
       break;
+
     case CURSOR_LINE:
+      if ((with_inset_graph(ss)) &&
+	  (cp->inset_graph))
+	draw_inset_line_cursor(cp, ax);
+      else
+	{
 #if USE_CAIRO
-      save_cursor_pix(cp, ax, 2, ap->y_axis_y0 - ap->y_axis_y1, cp->cx, ap->y_axis_y1);
+	  save_cursor_pix(cp, ax, 2, ap->y_axis_y0 - ap->y_axis_y1, cp->cx, ap->y_axis_y1);
 #endif
-      draw_line(ax, cp->cx, ap->y_axis_y0 - 1, cp->cx, ap->y_axis_y1);
+	  draw_line(ax, cp->cx, ap->y_axis_y0 - 1, cp->cx, ap->y_axis_y1);
+	}
       break;
+
     case CURSOR_PROC:
 #if USE_CAIRO
       /* in the cairo case, we need some info about the cursor shape, but I'll assume cursor_size is meaningful */
@@ -181,11 +226,13 @@ void draw_cursor(chan_info *cp)
 		 S_cursor_style " procedure");
       break;
     }
+
 #if USE_CAIRO
   set_foreground_color(ax, old_color);
 #endif
 }
 
+
 void erase_cursor(chan_info *cp)
 {
 #if USE_CAIRO
@@ -197,6 +244,7 @@ void erase_cursor(chan_info *cp)
 }
 
 
+/* -------------------------------------------------------------------------------- */
 
 #define AXIS_CONTEXT_ID_OK(Id) ((Id >= CHAN_GC) && (Id <= CHAN_TMPGC))
 #define AXIS_INFO_ID_OK(Id)    (Id <= (int)LISP_AXIS_INFO)
@@ -207,19 +255,19 @@ static axis_context *get_ax(chan_info *cp, int ax_id, const char *caller)
   if ((cp) && (AXIS_CONTEXT_ID_OK(ax_id)))
     return(set_context(cp, (chan_gc_t)ax_id));
   XEN_ERROR(XEN_ERROR_TYPE("no-such-graphics-context"),
-	    XEN_LIST_3(C_TO_XEN_STRING(caller),
-		       C_TO_XEN_STRING("axis: ~A, sound index: ~A (~A), chan: ~A"),
-		       XEN_LIST_4(C_TO_XEN_INT(ax_id),
-				  C_INT_TO_XEN_SOUND(cp->sound->index),
-				  C_TO_XEN_STRING(cp->sound->short_filename),
-				  C_TO_XEN_INT(cp->chan))));
+	    XEN_LIST_6(C_TO_XEN_STRING("~A: no such graphics context: ~A, sound index: ~A (~A), chan: ~A"),
+		       C_TO_XEN_STRING(caller),
+		       C_TO_XEN_INT(ax_id),
+		       C_INT_TO_XEN_SOUND(cp->sound->index),
+		       C_TO_XEN_STRING(cp->sound->short_filename),
+		       C_TO_XEN_INT(cp->chan)));
   return(NULL);
 }
 
 
 #define TO_C_AXIS_CONTEXT(Snd, Chn, Ax, Caller) \
   get_ax(get_cp(Snd, Chn, Caller), \
-	   XEN_TO_C_INT_OR_ELSE(Ax, (int)CHAN_GC),	\
+	 XEN_TO_C_INT_OR_ELSE(Ax, (int)CHAN_GC),	\
          Caller)
 
 axis_info *get_ap(chan_info *cp, axis_info_t ap_id, const char *caller)
@@ -231,15 +279,16 @@ axis_info *get_ap(chan_info *cp, axis_info_t ap_id, const char *caller)
       case TRANSFORM_AXIS_INFO: if (cp->fft) return(cp->fft->axis);            break;
       case LISP_AXIS_INFO:      if (cp->lisp_info) return(lisp_info_axis(cp)); break;
       }
+
   XEN_ERROR(XEN_ERROR_TYPE("no-such-axis"),
-	    XEN_LIST_3(C_TO_XEN_STRING(caller),
-		       ((!(cp->squelch_update)) || (!(AXIS_INFO_ID_OK(ap_id)))) ?
-		       C_TO_XEN_STRING("axis: ~A of sound ~A (~A), chan: ~A (axis should be " S_time_graph ", " S_lisp_graph ", or " S_transform_graph ")") :
-		       C_TO_XEN_STRING("axis: ~A of sound ~A (~A), chan: ~A does not exist, probably because output is squelched"),
-		       XEN_LIST_4(C_TO_XEN_INT((int)(ap_id)),
-				  C_INT_TO_XEN_SOUND(cp->sound->index),
-				  C_TO_XEN_STRING(cp->sound->short_filename),
-				  C_TO_XEN_INT(cp->chan))));
+	    XEN_LIST_6(((!(cp->squelch_update)) || (!(AXIS_INFO_ID_OK(ap_id)))) ?
+		         C_TO_XEN_STRING("~A: no such axis: ~A of sound ~A (~A), chan: ~A (axis should be " S_time_graph ", " S_lisp_graph ", or " S_transform_graph ")") :
+		         C_TO_XEN_STRING("~A: no such axis: ~A of sound ~A (~A), chan: ~A does not exist, probably because output is squelched"),
+		       C_TO_XEN_STRING(caller),
+		       C_TO_XEN_INT((int)(ap_id)),
+		       C_INT_TO_XEN_SOUND(cp->sound->index),
+		       C_TO_XEN_STRING(cp->sound->short_filename),
+		       C_TO_XEN_INT(cp->chan)));
   return(NULL);
 }
 
@@ -254,6 +303,7 @@ static XEN g_draw_line(XEN x0, XEN y0, XEN x1, XEN y1, XEN snd, XEN chn, XEN ax)
   XEN_ASSERT_TYPE(XEN_NUMBER_P(x1), x1, XEN_ARG_3, S_draw_line, "a number");
   XEN_ASSERT_TYPE(XEN_NUMBER_P(y1), y1, XEN_ARG_4, S_draw_line, "a number");
   XEN_ASSERT_TYPE(XEN_INTEGER_IF_BOUND_P(ax), ax, XEN_ARG_7, S_draw_line, "an integer such as " S_time_graph);
+
 #if USE_CAIRO
   {
     axis_context *axc;
@@ -289,6 +339,7 @@ static XEN g_draw_dot(XEN x0, XEN y0, XEN size, XEN snd, XEN chn, XEN ax)
   XEN_ASSERT_TYPE(XEN_NUMBER_P(y0), y0, XEN_ARG_2, S_draw_dot, "a number");
   XEN_ASSERT_TYPE(XEN_NUMBER_P(size), size, XEN_ARG_3, S_draw_dot, "a number");
   XEN_ASSERT_TYPE(XEN_INTEGER_IF_BOUND_P(ax), ax, XEN_ARG_6, S_draw_dot, "an integer such as " S_time_graph);
+
   draw_dot(TO_C_AXIS_CONTEXT(snd, chn, ax, S_draw_dot),
 	   XEN_TO_C_INT(x0),
 	   XEN_TO_C_INT(y0),
@@ -308,6 +359,7 @@ static XEN g_fill_rectangle(XEN x0, XEN y0, XEN width, XEN height, XEN snd, XEN
   XEN_ASSERT_TYPE(XEN_NUMBER_P(height), height, XEN_ARG_4, S_fill_rectangle, "a number");
   XEN_ASSERT_TYPE(XEN_INTEGER_IF_BOUND_P(ax), ax, XEN_ARG_7, S_fill_rectangle, "an integer such as " S_time_graph);
   XEN_ASSERT_TYPE(XEN_BOOLEAN_IF_BOUND_P(erase), erase, XEN_ARG_8, S_fill_rectangle, "a boolean");
+
   if ((XEN_BOOLEAN_P(erase)) &&
       (XEN_TRUE_P(erase)))
     erase_rectangle(get_cp(snd, chn, S_fill_rectangle),
@@ -335,6 +387,7 @@ static XEN g_draw_string(XEN text, XEN x0, XEN y0, XEN snd, XEN chn, XEN ax)
   XEN_ASSERT_TYPE(XEN_NUMBER_P(x0), x0, XEN_ARG_2, S_draw_string, "a number");
   XEN_ASSERT_TYPE(XEN_NUMBER_P(y0), y0, XEN_ARG_3, S_draw_string, "a number");
   XEN_ASSERT_TYPE(XEN_INTEGER_IF_BOUND_P(ax), ax, XEN_ARG_6, S_draw_string, "an integer such as " S_time_graph);
+
   tmp = XEN_TO_C_STRING(text);
 #if USE_MOTIF
   /* snd-xdraw to make motif draw-string act in the same way (coordinate-wise) as gtk */
@@ -355,20 +408,22 @@ static point_t *vector_to_points(XEN pts, const char *caller, int *vector_len)
 {
   int i, j, vlen = 0, len = 0;
   point_t *pack_pts;
+
   vlen = XEN_VECTOR_LENGTH(pts);
   if (vlen & 1)
     XEN_ERROR(XEN_ERROR_TYPE("bad-length"),
-	      XEN_LIST_3(C_TO_XEN_STRING(caller),
-			 C_TO_XEN_STRING("length of vector of points (~A) must be even"),
+	      XEN_LIST_3(C_TO_XEN_STRING("~A: length of vector of points (~A) must be even"),
+			 C_TO_XEN_STRING(caller),
 			 C_TO_XEN_INT(vlen)));
   if (vlen <= 0) 
     XEN_ERROR(NO_DATA,
-	      XEN_LIST_3(C_TO_XEN_STRING(caller), 
-			 C_TO_XEN_STRING("empty vector?"), 
+	      XEN_LIST_3(C_TO_XEN_STRING("~A: empty points vector? ~A"), 
+			 C_TO_XEN_STRING(caller), 
 			 pts));
   len = vlen / 2;
   (*vector_len) = len;
   pack_pts = (point_t *)calloc(len, sizeof(point_t));
+
   for (i = 0, j = 0; i < len; i++, j += 2)
     {
       pack_pts[i].x = XEN_TO_C_INT_OR_ELSE(XEN_VECTOR_REF(pts, j), 0);
@@ -386,12 +441,15 @@ static XEN g_draw_lines(XEN pts, XEN snd, XEN chn, XEN ax)
   point_t *pack_pts;
   axis_context *ax1;
   int vlen = 0;
+
   ASSERT_CHANNEL(S_draw_lines, snd, chn, 2);
   XEN_ASSERT_TYPE(XEN_VECTOR_P(pts), pts, XEN_ARG_1, S_draw_lines, "a vector");
   XEN_ASSERT_TYPE(XEN_INTEGER_IF_BOUND_P(ax), ax, XEN_ARG_4, S_draw_lines, "an integer such as " S_time_graph);
+
   ax1 = TO_C_AXIS_CONTEXT(snd, chn, ax, S_draw_lines);
   pack_pts = vector_to_points(pts, S_draw_lines, &vlen);
   draw_lines(ax1, pack_pts, vlen);
+
   free(pack_pts);
   return(pts);
 }
@@ -400,20 +458,24 @@ static XEN g_draw_lines(XEN pts, XEN snd, XEN chn, XEN ax)
 static XEN g_draw_dots(XEN pts, XEN size, XEN snd, XEN chn, XEN ax)
 {
   /* pts should be a vector of integers as (x y) pairs */
-  #define H_draw_dots "(" S_draw_dots " positions dot-size :optional snd chn (ax " S_time_graph ")): draw a vector of dots"
+  #define H_draw_dots "(" S_draw_dots " positions :optional dot-size snd chn (ax " S_time_graph ")): draw a vector of dots"
  
   point_t *pack_pts;
   axis_context *ax1;
   int vlen = 0;
+
   ASSERT_CHANNEL(S_draw_dots, snd, chn, 3);
   XEN_ASSERT_TYPE(XEN_VECTOR_P(pts), pts, XEN_ARG_1, S_draw_dots, "a vector");
+  XEN_ASSERT_TYPE(XEN_INTEGER_IF_BOUND_P(size), size, XEN_ARG_2, S_draw_dots, "an integer");
   XEN_ASSERT_TYPE(XEN_INTEGER_IF_BOUND_P(ax), ax, XEN_ARG_5, S_draw_dots, "an integer such as " S_time_graph);
+
   ax1 = TO_C_AXIS_CONTEXT(snd, chn, ax, S_draw_dots);
   pack_pts = vector_to_points(pts, S_draw_dots, &vlen);
   draw_points(ax1,
 	      pack_pts, 
 	      vlen,
 	      XEN_TO_C_INT_OR_ELSE(size, 1));
+
   free(pack_pts);
   return(pts);
 }
@@ -426,9 +488,11 @@ static XEN g_fill_polygon(XEN pts, XEN snd, XEN chn, XEN ax_id)
   point_t *pack_pts;
   axis_context *ax;
   int vlen = 0;
+
   ASSERT_CHANNEL(S_fill_polygon, snd, chn, 2);
   XEN_ASSERT_TYPE(XEN_VECTOR_P(pts), pts, XEN_ARG_1, S_fill_polygon, "a vector");
   XEN_ASSERT_TYPE(XEN_INTEGER_IF_BOUND_P(ax_id), ax_id, XEN_ARG_4, S_fill_polygon, "an integer such as " S_time_graph);
+
   ax = TO_C_AXIS_CONTEXT(snd, chn, ax_id, S_fill_polygon);
   pack_pts = vector_to_points(pts, S_fill_polygon, &vlen);
 #if USE_MOTIF
@@ -436,6 +500,7 @@ static XEN g_fill_polygon(XEN pts, XEN snd, XEN chn, XEN ax_id)
 #else
   fill_polygon_from_array(ax, pack_pts, vlen);
 #endif
+
   free(pack_pts);
   return(pts);
 }
@@ -449,12 +514,14 @@ static XEN g_make_bezier(XEN args1)
   #define H_make_bezier "(" S_make_bezier " x0 y0 x1 y1 x2 y2 x3 y3 n): return a vector of points corresponding to the bezier curve \
 defined by the 4 controlling points x0..y3; 'n' is how many points to return"
   /* XDrawBezier from cmn's glfed.c (where it was assuming PostScript coordinates) */
+
   int ax, ay, bx, by, cx, cy, i;
   float incr, val;
   int x[4];
   int y[4];
   int n = 50;
   XEN pts, args;
+
   args = XEN_COPY_ARG(args1);
   for (i = 0; i < 4; i++)
     {
@@ -464,6 +531,7 @@ defined by the 4 controlling points x0..y3; 'n' is how many points to return"
     }
   if (XEN_NOT_NULL_P(args)) 
     n = XEN_TO_C_INT(XEN_CAR(args));
+
   cx = 3 * (x[1] - x[0]);
   cy = 3 * (y[1] - y[0]);
   bx = 3 * (x[2] - x[1]) - cx;
@@ -471,9 +539,11 @@ defined by the 4 controlling points x0..y3; 'n' is how many points to return"
   ax = x[3] - (x[0] + cx + bx);
   ay = y[3] - (y[0] + cy + by);
   incr = 1.0 / (float)n;
-  pts = XEN_MAKE_VECTOR(2 * (n + 1), C_TO_XEN_INT(0));
+  pts = XEN_MAKE_VECTOR(2 * (n + 1), XEN_ZERO);
+
   XEN_VECTOR_SET(pts, 0, C_TO_XEN_INT(x[0]));
   XEN_VECTOR_SET(pts, 1, C_TO_XEN_INT(y[0]));
+
   for (i = 1, val = incr; i <= n; i++, val += incr)
     {
       XEN_VECTOR_SET(pts, i * 2, C_TO_XEN_INT((int)(x[0] + val * (cx + (val * (bx + (val * ax)))))));
@@ -488,10 +558,13 @@ static XEN g_foreground_color(XEN snd, XEN chn, XEN xax)
   #define H_foreground_color "(" S_foreground_color " :optional snd chn (ax " S_time_graph ")): current drawing color"
   chan_info *cp;
   axis_context *ax;
+
   ASSERT_CHANNEL(S_foreground_color, snd, chn, 1);
   XEN_ASSERT_TYPE(XEN_INTEGER_IF_BOUND_P(xax), xax, XEN_ARG_3, S_foreground_color, "an integer");
+
   cp = get_cp(snd, chn, S_foreground_color);
   if (!cp) return(XEN_FALSE);
+
   ax = get_ax(cp, XEN_TO_C_INT_OR_ELSE(xax, (int)CHAN_GC), S_foreground_color);
   return(XEN_WRAP_PIXEL(get_foreground_color(ax)));
 }
@@ -500,11 +573,14 @@ static XEN g_foreground_color(XEN snd, XEN chn, XEN xax)
 static XEN g_set_foreground_color(XEN color, XEN snd, XEN chn, XEN ax)
 {
   chan_info *cp;
+
   ASSERT_CHANNEL(S_setB S_foreground_color, snd, chn, 2);
   XEN_ASSERT_TYPE(XEN_PIXEL_P(color), color, XEN_ARG_1, S_setB S_foreground_color, "a color");
   XEN_ASSERT_TYPE(XEN_INTEGER_IF_BOUND_P(ax), ax, XEN_ARG_4, S_setB S_foreground_color, "an integer");
+
   cp = get_cp(snd, chn, S_setB S_foreground_color);
   if (!cp) return(XEN_FALSE);
+
   set_foreground_color(get_ax(cp, 
 			      XEN_TO_C_INT_OR_ELSE(ax, (int)CHAN_GC),
 			      S_setB S_foreground_color),
@@ -520,12 +596,14 @@ WITH_FOUR_SETTER_ARGS(g_set_foreground_color_reversed, g_set_foreground_color)
 static XEN g_set_current_font(XEN id, XEN snd, XEN chn, XEN ax_id)
 {
   axis_context *ax;
+
   ASSERT_CHANNEL(S_setB S_current_font, snd, chn, 2);
   XEN_ASSERT_TYPE(XEN_INTEGER_IF_BOUND_P(ax_id), ax_id, XEN_ARG_4, S_setB S_current_font, "an integer such as time-graph");
   XEN_ASSERT_TYPE((XEN_LIST_P(id)) &&
 		  (XEN_LIST_LENGTH(id) >= 2) &&
 		  (XEN_SYMBOL_P(XEN_CAR(id))) &&
 		  (strcmp("Font", XEN_SYMBOL_TO_C_STRING(XEN_CAR(id))) == 0), id, XEN_ARG_1, S_setB S_current_font, "a Font");
+
   ax = TO_C_AXIS_CONTEXT(snd, chn, ax_id, S_current_font);
   ax->current_font = (Font)XEN_TO_C_ULONG(XEN_CADR(id));
   XSetFont(ax->dp, ax->gc, ax->current_font);
@@ -538,10 +616,12 @@ static XEN g_current_font(XEN snd, XEN chn, XEN ax_id)
   #define H_current_font "(" S_current_font " :optional snd chn (ax " S_time_graph ")): current font id"
   axis_context *ax;
   chan_info *cp;
+
   ASSERT_CHANNEL(S_current_font, snd, chn, 1);
   XEN_ASSERT_TYPE(XEN_INTEGER_IF_BOUND_P(ax_id), ax_id, XEN_ARG_3, S_current_font, "an integer such as time-graph");
   cp = get_cp(snd, chn, S_current_font);
   if (!cp) return(XEN_FALSE);
+
   ax = get_ax(cp,
 	      XEN_TO_C_INT_OR_ELSE(ax_id, (int)CHAN_GC),
 	      S_current_font);
@@ -562,6 +642,7 @@ static XEN g_current_font(XEN snd, XEN chn, XEN ax_id)
 static XEN g_set_current_font(XEN id, XEN snd, XEN chn, XEN ax_id)
 {
   axis_context *ax;
+
   ASSERT_CHANNEL(S_setB S_current_font, snd, chn, 2);
   XEN_ASSERT_TYPE(XEN_INTEGER_IF_BOUND_P(ax_id), ax_id, XEN_ARG_4, S_setB S_current_font, "an integer such as time-graph");
   ax = TO_C_AXIS_CONTEXT(snd, chn, ax_id, S_setB S_current_font);
@@ -570,12 +651,14 @@ static XEN g_set_current_font(XEN id, XEN snd, XEN chn, XEN ax_id)
 		   (XEN_LIST_LENGTH(id) >= 2) &&
 		   (XEN_SYMBOL_P(XEN_CAR(id)))),
 		  id, XEN_ARG_1, S_setB S_current_font, "a wrapped object or a raw pointer");
+
   if (XEN_WRAPPED_C_POINTER_P(id))
     ax->current_font = (PangoFontDescription *)XEN_UNWRAP_C_POINTER(id); 
   else ax->current_font = (PangoFontDescription *)XEN_UNWRAP_C_POINTER(XEN_CADR(id));
   return(id);
 }
 
+
 static XEN g_current_font(XEN snd, XEN chn, XEN ax_id)
 {
   #define H_current_font "(" S_current_font " :optional snd chn (ax " S_time_graph ")): current font id"
@@ -735,6 +818,7 @@ void set_dialog_widget(snd_dialog_t which, widget_t wid)
     }
   sx->dialogs[sx->num_dialogs++] = wid;
   check_dialog_widget_table();
+
   if (XEN_FALSE_P(XEN_VECTOR_REF(dialog_widgets, (int)which)))
     XEN_VECTOR_SET(dialog_widgets, (int)which, 
 		   XEN_WRAP_WIDGET(wid));
@@ -760,7 +844,7 @@ static XEN g_widget_position(XEN wid)
   w = (widget_t)(XEN_UNWRAP_WIDGET(wid));
   if (!w)
     XEN_ERROR(NO_SUCH_WIDGET,
-	      XEN_LIST_2(C_TO_XEN_STRING(S_widget_position),
+	      XEN_LIST_2(C_TO_XEN_STRING(S_widget_position ": no such widget: ~A"),
 			 wid));
   return(XEN_LIST_2(C_TO_XEN_INT(widget_x(w)),
 		    C_TO_XEN_INT(widget_y(w))));
@@ -778,9 +862,8 @@ static XEN g_set_widget_position(XEN wid, XEN xy)
 			mus_iclamp(0, XEN_TO_C_INT(XEN_CAR(xy)), LOTSA_PIXELS),
 			mus_iclamp(0, XEN_TO_C_INT(XEN_CADR(xy)), LOTSA_PIXELS));
   else XEN_ERROR(NO_SUCH_WIDGET,
-		 XEN_LIST_3(C_TO_XEN_STRING(S_setB S_widget_position),
-			    wid,
-			    xy));
+		 XEN_LIST_2(C_TO_XEN_STRING(S_setB S_widget_position ": no such widget: ~A"),
+			    wid));
   return(wid);
 }
 
@@ -793,7 +876,7 @@ static XEN g_widget_size(XEN wid)
   w = (widget_t)(XEN_UNWRAP_WIDGET(wid));
   if (!w)
     XEN_ERROR(NO_SUCH_WIDGET,
-	      XEN_LIST_2(C_TO_XEN_STRING(S_widget_size),
+	      XEN_LIST_2(C_TO_XEN_STRING(S_widget_size ": no such widget: ~A"),
 			 wid));
   return(XEN_LIST_2(C_TO_XEN_INT(widget_width(w)),
 		    C_TO_XEN_INT(widget_height(w))));
@@ -811,9 +894,8 @@ static XEN g_set_widget_size(XEN wid, XEN wh)
 		    mus_iclamp(1, XEN_TO_C_INT(XEN_CAR(wh)), LOTSA_PIXELS),
 		    mus_iclamp(1, XEN_TO_C_INT(XEN_CADR(wh)), LOTSA_PIXELS));
   else XEN_ERROR(NO_SUCH_WIDGET,
-		 XEN_LIST_3(C_TO_XEN_STRING(S_setB S_widget_size),
-			    wid,
-			    wh));
+		 XEN_LIST_2(C_TO_XEN_STRING(S_setB S_widget_size ": no such widget: ~A"),
+			    wid));
   return(wid);
 }
 
@@ -822,8 +904,10 @@ static XEN g_widget_text(XEN wid)
 {
   #define H_widget_text "(" S_widget_text " wid): widget's text or label"
   widget_t w;
+
   XEN res = XEN_FALSE;
   XEN_ASSERT_TYPE(XEN_WIDGET_P(wid), wid, XEN_ONLY_ARG, S_widget_text, "a Widget");
+
   w = (widget_t)(XEN_UNWRAP_WIDGET(wid));
   if (w)
     {
@@ -876,7 +960,7 @@ static XEN g_widget_text(XEN wid)
 #endif
     }
   else XEN_ERROR(NO_SUCH_WIDGET,
-		 XEN_LIST_2(C_TO_XEN_STRING(S_widget_text),
+		 XEN_LIST_2(C_TO_XEN_STRING(S_widget_text ": no such widget: ~A"),
 			    wid));
   return(res);
 }
@@ -886,8 +970,10 @@ static XEN g_set_widget_text(XEN wid, XEN text)
 {
   widget_t w;
   const char *str = NULL;
+
   XEN_ASSERT_TYPE(XEN_WIDGET_P(wid), wid, XEN_ARG_1, S_setB S_widget_text, "a Widget");
   XEN_ASSERT_TYPE(XEN_STRING_P(text) || XEN_FALSE_P(text), text, XEN_ARG_2, S_setB S_widget_text, "a string");
+
   w = (widget_t)(XEN_UNWRAP_WIDGET(wid));
   if (w)
     {
@@ -903,9 +989,8 @@ static XEN g_set_widget_text(XEN wid, XEN text)
 #endif
     }
   else XEN_ERROR(NO_SUCH_WIDGET,
-		 XEN_LIST_3(C_TO_XEN_STRING(S_setB S_widget_text),
-			    wid,
-			    text));
+		 XEN_LIST_2(C_TO_XEN_STRING(S_setB S_widget_text ": no such widget: ~A"),
+			    wid));
   return(text);
 }
 
@@ -925,7 +1010,7 @@ static XEN g_hide_widget(XEN wid)
 #endif
     }
   else XEN_ERROR(NO_SUCH_WIDGET,
-		 XEN_LIST_2(C_TO_XEN_STRING(S_hide_widget),
+		 XEN_LIST_2(C_TO_XEN_STRING(S_hide_widget ": no such widget: ~A"),
 			    wid));
   return(wid);
 }
@@ -946,7 +1031,7 @@ static XEN g_show_widget(XEN wid)
 #endif
     }
   else XEN_ERROR(NO_SUCH_WIDGET,
-		 XEN_LIST_2(C_TO_XEN_STRING(S_show_widget),
+		 XEN_LIST_2(C_TO_XEN_STRING(S_show_widget ": no such widget: ~A"),
 			    wid));
   return(wid);
 }
@@ -961,7 +1046,7 @@ static XEN g_focus_widget(XEN wid)
   if (w)
     goto_window(w);
   else XEN_ERROR(NO_SUCH_WIDGET,
-		 XEN_LIST_2(C_TO_XEN_STRING(S_focus_widget),
+		 XEN_LIST_2(C_TO_XEN_STRING(S_focus_widget ": no such widget: ~A"),
 			    wid));
   return(wid);
 }
@@ -1623,6 +1708,7 @@ static XEN g_basic_color(void)
 
 
 #if USE_GTK
+
 static void recolor_everything_1(widget_t w, gpointer color)
 {
   if (GTK_IS_WIDGET(w)) 
@@ -1644,7 +1730,52 @@ static void recolor_everything(widget_t w, gpointer color)
   recolor_everything_1(w, color);
 #endif
 }
+
+
+static XEN g_color_to_list(XEN obj)
+{
+  #define H_color_to_list "(" S_color_to_list " obj): 'obj' rgb values as a list of floats"
+  color_info *v;
+  XEN_ASSERT_TYPE(XEN_PIXEL_P(obj), obj, XEN_ONLY_ARG, S_color_to_list, "a color"); 
+  v = XEN_UNWRAP_PIXEL(obj);
+  return(XEN_LIST_3(C_TO_XEN_DOUBLE(RGB_TO_FLOAT(v->red)),
+		    C_TO_XEN_DOUBLE(RGB_TO_FLOAT(v->green)),
+		    C_TO_XEN_DOUBLE(RGB_TO_FLOAT(v->blue))));
+}
+
+
+static XEN g_make_color(XEN r, XEN g, XEN b)
+{
+  #define H_make_color "(" S_make_color " r g b): return a color object with the indicated rgb values"
+  color_info *ccolor;
+  mus_float_t rf, gf, bf;
+
+  XEN_ASSERT_TYPE(XEN_NUMBER_P(r), r, XEN_ARG_1, S_make_color, "a number");
+  /* someday accept a list as r */
+  XEN_ASSERT_TYPE(XEN_NUMBER_P(g), g, XEN_ARG_2, S_make_color, "a number");
+  XEN_ASSERT_TYPE(XEN_NUMBER_P(b), b, XEN_ARG_3, S_make_color, "a number");
+
+  rf = check_color_range(S_make_color, r);
+  gf = check_color_range(S_make_color, g);
+  bf = check_color_range(S_make_color, b);
+#if USE_CAIRO
+  ccolor = (color_info *)calloc(1, sizeof(color_info)); /* memleak here -- need color smob + free to deal with this */
+  ccolor->red = rf;
+  ccolor->green = gf;
+  ccolor->blue = bf;
+#else
+  color_info gcolor;
+  gcolor.red = FLOAT_TO_RGB(rf);
+  gcolor.green = FLOAT_TO_RGB(gf);
+  gcolor.blue = FLOAT_TO_RGB(bf);
+  ccolor = gdk_color_copy(&gcolor);
+  gdk_rgb_find_color(gdk_colormap_get_system(), ccolor);
 #endif
+  return(XEN_WRAP_PIXEL(ccolor));
+}
+
+#endif
+
 
 
 #if USE_MOTIF
@@ -1658,6 +1789,57 @@ static void recolor_everything(widget_t w, color_t color)
 	XmChangeColor(w, ss->sgx->basic_color);
     }
 }
+
+static XEN g_color_to_list(XEN obj)
+{
+  #define H_color_to_list "(" S_color_to_list " obj): 'obj' rgb values as a list of floats"
+  Colormap cmap;
+  XColor tmp_color;
+  Display *dpy;
+
+  XEN_ASSERT_TYPE(XEN_PIXEL_P(obj), obj, XEN_ONLY_ARG, S_color_to_list, "a color"); 
+
+  dpy = XtDisplay(MAIN_SHELL(ss));
+  cmap = DefaultColormap(dpy, DefaultScreen(dpy));
+  tmp_color.flags = DoRed | DoGreen | DoBlue;
+  tmp_color.pixel = XEN_UNWRAP_PIXEL(obj);
+  XQueryColor(dpy, cmap, &tmp_color);
+  return(XEN_LIST_3(C_TO_XEN_DOUBLE(RGB_TO_FLOAT(tmp_color.red)),
+		    C_TO_XEN_DOUBLE(RGB_TO_FLOAT(tmp_color.green)),
+		    C_TO_XEN_DOUBLE(RGB_TO_FLOAT(tmp_color.blue))));
+}
+
+
+static XEN g_make_color(XEN r, XEN g, XEN b)
+{
+  #define H_make_color "(" S_make_color " r g b): return a color object with the indicated rgb values"
+  Colormap cmap;
+  XColor tmp_color;
+  Display *dpy;
+  mus_float_t rf, gf, bf;
+
+  XEN_ASSERT_TYPE(XEN_NUMBER_P(r), r, XEN_ARG_1, S_make_color, "a number");
+  /* someday accept a list as r */
+  XEN_ASSERT_TYPE(XEN_NUMBER_P(g), g, XEN_ARG_2, S_make_color, "a number");
+  XEN_ASSERT_TYPE(XEN_NUMBER_P(b), b, XEN_ARG_3, S_make_color, "a number");
+
+  rf = check_color_range(S_make_color, r);
+  gf = check_color_range(S_make_color, g);
+  bf = check_color_range(S_make_color, b);
+  dpy = XtDisplay(MAIN_SHELL(ss));
+  cmap = DefaultColormap(dpy, DefaultScreen(dpy));
+  tmp_color.flags = DoRed | DoGreen | DoBlue;
+  tmp_color.red = FLOAT_TO_RGB(rf);
+  tmp_color.green = FLOAT_TO_RGB(gf);
+  tmp_color.blue = FLOAT_TO_RGB(bf);
+
+  if ((XAllocColor(dpy, cmap, &tmp_color)) == 0)
+    XEN_ERROR(XEN_ERROR_TYPE("no-such-color"),
+	      XEN_LIST_4(C_TO_XEN_STRING(S_make_color ": can't allocate this color! (~A ~A ~A)"),
+			 r, g, b));
+
+  return(XEN_WRAP_PIXEL(tmp_color.pixel));
+}
 #endif
 
 
@@ -1688,6 +1870,38 @@ static XEN g_set_basic_color(XEN color)
 }
 
 
+static XEN g_mix_color(XEN mix_id) 
+{
+  #define H_mix_color "(" S_mix_color " :optional mix-id): color of all mix tags (if mix-id is omitted), or of mix-id's tag"
+  if (XEN_MIX_P(mix_id))
+    return(XEN_WRAP_PIXEL(mix_color_from_id(XEN_MIX_TO_C_INT(mix_id))));
+  return(XEN_WRAP_PIXEL(ss->sgx->mix_color));
+}
+
+
+static XEN g_set_mix_color(XEN color, XEN mix_id)
+{
+  XEN_ASSERT_TYPE(XEN_PIXEL_P(color), color, XEN_ARG_1, S_setB S_mix_color, "a color"); 
+  XEN_ASSERT_TYPE(XEN_MIX_P(mix_id) || XEN_NOT_BOUND_P(mix_id), mix_id, XEN_ARG_2, S_setB S_mix_color, "a mix");
+  if (XEN_MIX_P(mix_id))
+    mix_set_color_from_id(XEN_MIX_TO_C_INT(mix_id), XEN_UNWRAP_PIXEL(color));
+  else color_mixes(XEN_UNWRAP_PIXEL(color));
+  return(color);
+}
+
+WITH_TWO_SETTER_ARGS(g_set_mix_color_reversed, g_set_mix_color)
+
+
+bool foreground_color_ok(XEN color, axis_context *ax)
+{
+  if (XEN_PIXEL_P(color))
+    {
+      set_foreground_color(ax, (color_t)XEN_UNWRAP_PIXEL(color));
+      return(true);
+    }
+  return(false);
+}
+
 
 #ifdef XEN_ARGIFY_1
 XEN_ARGIFY_7(g_draw_line_w, g_draw_line)
@@ -1768,8 +1982,13 @@ XEN_NARGIFY_1(g_set_basic_color_w, g_set_basic_color)
 XEN_NARGIFY_0(g_pushed_button_color_w, g_pushed_button_color)
 XEN_NARGIFY_1(g_set_pushed_button_color_w, g_set_pushed_button_color)
 XEN_NARGIFY_1(g_color_p_w, g_color_p)
+XEN_NARGIFY_3(g_make_color_w, g_make_color)
+XEN_NARGIFY_1(g_color_to_list_w, g_color_to_list)
+XEN_ARGIFY_1(g_mix_color_w, g_mix_color)
+XEN_ARGIFY_2(g_set_mix_color_w, g_set_mix_color)
 
 #else
+
 #define g_draw_line_w g_draw_line
 #define g_draw_dot_w g_draw_dot
 #define g_draw_lines_w g_draw_lines
@@ -1848,6 +2067,10 @@ XEN_NARGIFY_1(g_color_p_w, g_color_p)
 #define g_pushed_button_color_w g_pushed_button_color
 #define g_set_pushed_button_color_w g_set_pushed_button_color
 #define g_color_p_w g_color_p
+#define g_make_color_w g_make_color
+#define g_color_to_list_w g_color_to_list
+#define g_mix_color_w g_mix_color
+#define g_set_mix_color_w g_set_mix_color
 
 #endif
 
@@ -1964,7 +2187,12 @@ void g_init_draw(void)
   XEN_DEFINE_PROCEDURE_WITH_SETTER(S_pushed_button_color, g_pushed_button_color_w, H_pushed_button_color,
 				   S_setB S_pushed_button_color, g_set_pushed_button_color_w,  0, 0, 1, 0);
 
-  XEN_DEFINE_PROCEDURE(S_color_p, g_color_p_w, 1, 0, 0, H_color_p);
+  XEN_DEFINE_PROCEDURE_WITH_REVERSED_SETTER(S_mix_color, g_mix_color_w, H_mix_color,
+					    S_setB S_mix_color, g_set_mix_color_w, g_set_mix_color_reversed, 0, 1, 1, 1);
+
+  XEN_DEFINE_PROCEDURE(S_color_p,       g_color_p_w,        1, 0, 0, H_color_p);
+  XEN_DEFINE_PROCEDURE(S_make_color,    g_make_color_w,     3, 0, 0, H_make_color);
+  XEN_DEFINE_PROCEDURE(S_color_to_list, g_color_to_list_w,  1, 0, 0, H_color_to_list);
 
 
   /* ---------------- unstable ---------------- */
@@ -1992,5 +2220,6 @@ void show_mark_triangle(chan_info *cp, int x) {}
 void erase_cursor(chan_info *cp) {}
 point_t *get_grf_points(void) {return(NULL);} 
 point_t *get_grf_points1(void) {return(NULL);}
+bool foreground_color_ok(XEN color, axis_context *ax) {return(true);}
 #endif
 
