@@ -1030,17 +1030,24 @@ void enved_show_background_waveform(axis_info *ap, axis_info *gray_ap, bool appl
   bool two_sided = false;
   axis_info *active_ap = NULL;
   chan_info *active_channel = NULL;
+
   if (!(any_selected_sound())) return;
+
   if ((!gray_ap) || (!ap)) return;
   gray_ap->x_axis_x0 = ap->x_axis_x0;
   gray_ap->x_axis_x1 = ap->x_axis_x1;
   gray_ap->y_axis_y0 = ap->y_axis_y0;
   gray_ap->y_axis_y1 = ap->y_axis_y1;
+
   active_channel = current_channel();
   if ((!active_channel) || 
-      (active_channel->active < CHANNEL_HAS_AXES)) return;
+      (active_channel->active < CHANNEL_HAS_AXES) ||
+      (active_channel->edits == NULL)) 
+    return;
+
   old_printing = active_channel->printing;
   active_channel->printing = printing;
+
   if (show_fft)
     {
       if (enved_max_fft_size < transform_size(ss)) enved_max_fft_size = transform_size(ss);
@@ -1238,6 +1245,11 @@ env *xen_to_env(XEN res)
 		      data[i + 1] = XEN_TO_C_DOUBLE(XEN_CADR(el));
 		    }
 		}
+	      else
+		{
+		  /* something is screwed up */
+		  return(NULL);
+		}
 	    }
 	  if (data)
 	    {
@@ -1349,7 +1361,7 @@ env *name_to_env(const char *str)
 {
   env *e;
   int pos;
-  if (!str) return(NULL);
+  if ((!str) || (!(*str))) return(NULL);
   pos = find_env(str);
   if (pos >= 0) return(copy_env(all_envs[pos]));
 #if HAVE_SCHEME || HAVE_FORTH
@@ -1472,10 +1484,14 @@ env *get_env(XEN e, const char *origin) /* list in e */
 
   if (len == 0)
     XEN_ERROR(NO_DATA,
-	      XEN_LIST_3(C_TO_XEN_STRING(origin), 
-			 C_TO_XEN_STRING("null env"), 
+	      XEN_LIST_3(C_TO_XEN_STRING("~A: null env, ~A"), 
+			 C_TO_XEN_STRING(origin), 
 			 e));
   new_env = xen_to_env(e);
+  if (!new_env)
+    XEN_ERROR(XEN_ERROR_TYPE("env-error"),
+	      XEN_LIST_2(C_TO_XEN_STRING("envelope break point list is screwed up: ~A"),
+			 e));
 
   for (i = 2; i < new_env->pts * 2; i += 2)
     if (new_env->data[i - 2] > new_env->data[i])
@@ -1488,7 +1504,7 @@ env *get_env(XEN e, const char *origin) /* list in e */
 	free(buf);
 	free_env(new_env);
 	XEN_ERROR(XEN_ERROR_TYPE("env-error"),
-		  XEN_LIST_3(C_TO_XEN_STRING(S_filter_channel),
+		  XEN_LIST_3(C_TO_XEN_STRING("~A, ~A"),
 			     msg,
 			     e));
       }
@@ -1518,7 +1534,7 @@ static XEN g_save_envelopes(XEN filename)
   if (!fd)
     {
       XEN_ERROR(CANNOT_SAVE,
-		XEN_LIST_3(C_TO_XEN_STRING(S_save_envelopes),
+		XEN_LIST_3(C_TO_XEN_STRING(S_save_envelopes ": can't save ~S, ~A"),
 			   filename,
 			   C_TO_XEN_STRING(snd_open_strerror())));
     }
@@ -1534,7 +1550,7 @@ static bool check_enved_hook(env *e, int pos, mus_float_t x, mus_float_t y, enve
   if (XEN_HOOKED(enved_hook))
     {
       int len = 0;
-#if HAVE_S7
+#if HAVE_SCHEME
       int gc_loc;
 #endif
       XEN result = XEN_FALSE;
@@ -1545,7 +1561,7 @@ static bool check_enved_hook(env *e, int pos, mus_float_t x, mus_float_t y, enve
        */
       procs = XEN_HOOK_PROCEDURES(enved_hook);
       env_list = env_to_xen(e);
-#if HAVE_S7
+#if HAVE_SCHEME
       gc_loc = s7_gc_protect(s7, env_list);
 #endif
 
@@ -1577,11 +1593,11 @@ static bool check_enved_hook(env *e, int pos, mus_float_t x, mus_float_t y, enve
 		e->data[i] = XEN_TO_C_DOUBLE(XEN_CAR(lst));
 	      if (XEN_NOT_NULL_P(procs))
 		{
-#if HAVE_S7
+#if HAVE_SCHEME
 		  s7_gc_unprotect_at(s7, gc_loc);
 #endif
 		  env_list = env_to_xen(e);
-#if HAVE_S7
+#if HAVE_SCHEME
 		  gc_loc = s7_gc_protect(s7, env_list);
 #endif
 	
@@ -1589,7 +1605,7 @@ static bool check_enved_hook(env *e, int pos, mus_float_t x, mus_float_t y, enve
 	      env_changed = true;
 	    }
 	}
-#if HAVE_S7
+#if HAVE_SCHEME
       s7_gc_unprotect_at(s7, gc_loc);
 #endif
     }
