@@ -94,6 +94,13 @@ typedef enum {WITH_DEFAULT_BACKGROUND, WITH_WHITE_BACKGROUND} snd_entry_bg_t;
   #define EVENT_X(Ev) (Ev)->x
   #define EVENT_Y(Ev) (Ev)->y
 #endif
+#if HAVE_GTK_SCALE_NEW
+  #define SET_CAN_FOCUS(Wid) gtk_widget_set_can_focus(Wid, true)
+  #define UNSET_CAN_FOCUS(Wid) gtk_widget_set_can_focus(Wid, false)
+#else
+  #define SET_CAN_FOCUS(Wid) GTK_WIDGET_SET_FLAGS(Wid, GTK_CAN_FOCUS)
+  #define UNSET_CAN_FOCUS(Wid) GTK_WIDGET_UNSET_FLAGS(Wid, GTK_CAN_FOCUS)
+#endif
 
 /* no accessors: */
 #define EVENT_WINDOW(Ev)      (Ev)->window
