@@ -93,8 +93,6 @@ void save_colors(FILE *Fp);
   GtkWidget *snd_as_widget(int argc, char **argv, GtkWidget *parent, void (*error_func)(const char *));
 #endif
 
-void g_init_gxmain(void);
-
 
 
 /* -------- snd-gmenu.c -------- */
@@ -169,13 +167,6 @@ int regrow_get_pos(void *ur);
 void g_init_gxregion(void);
 
 
-/* -------- snd-gxutils -------- */
-
-bool send_mozilla(const char *html_viewer, const char *url);
-void g_init_gxutils(void);
-
-
-
 /* -------- snd-gxbitmaps.c -------- */
 
 const char **mini_bomb_bits(int n);
