@@ -280,7 +280,9 @@ static void env_redisplay_1(printing_t printing)
 	  char *name = NULL;
 	  name = (char *)gtk_entry_get_text(GTK_ENTRY(textL));
 	  if (!name) name = _("noname");
-	  if (enved_wave_p(ss))
+	  if ((enved_wave_p(ss)) &&
+	      (active_channel) &&
+	      (!(active_channel->squelch_update)))
 	    {
 #if USE_CAIRO
 	      gray_ap->ax->cr = gdk_cairo_create(WIDGET_TO_WINDOW(drawer));
@@ -299,9 +301,15 @@ static void env_redisplay_1(printing_t printing)
 }
 
 
-void env_redisplay(void) {env_redisplay_1(NOT_PRINTING);}
+void env_redisplay(void) 
+{
+  env_redisplay_1(NOT_PRINTING);
+}
 
-void env_redisplay_with_print(void) {env_redisplay_1(PRINTING);}
+void env_redisplay_with_print(void) 
+{
+  env_redisplay_1(PRINTING);
+}
 
 
 void update_enved_background_waveform(chan_info *cp)
@@ -1265,7 +1273,7 @@ void set_enved_base(mus_float_t val)
 
 bool enved_dialog_is_active(void)
 {
-  return((enved_dialog) && (GTK_WIDGET_VISIBLE(enved_dialog)));
+  return((enved_dialog) && (widget_is_active(enved_dialog)));
 }
 
 
@@ -1349,7 +1357,7 @@ static XEN g_set_enved_envelope(XEN e)
   else active_env = xen_to_env(e);
   if ((!active_env) && (!(XEN_LIST_P(e))))
     XEN_ERROR(NO_SUCH_ENVELOPE,
-	      XEN_LIST_2(C_TO_XEN_STRING(S_setB S_enved_envelope),
+	      XEN_LIST_2(C_TO_XEN_STRING(S_setB S_enved_envelope ": bad envelope arg: ~A"),
 			 e));
   if (enved_dialog) 
     env_redisplay();
