@@ -17,7 +17,7 @@ static gboolean find_modify_key_press(GtkWidget *w, GdkEventKey *event, gpointer
 
 static void clear_find_error(void)
 {
-  if ((find_error_frame) && (GTK_WIDGET_VISIBLE(find_error_frame)))
+  if ((find_error_frame) && (widget_is_active(find_error_frame)))
     set_label(find_error_label, "");
   if (find_key_press_handler_id)
     {
@@ -84,7 +84,7 @@ static void edit_find_find(read_direction_t direction, GtkWidget *w, gpointer co
 	{
 	  ss->search_proc = proc;
 	  ss->search_proc_loc = snd_protect(proc);
-#if HAVE_S7
+#if HAVE_SCHEME
 	  if (optimization(ss) > 0)
 	    ss->search_tree = mus_run_form_to_ptree_1_b(XEN_PROCEDURE_SOURCE(proc));
 #endif
@@ -103,7 +103,7 @@ static void edit_find_find(read_direction_t direction, GtkWidget *w, gpointer co
 	  /* using global search_proc set by user */
 	  buf = (char *)calloc(PRINT_BUFFER_SIZE, sizeof(char));
 	  mus_snprintf(buf, PRINT_BUFFER_SIZE, _("find: %s"), temp = (char *)XEN_AS_STRING(ss->search_proc));
-#if HAVE_S7
+#if HAVE_SCHEME
 	  if (temp) free(temp);
 #endif
 	  set_label(edit_find_label, buf);
@@ -224,7 +224,7 @@ void edit_find_callback(GtkWidget *w, gpointer context)
 
 void save_find_dialog_state(FILE *fd)
 {
-  if ((edit_find_dialog) && (GTK_WIDGET_VISIBLE(edit_find_dialog)))
+  if ((edit_find_dialog) && (widget_is_active(edit_find_dialog)))
     {
       char *text = NULL;
       text = sg_get_text(edit_find_text, 0, -1);
