@@ -1667,6 +1667,7 @@ snd_info *add_sound_window(char *filename, read_only_t read_only, file_info *hdr
   sp->inuse = SOUND_NORMAL;
   sx = sp->sgx;
   sp->bomb_ctr = 0;
+  sp->write_date = file_write_date(filename); /* needed early in this process by the peak-env handlers */
   make_pixmaps();
 
   if (sx->snd_widgets == NULL)
@@ -2193,7 +2194,7 @@ void snd_info_cleanup(snd_info *sp)
 	  set_toggle_button(REVERB_RIGHT_BUTTON(sp), false, false, (void *)sp);
 	  set_toggle_button(UNITE_BUTTON(sp), false, false, (void *)sp);
 	}
-      if ((sx->dialog) && (GTK_WIDGET_VISIBLE(sx->dialog)))
+      if ((sx->dialog) && (widget_is_active(sx->dialog)))
 	gtk_widget_hide(sx->dialog);
 
       if ((sx->snd_widgets) && (SND_PANE(sp))) gtk_widget_hide(SND_PANE(sp));
@@ -2221,8 +2222,13 @@ void hide_controls(snd_info *sp)
 
 bool showing_controls(snd_info *sp)
 {
+#if defined(GTK_WIDGET_MAPPED)
   return((GTK_WIDGET_MAPPED(CONTROL_PANEL(sp))) && 
-	 (GTK_WIDGET_VISIBLE(CONTROL_PANEL(sp))));
+	 (widget_is_active(CONTROL_PANEL(sp))));
+#else
+  return((gtk_widget_get_mapped(CONTROL_PANEL(sp))) && 
+	 (gtk_widget_get_visible(CONTROL_PANEL(sp))));
+#endif
 }
 
 
