@@ -17,11 +17,8 @@
 ;;; make-pixmap
 ;;; notebook-with-top-tabs
 ;;; make-font-selector-dialog
-;;; make-color-selector-dialog
 ;;; add-main-menu-mnemonics
 
-(use-modules (ice-9 format) (ice-9 common-list))
-
 (if (not (provided? 'snd-gtk)) (snd-error "snd-gtk.scm is Gtk-specific"))
 
 
@@ -33,8 +30,8 @@
 
 (provide 'snd-snd-gtk.scm)
 
-(if (not (provided? 'snd-extensions.scm)) (load-from-path "extensions.scm"))
-(if (not (provided? 'snd-play.scm)) (load-from-path "play.scm"))
+(if (not (provided? 'snd-extensions.scm)) (load "extensions.scm"))
+(if (not (provided? 'snd-play.scm)) (load "play.scm"))
 
 (define (load-font name)
   (pango_font_description_from_string name))
@@ -103,10 +100,10 @@
       (define circle-vct-ref 
 	(lambda (v i)
 	  (if (< i 0)
-	      (vct-ref v (+ size i))
+	      (v (+ size i))
 	      (if (>= i size)
-		  (vct-ref v (- i size))
-		  (vct-ref v i)))))
+		  (v (- i size))
+		  (v i)))))
       (let* ((dm (/ damp mass))
 	     (km (/ xspring mass))
 	     (denom (+ 1.0 dm))
@@ -115,10 +112,10 @@
 	     (p3 (/ -1.0 denom)))
 	(do ((i 0 (+ 1 i)))
 	    ((= i size))
-	  (vct-set! x0 i (min (+ (* p1 (vct-ref x1 i))
-				 (* p2 (+ (circle-vct-ref x1 (- i 1)) (circle-vct-ref x1 (+ i 1))))
-				 (* p3 (vct-ref x2 i)))
-			      1000.0)))
+	  (set! (x0 i) (min (+ (* p1 (x1 i))
+			       (* p2 (+ (circle-vct-ref x1 (- i 1)) (circle-vct-ref x1 (+ i 1))))
+			       (* p3 (x2 i)))
+			    1000.0)))
 	(vct-fill! x2 0.0)
 	(vct-add! x2 x1)
 	(vct-fill! x1 0.0)
@@ -185,11 +182,11 @@
 
     (define (cairo-draw-lines cr data size)
       (cairo_set_line_width cr 4.0)
-      (cairo_move_to cr (vector-ref data 0) (vector-ref data 1))
+      (cairo_move_to cr (data 0) (data 1))
       (do ((i 1 (+ 1 i))
 	   (j 2 (+ j 2)))
 	  ((= i size))
-	(cairo_line_to cr (vector-ref data j) (vector-ref data (+ j 1))))
+	(cairo_line_to cr (data j) (data (+ j 1))))
       (cairo_stroke cr))
 
     (define (draw-graph)
@@ -210,18 +207,18 @@
 		(cairo_set_source_rgb cr 0.0 0.0 0.0)
 		(cairo_set_line_width cr 1.0)
 		(let ((x (floor ax0))
-		      (y (y->grfy (vct-ref gx0 0) diff)))
+		      (y (y->grfy (gx0 0) diff)))
 		  (cairo_move_to cr x y)
-		  (vector-set! vect 0 x)
-		  (vector-set! vect 1 y))
+		  (set! (vect 0) x)
+		  (set! (vect 1) y))
 		(do ((i 1 (+ 1 i))
 		     (j 2 (+ j 2))
 		     (xi (+ ax0 xincr) (+ xi xincr)))
 		    ((= i size))
 		  (let ((x (floor xi))
-			(y (y->grfy (vct-ref gx0 i) diff)))
-		    (vector-set! vect j x)
-		    (vector-set! vect (+ j 1) y)
+			(y (y->grfy (gx0 i) diff)))
+		    (set! (vect j) x)
+		    (set! (vect (+ j 1)) y)
 		    (cairo_line_to cr x y)))
 		(cairo_stroke cr)
 		(set! pts1 vect)
@@ -238,8 +235,8 @@
 		     (j 0 (+ j 2))
 		     (xi ax0 (+ xi xincr)))
 		    ((= i size))
-		  (vector-set! vect j (floor xi))
-		  (vector-set! vect (+ j 1) (y->grfy (vct-ref gx0 i) diff)))
+		  (set! (vect j) (floor xi))
+		  (set! (vect (+ j 1)) (y->grfy (gx0 i) diff)))
 		(if pts1 (freeGdkPoints pts1))
 		(set! pts0 (vector->GdkPoints vect))
 		(set! pts1 pts0)
@@ -273,7 +270,7 @@
       (do ((i 0 (+ 1 i)))
 	  ((= i 12))
 	(let ((val (sin (/ (* 2 pi i) 12.0))))
-	  (vct-set! gx1 (+ i (- (/ size 4) 6)) val)))
+	  (set! (gx1 (+ i (- (/ size 4) 6))) val)))
       (set! work-proc (g_idle_add tick-synthesis #f)))
     
     (define (continue-synthesis)
@@ -396,7 +393,7 @@
 
 ;;; -------- show-smpte-label
 ;;;
-;;; (show-smpte-label :optional on-or-off)
+;;; (show-smpte-label on-or-off)
 ;;;   turns on/off a label in the time-domain graph showing the current smpte frame of the leftmost sample
 
 (define smpte-frames-per-second 24.0)
@@ -727,7 +724,7 @@ Reverb-feedback sets the scaler on the feedback.
 	    ((pred (car l)) (car l))
 	    (else (find-if pred (cdr l)))))
 
-    (lambda* (:optional snd-arg)
+    (lambda* (snd-arg)
       "(show-disk-space) adds a label to the minibuffer area showing the current free space (for use with after-open-hook)"
 
       (let* ((snd (or snd-arg (selected-sound)))
@@ -799,7 +796,7 @@ Reverb-feedback sets the scaler on the feedback.
 		((= i 12))
 	      (let* ((pix (gdk_pixmap_new (GDK_DRAWABLE win) 16 16 -1))
 		     (pixwin (GDK_DRAWABLE pix)))
-		(vector-set! clock-pixmaps i pix)
+		(set! (clock-pixmaps i) pix)
 		(gdk_gc_set_foreground dgc (basic-color))
 		(gdk_draw_rectangle pixwin dgc #t 0 0 16 16)
 		(gdk_gc_set_foreground dgc white-pixel)
@@ -812,7 +809,7 @@ Reverb-feedback sets the scaler on the feedback.
 	    (gdk_gc_set_foreground dgc (data-color))
 	    (lambda (snd hour)
 	      (gdk_draw_drawable (GDK_DRAWABLE (gtk_widget_get_window (list-ref (sound-widgets snd) 8))) dgc 
-				 (GDK_DRAWABLE (vector-ref clock-pixmaps hour)) 0 0 0 4 16 16)
+				 (GDK_DRAWABLE (clock-pixmaps hour)) 0 0 0 4 16 16)
 	      #f)))))
 
 
@@ -868,7 +865,7 @@ Reverb-feedback sets the scaler on the feedback.
 
 ;;; -------- select-file --------
 ;;;
-;;; (select-file func :optional title dir filter help)
+;;; (select-file func title dir filter help)
 ;;;   starts a File Chooser Dialog, runs func if a file is selected
 ;;;
 ;;; (add-to-menu 0 "Insert File" 
@@ -1053,7 +1050,7 @@ Reverb-feedback sets the scaler on the feedback.
 	  (gdk_draw_rectangle win gc #t 0 0 width height)
 	  (gdk_gc_set_foreground gc black-pixel)
 	  (gdk_draw_arc win gc #f 0 top width width ang0 ang1)
-	  (gdk_draw_arc win gc #f 0 (1- top) width width ang0 ang1)
+	  (gdk_draw_arc win gc #f 0 (- top 1) width width ang0 ang1)
 	  (if (> width 100)
 	      (gdk_draw_arc win gc #f 0 (- top 2) width width ang0 ang1))
 	  (gdk_draw_arc win gc #f 4 (+ top 4) (- width 8) (- width 8) ang0 ang1)
@@ -1200,7 +1197,7 @@ Reverb-feedback sets the scaler on the feedback.
     (gtk_widget_show variables-dialog)
     variables-dialog))
 
-(define* (make-variable-display page-name variable-name :optional (type 'text) (range (list 0.0 1.0)))
+(define* (make-variable-display page-name variable-name (type 'text) (range (list 0.0 1.0)))
   ;; type = 'text, 'meter, 'graph, 'spectrum, 'scale
   (if (not variables-dialog) (make-variables-dialog))
   (let ((page-info (assoc page-name variables-pages)))
@@ -1388,256 +1385,6 @@ Reverb-feedback sets the scaler on the feedback.
 	)))
 
 
-;;; -------- color selector --------
-
-(define color-selector-dialog #f)
-(define color-selectors '())
-
-;; this doesn't work in the --with-cairo Snd -- needs conversion from GdkColor* to color_t
-
-(define (make-color-selector-dialog)
-  (if (not color-selector-dialog)
-      (let ((dismiss-button (gtk_button_new_with_label "Go Away"))
-	    (help-button (gtk_button_new_with_label "Help")))
-	(gtk_widget_set_name dismiss-button "quit_button")
-	(gtk_widget_set_name help-button "help_button")
-	(set! color-selector-dialog (gtk_color_selection_dialog_new "Choose a Color"))
-	(gtk_window_set_default_size (GTK_WINDOW color-selector-dialog) -1 -1)
-	(gtk_color_selection_set_has_palette (GTK_COLOR_SELECTION (gtk_color_selection_dialog_get_color_selection (GTK_COLOR_SELECTION_DIALOG color-selector-dialog))) #t)
-	(gtk_window_set_resizable (GTK_WINDOW color-selector-dialog) #t)
-	(gtk_widget_realize color-selector-dialog)
-	(g_signal_connect color-selector-dialog "delete_event" (lambda (w ev data) (gtk_widget_hide color-selector-dialog) #t) #f)
-	(gtk_box_pack_start (GTK_BOX (gtk_dialog_get_action_area (GTK_DIALOG color-selector-dialog))) dismiss-button #t #t 20)
-	(g_signal_connect dismiss-button "clicked" (lambda (w data) (gtk_widget_hide color-selector-dialog)) #f)
-	(gtk_widget_show dismiss-button)
-	(gtk_box_pack_end (GTK_BOX (gtk_dialog_get_action_area (GTK_DIALOG color-selector-dialog))) help-button #t #t 20)
-	(g_signal_connect help-button "clicked" 
-			  (lambda (w data) 
-			    (help-dialog "Choose a Color" 
-					 "choose a color, set which fields you want to use that color, and click 'ok'"))
-			  #f)
-	(gtk_widget_show help-button)
-	(let ((ok-button (.ok_button (GTK_COLOR_SELECTION_DIALOG color-selector-dialog))))
-	  (gtk_widget_set_name ok-button "doit_button")
-	  (g_signal_connect ok-button "clicked"
-			    (lambda (w d) 
-			      (let ((color (GdkColor))
-				    (new-color #f))
-				(gtk_color_selection_get_current_color 
-				 (GTK_COLOR_SELECTION (gtk_color_selection_dialog_get_color_selection (GTK_COLOR_SELECTION_DIALOG color-selector-dialog)))
-				 color)
-				(set! new-color (gdk_color_copy color))
-				(gdk_rgb_find_color (gdk_colormap_get_system) new-color)
-				(for-each 
-				 (lambda (fd)
-				   (let ((button (car fd))
-					 (func (cadr fd)))
-				     (if (gtk_toggle_button_get_active (GTK_TOGGLE_BUTTON button))
-					 (set! (func) new-color))))
-				 color-selectors)
-				(if (> (length (sounds)) 0)
-				    (begin
-				      (if (time-graph?) (update-time-graph))
-				      (if (transform-graph?) (update-transform-graph))
-				      (if (lisp-graph?) (update-lisp-graph))))))
-			    #f))
-	(let ((cancel (.cancel_button (GTK_COLOR_SELECTION_DIALOG color-selector-dialog))))
-	  (gtk_widget_set_name cancel "reset_button")
-	  (g_signal_connect cancel "clicked"
-			    (lambda (w d) 
-			      (for-each 
-			       (lambda (fd)
-				 (let ((func (cadr fd))
-				       (old-value (caddr fd)))
-				   (set! (func) old-value)))
-			       color-selectors)
-			      (if (> (length (sounds)) 0)
-				  (begin
-				    (if (time-graph?) (update-time-graph))
-				    (if (transform-graph?) (update-transform-graph))
-				    (if (lisp-graph?) (update-lisp-graph)))))
-			    #f))
-	(let ((mainform (gtk_dialog_get_content_area (GTK_DIALOG color-selector-dialog))))
-	  (let ((label (gtk_label_new "Apply color to:")))
-	    (gtk_box_pack_start (GTK_BOX mainform) label #f #f 4)
-	    (gtk_misc_set_alignment (GTK_MISC label) 0.1 0.0)
-	    (gtk_widget_show label))
-	  (let ((table (gtk_table_new 12 2 #f))
-		(row 0)
-		(column 0))
-	    (gtk_box_pack_start (GTK_BOX mainform) table #t #t 4)
-	    (gtk_widget_show table)
-	    (for-each
-	     (lambda (title func)
-	       (let* ((button (gtk_toggle_button_new_with_label (symbol->string title))))
-		 (gtk_table_attach_defaults (GTK_TABLE table) button column (+ 1 column) row (+ 1 row))
-		 (set! row (+ 1 row))
-		 (if (= row 12)
-		     (begin
-		       (set! row 0)
-		       (set! column 1)))
-		 (set! color-selectors (cons (list button func (func)) color-selectors))
-		 (gtk_widget_show button)))
-	     (list 'basic-color 'cursor-color 'data-color 'doit-button-color 'doit-again-button-color 'enved-waveform-color
-		   'filter-control-waveform-color 'graph-color 'help-button-color 'highlight-color 'listener-color
-		   'listener-text-color 'mark-color 'mix-color 'position-color 'pushed-button-color 'quit-button-color
-		   'reset-button-color 'sash-color 'selected-data-color 'selected-graph-color 'selection-color
-		   'text-focus-color 'zoom-color)
-	     (list basic-color cursor-color data-color doit-button-color doit-again-button-color enved-waveform-color
-		   filter-control-waveform-color graph-color help-button-color highlight-color listener-color
-		   listener-text-color mark-color mix-color position-color pushed-button-color quit-button-color
-		   reset-button-color sash-color selected-data-color selected-graph-color selection-color
-		   text-focus-color zoom-color))))
-	(add-to-menu 3 "Choose Color" 
-		     (lambda () 
-		       (gtk_widget_show color-selector-dialog)))
-	)))
-
-
-(define (add-main-menu-mnemonics)
-  ;; thanks to Maxim Krikun
-  (gtk_label_set_text_with_mnemonic (GTK_LABEL (gtk_bin_get_child (GTK_BIN (main-menu 0)))) "_File") 
-  (gtk_label_set_text_with_mnemonic (GTK_LABEL (gtk_bin_get_child (GTK_BIN (main-menu 1)))) "_Edit") 
-  (gtk_label_set_text_with_mnemonic (GTK_LABEL (gtk_bin_get_child (GTK_BIN (main-menu 2)))) "_View") 
-  (gtk_label_set_text_with_mnemonic (GTK_LABEL (gtk_bin_get_child (GTK_BIN (main-menu 3)))) "_Options") 
-  (gtk_label_set_text_with_mnemonic (GTK_LABEL (gtk_bin_get_child (GTK_BIN (main-menu 4)))) "_Help"))
-
-
-
-#|
-;;; this code changes the main window's cursor, based on some obsolete code in the gdk documentation
-;;;   unfortunately, it has no effect on the text widget's cursor
-
-(define* (istring :rest ints)
-  (apply string (map integer->char ints)))
-
-(define cursor-bits (istring
-  #x80 #x01 #x40 #x02 #x20 #x04 #x10 #x08 #x08 #x10 #x04 #x20
-  #x82 #x41 #x41 #x82 #x41 #x82 #x82 #x41 #x04 #x20 #x08 #x10
-  #x10 #x08 #x20 #x04 #x40 #x02 #x80 #x01))
-
-(define cursor-mask (istring
-  #x80 #x01 #xc0 #x03 #x60 #x06 #x30 #x0c #x18 #x18 #x8c #x31
-  #xc6 #x63 #x63 #xc6 #x63 #xc6 #xc6 #x63 #x8c #x31 #x18 #x18
-  #x30 #x0c #x60 #x06 #xc0 #x03 #x80 #x01))
-
-(define blue-pixel
-  (let ((tmp (GdkColor)))
-    (gdk_color_parse "blue" tmp)
-    (let ((col (gdk_color_copy tmp)))
-      (gdk_rgb_find_color (gdk_colormap_get_system) col)
-      col)))
-
-(define black-pixel
-  (let ((tmp (GdkColor)))
-    (gdk_color_parse "black" tmp)
-    (let ((col (gdk_color_copy tmp)))
-      (gdk_rgb_find_color (gdk_colormap_get_system) col)
-      col)))
-
-(let* ((listener-text (list-ref (main-widgets) 4))
-       (source (gdk_bitmap_create_from_data (GDK_DRAWABLE (car (main-widgets))) cursor-bits 16 16))
-       (mask (gdk_bitmap_create_from_data (GDK_DRAWABLE (car (main-widgets))) cursor-mask 16 16))
-       (new-cursor (gdk_cursor_new_from_pixmap (GDK_PIXMAP source) (GDK_PIXMAP mask) blue-pixel black-pixel 8 8)))
-  (gdk_window_set_cursor (car (main-widgets)) new-cursor))
-|#
-
-
-#|
-;;; this is an example of the Gtk Print dialog and cairo.
-
-(define settings #f)
-
-(define (begin-print op cntxt data)
-  (gtk_print_operation_set_n_pages (GTK_PRINT_OPERATION op) 1)
-  #f)
-
-(define (draw-page operation context page_num data)
-  (let* ((cr (gtk_print_context_get_cairo_context context))
-	 (width (round (gtk_print_context_get_width context))))
-
-    (cairo_rectangle cr 0 0 width 10)
-    (cairo_set_source_rgb cr 0.8 0.8 0.8)
-    (cairo_fill_preserve cr)
-
-    (cairo_set_source_rgb cr 0 0 0)
-    (cairo_set_line_width cr 1)
-    (cairo_stroke cr)
-
-    (let* ((layout (gtk_print_context_create_pango_layout context))
-	   (desc (pango_font_description_from_string "sans 14")))
-
-      (pango_layout_set_font_description layout desc)
-      (pango_font_description_free desc)
-
-      (pango_layout_set_text layout "nope" -1)
-      (pango_layout_set_width layout width)
-      (pango_layout_set_alignment layout PANGO_ALIGN_CENTER)
-
-      (cairo_move_to cr (/ width 2) 25)
-      (pango_cairo_show_layout cr layout)
-
-      (g_object_unref (GPOINTER layout))
-      #f)))
-
-(define (end-print op context data)
-  #f)
-
-(define (make-print-dialog)
-  (let* ((operation (gtk_print_operation_new)))
-    (if settings
-	(gtk_print_operation_set_print_settings operation settings))
-
-    (g_signal_connect (G_OBJECT operation) "begin-print" begin-print)
-    (g_signal_connect (G_OBJECT operation) "draw-page" draw-page)
-    (g_signal_connect (G_OBJECT operation) "end-print" end-print)
-
-    (let ((res (gtk_print_operation_run operation GTK_PRINT_OPERATION_ACTION_PRINT_DIALOG (GTK_WINDOW (cadr (main-widgets))))))
-      (if (= (car res) GTK_PRINT_OPERATION_RESULT_APPLY)
-	  (begin
-	    (if settings (g_object_unref (GPOINTER settings)))
-	    (set! settings (gtk_print_operation_get_print_settings operation))
-	    (g_object_ref (GPOINTER settings))))
-
-      (g_object_unref (GPOINTER operation)))))
-
-
-;;; and an example of drawing in a Snd graph:
-
-(define* (c-circles :optional (xc 5.0)  (yc 5.0) (radius 100.0) (width 2))
-  (let* ((drawer (car (channel-widgets)))
-	 (cr (gdk_cairo_create (GDK_DRAWABLE (gtk_widget_get_window drawer)))))
-
-    (let ((angle1 0)
-	  (angle2 pi))
-      (cairo_arc cr xc yc radius angle1 angle2)
-      (cairo_stroke cr)
-      (cairo_set_source_rgba cr 1 0.2 0.2 0.6)
-      (cairo_arc cr xc yc 5 0 (* 2 pi))
-      (cairo_fill cr)
-      (cairo_set_line_width cr width)
-      (cairo_arc cr xc yc radius angle1 angle1)
-      (cairo_line_to cr xc yc)
-      (cairo_arc cr xc yc radius angle2 angle2)
-      (cairo_line_to cr xc yc)
-      (cairo_stroke cr))
-
-    (cairo_destroy cr)))
-
-;;; to write out an image as a png file:
-
-  (let* ((surface (cairo_image_surface_create CAIRO_FORMAT_RGB24 width height))
-	 (cr (cairo_create surface)))
-    ;; now draw using cr
-    (cairo_surface_flush surface)
-    (cairo_surface_write_to_png surface "test.png")
-    (cairo_surface_destroy surface)
-    (cairo_destroy cr))
-
-|#
-
-
-
 #|
 ;;; this doesn't actually work yet, but the simpler C case below almost works
 (define (emacs)
