@@ -849,7 +849,7 @@ GtkWidget *snd_gtk_entry_label_new(const char *label, color_info *color)
   gtk_entry_set_has_frame(GTK_ENTRY(rlw), false);
   if (label) gtk_entry_set_text(GTK_ENTRY(rlw), label);
   gtk_editable_set_editable(GTK_EDITABLE(rlw), false);
-  GTK_WIDGET_UNSET_FLAGS(GTK_WIDGET(rlw), GTK_CAN_FOCUS); /* turn off the $%#@$! blinking cursor */
+  UNSET_CAN_FOCUS(GTK_WIDGET(rlw)); /* turn off the $%#@$! blinking cursor */
   widget_modify_base(rlw, GTK_STATE_NORMAL, color);
   widget_modify_base(rlw, GTK_STATE_ACTIVE, color);
   return(rlw);
@@ -995,7 +995,7 @@ static GtkWidget *slist_new_item(slist *lst, const char *label, int row)
   gtk_widget_set_name(item, "white_button");
   slist_set_row(item, row);
   gtk_button_set_relief(GTK_BUTTON(item), GTK_RELIEF_HALF);
-#if HAVE_GTK_BUTTON_SET_ALIGNMENT
+#if HAVE_GTK_ABOUT_DIALOG_NEW
   gtk_button_set_alignment(GTK_BUTTON(item), 0.05, 1.0);
 #endif
   gtk_box_pack_start(GTK_BOX(lst->topics), item, false, false, 0);
