@@ -241,16 +241,15 @@ static mus_float_t **make_xen_colormap(int size, XEN lambda)
       else str = XEN_FALSE;
 
       XEN_ERROR(XEN_ERROR_TYPE("colormap-error"),
-		XEN_LIST_3(C_TO_XEN_STRING(S_add_colormap),
-			   C_TO_XEN_STRING("function error:"),
+		XEN_LIST_2(C_TO_XEN_STRING(S_add_colormap ": function error ~A"),
 			   str));
     }
 
   if (!(XEN_LIST_P(xrgb)))
     XEN_ERROR(XEN_ERROR_TYPE("colormap-error"),
-	      XEN_LIST_3(C_TO_XEN_STRING(S_add_colormap),
-			 C_TO_XEN_STRING("colormap func must return a list of 3 vcts"),
-			 lambda));
+	      XEN_LIST_3(C_TO_XEN_STRING(S_add_colormap ": colormap function, ~A, returned ~A, but should return a list of 3 vcts"),
+			 lambda,
+			 xrgb));
   else
     {
       vct *xr, *xg, *xb;
@@ -261,15 +260,13 @@ static mus_float_t **make_xen_colormap(int size, XEN lambda)
 
       if (!(mus_vct_p(XEN_LIST_REF(xrgb, 0)))) 
 	XEN_ERROR(XEN_ERROR_TYPE("colormap-error"),
-		  XEN_LIST_3(C_TO_XEN_STRING(S_add_colormap),
-			     C_TO_XEN_STRING("function did not return a list of vcts!"),
+		  XEN_LIST_2(C_TO_XEN_STRING(S_add_colormap ": function did not return a list of vcts! ~A"),
 			     xrgb));
 
       xr = XEN_TO_VCT(XEN_LIST_REF(xrgb, 0));
       if (xr->length < size)
 	XEN_ERROR(XEN_ERROR_TYPE("colormap-error"),
-		  XEN_LIST_3(C_TO_XEN_STRING(S_add_colormap),
-			     C_TO_XEN_STRING("function did not return a list of vcts of the correct size"),
+		  XEN_LIST_2(C_TO_XEN_STRING(S_add_colormap ": function did not return a list of vcts of the correct size: ~A"),
 			     xrgb));
 
       xg = XEN_TO_VCT(XEN_LIST_REF(xrgb, 1));
@@ -940,7 +937,7 @@ static XEN g_xen_colormap_to_string(XEN obj)
 #endif
 
 
-#if (!HAVE_S7)
+#if (!HAVE_SCHEME)
 static bool xen_colormap_equalp(xen_colormap *v1, xen_colormap *v2) 
 {
   return((v1 == v2) ||
@@ -950,7 +947,7 @@ static bool xen_colormap_equalp(xen_colormap *v1, xen_colormap *v2)
 static XEN equalp_xen_colormap(XEN obj1, XEN obj2)
 {
   if ((!(XEN_COLORMAP_P(obj1))) || (!(XEN_COLORMAP_P(obj2)))) return(XEN_FALSE);
-  return(xen_return_first(C_TO_XEN_BOOLEAN(xen_colormap_equalp(XEN_TO_XEN_COLORMAP(obj1), XEN_TO_XEN_COLORMAP(obj2))), obj1, obj2));
+  return(C_TO_XEN_BOOLEAN(xen_colormap_equalp(XEN_TO_XEN_COLORMAP(obj1), XEN_TO_XEN_COLORMAP(obj2))));
 }
 #endif
 
@@ -977,7 +974,7 @@ static XEN new_xen_colormap(int n)
 #define C_INT_TO_XEN_COLORMAP(Val) new_xen_colormap(Val)
 
 
-#if HAVE_S7
+#if HAVE_SCHEME
 static bool s7_xen_colormap_equalp(void *obj1, void *obj2)
 {
   return((obj1 == obj2) ||
@@ -1001,7 +998,7 @@ static XEN s7_colormap_apply(s7_scheme *sc, XEN obj, XEN args)
 
 static void init_xen_colormap(void)
 {
-#if HAVE_S7
+#if HAVE_SCHEME
   xen_colormap_tag = XEN_MAKE_OBJECT_TYPE("<colormap>", print_xen_colormap, free_xen_colormap, s7_xen_colormap_equalp, 
 				       NULL, s7_colormap_apply, NULL, s7_xen_colormap_length, NULL, NULL);
 #else
@@ -1012,12 +1009,6 @@ static void init_xen_colormap(void)
 #endif
 #endif
 
-#if HAVE_GUILE
-  scm_set_smob_print(xen_colormap_tag,  print_xen_colormap);
-  scm_set_smob_free(xen_colormap_tag,   free_xen_colormap);
-  scm_set_smob_equalp(xen_colormap_tag, equalp_xen_colormap);
-#endif
-
 #if HAVE_FORTH
   fth_set_object_inspect(xen_colormap_tag,   print_xen_colormap);
   fth_set_object_dump(xen_colormap_tag,      g_xen_colormap_to_string);
@@ -1067,7 +1058,7 @@ static XEN g_colormap_ref(XEN map, XEN pos)
   index = XEN_COLORMAP_TO_C_INT(map);
   if (!(is_colormap(index)))
     XEN_ERROR(NO_SUCH_COLORMAP,
-	      XEN_LIST_2(C_TO_XEN_STRING(S_colormap_ref),
+	      XEN_LIST_2(C_TO_XEN_STRING(S_colormap_ref ": no such colormap: ~A"),
 			 map));
 
   x = XEN_TO_C_DOUBLE(pos);
@@ -1098,7 +1089,7 @@ static XEN g_set_colormap(XEN val)
   index = XEN_COLORMAP_TO_C_INT(val);
   if (!(is_colormap(index)))
     XEN_ERROR(NO_SUCH_COLORMAP,
-	      XEN_LIST_2(C_TO_XEN_STRING(S_colormap),
+	      XEN_LIST_2(C_TO_XEN_STRING(S_colormap ": no such colormap: ~A"),
 			 val));
 
   set_color_map(index); /* this normally redisplays */
@@ -1138,7 +1129,7 @@ static XEN g_colormap_name(XEN col)
   map = XEN_COLORMAP_TO_C_INT(col);
   if (!(is_colormap(map)))
     XEN_ERROR(NO_SUCH_COLORMAP,
-	      XEN_LIST_2(C_TO_XEN_STRING(S_colormap_name),
+	      XEN_LIST_2(C_TO_XEN_STRING(S_colormap_name ": no such colormap: ~A"),
 			 col));
 
   return(C_TO_XEN_STRING(cmaps[map]->name));
@@ -1163,7 +1154,7 @@ static XEN g_delete_colormap(XEN col)
   map = XEN_COLORMAP_TO_C_INT(col);
   if (!(is_colormap(map)))
     XEN_ERROR(NO_SUCH_COLORMAP,
-	      XEN_LIST_2(C_TO_XEN_STRING(S_delete_colormap),
+	      XEN_LIST_2(C_TO_XEN_STRING(S_delete_colormap ": no such colormap: ~A"),
 			 col));
 
   delete_cmap(map);
