@@ -93,7 +93,7 @@ int snd_open(const char *filename, int flags, mode_t mode)
   ss->local_errno = 0;
   ss->local_open_errno = 0;
   errno = 0;
-#if MUS_WINDOZE
+#if HAVE_WINDOZE
   result = open(filename, flags);
 #else
   result = open(filename, flags, mode);
@@ -271,11 +271,16 @@ snd_io *make_file_state(int fd, file_info *hdr, int chan, mus_long_t beg, int su
   snd_io *io;
   int bufsize;
   mus_long_t chansize;
+  #define MAX_FILE_BUFFER_SIZE 65536
+
   bufsize = suggested_bufsize;
+
   chansize = (hdr->samples / hdr->chans); /* this can be bogus if the header is messed up */
-  if ((chansize > 0) && 
-      (bufsize > chansize)) 
+  if ((chansize >= 0) && 
+      ((bufsize > chansize) ||
+       (MAX_FILE_BUFFER_SIZE > chansize)))
     bufsize = chansize + 1;
+
   io = (snd_io *)calloc(1, sizeof(snd_io)); /* only creation point */
   io->arrays = (mus_sample_t **)calloc(hdr->chans, sizeof(mus_sample_t *));
   io->fd = fd;
@@ -576,9 +581,6 @@ void forget_temp(const char *filename, int chan)
 	  return;
 	}
     }
-#if MUS_DEBUGGING
-  fprintf(stderr,"can't forget %s!\n", filename);
-#endif
 }
 
 
@@ -596,9 +598,6 @@ static void tick_temp(const char *filename, int chan)
 	  return;
 	}
     }
-#if MUS_DEBUGGING
-  fprintf(stderr, "attempt to tick unremembered temp file %s\n", filename);
-#endif
 }
 
 
@@ -705,7 +704,7 @@ snd_data *free_snd_data(snd_data *sd)
     {
       if (!(sd->inuse))
 	{
-	  /* assume the inuse cases will eventually be freed via Guile GC.
+	  /* assume the inuse cases will eventually be freed the GC.
 	   *   this can happen if a sampler is created, and forgotten,
 	   *   and the associated sound is closed.  The closing runs through
 	   *   the snd_data (sounds) list freeing the descriptors, but the
