@@ -203,7 +203,7 @@ static void execute_named_macro(chan_info *cp, char *name, mus_long_t count)
     /* not a macro...*/
     {
 #if HAVE_EXTENSION_LANGUAGE
-#if HAVE_S7
+#if HAVE_SCHEME
       XEN result = XEN_FALSE;
       int i, loc, one_edit;
       one_edit = cp->edit_ctr + 1;
@@ -269,7 +269,7 @@ int in_user_keymap(int key, int state, bool cx_extended)
 }
 
 
-#if HAVE_S7
+#if HAVE_SCHEME
   #define kbd_false 0
 #else
   #define kbd_false XEN_FALSE
@@ -288,10 +288,10 @@ static key_entry built_in_key_bindings[NUM_BUILT_IN_KEY_BINDINGS] = {
   {snd_K_less,       snd_ControlMask, 0, kbd_false, false, "move cursor to sample 0",                    NULL, -1},
   {snd_K_greater,    snd_ControlMask, 0, kbd_false, false, "move cursor to last sample",                 NULL, -1},
   {snd_K_a,          snd_ControlMask, 0, kbd_false, false, "move cursor to window start",                NULL, -1},
-  {snd_K_b,          snd_ControlMask, 0, kbd_false, false, "move cursor back one sample",                NULL, -1},
+  {snd_K_b,          snd_ControlMask, 0, kbd_false, false, "move cursor back one pixel",                 NULL, -1},
   {snd_K_d,          snd_ControlMask, 0, kbd_false, false, "delete sample at cursor",                    NULL, -1},
   {snd_K_e,          snd_ControlMask, 0, kbd_false, false, "move cursor to window end",                  NULL, -1},
-  {snd_K_f,          snd_ControlMask, 0, kbd_false, false, "move cursor ahead one sample",               NULL, -1},
+  {snd_K_f,          snd_ControlMask, 0, kbd_false, false, "move cursor ahead one pixel",                NULL, -1},
   {snd_K_g,          snd_ControlMask, 0, kbd_false, false, "abort current command",                      NULL, -1},
   {snd_K_h,          snd_ControlMask, 0, kbd_false, false, "delete previous sample",                     NULL, -1},
   {snd_K_i,          snd_ControlMask, 0, kbd_false, false, "display cursor info",                        NULL, -1},
@@ -423,23 +423,6 @@ char *key_binding_description(int key, int state, bool cx_extended)
   if (pos < 0) pos = in_user_keymap(key, state, cx_extended);
   if (pos >= 0)
     {
-#if HAVE_GUILE
-      XEN value, help_text = XEN_FALSE;
-      value = user_keymap[pos].func;
-      help_text = XEN_PROCEDURE_HELP(value);            /* (procedure-property ...) */
-      if (XEN_FALSE_P(help_text))
-	{
-	  help_text = XEN_PROCEDURE_SOURCE_HELP(value); /* (procedure-documentation ...) -- this is the first line of source if string */
-	  if (XEN_FALSE_P(help_text))
-	    help_text = XEN_PROCEDURE_NAME(value);
-	}
-      if (!(XEN_FALSE_P(help_text))) 
-	{
-	  if (XEN_STRING_P(help_text))
-	    return(mus_strdup(XEN_TO_C_STRING(help_text)));
-	  return(mus_strdup(XEN_AS_STRING(help_text)));
-	}
-#endif
       if (user_keymap[pos].origin)
 	return(mus_strdup(user_keymap[pos].origin));
       return(mus_strdup("something indescribable")); /* NULL would mean "no binding" */
@@ -526,7 +509,7 @@ void set_keymap_entry(int key, int state, int args, XEN func, bool cx_extended,
 static void call_user_keymap(int hashedsym, int count)
 {
   kbd_cursor_t res = KEYBOARD_NO_ACTION;
-  /* if guile call the associated scheme code, else see if basic string parser can handle it */
+
   if (XEN_BOUND_P(user_keymap[hashedsym].func))
     {
       /* not _NO_CATCH here because the code is not protected at any higher level */
@@ -1402,7 +1385,6 @@ void control_g(snd_info *sp)
       for_each_sound_chan(sp, stop_fft_in_progress);
       clear_minibuffer(sp);
     }
-  ss->error_lock = false;
 }
 
 #ifndef SND_KEYMASK
@@ -1468,7 +1450,9 @@ void keyboard_command(chan_info *cp, int keysym, int unmasked_state)
 
   u_count = false;
 
-  if ((keysym != snd_K_X) && (keysym != snd_K_x))
+  if ((keysym != snd_K_X) && (keysym != snd_K_x) &&
+      (keysym != snd_K_B) && (keysym != snd_K_b) &&
+      (keysym != snd_K_F) && (keysym != snd_K_f))
     {
       got_count = false;
       if (count == 0) return;
@@ -1509,8 +1493,19 @@ void keyboard_command(chan_info *cp, int keysym, int unmasked_state)
 	      break;
 
 	    case snd_K_B: case snd_K_b: 
-	      cp->cursor_on = true; 
-	      cursor_move(cp, -count); 
+	      /* this was by samples which is nuts if we're looking at a large window -- should be by pixel, I think */
+	      {
+		int samples_per_pixel = 1;
+		if ((!got_count) &&                              /* C-u 2.1 C-b moves back 2.1 seconds */
+		    (cp->axis->x_axis_x1 > cp->axis->x_axis_x0)) /* avoid divide by zero if window tiny */
+		  {
+		    samples_per_pixel = (cp->axis->hisamp - cp->axis->losamp) / (cp->axis->x_axis_x1 - cp->axis->x_axis_x0);
+		    if (samples_per_pixel < 1) samples_per_pixel = 1;
+		  }
+		cp->cursor_on = true; 
+		cursor_move(cp, -count * samples_per_pixel);
+		got_count = false;
+	      }
 	      break;
 
 	    case snd_K_D: case snd_K_d: 
@@ -1526,8 +1521,18 @@ void keyboard_command(chan_info *cp, int keysym, int unmasked_state)
 	      break;
 
 	    case snd_K_F: case snd_K_f:
-	      cp->cursor_on = true; 
-	      cursor_move(cp, count); 
+	      {
+		int samples_per_pixel = 1;
+		if ((!got_count) &&
+		    (cp->axis->x_axis_x1 > cp->axis->x_axis_x0))
+		  {
+		    samples_per_pixel = (cp->axis->hisamp - cp->axis->losamp) / (cp->axis->x_axis_x1 - cp->axis->x_axis_x0);
+		    if (samples_per_pixel < 1) samples_per_pixel = 1;
+		  }
+		cp->cursor_on = true; 
+		cursor_move(cp, count * samples_per_pixel); 
+		got_count = false;
+	      }
 	      break;
 
 	    case snd_K_G: case snd_K_g: 
@@ -2321,10 +2326,10 @@ static XEN check_for_key_error(int k, int s, const char *caller)
   if ((k < MIN_KEY_CODE) || (k > MAX_KEY_CODE) ||
       (s < MIN_KEY_STATE) || (s > MAX_KEY_STATE))
     XEN_ERROR(XEN_ERROR_TYPE("no-such-key"),
-	      XEN_LIST_3(C_TO_XEN_STRING(caller),
-			 C_TO_XEN_STRING("key: ~A, state: ~A"),
-			 XEN_LIST_2(C_TO_XEN_INT(k),
-				    C_TO_XEN_INT(s))));
+	      XEN_LIST_4(C_TO_XEN_STRING("~A: no such key: ~A, state: ~A"),
+			 C_TO_XEN_STRING(caller),
+			 C_TO_XEN_INT(k),
+			 C_TO_XEN_INT(s)));
   return(XEN_FALSE);
 }
 
@@ -2335,15 +2340,18 @@ static XEN g_key_binding(XEN key, XEN state, XEN cx_extended)
 modifiers.  As in " S_bind_key ", state is the logical 'or' of ctrl=4, meta=8, and 'extended' is " PROC_TRUE " if the key is \
 prefixed with C-x. 'key' can be a character, a key name such as 'Home', or an integer."
   int i, k, s;
+
   XEN_ASSERT_TYPE(XEN_INTEGER_P(key) || XEN_CHAR_P(key) || XEN_STRING_P(key), key, XEN_ARG_1, S_key_binding, "an integer, character, or string");
   XEN_ASSERT_TYPE(XEN_INTEGER_IF_BOUND_P(state), state, XEN_ARG_2, S_key_binding, "an integer");
   XEN_ASSERT_TYPE(XEN_BOOLEAN_IF_BOUND_P(cx_extended), cx_extended, XEN_ARG_3, S_key_binding, "a boolean");
+
   k = key_name_to_key(key, S_key_binding);
   s = XEN_TO_C_INT_OR_ELSE(state, 0) & 0xfffe; /* no shift bit */
   check_for_key_error(k, s, S_key_binding);
   i = in_user_keymap(k, s, XEN_TRUE_P(cx_extended));
   if (i >= 0) 
     return(user_keymap[i].func);
+
   return(XEN_UNDEFINED);
 }
 
@@ -2418,15 +2426,19 @@ static XEN g_key(XEN kbd, XEN buckybits, XEN snd, XEN chn)
   #define H_key "(" S_key " key modifiers :optional snd chn): simulate typing 'key' with 'modifiers' in snd's channel chn"
   chan_info *cp;
   int k, s;
+
   XEN_ASSERT_TYPE(XEN_INTEGER_P(kbd) || XEN_CHAR_P(kbd) || XEN_STRING_P(kbd), kbd, XEN_ARG_1, S_key, "an integer, character, or string");
   XEN_ASSERT_TYPE(XEN_INTEGER_P(buckybits), buckybits, XEN_ARG_2, S_key, "an integer");
   ASSERT_CHANNEL(S_key, snd, chn, 3);
+
   cp = get_cp(snd, chn, S_key);
   if (!cp) return(XEN_FALSE);
+
   k = key_name_to_key(kbd, S_key);
   s = XEN_TO_C_INT(buckybits);
   check_for_key_error(k, s, S_key);
   keyboard_command(cp, k, s);
+
   return(kbd);
 }
 
@@ -2436,7 +2448,9 @@ static XEN g_save_macros(XEN file)
   #define H_save_macros "(" S_save_macros " :optional (file \"~/.snd\")): save keyboard macros file"
   FILE *fd = NULL;
   const char *name;
+
   XEN_ASSERT_TYPE(XEN_STRING_P(file), file, XEN_ONLY_ARG, S_save_macros, "a string");
+
   name = XEN_TO_C_STRING(file);
   fd = FOPEN(name, "a");
   if (fd) 
@@ -2447,7 +2461,7 @@ static XEN g_save_macros(XEN file)
   else
     {
       XEN_ERROR(CANNOT_SAVE,
-		XEN_LIST_3(C_TO_XEN_STRING(S_save_macros),
+		XEN_LIST_3(C_TO_XEN_STRING(S_save_macros ": ~S ~A"),
 			   file,
 			   C_TO_XEN_STRING(snd_io_strerror())));
     }
@@ -2524,6 +2538,7 @@ static XEN g_report_in_minibuffer(XEN msg, XEN snd, XEN as_error)
   #define H_report_in_minibuffer "(" S_report_in_minibuffer " msg :optional snd as-error): display msg in snd's minibuffer. \
 If 'as-error' is " PROC_TRUE ", place the message in the minibuffer's error label."
   snd_info *sp;
+
   XEN_ASSERT_TYPE(XEN_STRING_P(msg), msg, XEN_ARG_1, S_report_in_minibuffer, "a string");
   XEN_ASSERT_TYPE(XEN_BOOLEAN_IF_BOUND_P(as_error), as_error, XEN_ARG_2, S_report_in_minibuffer, "a boolean");
   ASSERT_SOUND(S_report_in_minibuffer, snd, 2);
@@ -2544,7 +2559,9 @@ static XEN g_clear_minibuffer(XEN snd)
   #define H_clear_minibuffer "(" S_clear_minibuffer " :optional snd) clears snd's minibuffer (erasing any \
 error message as well)."
   snd_info *sp;
+
   ASSERT_SOUND(S_clear_minibuffer, snd, 1);
+
   sp = get_sp(snd);
   if ((sp == NULL) || (sp->inuse != SOUND_NORMAL))
     return(snd_no_such_sound_error(S_clear_minibuffer, snd));
@@ -2567,11 +2584,13 @@ static XEN g_snd_simulate_keystroke(XEN snd, XEN chn, XEN key, XEN state)
 {
   /* intended for testing */
   chan_info *cp;
+
   XEN_ASSERT_TYPE(XEN_INTEGER_P(key), key, XEN_ARG_3, S_snd_simulate_keystroke, "key number (int)");
   XEN_ASSERT_TYPE(XEN_INTEGER_P(state), state, XEN_ARG_4, S_snd_simulate_keystroke, "key state (int)");
   ASSERT_CHANNEL(S_snd_simulate_keystroke, snd, chn, 1);
   cp = get_cp(snd, chn, S_snd_simulate_keystroke);
   if (!cp) return(XEN_FALSE);
+
   keyboard_command(cp, XEN_TO_C_INT(key), XEN_TO_C_INT(state));
   return(key);
 }
@@ -2626,7 +2645,7 @@ void g_init_kbd(void)
   XEN_DEFINE_PROCEDURE(S_prompt_in_minibuffer,   g_prompt_in_minibuffer_w,   1, 3, 0, H_prompt_in_minibuffer);
   XEN_DEFINE_PROCEDURE(S_snd_simulate_keystroke, g_snd_simulate_keystroke_w, 4, 0, 0, "internal testing function");
 
-#if HAVE_S7
+#if HAVE_SCHEME
   {
     int i;
     for (i = 0; i < NUM_BUILT_IN_KEY_BINDINGS; i++)
