@@ -2062,7 +2062,7 @@ static XEN g_xen_mark_to_string(XEN obj)
 #endif
 
 
-#if (!HAVE_S7)
+#if (!HAVE_SCHEME)
 static bool xen_mark_equalp(xen_mark *v1, xen_mark *v2) 
 {
   return((v1 == v2) ||
@@ -2072,7 +2072,7 @@ static bool xen_mark_equalp(xen_mark *v1, xen_mark *v2)
 static XEN equalp_xen_mark(XEN obj1, XEN obj2)
 {
   if ((!(XEN_MARK_P(obj1))) || (!(XEN_MARK_P(obj2)))) return(XEN_FALSE);
-  return(xen_return_first(C_TO_XEN_BOOLEAN(xen_mark_equalp(XEN_TO_XEN_MARK(obj1), XEN_TO_XEN_MARK(obj2))), obj1, obj2));
+  return(C_TO_XEN_BOOLEAN(xen_mark_equalp(XEN_TO_XEN_MARK(obj1), XEN_TO_XEN_MARK(obj2))));
 }
 #endif
 
@@ -2097,7 +2097,7 @@ XEN new_xen_mark(int n)
 }
 
 
-#if HAVE_S7
+#if HAVE_SCHEME
 static bool s7_xen_mark_equalp(void *obj1, void *obj2)
 {
   return((obj1 == obj2) ||
@@ -2121,7 +2121,7 @@ static XEN s7_xen_mark_copy(s7_scheme *sc, s7_pointer obj)
 
 static void init_xen_mark(void)
 {
-#if HAVE_S7
+#if HAVE_SCHEME
   xen_mark_tag = XEN_MAKE_OBJECT_TYPE("<mark>", print_xen_mark, free_xen_mark, s7_xen_mark_equalp, NULL, NULL, NULL, NULL, s7_xen_mark_copy, NULL);
 #else
 #if HAVE_RUBY
@@ -2131,12 +2131,6 @@ static void init_xen_mark(void)
 #endif
 #endif
 
-#if HAVE_GUILE
-  scm_set_smob_print(xen_mark_tag,  print_xen_mark);
-  scm_set_smob_free(xen_mark_tag,   free_xen_mark);
-  scm_set_smob_equalp(xen_mark_tag, equalp_xen_mark);
-#endif
-
 #if HAVE_FORTH
   fth_set_object_inspect(xen_mark_tag,   print_xen_mark);
   fth_set_object_dump(xen_mark_tag,      g_xen_mark_to_string);
@@ -2173,7 +2167,8 @@ static XEN g_mark_to_integer(XEN n)
 static XEN snd_no_such_mark_error(const char *caller, XEN id)
 {
   XEN_ERROR(XEN_ERROR_TYPE("no-such-mark"),
-	    XEN_LIST_2(C_TO_XEN_STRING(caller),
+	    XEN_LIST_3(C_TO_XEN_STRING("~A: no such mark ~A"),
+		       C_TO_XEN_STRING(caller),
 		       id));
   return(XEN_FALSE);
 }
@@ -2434,7 +2429,7 @@ static XEN g_add_mark_1(XEN samp_n, XEN snd, XEN chn_n, XEN name, XEN sync, bool
   if ((loc < 0) || 
       (loc >= CURRENT_SAMPLES(cp)))
     XEN_ERROR(NO_SUCH_SAMPLE,
-	      XEN_LIST_2(C_TO_XEN_STRING(S_add_mark),
+	      XEN_LIST_2(C_TO_XEN_STRING(S_add_mark ": no such sample, ~A"),
 			 samp_n));
 
   if (XEN_STRING_P(name)) mname = XEN_TO_C_STRING(name);
@@ -2618,7 +2613,7 @@ mark list is: channel given: (id id ...), snd given: ((id id) (id id ...)), neit
 		  pos = cp->edit_ctr;
 		if ((pos < 0) || (pos >= cp->edit_size) || (cp->edits[pos] == NULL))
 		  XEN_ERROR(NO_SUCH_EDIT,
-			    XEN_LIST_2(C_TO_XEN_STRING(S_marks),
+			    XEN_LIST_2(C_TO_XEN_STRING(S_marks ": no such edit, ~A"),
 				       pos_n));
 	      }
 	    else pos = cp->edit_ctr;
@@ -2872,10 +2867,9 @@ The saved file is " XEN_LANGUAGE_NAME " code, so to restore the marks, load that
 	  lname = C_TO_XEN_STRING(newname);
 	  free(newname);
 	  XEN_ERROR(CANNOT_SAVE,
-		    XEN_LIST_3(C_TO_XEN_STRING(S_save_marks),
-			       C_TO_XEN_STRING("open ~A: ~A"),
-			       XEN_LIST_2(lname,
-					  C_TO_XEN_STRING(snd_open_strerror()))));
+		    XEN_LIST_3(C_TO_XEN_STRING(S_save_marks ": can't save ~S, ~A"),
+			       lname,
+			       C_TO_XEN_STRING(snd_open_strerror())));
 	}
       else
 	{
@@ -2935,6 +2929,17 @@ static XEN g_set_mark_properties(XEN n, XEN val)
 }
 
 
+static XEN g_mark_property(XEN key, XEN id) 
+{
+  #define H_mark_property "(" S_mark_property " key id) returns the value associated with 'key' in the given mark's property list, or #f"
+  return(XEN_ASSOC_REF(key, g_mark_properties(id)));
+}
+
+static XEN g_set_mark_property(XEN key, XEN id, XEN val) 
+{
+  g_set_mark_properties(id, XEN_ASSOC_SET(key, val, g_mark_properties(id)));
+  return(val);
+}
 
 
 
@@ -2964,6 +2969,8 @@ XEN_NARGIFY_1(g_integer_to_mark_w, g_integer_to_mark)
 XEN_NARGIFY_1(g_mark_to_integer_w, g_mark_to_integer)
 XEN_NARGIFY_1(g_mark_properties_w, g_mark_properties)
 XEN_NARGIFY_2(g_set_mark_properties_w, g_set_mark_properties)
+XEN_NARGIFY_2(g_mark_property_w, g_mark_property)
+XEN_NARGIFY_3(g_set_mark_property_w, g_set_mark_property)
 #if MUS_DEBUGGING && HAVE_SCHEME
   XEN_NARGIFY_3(g_test_control_drag_mark_w, g_test_control_drag_mark)
 #endif
@@ -2993,6 +3000,8 @@ XEN_NARGIFY_2(g_set_mark_properties_w, g_set_mark_properties)
 #define g_mark_to_integer_w g_mark_to_integer
 #define g_mark_properties_w g_mark_properties
 #define g_set_mark_properties_w g_set_mark_properties
+#define g_mark_property_w g_mark_property
+#define g_set_mark_property_w g_set_mark_property
 #if MUS_DEBUGGING && HAVE_SCHEME
   #define g_test_control_drag_mark_w g_test_control_drag_mark
 #endif
@@ -3041,6 +3050,9 @@ void g_init_marks(void)
   XEN_DEFINE_PROCEDURE_WITH_SETTER(S_mark_properties, g_mark_properties_w, H_mark_properties, 
 				   S_setB S_mark_properties, g_set_mark_properties_w, 1, 0, 2, 0);
 
+  XEN_DEFINE_PROCEDURE_WITH_SETTER(S_mark_property, g_mark_property_w, H_mark_property, 
+				   S_setB S_mark_property, g_set_mark_property_w, 2, 0, 3, 0);
+
   #define H_draw_mark_hook S_draw_mark_hook " (mark-id): called before a mark is drawn (in XOR mode). \
 If the hook returns " PROC_TRUE ", the mark is not drawn."
 
