@@ -94,6 +94,11 @@ void view_menu_update(void)
   /* verbose cursor label */
   set_menu_label(view_cursor_menu, (verbose_cursor(ss)) ? _("Silent cursor") : _("Verbose cursor"));
 
+#if HAVE_EXTENSION_LANGUAGE
+  /* inset graph label */
+  set_menu_label(view_inset_menu, (with_inset_graph(ss)) ? _("Without inset graph") : _("With inset graph"));
+#endif
+
   /* channel style */
   set_sensitive(view_combine_separate_menu,     channel_style(ss) != CHANNELS_SEPARATE);
   set_sensitive(view_combine_combined_menu,     channel_style(ss) != CHANNELS_COMBINED);
@@ -107,8 +112,11 @@ void view_menu_update(void)
   set_sensitive(view_all_axes_unlabelled_menu,    show_axes(ss) != SHOW_ALL_AXES_UNLABELLED);
   set_sensitive(view_bare_x_axis_menu,            show_axes(ss) != SHOW_BARE_X_AXIS);
 
+#if HAVE_EXTENSION_LANGUAGE
   /* make sure listener menu option label correctly reflects current listener state */
   set_menu_label(view_listener_menu, (listener_is_visible()) ? _("Hide listener") : _("Show listener"));
+#endif
+
   set_menu_label(view_controls_menu, (in_show_controls(ss)) ? _("Hide controls") : _("Show controls"));
 
   /* set_sensitive(view_files_menu, get_view_files_end() >= 0); */
@@ -287,7 +295,8 @@ void save_state_from_menu(void)
 static XEN snd_no_such_menu_error(const char *caller, XEN id)
 {
   XEN_ERROR(XEN_ERROR_TYPE("no-such-menu"),
-	    XEN_LIST_2(C_TO_XEN_STRING(caller),
+	    XEN_LIST_3(C_TO_XEN_STRING("~A: no such menu, ~A"),
+		       C_TO_XEN_STRING(caller),
 		       id));
   return(XEN_FALSE);
 }
@@ -409,12 +418,7 @@ func (a function of no args) when the new menu is activated. Returns the new men
       if (XEN_INTEGER_P(gpos)) position = XEN_TO_C_INT(gpos);
 
       result = g_add_to_menu(m,
-#if (MUS_SGI) && (!(HAVE_EXTENSION_LANGUAGE)) && (!(defined(__GNUC__)))
-			     /* SGI C-compiler thinks NULL:NULL can't be char*! */
-			     (XEN_FALSE_P(label)) ? "" : XEN_TO_C_STRING(label),
-#else
 			     (XEN_FALSE_P(label)) ? NULL : XEN_TO_C_STRING(label),
-#endif
 			     slot,
 			     position);
 #if (!USE_NO_GUI)
@@ -465,7 +469,7 @@ static XEN g_main_menu(XEN which)
   which_menu = XEN_TO_C_INT(which);
   if ((which_menu < 0) || (which_menu >= MAX_MAIN_MENUS))
     XEN_ERROR(XEN_ERROR_TYPE("no-such-menu"),
-	      XEN_LIST_2(C_TO_XEN_STRING(S_main_menu),
+	      XEN_LIST_2(C_TO_XEN_STRING(S_main_menu ": no such menu, ~A"),
 			 which));
   return(XEN_WRAP_WIDGET(menu_widget(which_menu)));
 }
