@@ -8,7 +8,6 @@ void snd_help_back_to_top(void) {}
 color_t get_in_between_color(color_t fg, color_t bg) {return(0);}
 void set_find_dialog_label(const char *str) {}
 void save_find_dialog_state(FILE *fd) {}
-bool send_mozilla(const char *html_viewer, const char *url) {return(false);}
 void check_menu_labels(int key, int state, bool extended) {}
 int add_channel_window(snd_info *sound, int channel, int chan_y, int insertion, widget_t main, fw_button_t arrows, bool with_events) {return(0);}
 int snd_help(const char *subject, const char *help, with_word_wrap_t with_wrap) {fprintf(stdout, "%s", help); return(0);}
@@ -382,7 +381,6 @@ void snd_doit(int argc, char **argv)
   XEN_EVAL_C_STRING("(define " S_mouse_leave_text_hook " (make-hook 1))");
   XEN_EVAL_C_STRING("(define " S_new_widget_hook " (make-hook 1))");
   XEN_EVAL_C_STRING("(define " S_orientation_hook " (make-hook 0))");
-  XEN_EVAL_C_STRING("(define " S_window_property_changed_hook " (make-hook 1))");
 
   XEN_EVAL_C_STRING("(define " S_copy_context " 0)");
   XEN_EVAL_C_STRING("(define " S_cursor_context " 3)");
@@ -442,7 +440,6 @@ void snd_doit(int argc, char **argv)
   XEN_EVAL_C_STRING("(define (" S_make_graph_data " . args) #f)");
   XEN_EVAL_C_STRING("(define (" S_menu_widgets " . args) #f)");
   XEN_EVAL_C_STRING("(define (" S_reset_listener_cursor ") #f)");
-  XEN_EVAL_C_STRING("(define (" S_send_mozilla " . args) #f)");
   XEN_EVAL_C_STRING("(define (" S_sound_widgets " . args) #f)");
   XEN_EVAL_C_STRING("(define (" S_view_regions_dialog " . args) #f)");
   XEN_EVAL_C_STRING("(define (" S_find_dialog " . args) #f)");
@@ -450,7 +447,6 @@ void snd_doit(int argc, char **argv)
   XEN_EVAL_C_STRING("(define (" S_goto_listener_end ") #f)");
   XEN_EVAL_C_STRING("(define (" S_y_to_position " . args) #f)");
   XEN_EVAL_C_STRING("(define (" S_x_to_position " . args) #f)");
-  XEN_EVAL_C_STRING("(define (" S_window_property " . args) #f)");
   XEN_EVAL_C_STRING("(define (" S_snd_gcs " . args) #f)");
   XEN_EVAL_C_STRING("(define (" S_show_widget " . args) #f)");
   XEN_EVAL_C_STRING("(define (" S_position_to_y " . args) #f)");
@@ -555,14 +551,12 @@ void snd_doit(int argc, char **argv)
   XEN_EVAL_C_STRING("def set_widget_position (a) false end");
   XEN_EVAL_C_STRING("def colormap? (a) false end");
   XEN_EVAL_C_STRING("def in (a, b) false end");
-  XEN_EVAL_C_STRING("def send_mozilla (a) false end");
   XEN_EVAL_C_STRING("def widget_text (a) false end");
 
   XEN_EVAL_C_STRING("def y2position (a) false end");
   XEN_EVAL_C_STRING("def x2position (a) false end");
   XEN_EVAL_C_STRING("def position2y (a) false end");
   XEN_EVAL_C_STRING("def position2x (a) false end");
-  XEN_EVAL_C_STRING("def window_property (a) false end");
   XEN_EVAL_C_STRING("def snd_gcs (a) false end");
   XEN_EVAL_C_STRING("def show_widget (a) false end");
   XEN_EVAL_C_STRING("def listener_selection (a) false end");
@@ -596,7 +590,6 @@ void snd_doit(int argc, char **argv)
   XEN_EVAL_C_STRING("$mouse_leave_text_hook = false");
   XEN_EVAL_C_STRING("$new_widget_hook = false");
   XEN_EVAL_C_STRING("$orientation_hook = false");
-  XEN_EVAL_C_STRING("$window_property_changed_hook = false");
 
   XEN_EVAL_C_STRING("Copy_context = 0");
   XEN_EVAL_C_STRING("Cursor_context = 3");
@@ -626,8 +619,7 @@ void snd_doit(int argc, char **argv)
 1 #f create-hook " S_mouse_leave_listener_hook "\n\
 1 #f create-hook " S_mouse_leave_text_hook "\n\
 1 #f create-hook " S_new_widget_hook "\n\
-0 #f create-hook " S_orientation_hook "\n\
-1 #f create-hook " S_window_property_changed_hook "\n");
+0 #f create-hook " S_orientation_hook "\n");
 
   XEN_EVAL_C_STRING("\
 0 constant " S_copy_context "\n\
@@ -708,7 +700,6 @@ void snd_doit(int argc, char **argv)
 : " S_make_graph_data " { a b c } #f ;\n\
 : " S_menu_widgets " { s } #f ;\n\
 : " S_reset_listener_cursor " #f ;\n\
-: " S_send_mozilla " { a } #f ;\n\
 : " S_sound_widgets " { s } #f ;\n\
 : " S_view_regions_dialog " #f ;\n\
 : " S_widget_text " { a } #f ;\n\
