@@ -101,7 +101,12 @@ static void free_region(region *r, int complete)
       if (r->use_temp_file == REGION_DEFERRED)
 	r->dr = free_deferred_region(r->dr);
       if (r->rsp) 
-	r->rsp = completely_free_snd_info(r->rsp);
+	{
+	  if ((r->rsp->chans) &&
+	      (r->rsp->chans[0]->edits))
+	    r->rsp->chans[0]->edits[0]->peak_env = NULL;
+	  r->rsp = completely_free_snd_info(r->rsp);
+	}
       if (complete == COMPLETE_DELETION) free(r);
     }
 }
@@ -298,6 +303,7 @@ static mus_float_t region_sample(int reg, int chn, mus_long_t samp)
 	      free_snd_fd(sf);
 	      return(val);
 	      break;
+
 	    case REGION_DEFERRED:
 	      drp = r->dr;
 	      return(chn_sample(samp + r->begs[chn], drp->cps[chn], drp->edpos[chn]));
@@ -345,6 +351,7 @@ static void region_samples(int reg, int chn, mus_long_t beg, mus_long_t num, mus
 		data[j] = read_sample(sf);
 	      free_snd_fd(sf);
 	      break;
+
 	    case REGION_DEFERRED:
 	      drp = r->dr;
 	      sf = init_sample_read_any(beg + r->begs[chn], drp->cps[chn], READ_FORWARD, drp->edpos[chn]);
@@ -433,7 +440,7 @@ static void make_region_readable(region *r)
       else
 	{
 	  XEN_ERROR(XEN_ERROR_TYPE("IO-error"),
-		    XEN_LIST_3(C_TO_XEN_STRING(_("can't read region file!!")),
+		    XEN_LIST_3(C_TO_XEN_STRING("can't read region file ~S, ~A"),
 			       C_TO_XEN_STRING(r->filename),
 			       C_TO_XEN_STRING(snd_open_strerror())));
 	}
@@ -468,6 +475,7 @@ file_info *fixup_region_data(chan_info *cp, int chan, int pos)
 	  cp->edits[0]->samples = ncp->edits[0]->samples;
 	  cp->axis = ncp->axis;
 
+	  /* cp here is actually region sound chan 0 */
 	  if ((r->peak_envs) && (r->peak_envs[chan]))
 	    cp->edits[0]->peak_env = r->peak_envs[chan];
 	  else
@@ -561,11 +569,14 @@ int remove_region_from_list(int pos) /* region browser */
   int i, id;
   id = region_list_position_to_id(pos);
   if (id == INVALID_REGION) return(INVALID_REGION);
+
   stop_playing_region(id, PLAY_CLOSE);
+
   free_region(id_to_region(id), COMPLETE_DELETION);
   for (i = pos; i < regions_size - 1; i++) 
     regions[i] = regions[i + 1]; 
   regions[regions_size - 1] = NULL;
+
   return(check_regions());
 }
 
@@ -904,17 +915,7 @@ static void deferred_region_to_temp_file(region *r)
     {
       mus_long_t max_position = 0;
       io_error_t io_err = IO_NO_ERROR;
-#if MUS_DEBUGGING
-      char *regstr;
-      regstr = mus_format("region %d (%s: %s %s), from %s[%d]",
-			  r->id, r->name, r->start, r->end,
-			  (r->rsp) ? (r->rsp->filename) : "unknown sound",
-			  (r->rsp) ? (r->rsp->index) : 0);
-      hdr = make_temp_header(r->filename, r->srate, r->chans, 0, regstr);
-      free(regstr);
-#else
       hdr = make_temp_header(r->filename, r->srate, r->chans, 0, (char *)c__FUNCTION__);
-#endif
       ofd = open_temp_file(r->filename, r->chans, hdr, &io_err);
       if (ofd == -1)
 	snd_error(_("%s region temp file %s: %s"), 
@@ -1381,7 +1382,7 @@ static XEN g_xen_region_to_string(XEN obj)
 #endif
 
 
-#if (!HAVE_S7)
+#if (!HAVE_SCHEME)
 static bool xen_region_equalp(xen_region *v1, xen_region *v2) 
 {
   return((v1 == v2) ||
@@ -1391,7 +1392,7 @@ static bool xen_region_equalp(xen_region *v1, xen_region *v2)
 static XEN equalp_xen_region(XEN obj1, XEN obj2)
 {
   if ((!(XEN_REGION_P(obj1))) || (!(XEN_REGION_P(obj2)))) return(XEN_FALSE);
-  return(xen_return_first(C_TO_XEN_BOOLEAN(xen_region_equalp(XEN_TO_XEN_REGION(obj1), XEN_TO_XEN_REGION(obj2))), obj1, obj2));
+  return(C_TO_XEN_BOOLEAN(xen_region_equalp(XEN_TO_XEN_REGION(obj1), XEN_TO_XEN_REGION(obj2))));
 }
 #endif
 
@@ -1416,7 +1417,7 @@ XEN new_xen_region(int n)
 }
 
 
-#if HAVE_S7
+#if HAVE_SCHEME
 static bool s7_xen_region_equalp(void *obj1, void *obj2)
 {
   return((obj1 == obj2) ||
@@ -1432,7 +1433,7 @@ static XEN s7_xen_region_length(s7_scheme *sc, XEN obj)
 
 static void init_xen_region(void)
 {
-#if HAVE_S7
+#if HAVE_SCHEME
   xen_region_tag = XEN_MAKE_OBJECT_TYPE("<region>", print_xen_region, free_xen_region, s7_xen_region_equalp, NULL, NULL, NULL, s7_xen_region_length, NULL, NULL);
 #else
 #if HAVE_RUBY
@@ -1442,12 +1443,6 @@ static void init_xen_region(void)
 #endif
 #endif
 
-#if HAVE_GUILE
-  scm_set_smob_print(xen_region_tag,  print_xen_region);
-  scm_set_smob_free(xen_region_tag,   free_xen_region);
-  scm_set_smob_equalp(xen_region_tag, equalp_xen_region);
-#endif
-
 #if HAVE_FORTH
   fth_set_object_inspect(xen_region_tag,   print_xen_region);
   fth_set_object_dump(xen_region_tag,      g_xen_region_to_string);
@@ -1485,7 +1480,8 @@ static XEN g_region_to_integer(XEN n)
 static XEN snd_no_such_region_error(const char *caller, XEN n)
 {
   XEN_ERROR(XEN_ERROR_TYPE("no-such-region"),
-	    XEN_LIST_2(C_TO_XEN_STRING(caller),
+	    XEN_LIST_3(C_TO_XEN_STRING("~A: no such region, ~A"),
+		       C_TO_XEN_STRING(caller),
 		       n));
   return(XEN_FALSE);
 }
@@ -1556,12 +1552,12 @@ insert region data into snd's channel chn starting at start-samp"
     return(snd_no_such_region_error(S_insert_region, reg_n));
 
   samp = beg_to_sample(samp_n, S_insert_region);
-
   err = paste_region_2(rg, cp, false, samp);
 
   if (SERIOUS_IO_ERROR(err))
-    XEN_ERROR(CANT_UPDATE_FILE,
-	      XEN_LIST_2(C_TO_XEN_STRING(S_insert_region),
+    XEN_ERROR(XEN_ERROR_TYPE("IO-error"),
+	      XEN_LIST_3(C_TO_XEN_STRING(S_insert_region ": can't edit ~A (region access problem?), ~A"),
+			 C_TO_XEN_STRING(cp->sound->filename),
 			 C_TO_XEN_STRING(io_error_name(err))));
   update_graph(cp);
   return(reg_n);
@@ -1642,7 +1638,7 @@ static XEN g_region_position(XEN n, XEN chan)
 }
 
 
-typedef enum {REGION_SRATE, REGION_CHANS, REGION_MAXAMP, REGION_FORGET, REGION_PLAY, REGION_MAXAMP_POSITION, REGION_HOME} region_field_t;
+typedef enum {REGION_SRATE, REGION_CHANS, REGION_MAXAMP, REGION_FORGET, REGION_MAXAMP_POSITION, REGION_HOME} region_field_t;
 
 static XEN region_get(region_field_t field, XEN n, const char *caller)
 {
@@ -1842,7 +1838,7 @@ static void save_region_to_xen_error(const char *msg, void *data)
 {
   redirect_snd_error_to(NULL, NULL);
   XEN_ERROR(CANNOT_SAVE,
-	    XEN_LIST_2(C_TO_XEN_STRING(S_save_region),
+	    XEN_LIST_2(C_TO_XEN_STRING(S_save_region ": can't save ~S"),
 		       C_TO_XEN_STRING(msg)));
 }
 
@@ -1883,8 +1879,7 @@ using data format (default depends on machine byte order), header type (" S_mus_
 
   if (file == NULL) 
     XEN_ERROR(XEN_ERROR_TYPE("IO-error"),
-	      XEN_LIST_2(C_TO_XEN_STRING(S_save_region),
-			 C_TO_XEN_STRING("no output file?")));
+	      XEN_LIST_1(C_TO_XEN_STRING(S_save_region ": no output file?")));
 
   name = mus_expand_filename(file);
 
@@ -1944,8 +1939,8 @@ it returns a list of the new mixes"
 
   /* id might legitmately be invalid mix id if with_mix_tags is #f or virtual mix not ok */
   if (SERIOUS_IO_ERROR(err))
-    XEN_ERROR(CANT_UPDATE_FILE,
-	      XEN_LIST_2(C_TO_XEN_STRING(S_mix_region),
+    XEN_ERROR(XEN_ERROR_TYPE("IO-error"),
+	      XEN_LIST_2(C_TO_XEN_STRING(S_mix_region ": can't edit, ~A"),
 			 C_TO_XEN_STRING(io_error_name(err))));
   
   if (id == -1) return(XEN_FALSE);
