@@ -881,7 +881,7 @@ static XEN g_xen_selection_to_string(XEN obj)
 #endif
 
 
-#if (!HAVE_S7)
+#if (!HAVE_SCHEME)
 static bool xen_selection_equalp(xen_selection *v1, xen_selection *v2) 
 {
   return((v1 == v2) ||
@@ -892,7 +892,7 @@ static bool xen_selection_equalp(xen_selection *v1, xen_selection *v2)
 static XEN equalp_xen_selection(XEN obj1, XEN obj2)
 {
   if ((!(XEN_SELECTION_P(obj1))) || (!(XEN_SELECTION_P(obj2)))) return(XEN_FALSE);
-  return(xen_return_first(C_TO_XEN_BOOLEAN(xen_selection_equalp(XEN_TO_XEN_SELECTION(obj1), XEN_TO_XEN_SELECTION(obj2))), obj1, obj2));
+  return(C_TO_XEN_BOOLEAN(xen_selection_equalp(XEN_TO_XEN_SELECTION(obj1), XEN_TO_XEN_SELECTION(obj2))));
 }
 #endif
 
@@ -919,7 +919,7 @@ static XEN g_selection(void)
 }
 
 
-#if HAVE_S7
+#if HAVE_SCHEME
 static XEN s7_xen_selection_length(s7_scheme *sc, XEN obj)
 {
   return(g_selection_frames(XEN_UNDEFINED, XEN_UNDEFINED));
@@ -990,7 +990,7 @@ static XEN s7_xen_selection_fill(s7_scheme *sc, XEN obj, XEN val)
 
 static void init_xen_selection(void)
 {
-#if HAVE_S7
+#if HAVE_SCHEME
   xen_selection_tag = XEN_MAKE_OBJECT_TYPE("<selection>", 
 					   print_xen_selection, free_xen_selection, s7_xen_selection_equalp, 
 					   NULL, NULL, NULL, s7_xen_selection_length, 
@@ -1003,12 +1003,6 @@ static void init_xen_selection(void)
 #endif
 #endif
 
-#if HAVE_GUILE
-  scm_set_smob_print(xen_selection_tag,  print_xen_selection);
-  scm_set_smob_free(xen_selection_tag,   free_xen_selection);
-  scm_set_smob_equalp(xen_selection_tag, equalp_xen_selection);
-#endif
-
 #if HAVE_FORTH
   fth_set_object_inspect(xen_selection_tag,   print_xen_selection);
   fth_set_object_dump(xen_selection_tag,      g_xen_selection_to_string);
@@ -1264,7 +1258,7 @@ static XEN g_insert_selection(XEN beg, XEN snd, XEN chn)
 
       if (SERIOUS_IO_ERROR(io_err))
 	XEN_ERROR(XEN_ERROR_TYPE("IO-error"),
-		  XEN_LIST_2(C_TO_XEN_STRING(S_insert_selection),
+		  XEN_LIST_2(C_TO_XEN_STRING(S_insert_selection ": IO error ~A"),
 			     C_TO_XEN_STRING(io_error_name(io_err))));
       return(XEN_FALSE);
     }
@@ -1304,7 +1298,7 @@ static XEN g_mix_selection(XEN beg, XEN snd, XEN chn, XEN sel_chan)
 
       if (SERIOUS_IO_ERROR(io_err))
 	XEN_ERROR(XEN_ERROR_TYPE("IO-error"),
-		  XEN_LIST_2(C_TO_XEN_STRING(S_mix_selection),
+		  XEN_LIST_2(C_TO_XEN_STRING(S_mix_selection ": IO error ~A"),
 			     C_TO_XEN_STRING(io_error_name(io_err))));
 
       if (id == -1) return(XEN_FALSE);
@@ -1338,7 +1332,7 @@ static XEN g_selection_to_mix(void)
 	  if (tempfile) free(tempfile);
 	  free_sync_info(si_out);
 	  XEN_ERROR(XEN_ERROR_TYPE("IO-error"),
-		    XEN_LIST_2(C_TO_XEN_STRING(S_selection_to_mix),
+		    XEN_LIST_2(C_TO_XEN_STRING(S_selection_to_mix ": IO error ~A"),
 			       C_TO_XEN_STRING(io_error_name(io_err))));
 	}
 
@@ -1628,26 +1622,22 @@ save the current selection in file using the indicated file attributes.  If chan
 
   if (file == NULL) 
     XEN_ERROR(XEN_ERROR_TYPE("IO-error"),
-	      XEN_LIST_2(C_TO_XEN_STRING(S_save_selection),
-			 C_TO_XEN_STRING("no output file?")));
+	      XEN_LIST_1(C_TO_XEN_STRING(S_save_selection ": no output file?")));
 
   if ((type != -1) && (!(mus_header_writable(type, -2))))
     XEN_ERROR(CANNOT_SAVE,
-	      XEN_LIST_3(C_TO_XEN_STRING(S_save_selection),
-			 C_TO_XEN_STRING(_("can't write this header type:")),
+	      XEN_LIST_2(C_TO_XEN_STRING(S_save_selection ": can't write a ~A header"),
 			 C_TO_XEN_STRING(mus_header_type_name(type))));
 
   if ((type != -1) && (format != -1) && (!(mus_header_writable(type, format))))
     XEN_ERROR(CANNOT_SAVE,
-	      XEN_LIST_4(C_TO_XEN_STRING(S_save_selection),
-			 C_TO_XEN_STRING(_("can't write this combination of header type and data format:")),
-			 C_TO_XEN_STRING(mus_header_type_name(type)),
-			 C_TO_XEN_STRING(mus_data_format_name(format))));
+	      XEN_LIST_3(C_TO_XEN_STRING(S_save_selection ": can't write ~A data to a ~A header"),
+			 C_TO_XEN_STRING(mus_data_format_name(format)),
+			 C_TO_XEN_STRING(mus_header_type_name(type))));
 
   if ((sr != -1) && (sr <= 0))
     XEN_ERROR(CANNOT_SAVE,
-	      XEN_LIST_3(C_TO_XEN_STRING(S_save_selection),
-			 C_TO_XEN_STRING(_("srate can't be <= 0")),
+	      XEN_LIST_2(C_TO_XEN_STRING(S_save_selection ": srate (~A) can't be <= 0"),
 			 C_TO_XEN_INT(sr)));
 
   fname = mus_expand_filename(file);
@@ -1658,7 +1648,8 @@ save the current selection in file using the indicated file attributes.  If chan
       (io_err != IO_INTERRUPTED) &&
       (io_err != IO_SAVE_HOOK_CANCELLATION))
     XEN_ERROR(CANNOT_SAVE,
-	      XEN_LIST_2(C_TO_XEN_STRING(S_save_selection),
+	      XEN_LIST_3(C_TO_XEN_STRING(S_save_selection ": can't save ~S, ~A"),
+			 keys[0],
 			 C_TO_XEN_STRING(snd_open_strerror())));
   return(args[orig_arg[0] - 1]);
 }
