@@ -527,7 +527,6 @@
 #define S_selection_p                   "selection?"
 #define S_selection_position            "selection-position"
 #define S_selection_srate               "selection-srate"
-#define S_send_mozilla                  "send-mozilla"
 #define S_short_file_name               "short-file-name"
 #define S_show_all_axes                 "show-all-axes"
 #define S_show_all_axes_unlabelled      "show-all-axes-unlabelled"
@@ -672,8 +671,6 @@
 #define S_widget_size                   "widget-size"
 #define S_widget_text                   "widget-text"
 #define S_window_height                 "window-height"
-#define S_window_property               "window-property"
-#define S_window_property_changed_hook  "window-property-changed-hook"
 #define S_window_width                  "window-width"
 #define S_window_x                      "window-x"
 #define S_window_y                      "window-y"
