@@ -13,32 +13,44 @@
  *   IBM ADPCM (as per Perry Cook)
  *   Yamaha TX-16 12-bit
  *   NeXT/Sun G721, G723 3 and 5 bit versions (also RIFF) (AIFC cases could be handled if they exist)
+ *
+ *   libavcodec has an amazing number of decoders -- are these useful in this context?
+ *   also libmpcodecs (available with MPlayer)
  */
 
 #include "snd.h"
 
+
+/* from io.c, but no longer in sndlib.h */
+void mus_bint_to_char(unsigned char *j, int x);
+void mus_bshort_to_char(unsigned char *j, short x);
+int mus_char_to_bint(const unsigned char *inp);
+short mus_char_to_bshort(const unsigned char *inp);
+short mus_char_to_lshort(const unsigned char *inp);
+
+
 #define TRANS_BUF_SIZE 8192
 
 static char write_error_buffer[PRINT_BUFFER_SIZE];
 
-static int snd_checked_write(int fd, unsigned char *buf, int bytes, const char *filename)
+static ssize_t snd_checked_write(int fd, unsigned char *buf, ssize_t bytes, const char *filename)
 {
   /* io.c checked_write assumes its file descriptors are around */
   /* can't call mus_error here because we need to clean up first in case of error */
-  int bytes_written;
-  off_t kfree;
+  ssize_t bytes_written;
+  mus_long_t kfree;
   kfree = disk_kspace(filename);
   if (kfree < 0) 
     {
       mus_snprintf(write_error_buffer, PRINT_BUFFER_SIZE,
 		   _("no space left on device: %s"),
-		   strerror(errno)); 
+		   snd_io_strerror()); 
       return(MUS_ERROR);
     }
   if (kfree < (bytes >> 10))
     { 
       mus_snprintf(write_error_buffer, PRINT_BUFFER_SIZE,
-		   _("only " PRId64 " bytes left on device (we need %d bytes)"),
+		   _("only " MUS_LD " bytes left on device (we need " SSIZE_TD " bytes)"),
 		   kfree << 10, bytes);
       return(MUS_ERROR);
     }
@@ -46,13 +58,14 @@ static int snd_checked_write(int fd, unsigned char *buf, int bytes, const char *
   if (bytes_written != bytes)
     {
       mus_snprintf(write_error_buffer, PRINT_BUFFER_SIZE,
-		   _("write error (wrote %d of requested %d bytes): %s"),
-		   bytes_written, bytes, strerror(errno));
+		   _("write error (wrote " SSIZE_TD " of requested " SSIZE_TD " bytes): %s"),
+		   bytes_written, bytes, snd_io_strerror());
       return(MUS_ERROR);
     }
   return(bytes_written);
 }
 
+
 static int be_snd_checked_write(int fd, unsigned char *buf, int bytes, const char *filename)
 {
   /* handle little-endian swap if necessary */
@@ -69,7 +82,9 @@ static int be_snd_checked_write(int fd, unsigned char *buf, int bytes, const cha
   return(snd_checked_write(fd, buf, bytes, filename));
 }
 
-#define RETURN_MUS_IO_ERROR(IO_Func, IO_Name) return(mus_error(MUS_CANT_OPEN_FILE, "translator: %s(%s) %s", IO_Func, IO_Name, strerror(errno)))
+
+#define RETURN_MUS_IO_ERROR(IO_Func, IO_Name) return(mus_error(MUS_CANT_OPEN_FILE, "translator: %s(%s) %s", IO_Func, IO_Name, snd_io_strerror()))
+
 
 #define RETURN_MUS_WRITE_ERROR(OldName, NewName) \
   do { \
@@ -79,18 +94,22 @@ static int be_snd_checked_write(int fd, unsigned char *buf, int bytes, const cha
     } \
   while (false)
 
+
 #define RETURN_MUS_ALLOC_ERROR(OldName, Bytes, VariableName) \
   return(mus_error(MUS_MEMORY_ALLOCATION_FAILED, "translate %s: can't allocate %d bytes for %s", OldName, Bytes, VariableName))
 
+
 /* I'm using the same variable names in most cases below, so these two macros save lots of repetition */
-#define CLEANUP() \
+
+#define CLEANUP(OldName, NewName)		\
   do { \
-      if (fs != -1) CLOSE(fs); \
-      if (fd != -1) CLOSE(fd); \
-      if (buf) FREE(buf); \
+    if (fs != -1) snd_close(fs, NewName); \
+    if (fd != -1) snd_close(fd, OldName); \
+      if (buf) free(buf); \
      } \
   while (false)
 
+
 #define STARTUP(OldName, NewName, BufSize, BufType) \
   do { \
     fs = CREAT(NewName, 0666); \
@@ -98,13 +117,13 @@ static int be_snd_checked_write(int fd, unsigned char *buf, int bytes, const cha
     fd = OPEN(OldName, O_RDONLY, 0); \
     if (fd == -1) \
       { \
-        CLEANUP(); \
+        CLEANUP(OldName, NewName); \
         RETURN_MUS_IO_ERROR("open", OldName); \
       } \
-    buf = (BufType *)CALLOC(BufSize, sizeof(BufType)); \
+    buf = (BufType *)calloc(BufSize, sizeof(BufType)); \
     if (buf == NULL) \
       { \
-        CLEANUP(); \
+        CLEANUP(OldName, NewName); \
         RETURN_MUS_ALLOC_ERROR(OldName, BufSize, "buf"); \
       } \
     } \
@@ -123,7 +142,8 @@ static int be_snd_checked_write(int fd, unsigned char *buf, int bytes, const cha
 
 static int read_midi_sample_dump(const char *oldname, const char *newname, char *hdr)
 {
-  int fs = -1, fd = -1, err = MUS_NO_ERROR, totalin, chans, srate, inp, outp;
+  int fs = -1, fd = -1, err = MUS_NO_ERROR, chans, srate, inp, outp;
+  ssize_t totalin;
   bool happy;
   int val = 0, bits, block_count, header_count, state, samples, shift1, shift2, offset;
   int osp;
@@ -141,7 +161,7 @@ static int read_midi_sample_dump(const char *oldname, const char *newname, char
   else mus_bint_to_char((unsigned char *)(hdr + 8), samples);
   if (snd_checked_write(fs, (unsigned char *)hdr, 28, newname) == MUS_ERROR)
     {
-      CLEANUP();
+      CLEANUP(oldname, newname);
       RETURN_MUS_WRITE_ERROR(oldname, newname);
     }
   happy = true;
@@ -180,7 +200,7 @@ static int read_midi_sample_dump(const char *oldname, const char *newname, char
 	{
 	  if (snd_checked_write(fs, (unsigned char *)hdr, TRANS_BUF_SIZE, newname) == MUS_ERROR) 
 	    {
-	      CLEANUP();
+	      CLEANUP(oldname, newname);
 	      RETURN_MUS_WRITE_ERROR(oldname, newname);
 	    }
 	  osp = 0;
@@ -234,7 +254,7 @@ static int read_midi_sample_dump(const char *oldname, const char *newname, char
 	}
     }
   if (outp > 0) err = snd_checked_write(fs, (unsigned char *)hdr, outp, newname);
-  CLEANUP();
+  CLEANUP(oldname, newname);
   if (err == MUS_ERROR) RETURN_MUS_WRITE_ERROR(oldname, newname);
   return(MUS_NO_ERROR);
 }
@@ -249,7 +269,8 @@ static int read_ieee_text(const char *oldname, const char *newname, char *hdr)
   /* look for "%sampling rate: nn.nn KHz\n", also get end of to comment (i.e. data location) */
   char str[32];
   char *buf = NULL;
-  int fd = -1, fs = -1, totalin;
+  int fd = -1, fs = -1;
+  ssize_t totalin;
   int inp, outp, op, i, j, s0, srate, err = MUS_NO_ERROR;
   bool commenting, happy;
   float fsrate;
@@ -307,7 +328,7 @@ static int read_ieee_text(const char *oldname, const char *newname, char *hdr)
     }
   if (srate == 0) 
     {
-      CLEANUP();
+      CLEANUP(oldname, newname);
       return(MUS_ERROR);
     }
   i = (outp % 4);
@@ -316,7 +337,7 @@ static int read_ieee_text(const char *oldname, const char *newname, char *hdr)
   mus_bint_to_char((unsigned char *)(hdr + 16), srate);
   if (snd_checked_write(fs, (unsigned char *)hdr, outp, newname) == MUS_ERROR) 
     {
-      CLEANUP();
+      CLEANUP(oldname, newname);
       RETURN_MUS_WRITE_ERROR(oldname, newname);
     }
   happy = true;
@@ -339,7 +360,7 @@ static int read_ieee_text(const char *oldname, const char *newname, char *hdr)
 	{
 	  if (snd_checked_write(fs, (unsigned char *)hdr, TRANS_BUF_SIZE, newname) == MUS_ERROR) 
 	    {
-	      CLEANUP();
+	      CLEANUP(oldname, newname);
 	      RETURN_MUS_WRITE_ERROR(oldname, newname);
 	    }
 	  osp = 0;
@@ -367,7 +388,7 @@ static int read_ieee_text(const char *oldname, const char *newname, char *hdr)
     }
   err = snd_checked_write(fs, (unsigned char *)hdr, outp, newname);
   /* update size field? */
-  CLEANUP();
+  CLEANUP(oldname, newname);
   if (err == MUS_ERROR) RETURN_MUS_WRITE_ERROR(oldname, newname);
   return(MUS_NO_ERROR);
 }
@@ -383,7 +404,8 @@ static int read_mus10(const char *oldname, const char *newname, char *hdr)
   /* nostalgic code -- 36 bit words, two 16-bit samples, right justified */
   /* or (even more archaeological) 12 bits packed 3 to a 36-bit word */
   unsigned char *buf = NULL;
-  int fd = -1, fs = -1, totalin, inp, outp, val, err = MUS_NO_ERROR;
+  int fd = -1, fs = -1, inp, outp, val, err = MUS_NO_ERROR;
+  ssize_t totalin;
   bool happy;
   int osp;
   float fsrate, fraction;
@@ -397,8 +419,8 @@ static int read_mus10(const char *oldname, const char *newname, char *hdr)
   /* PDP-10 floating point format was sign in bit 0 , excess 128 exponent in 1-8, fraction in 9-35 */
   if (srateH & 0400000) sign = -1; else sign = 1;
   exponent = ((srateH & 0377000) >> 9) - 128;
-  fraction = (float)(((srateH & 0777) << 18) | srateL) / snd_ipow2(27);
-  fsrate = sign * snd_ipow2(exponent) * fraction;
+  fraction = (float)(((srateH & 0777) << 18) | srateL) / snd_int_pow2(27);
+  fsrate = sign * snd_int_pow2(exponent) * fraction;
   if (fsrate > 6400.0) 
     mus_bint_to_char((unsigned char *)(hdr + 16), (int)fsrate);  
   else
@@ -412,7 +434,7 @@ static int read_mus10(const char *oldname, const char *newname, char *hdr)
   mus_bint_to_char((unsigned char *)(hdr + 20), chans);
   if ((mode != 4) && (mode != 0)) 
     {
-      CLEANUP();
+      CLEANUP(oldname, newname);
       return(mus_error(MUS_UNSUPPORTED_DATA_FORMAT,
 		       _("read_mus10: can't translate Mus10 file %s:\n  mode = %d\n"),
 		       oldname, mode));
@@ -422,7 +444,7 @@ static int read_mus10(const char *oldname, const char *newname, char *hdr)
   inp = 576;
   if (snd_checked_write(fs, (unsigned char *)hdr, 28, newname) == MUS_ERROR) 
     {
-      CLEANUP();
+      CLEANUP(oldname, newname);
       RETURN_MUS_WRITE_ERROR(oldname, newname);
     }
   happy = true;
@@ -444,7 +466,7 @@ static int read_mus10(const char *oldname, const char *newname, char *hdr)
 	{
 	  if (snd_checked_write(fs, (unsigned char *)hdr, TRANS_BUF_SIZE, newname) == MUS_ERROR) 
 	    {
-	      CLEANUP();
+	      CLEANUP(oldname, newname);
 	      RETURN_MUS_WRITE_ERROR(oldname, newname);
 	    }
 	  osp = 0;
@@ -478,7 +500,7 @@ static int read_mus10(const char *oldname, const char *newname, char *hdr)
 	}
     }
   err = snd_checked_write(fs, (unsigned char *)hdr, outp, newname);
-  CLEANUP();
+  CLEANUP(oldname, newname);
   if (err == MUS_ERROR) RETURN_MUS_WRITE_ERROR(oldname, newname);
   return(MUS_NO_ERROR);
 }
@@ -488,31 +510,42 @@ static int read_mus10(const char *oldname, const char *newname, char *hdr)
 
 static int read_hcom(const char *oldname, const char *newname, char *hdr)
 {
-  short **d;
+  short **d = NULL;
   int osp, isp;
-  int dc, di, bits, outp, totalin;
+  int dc = 0, di, bits, outp;
+  ssize_t totalin;
   bool happy;
   unsigned int curval = 0;
-  int i, sample, size, datum, count, err = MUS_NO_ERROR;
+  int i, sample, size = 0, datum, count = 0, err = MUS_NO_ERROR;
   unsigned char *buf = NULL;
   int fd = -1, fs = -1;
+  size_t bytes;
   STARTUP(oldname, newname, TRANS_BUF_SIZE, unsigned char);
   if (snd_checked_write(fs, (unsigned char *)hdr, 28, newname) == MUS_ERROR)
     {
-      CLEANUP();
+      CLEANUP(oldname, newname);
       RETURN_MUS_WRITE_ERROR(oldname, newname);
     }
   lseek(fd, 132, SEEK_SET);
-  read(fd, buf, 18);  /* count sum type div size */
-  count = mus_char_to_bint((unsigned char *)buf) - 1;
-  dc = mus_char_to_bint((unsigned char *)(buf + 8));
-  size = mus_char_to_bshort((unsigned char *)(buf + 16));
-  d = (short **)CALLOC(size, sizeof(short *));
-  read(fd, buf, size * 4 + 2); /* 2 for pad byte + first sample */
+  bytes = read(fd, buf, 18);  /* count sum type div size */
+  if (bytes != 0)
+    {
+      count = mus_char_to_bint((unsigned char *)buf) - 1;
+      dc = mus_char_to_bint((unsigned char *)(buf + 8));
+      size = mus_char_to_bshort((unsigned char *)(buf + 16));
+      d = (short **)calloc(size, sizeof(short *));
+      bytes = read(fd, buf, size * 4 + 2); /* 2 for pad byte + first sample */
+    }
+  if (bytes == 0)
+    {
+      if (d) free(d);
+      CLEANUP(oldname, newname);
+      RETURN_MUS_WRITE_ERROR(oldname, newname); /* read actually, but it's a generic message */
+    }
   osp = 0;
   for (i = 0; i < size; i++) 
     {
-      d[i] = (short *)CALLOC(2, sizeof(short));
+      d[i] = (short *)calloc(2, sizeof(short));
       d[i][0] = mus_char_to_bshort((unsigned char *)(buf + osp)); osp += 2;
       d[i][1] = mus_char_to_bshort((unsigned char *)(buf + osp)); osp += 2;
     }
@@ -541,9 +574,9 @@ static int read_hcom(const char *oldname, const char *newname, char *hdr)
 	{
 	  if (snd_checked_write(fs, (unsigned char *)hdr, TRANS_BUF_SIZE, newname) == MUS_ERROR) 
 	    {
-	      for (i = 0; i < size; i++) FREE(d[i]);
-	      FREE(d);
-	      CLEANUP();
+	      for (i = 0; i < size; i++) free(d[i]);
+	      free(d);
+	      CLEANUP(oldname, newname);
 	      RETURN_MUS_WRITE_ERROR(oldname, newname);
 	    }
 	  osp = 0;
@@ -560,7 +593,7 @@ static int read_hcom(const char *oldname, const char *newname, char *hdr)
 	  if (curval & 0x80000000) di = d[di][1]; else di = d[di][0];
 	  curval = curval << 1;
 	  bits--;
-	  if(d[di][0] < 0) 
+	  if (d[di][0] < 0) 
 	    {
 	      datum = d[di][1];
 	      if (!dc) sample = 0;
@@ -575,9 +608,9 @@ static int read_hcom(const char *oldname, const char *newname, char *hdr)
 	}
     }
   err = snd_checked_write(fs, (unsigned char *)hdr, outp, newname);
-  for (i = 0; i < size; i++) FREE(d[i]);
-  FREE(d);
-  CLEANUP();
+  for (i = 0; i < size; i++) free(d[i]);
+  free(d);
+  CLEANUP(oldname, newname);
   if (err == MUS_ERROR) RETURN_MUS_WRITE_ERROR(oldname, newname);
   return(MUS_NO_ERROR);
 }
@@ -589,7 +622,8 @@ static unsigned short log2s[] = {1, 2, 4, 8, 16, 32, 64, 128, 256, 512, 1024, 20
 
 static int read_nist_shortpack(const char *oldname, const char *newname, char *hdr)
 {
-  int fs = -1, fd = -1, err = MUS_NO_ERROR, totalin, chans, srate, outp, i = 0, k, num, bits = 0, out, els = 0;
+  int fs = -1, fd = -1, err = MUS_NO_ERROR, chans, srate, outp, i = 0, k, num, bits = 0, out, els = 0;
+  ssize_t totalin;
   bool happy;
   int isp, osp;
   unsigned short *ptr = NULL, *stop, *start, *kptr;
@@ -603,7 +637,7 @@ static int read_nist_shortpack(const char *oldname, const char *newname, char *h
   STARTUP(oldname, newname, TRANS_BUF_SIZE, unsigned char);
   if (snd_checked_write(fs, (unsigned char *)hdr, 28, newname) == MUS_ERROR)
     {
-      CLEANUP();
+      CLEANUP(oldname, newname);
       RETURN_MUS_WRITE_ERROR(oldname, newname);
     }
   lseek(fd, 1024, SEEK_SET);                       /* NIST header always 1024 bytes */
@@ -708,7 +742,7 @@ static int read_nist_shortpack(const char *oldname, const char *newname, char *h
 	{
 	  if (snd_checked_write(fs, (unsigned char *)hdr, TRANS_BUF_SIZE, newname) == MUS_ERROR)
 	    {
-	      CLEANUP();
+	      CLEANUP(oldname, newname);
 	      RETURN_MUS_WRITE_ERROR(oldname, newname);
 	    }
 	  osp = 0;
@@ -716,7 +750,7 @@ static int read_nist_shortpack(const char *oldname, const char *newname, char *h
 	}
     }
   err = snd_checked_write(fs, (unsigned char *)hdr, outp, newname);
-  CLEANUP();
+  CLEANUP(oldname, newname);
   if (err == MUS_ERROR) RETURN_MUS_WRITE_ERROR(oldname, newname);
   return(MUS_NO_ERROR);
 }
@@ -730,12 +764,11 @@ static int read_nist_shortpack(const char *oldname, const char *newname, char *h
 static int read_ibm_adpcm(const char *oldname, const char *newname, char *hdr)
 {
   short MAX_STEP = 2048, MIN_STEP = 16;
-  int totalin, i, j, k, fs = -1, fd = -1;
+  int i, j, k, fs = -1, fd = -1;
   unsigned char *buf = NULL;
   short *buf1;
-  off_t loc;
+  mus_long_t loc;
   short XHAT1 = 0, delndec, del1dec = 8, ln1dec, temp;
-  unsigned short data_in;
   float M[16] = {0.909, 0.909, 0.909, 0.909, 1.21, 1.4641, 1.771561, 2.143589, 0.909, 0.909, 0.909, 0.909, 1.21, 1.4641, 1.771561, 2.143589};
   float del_table[16] = {0.0, 0.25, 0.5, 0.75, 1.0, 1.25, 1.5, 1.75, 0.0, -0.25, -0.5, -0.75, -1.0, -1.25, -1.5, -1.75};
   loc = mus_sound_data_location(oldname);
@@ -744,17 +777,19 @@ static int read_ibm_adpcm(const char *oldname, const char *newname, char *hdr)
   STARTUP(oldname, newname, TRANS_BUF_SIZE, unsigned char);
   if (snd_checked_write(fs, (unsigned char *)hdr, 28, newname) == MUS_ERROR)
     {
-      CLEANUP();
+      CLEANUP(oldname, newname);
       RETURN_MUS_WRITE_ERROR(oldname, newname);
     }
   lseek(fd, loc, SEEK_SET);
-  buf1 = (short *)CALLOC(TRANS_BUF_SIZE, sizeof(short));
+  buf1 = (short *)calloc(TRANS_BUF_SIZE, sizeof(short));
   while (true)
     {
+      ssize_t totalin;
       totalin = read(fd, buf, TRANS_BUF_SIZE / 4);
       if (totalin <= 0) break;
       for (i = 0, j = 0; i < totalin; i += 2, j += 4)
 	{
+	  unsigned short data_in;
 	  data_in = (*((short *)(buf + i)));
 	  for (k = 0; k < 4; k++)
 	    {
@@ -773,13 +808,13 @@ static int read_ibm_adpcm(const char *oldname, const char *newname, char *hdr)
 	}
       if (be_snd_checked_write(fs, (unsigned char *)buf1, j * 2, newname) == MUS_ERROR) 
 	{
-	  FREE(buf1);
-	  CLEANUP();
+	  free(buf1);
+	  CLEANUP(oldname, newname);
 	  RETURN_MUS_WRITE_ERROR(oldname, newname);
 	}
     }
-  FREE(buf1);
-  CLEANUP();
+  free(buf1);
+  CLEANUP(oldname, newname);
   return(MUS_NO_ERROR);
 }
 
@@ -793,6 +828,7 @@ static int read_ibm_adpcm(const char *oldname, const char *newname, char *hdr)
  */
 
 static int indexTable[16] = {-1, -1, -1, -1, 2, 4, 6, 8, -1, -1, -1, -1, 2, 4, 6, 8};
+
 static int stepsizeTable[89] = {7, 8, 9, 10, 11, 12, 13, 14, 16, 17, 19, 21, 23, 25, 28, 31, 34, 37, 41, 45,
 				50, 55, 60, 66, 73, 80, 88, 97, 107, 118, 130, 143, 157, 173, 190, 209, 230, 253, 279, 307,
 				337, 371, 408, 449, 494, 544, 598, 658, 724, 796, 876, 963, 1060, 1166, 1282, 1411, 1552, 1707, 1878, 2066,
@@ -851,9 +887,9 @@ static int adpcm_decoder(unsigned char *indata, short *outdata, int totalbytes,
 
 static int read_dvi_adpcm(const char *oldname, const char *newname, char *hdr, int type)
 {
-  int fs = -1, fd = -1, totalin, chans, srate, blksiz, samps, samps_read;
+  int fs = -1, fd = -1, chans, srate, blksiz, samps, samps_read;
   unsigned char *buf = NULL;
-  off_t loc;
+  mus_long_t loc;
   loc = mus_sound_data_location(oldname);
   chans = mus_sound_chans(oldname);
   blksiz = mus_sound_block_align(oldname);
@@ -868,24 +904,25 @@ static int read_dvi_adpcm(const char *oldname, const char *newname, char *hdr, i
   STARTUP(oldname, newname, blksiz, unsigned char);
   if (snd_checked_write(fs, (unsigned char *)hdr, 28, newname) == MUS_ERROR)
     {
-      CLEANUP();
+      CLEANUP(oldname, newname);
       RETURN_MUS_WRITE_ERROR(oldname, newname);
     }
   lseek(fd, loc, SEEK_SET);
   samps_read = 0;
   while (samps > 0)
     {
+      ssize_t totalin;
       totalin = read(fd, buf, blksiz);
       if (totalin < blksiz) break;
       samps_read = adpcm_decoder(buf, (short *)hdr, totalin, type);
       if (be_snd_checked_write(fs, (unsigned char *)hdr, samps_read * 2, newname) == MUS_ERROR) 
 	{
-	  CLEANUP();
+	  CLEANUP(oldname, newname);
 	  RETURN_MUS_WRITE_ERROR(oldname, newname);
 	}
       samps -= samps_read;
     }
-  CLEANUP();
+  CLEANUP(oldname, newname);
   return(MUS_NO_ERROR);
 }
 
@@ -907,15 +944,16 @@ static short oki_step_size[49] = { 16, 17, 19, 21, 23, 25, 28, 31, 34, 37, 41,
 
 static short oki_adjust[8] = {-1, -1, -1, -1, 2, 4, 6, 8};
 
+
 static short oki_adpcm_decode(char code, struct oki_adpcm_status *stat) 
 {
-  short diff, E, SS, samp;
-  SS = oki_step_size[stat->step_index];
-  E = SS/8;
-  if (code & 0x01) E += SS / 4;
-  if (code & 0x02) E += SS / 2;
-  if (code & 0x04) E += SS;
-  diff = (code & 0x08) ? -E : E;
+  short diff, E8, SS8, samp; /* SS apparently a predefined macro in Solaris 10.4/opteron */
+  SS8 = oki_step_size[stat->step_index];
+  E8 = SS8/8;
+  if (code & 0x01) E8 += SS8 / 4;
+  if (code & 0x02) E8 += SS8 / 2;
+  if (code & 0x04) E8 += SS8;
+  diff = (code & 0x08) ? -E8 : E8;
   samp = stat->last + diff;
   if (samp > 2048) samp = 2048;
   if (samp < -2048) samp = -2048;
@@ -928,11 +966,13 @@ static short oki_adpcm_decode(char code, struct oki_adpcm_status *stat)
   return(samp << 4);
 }
 
+
 static int read_oki_adpcm(const char *oldname, const char *newname, char *hdr)
 {
-  int fs = -1, fd = -1, i, j, totalin, chans, srate, blksiz, samps, samps_read;
+  int fs = -1, fd = -1, i, j, chans, srate, blksiz, samps, samps_read;
+  ssize_t totalin;
   unsigned char *buf = NULL;
-  off_t loc;
+  mus_long_t loc;
   short *buf1;
   struct oki_adpcm_status stat;
   chans = mus_sound_chans(oldname);
@@ -944,7 +984,7 @@ static int read_oki_adpcm(const char *oldname, const char *newname, char *hdr)
   blksiz = mus_sound_block_align(oldname);
   if (blksiz == 0) blksiz = 256;
   STARTUP(oldname, newname, blksiz, unsigned char);
-  buf1 = (short *)CALLOC(blksiz * 2, sizeof(short));
+  buf1 = (short *)calloc(blksiz * 2, sizeof(short));
   samps = mus_sound_fact_samples(oldname);
   if (samps == 0) samps = (int)mus_sound_frames(oldname);
   srate = mus_sound_srate(oldname);
@@ -952,8 +992,8 @@ static int read_oki_adpcm(const char *oldname, const char *newname, char *hdr)
   mus_bint_to_char((unsigned char *)(hdr + 20), chans);
   if (snd_checked_write(fs, (unsigned char *)hdr, 28, newname) == MUS_ERROR)
     {
-      FREE(buf1);
-      CLEANUP();
+      free(buf1);
+      CLEANUP(oldname, newname);
       RETURN_MUS_WRITE_ERROR(oldname, newname);
     }
   lseek(fd, loc, SEEK_SET);
@@ -973,26 +1013,29 @@ static int read_oki_adpcm(const char *oldname, const char *newname, char *hdr)
       samps_read = totalin * 2;
       if (be_snd_checked_write(fs, (unsigned char *)buf1, samps_read * 2, newname) == MUS_ERROR) 
 	{
-	  FREE(buf1);
-	  CLEANUP();
+	  free(buf1);
+	  CLEANUP(oldname, newname);
 	  RETURN_MUS_WRITE_ERROR(oldname, newname);
 	}
       samps -= samps_read;
     }
-  FREE(buf1);
-  CLEANUP();
+  free(buf1);
+  CLEANUP(oldname, newname);
   return(MUS_NO_ERROR);
 }
 
+
+
 /* -------------------------------- 12 bit cases --------------------------------
  */
 
 static int read_12bit(const char *oldname, const char *newname, char *hdr)
 {
-  int chans, totalin, i, j, fs = -1, fd = -1;
+  int chans, i, j, fs = -1, fd = -1;
+  ssize_t totalin;
   unsigned char *buf = NULL;
   short *buf1;
-  off_t loc, samps;
+  mus_long_t loc, samps;
   loc = mus_sound_data_location(oldname);
   chans = mus_sound_chans(oldname);
   samps = mus_sound_samples(oldname);
@@ -1001,11 +1044,11 @@ static int read_12bit(const char *oldname, const char *newname, char *hdr)
   STARTUP(oldname, newname, ((int)(TRANS_BUF_SIZE * 1.5)), unsigned char);
   if (snd_checked_write(fs, (unsigned char *)hdr, 28, newname) == MUS_ERROR)
     {
-      CLEANUP();
+      CLEANUP(oldname, newname);
       RETURN_MUS_WRITE_ERROR(oldname, newname);
     }
   lseek(fd, loc, SEEK_SET);
-  buf1 = (short *)CALLOC(TRANS_BUF_SIZE, sizeof(short));
+  buf1 = (short *)calloc(TRANS_BUF_SIZE, sizeof(short));
   while (samps > 0)
     {
       totalin = read(fd, buf, (int)(TRANS_BUF_SIZE * 1.5));
@@ -1017,14 +1060,14 @@ static int read_12bit(const char *oldname, const char *newname, char *hdr)
 	}
       if (be_snd_checked_write(fs, (unsigned char *)buf1, j * 2, newname) == MUS_ERROR) 
 	{
-	  FREE(buf1);
-	  CLEANUP();
+	  free(buf1);
+	  CLEANUP(oldname, newname);
 	  RETURN_MUS_WRITE_ERROR(oldname, newname);
 	}
       samps -= j;
     }
-  FREE(buf1);
-  CLEANUP();
+  free(buf1);
+  CLEANUP(oldname, newname);
   return(MUS_NO_ERROR);
 }
 
@@ -1034,6 +1077,7 @@ static int read_12bit(const char *oldname, const char *newname, char *hdr)
  */
 
 struct g72x_state {long yl; short yu; short dms; short dml; short ap; short a[2]; short b[6]; short pk[2]; short dq[6]; short sr[2]; char td;};
+
 static short power2[15] = {1, 2, 4, 8, 0x10, 0x20, 0x40, 0x80, 0x100, 0x200, 0x400, 0x800, 0x1000, 0x2000, 0x4000};
 
 static int quan(int val, short *table, int size)
@@ -1041,9 +1085,10 @@ static int quan(int val, short *table, int size)
   int i;
   for (i = 0; i < size; i++)
     if (val < *table++) break;
-  return (i);
+  return(i);
 }
 
+
 static int fmult(int an, int srn)
 {
   short	anmag, anexp, anmant;
@@ -1055,9 +1100,10 @@ static int fmult(int an, int srn)
   wanexp = anexp + ((srn >> 6) & 0xF) - 13;
   wanmant = (anmant * (srn & 077) + 0x30) >> 4;
   retval = (wanexp >= 0) ? ((wanmant << wanexp) & 0x7FFF) : (wanmant >> -wanexp);
-  return (((an ^ srn) < 0) ? -retval : retval);
+  return(((an ^ srn) < 0) ? -retval : retval);
 }
 
+
 static void g72x_init_state(struct g72x_state *state_ptr)
 {
   int cnta;
@@ -1080,23 +1126,26 @@ static void g72x_init_state(struct g72x_state *state_ptr)
   state_ptr->td = 0;
 }
 
+
 static int predictor_zero(struct g72x_state *state_ptr)
 {
   int i, sezi;
   sezi = fmult(state_ptr->b[0] >> 2, state_ptr->dq[0]);
   for (i = 1; i < 6; i++) sezi += fmult(state_ptr->b[i] >> 2, state_ptr->dq[i]);
-  return (sezi);
+  return(sezi);
 }
 
+
 static int predictor_pole(struct g72x_state *state_ptr)
 {
-  return (fmult(state_ptr->a[1] >> 2, state_ptr->sr[1]) + fmult(state_ptr->a[0] >> 2, state_ptr->sr[0]));
+  return(fmult(state_ptr->a[1] >> 2, state_ptr->sr[1]) + fmult(state_ptr->a[0] >> 2, state_ptr->sr[0]));
 }
 
+
 static int step_size(struct g72x_state *state_ptr)
 {
   int y, dif, al;
-  if (state_ptr->ap >= 256)  return (state_ptr->yu);
+  if (state_ptr->ap >= 256)  return(state_ptr->yu);
   else 
     {
       y = state_ptr->yl >> 6;
@@ -1104,23 +1153,25 @@ static int step_size(struct g72x_state *state_ptr)
       al = state_ptr->ap >> 2;
       if (dif > 0) y += (dif * al) >> 6;
       else if (dif < 0) y += (dif * al + 0x3F) >> 6;
-      return (y);
+      return(y);
     }
 }
 
+
 static int reconstruct(int sign, int dqln, int y)
 {
   short	dql, dex, dqt, dq;
   dql = dqln + (y >> 2);
-  if (dql < 0) {return ((sign) ? -0x8000 : 0);} 
+  if (dql < 0) {return((sign) ? -0x8000 : 0);} 
   else {
     dex = (dql >> 7) & 15;
     dqt = 128 + (dql & 127);
     dq = (dqt << 7) >> (14 - dex);
-    return ((sign) ? (dq - 0x8000) : dq);
+    return((sign) ? (dq - 0x8000) : dq);
   }
 }
 
+
 static void update(int	code_size, int y, int wi, int fi, int dq, int sr, int dqsez, struct g72x_state *state_ptr)
 {
   int cnt;
@@ -1217,6 +1268,7 @@ static void update(int	code_size, int y, int wi, int fi, int dq, int sr, int dqs
     state_ptr->ap += (-state_ptr->ap) >> 4;
 }
 
+
 static int g721_decoder(int i, struct g72x_state *state_ptr)
 {
   static short dqlntab[16] = {-2048, 4, 135, 213, 273, 323, 373, 425, 425, 373, 323, 273, 213, 135, 4, -2048};
@@ -1233,9 +1285,10 @@ static int g721_decoder(int i, struct g72x_state *state_ptr)
   sr = (dq < 0) ? (se - (dq & 0x3FFF)) : se + dq;
   dqsez = sr - se + sez;
   update(4, y, witab[i] << 5, fitab[i], dq, sr, dqsez, state_ptr);
-  return (sr << 2);
+  return(sr << 2);
 }
 
+
 static int g723_24_decoder(int	i, struct g72x_state *state_ptr)
 {
   static short dqlntab[8] = {-2048, 135, 273, 373, 373, 273, 135, -2048};
@@ -1252,9 +1305,10 @@ static int g723_24_decoder(int	i, struct g72x_state *state_ptr)
   sr = (dq < 0) ? (se - (dq & 0x3FFF)) : (se + dq);
   dqsez = sr - se + sez;
   update(3, y, witab[i], fitab[i], dq, sr, dqsez, state_ptr);
-  return (sr << 2);
+  return(sr << 2);
 }
 
+
 static int g723_40_decoder(int i, struct g72x_state *state_ptr)
 {
   static short dqlntab[32] = {-2048, -66, 28, 104, 169, 224, 274, 318, 358, 395, 429, 459, 488, 514, 539, 566,
@@ -1274,9 +1328,10 @@ static int g723_40_decoder(int i, struct g72x_state *state_ptr)
   sr = (dq < 0) ? (se - (dq & 0x7FFF)) : (se + dq);
   dqsez = sr - se + sez;
   update(5, y, witab[i], fitab[i], dq, sr, dqsez, state_ptr);
-  return (sr << 2);
+  return(sr << 2);
 }
 
+
 static bool unpack_input(FILE *fin, unsigned char *code, int bits)
 {
   static unsigned int in_buffer = 0;
@@ -1298,13 +1353,15 @@ static bool unpack_input(FILE *fin, unsigned char *code, int bits)
   return(true);
 }
 
+
 static int read_g72x_adpcm(const char *oldname, const char *newname, char *hdr, int which_g)
 {
   int fs = -1, j, chans, srate, dec_bits = 0, err = MUS_NO_ERROR;
   FILE *fd;
-  off_t loc;
+  mus_long_t loc;
   unsigned char code;
   short *buf = NULL;
+  size_t bytes;
   struct g72x_state state;
   g72x_init_state(&state);
   chans = mus_sound_chans(oldname);
@@ -1330,14 +1387,21 @@ static int read_g72x_adpcm(const char *oldname, const char *newname, char *hdr,
       snd_fclose(fd, oldname);
       RETURN_MUS_WRITE_ERROR(oldname, newname);
     }
-  buf = (short *)CALLOC(TRANS_BUF_SIZE, sizeof(short));
+  buf = (short *)calloc(TRANS_BUF_SIZE, sizeof(short));
   if (buf == NULL) 
     {
       snd_close(fs, newname); 
       snd_fclose(fd, oldname); 
       RETURN_MUS_ALLOC_ERROR(oldname, TRANS_BUF_SIZE, "buf");
     }
-  fread(buf, 1, loc, fd);
+  bytes = fread(buf, 1, loc, fd);
+  if (bytes == 0)
+    {
+      snd_close(fs, newname); 
+      snd_fclose(fd, oldname); 
+      free(buf); 
+      RETURN_MUS_WRITE_ERROR(oldname, newname);
+    }
   switch (which_g)
     {
     case 0: /* G721 */ dec_bits = 4; break;
@@ -1359,7 +1423,7 @@ static int read_g72x_adpcm(const char *oldname, const char *newname, char *hdr,
 	    {
 	      snd_close(fs, newname); 
 	      snd_fclose(fd, oldname); 
-	      FREE(buf); 
+	      free(buf); 
 	      RETURN_MUS_WRITE_ERROR(oldname, newname);
 	    }
 	  j = 0;
@@ -1368,7 +1432,7 @@ static int read_g72x_adpcm(const char *oldname, const char *newname, char *hdr,
   if (j > 0) err = be_snd_checked_write(fs, (unsigned char *)buf, j * 2, newname);
   snd_close(fs, newname);
   snd_fclose(fd, oldname);
-  FREE(buf);
+  free(buf);
   if (err == MUS_ERROR) RETURN_MUS_WRITE_ERROR(oldname, newname);
   return(MUS_NO_ERROR);
 }
@@ -1379,18 +1443,14 @@ static int read_g72x_adpcm(const char *oldname, const char *newname, char *hdr,
 
 #define RIFF_Intel_ADPCM 0x11
 #define RIFF_Oki_ADPCM 0x10
-#define RIFF_G721 0x40
 #define RIFF_G723 0x14
 #define RIFF_MS_G723 0x42
 #define RIFF_Lucent_G723 0x59
 #define RIFF_Vivo_G723 0x111
-#define RIFF_Gsm610 0x31
 #define RIFF_G721 0x40
-#define RIFF_MPEG 0x50
 #define RIFF_MS_ADPCM 2
 #define RIFF_IBM_ADPCM 0x103
 #define NeXT_G721 23
-#define NeXT_G722 24
 #define NeXT_G723 25
 #define NeXT_G723_5 26
 
@@ -1406,37 +1466,72 @@ static const char *any_format_name(const char *name)
 					      mus_sound_header_type(name)));
 }
 
+
 int snd_translate(const char *oldname, const char *newname, int type)
 {
   /* read oldname, translate to newname as 16-bit linear NeXT file */
   /* called from snd-file.c */
   int err;
   char *hdr = NULL;
-  if (MUS_CANT_TRANSLATE == 0) MUS_CANT_TRANSLATE = mus_make_error("can't translate");
+
+  if (MUS_CANT_TRANSLATE == 0) MUS_CANT_TRANSLATE = mus_make_error((char *)"can't translate");
   err = MUS_CANT_TRANSLATE;
-  hdr = (char *)CALLOC(TRANS_BUF_SIZE, sizeof(char));
+
+  hdr = (char *)calloc(TRANS_BUF_SIZE, sizeof(char));
   /* set up default output header */
-  mus_bint_to_char((unsigned char *)hdr, 0x2e736e64); /* .snd */
+  mus_bint_to_char((unsigned char *)hdr, 0x2e736e64);   /* .snd */
   mus_bint_to_char((unsigned char *)(hdr + 4), 28);     /* data location */
   mus_bint_to_char((unsigned char *)(hdr + 8), 0);      /* bytes in data portion */
   mus_bint_to_char((unsigned char *)(hdr + 12), 3);     /* 16-bit linear */
   mus_bint_to_char((unsigned char *)(hdr + 16), 22050);
   mus_bint_to_char((unsigned char *)(hdr + 20), 1);     /* chans */
+
   switch (type)
     {
-    case MUS_MIDI_SAMPLE_DUMP: err = read_midi_sample_dump(oldname, newname, hdr); break;
-    case MUS_IEEE: err = read_ieee_text(oldname, newname, hdr); break;
-    case MUS_MUS10: err = read_mus10(oldname, newname, hdr); break;
-    case MUS_HCOM: err = read_hcom(oldname, newname, hdr); break;
-    case MUS_YAMAHA_TX16W: err = read_12bit(oldname, newname, hdr); break;
-    case MUS_NVF: err = read_g72x_adpcm(oldname, newname, hdr, 0); break;
+    case MUS_MIDI_SAMPLE_DUMP: 
+      err = read_midi_sample_dump(oldname, newname, hdr); 
+      break;
+
+    case MUS_IEEE: 
+      err = read_ieee_text(oldname, newname, hdr); 
+      break;
+
+    case MUS_MUS10: 
+      err = read_mus10(oldname, newname, hdr); 
+      break;
+
+    case MUS_HCOM: 
+      err = read_hcom(oldname, newname, hdr); 
+      break;
+
+    case MUS_YAMAHA_TX16W: 
+      err = read_12bit(oldname, newname, hdr); 
+      break;
+
+    case MUS_NVF: 
+      err = read_g72x_adpcm(oldname, newname, hdr, 0); 
+      break;
+
+    case MUS_RF64:
     case MUS_RIFF:
       switch (mus_sound_original_format(oldname))
 	{
-	case RIFF_MS_ADPCM: case RIFF_Intel_ADPCM: err = read_dvi_adpcm(oldname, newname, hdr, 0); break;
-	case RIFF_IBM_ADPCM: err = read_ibm_adpcm(oldname, newname, hdr); break;
-	case RIFF_Oki_ADPCM: err = read_oki_adpcm(oldname, newname, hdr); break;
-	case RIFF_G721: err = read_g72x_adpcm(oldname, newname, hdr, 0); break; /* untested */
+	case RIFF_MS_ADPCM: case RIFF_Intel_ADPCM: 
+	  err = read_dvi_adpcm(oldname, newname, hdr, 0); 
+	  break;
+
+	case RIFF_IBM_ADPCM: 
+	  err = read_ibm_adpcm(oldname, newname, hdr); 
+	  break;
+
+	case RIFF_Oki_ADPCM: 
+	  err = read_oki_adpcm(oldname, newname, hdr); 
+	  break;
+
+	case RIFF_G721: 
+	  err = read_g72x_adpcm(oldname, newname, hdr, 0); 
+	  break; /* untested */
+
 	case RIFF_G723: case RIFF_MS_G723: case RIFF_Lucent_G723: case RIFF_Vivo_G723: /* untested */
 	  if (mus_sound_bits_per_sample(oldname) == 3)
 	    err = read_g72x_adpcm(oldname, newname, hdr, 1);
@@ -1446,42 +1541,41 @@ int snd_translate(const char *oldname, const char *newname, int type)
 	  break;
 	}
       break;
+
     case MUS_NIST:
       if (mus_sound_original_format(oldname) == MUS_NIST_SHORTPACK) 
 	err = read_nist_shortpack(oldname, newname, hdr); 
       break;
+
     case MUS_NEXT:
       switch (mus_sound_original_format(oldname))
 	{
-	case NeXT_G721: err = read_g72x_adpcm(oldname, newname, hdr, 0); break;
-	case NeXT_G723: err = read_g72x_adpcm(oldname, newname, hdr, 1); break;
+	case NeXT_G721:   err = read_g72x_adpcm(oldname, newname, hdr, 0); break;
+	case NeXT_G723:   err = read_g72x_adpcm(oldname, newname, hdr, 1); break;
 	case NeXT_G723_5: err = read_g72x_adpcm(oldname, newname, hdr, 2); break;
 	}
       break;
+
     case MUS_AIFC:
       if (mus_sound_original_format(oldname) == MUS_AIFF_IMA_ADPCM) 
 	err = read_dvi_adpcm(oldname, newname, hdr, 1); 
       break;
-    case MUS_MATLAB:
-      /* assume all vectors are channels */
+ 
+    case MUS_OGG: case MUS_SPEEX: case MUS_FLAC: case MUS_MIDI: case MUS_MPEG:
+    case MUS_SHORTEN: case MUS_TTA: case MUS_WAVPACK:
+    default:
+      if (snd_decode(type, oldname, newname) == 0)
+	err = MUS_NO_ERROR;
       break;
     }
-  FREE(hdr);
-  if (err == MUS_CANT_TRANSLATE) /* i.e a case we don't even try to handle */
-    {
-      if (ss->catch_exists)
-	return(mus_error(MUS_CANT_TRANSLATE,
-			 _("can't translate %s\n  (%s header: %s (0x%x) data format)\n"),
-			 oldname,
-			 mus_header_type_name(type),
-			 any_format_name(oldname),
-			 mus_sound_original_format(oldname)));
-      else 
-	snd_error(_("can't translate %s\n  (%s header: %s (0x%x) data format)\n"),
+
+  free(hdr);
+  if (err == MUS_CANT_TRANSLATE)
+    return(mus_error(MUS_CANT_TRANSLATE,
+		     _("can't translate %s\n  (%s header: %s (0x%x) data format)\n"),
 		     oldname,
 		     mus_header_type_name(type),
 		     any_format_name(oldname),
-		     mus_sound_original_format(oldname));
-    }
+		     mus_sound_original_format(oldname)));
   return(err);
 }
