@@ -265,24 +265,6 @@ disk_space_t disk_space_p(mus_long_t bytes, const char *filename)
 }
 
 
-#if HAVE_LANGINFO_DECIMAL_POINT || HAVE_LANGINFO_RADIXCHAR
-  #include <langinfo.h>
-#endif
-
-static char decimal_pt;
-
-static char local_decimal_point(void)
-{
-#if HAVE_LANGINFO_DECIMAL_POINT
-  return(nl_langinfo(DECIMAL_POINT)[0]);
-#endif
-#if HAVE_LANGINFO_RADIXCHAR
-  return(nl_langinfo(RADIXCHAR)[0]);
-#endif
-  return('.');
-}
-
-
 char *prettyf(double num, int tens)
 { 
   /* try to prettify float display -- if tens <= 0, return int */
@@ -341,7 +323,6 @@ char *shorter_tempnam(const char *udir, const char *prefix)
 
 char *snd_tempnam(void)
 {
-  /* problem here is that NULL passed back from Guile becomes "" which is not NULL from tempnam's point of view */
   char *udir;
   udir = temp_dir(ss);
   if ((udir) && (*udir))
@@ -350,17 +331,23 @@ char *snd_tempnam(void)
 }
 
 
+#if MUS_PORTAUDIO
+#include <portaudio.h>
+#endif
+
 void snd_exit(int val)
 {
 #ifndef SND_AS_WIDGET
+#if MUS_PORTAUDIO
+  Pa_Terminate();
+#endif
   exit(val);
 #endif
 }
 
 
-/* PERHAPS: glib now has a "gio" module that provides a fam-like service: HAVE_GFILEMONITOR or libgiofam?
- *            or is this just a fam wrapper?
- */
+/* glib now has a "gio" module that provides a fam-like service, but it requires using gio style file handlers throughout. */
+
 
 /* ---------------- file alteration monitor (fam or gamin) ---------------- */
 #if HAVE_FAM
@@ -683,7 +670,6 @@ static XEN g_file_to_string(XEN name)
 
 void g_init_utils(void)
 {
-  decimal_pt = local_decimal_point();
 #if HAVE_SCHEME
   XEN_DEFINE_PROCEDURE(S_file_to_string, g_file_to_string_w, 1, 0, 0, "file contents as string");
 #endif
