@@ -17,25 +17,15 @@
 #define LOTSA_PIXELS 10000
 #define XEN_WRAP_WIDGET(Value)       ((Value) ? XEN_LIST_2(C_STRING_TO_XEN_SYMBOL("Widget"), XEN_WRAP_C_POINTER(Value)) : XEN_FALSE)
 #define XEN_WRAP_WINDOW(Value)       ((Value) ? XEN_LIST_2(C_STRING_TO_XEN_SYMBOL("Window"), C_TO_XEN_ULONG(Value)) : XEN_FALSE)
-#define XEN_WRAP_PIXEL(Value)        XEN_LIST_2(C_STRING_TO_XEN_SYMBOL("Pixel"), C_TO_XEN_INT((int)Value))
-                                     /* not ulong here! -- messes up the equal? check */
 #define XEN_UNWRAP_WIDGET(Value)     (XEN_LIST_P(Value) ? XEN_UNWRAP_C_POINTER(XEN_CADR(Value)) : 0)
-#define XEN_UNWRAP_PIXEL(Value)      (unsigned long)XEN_TO_C_INT(XEN_CADR(Value))
 #define XEN_WIDGET_P(Value)          (XEN_LIST_P(Value) && (XEN_LIST_LENGTH(Value) >= 2) && (XEN_SYMBOL_P(XEN_CAR(Value))) && \
                                       (strcmp("Widget", XEN_SYMBOL_TO_C_STRING(XEN_CAR(Value))) == 0))
-#define XEN_PIXEL_P(Value)           (XEN_LIST_P(Value) && (XEN_LIST_LENGTH(Value) >= 2) && (XEN_SYMBOL_P(XEN_CAR(Value))) && \
-                                      (strcmp("Pixel", XEN_SYMBOL_TO_C_STRING(XEN_CAR(Value))) == 0))
 #define NULL_WIDGET NULL
 
 typedef enum {NOT_ACTIVATABLE, ACTIVATABLE, NOT_ACTIVATABLE_OR_FOCUSED, ACTIVATABLE_BUT_NOT_FOCUSED} text_cr_t;
 
-#ifdef MUS_SGI
-  #define LINE_MARGIN 10
-  #define CONTROLS_MARGIN 0
-#else
-  #define LINE_MARGIN 4
-  #define CONTROLS_MARGIN 1
-#endif
+#define LINE_MARGIN 4
+#define CONTROLS_MARGIN 1
 
 #define SCROLLBAR_MAX 10000
 
@@ -179,7 +169,7 @@ typedef enum {WITHOUT_COMMENT_FIELD, WITH_COMMENT_FIELD} dialog_comment_t;
 
 #define snd_ShiftMask ShiftMask
 #define snd_ControlMask ControlMask
-#ifndef MUS_SUN
+#if (!HAVE_SUN)
   #define snd_MetaMask Mod1Mask
 #else
   #define snd_MetaMask (Mod1Mask | Mod4Mask)
