@@ -111,8 +111,6 @@ void save_colors(FILE *Fp);
   void snd_as_widget(int argc, char **argv, XtAppContext app, Widget parent, Arg *caller_args, int caller_argn);
 #endif
 
-void g_init_gxmain(void);
-
 
 
 /* -------- snd-xfft.c -------- */
@@ -170,13 +168,6 @@ int regrow_get_pos(void *ur);
 void g_init_gxregion(void);
 
 
-/* -------- snd-gxutils -------- */
-
-bool send_mozilla(const char *html_viewer, const char *url);
-void g_init_gxutils(void);
-
-
-
 /* -------- snd-gxbitmaps.c -------- */
 
 const char **mini_bomb_bits(int n);
