@@ -667,7 +667,7 @@ static XEN eval_file_wrapper(void *data)
 }
 
 
-char *g_print_1(XEN obj) /* free return val */
+static char *g_print_1(XEN obj) /* free return val */
 {
 #if HAVE_SCHEME
   return(XEN_AS_STRING(obj)); 
@@ -688,6 +688,10 @@ static char *gl_print(XEN result)
   char *newbuf = NULL, *str = NULL;
   int i, ilen, savelen;
 
+#if HAVE_SCHEME
+  return(g_print_1(result));
+#endif
+
   /* specialize vectors which can be enormous in this context */
   if ((!(XEN_VECTOR_P(result))) || 
       ((int)(XEN_VECTOR_LENGTH(result)) <= print_length(ss)))
@@ -697,7 +701,7 @@ static char *gl_print(XEN result)
   newbuf = (char *)calloc(128, sizeof(char));
   savelen = 128;
 
-#if HAVE_SCHEME || HAVE_FORTH
+#if HAVE_FORTH
   sprintf(newbuf, "#("); 
 #endif
 
@@ -722,7 +726,7 @@ static char *gl_print(XEN result)
 	}
     }
 
-#if HAVE_SCHEME || HAVE_FORTH
+#if HAVE_FORTH
   newbuf = mus_strcat(newbuf, " ...)", &savelen);
 #endif
 
@@ -2558,99 +2562,22 @@ static char *legalize_path(const char *in_str)
 } 
 
 
-/* -------------------------------------------------------------------------------- */
-
-#if HAVE_SCHEME
-/* an experiment */
-
-/* TODO: needs read-line etc. also minibuffer funcs.
- *          string_to_minbuffer(cp, str)? snd-kbd 1066 snd_minibuffer_activate
- *       looks like both forms need a flag or something: read_line_waiting
- *
- * (read-char (minibuffer-input-port index))
- * (let ((port (minibuffer-input-port index))) (read-char port)).
- */
-
-static s7_pointer listener_read(s7_scheme *sc, s7_read_t read_choice, s7_pointer port)
+#if HAVE_GL
+static XEN g_snd_glx_context(void)
 {
-  switch (read_choice)
-    {
-    case S7_READ_CHAR:
-    case S7_READ_BYTE:
-      {
-	char c;
-	while (ss->listener_char == 0) check_for_event();
-	c = ss->listener_char;
-	ss->listener_char = 0;
-	if (read_choice == S7_READ_CHAR)
-	  return(s7_make_character(s7, c));
-	return(s7_make_integer(s7, (s7_Int)c));
-      }
-
-    case S7_IS_CHAR_READY:
-      return((ss->listener_char) ? xen_true : xen_false);
-
-    case S7_PEEK_CHAR:
-      return(s7_make_character(s7, ss->listener_char));
-
-    case S7_READ_LINE:
-    case S7_READ:
-      /* wait for activation, if read_line return string else eval it and return value? -- need read-from-string */
-      /*  => (with-input-from-string <line> (lambda () (read))) */
-      fprintf(stderr, "can't handle this read choice yet");
-    }
-  return(xen_false);
-}
-
-static void listener_write(s7_scheme *sc, unsigned char c, s7_pointer port)
-{
-  char str[2];
-  str[0] = c;
-  str[1] = 0;
-  append_listener_text(-1, str); /* -1 means get eot after append and move cursor to it */
-  ss->listener_char = 0;
-  /* (let () (format (listener-output-port) "~%;a prompt: ") (read-char (listener-input-port))) */
-}
+  return(XEN_LIST_2(C_STRING_TO_XEN_SYMBOL("GLXContext"), 
+		    XEN_WRAP_C_POINTER(ss->sgx->cx)));
+} 
 
 
-#if 0
-static void minibuffer_write(s7_scheme *sc, char c, s7_pointer port)
-{
-  int index;
-  index = (int)s7_port_data(port);
-  /* need open at snd pane creation, s7_port_set_data(port, (void *)(snd->index))
-   * need minibuffer_append
-   */
-}
+#ifdef XEN_ARGIFY_1
+XEN_NARGIFY_0(g_snd_glx_context_w, g_snd_glx_context)
+#else
+#define g_snd_glx_context_w g_snd_glx_context
+#endif
 #endif
 
 
-static s7_pointer listener_input_port, listener_output_port;
-
-static s7_pointer g_listener_input_port(s7_scheme *sc, s7_pointer args)
-{
-  return(listener_input_port);
-}
-
-static s7_pointer g_listener_output_port(s7_scheme *sc, s7_pointer args)
-{
-  return(listener_output_port);
-}
-
-static void init_listener_ports(void)
-{
-  listener_input_port = s7_open_input_function(s7, listener_read);
-  s7_gc_protect(s7, listener_input_port);
-
-  listener_output_port = s7_open_output_function(s7, listener_write);
-  s7_gc_protect(s7, listener_output_port);
-
-  s7_define_function(s7, "listener-input-port", g_listener_input_port, 0, 0, false, "(listener-input-port) returns a port to read from the listener text widget");
-  s7_define_function(s7, "listener-output-port", g_listener_output_port, 0, 0, false, "(listener-output-port) returns a port to write to the listener text widget");
-}
-
-#endif
-
 
 /* -------------------------------------------------------------------------------- */
 void g_xen_initialize(void)
@@ -2793,14 +2720,12 @@ If it returns some non-#f result, Snd assumes you've sent the text out yourself,
   g_init_env();
   g_init_find();
 #if (!USE_NO_GUI)
-  g_init_gxutils();
   g_init_gxcolormaps();
   g_init_gxfile();
   g_init_gxdraw();
   g_init_gxenv();
   g_init_gxmenu();
   g_init_axis();
-  g_init_gxmain();
   g_init_gxlistener();
   g_init_gxchn();
   g_init_draw();
@@ -2839,7 +2764,6 @@ If it returns some non-#f result, Snd assumes you've sent the text out yourself,
   } 
 
 #if HAVE_SCHEME
-  init_listener_ports();
   XEN_DEFINE_PROCEDURE("_snd_s7_error_handler_", g_snd_s7_error_handler_w,  0, 0, 1, "internal error redirection for snd/s7");
 
   XEN_EVAL_C_STRING("(define redo-edit redo)");        /* consistency with Ruby */
@@ -2941,6 +2865,9 @@ If it returns some non-#f result, Snd assumes you've sent the text out yourself,
                        (snd-print (apply format #f args)))");
 #endif
 
+#if HAVE_GL
+  XEN_DEFINE_PROCEDURE("snd-glx-context", g_snd_glx_context_w, 0, 0, 0, "OpenGL GLXContext");
+#endif
 
 #if HAVE_STATIC_XM
   #if USE_MOTIF
