@@ -273,8 +273,10 @@ static void env_redisplay_1(printing_t printing)
 	  name = XmTextGetString(textL);
 	  if (!name) name = mus_strdup(_("noname"));
 	  /* active_env can be null here if just showing axes (empty initial graph) */
-
-	  if (enved_wave_p(ss))
+	  
+	  if ((enved_wave_p(ss)) &&
+	      (active_channel) &&
+	      (!(active_channel->squelch_update)))
 	    {
 	      if ((enved_target(ss) == ENVED_SPECTRUM) && (active_env) && (FIR_p) && (printing == NOT_PRINTING))
 		display_frequency_response(active_env, axis, gray_ap->ax, enved_filter_order(ss), enved_in_dB(ss));
@@ -288,9 +290,15 @@ static void env_redisplay_1(printing_t printing)
 }
 
 
-void env_redisplay(void) {env_redisplay_1(NOT_PRINTING);}
+void env_redisplay(void) 
+{
+  env_redisplay_1(NOT_PRINTING);
+}
 
-void env_redisplay_with_print(void) {env_redisplay_1(PRINTING);}
+void env_redisplay_with_print(void) 
+{
+  env_redisplay_1(PRINTING);
+}
 
 
 void update_enved_background_waveform(chan_info *cp)
@@ -523,7 +531,7 @@ static void enved_display_point_label(mus_float_t x, mus_float_t y)
 }
 
 
-#ifdef MUS_MAC_OSX
+#if HAVE_OSX
 static int press_x, press_y;
 #endif
 
@@ -535,7 +543,7 @@ static void drawer_button_motion(Widget w, XtPointer context, XEvent *event, Boo
   if (!showing_all_envs)
     {
       mus_float_t x, y;
-#ifdef MUS_MAC_OSX
+#if HAVE_OSX
       if ((ev->x == press_x) && (ev->y == press_y)) return;
 #endif
       env_editor_button_motion_with_xy(ss->enved, ev->x, ev->y, ev->time, active_env, &x, &y);
@@ -549,7 +557,7 @@ static void drawer_button_press(Widget w, XtPointer context, XEvent *event, Bool
 {
   XButtonEvent *ev = (XButtonEvent *)event;
   int pos;
-#ifdef MUS_MAC_OSX
+#if HAVE_OSX
   press_x = ev->x;
   press_y = ev->y;
 #endif
@@ -1049,9 +1057,7 @@ Widget create_envelope_editor(void)
       XtSetArg(args[n], XmNrightAttachment, XmATTACH_FORM); n++;
       XtSetArg(args[n], XmNcolumns, 3); n++;
       XtSetArg(args[n], XmNrecomputeSize, false); n++;
-#ifndef MUS_SGI
       XtSetArg(args[n], XmNheight, 24); n++;
-#endif
       XtSetArg(args[n], XmNresizeWidth, false); n++;
       XtSetArg(args[n], XmNalignment, XmALIGNMENT_BEGINNING); n++;	
       XtSetArg(args[n], XmNmarginHeight, 0); n++;
@@ -1668,7 +1674,7 @@ static XEN g_set_enved_envelope(XEN e)
   else active_env = xen_to_env(e);
   if ((!active_env) && (!(XEN_LIST_P(e))))
     XEN_ERROR(NO_SUCH_ENVELOPE,
-	      XEN_LIST_2(C_TO_XEN_STRING(S_setB S_enved_envelope),
+	      XEN_LIST_2(C_TO_XEN_STRING(S_setB S_enved_envelope ": bad envelope arg: ~A"),
 			 e));
   if (enved_dialog) 
     env_redisplay();
