@@ -195,7 +195,7 @@ void map_over_children(Widget w, void (*func)(Widget uw))
 {
   /* apply func to each child in entire tree beneath top widget */
   /* taken from Douglas Young, "Motif Debugging and Performance Tuning" Prentice-Hall 1995 */
-  /* used mostly to get colors right in non-SGI environments with "convenience" widgets */
+  /* used mostly to get colors right in environments with "convenience" widgets */
   if (w)
     {
       unsigned int i;
@@ -667,7 +667,7 @@ static Pixmap rotate_text(Widget w, const char *str, XFontStruct *font, mus_floa
   rotpix= XCreatePixmap(dp, wn, nwidth, nheight, depth);
   XFillRectangle(dp, pix, d_gc, 0, 0, width, height);
   XFillRectangle(dp, rotpix, d_gc, 0, 0, nwidth, nheight);
-#ifdef MUS_SUN
+#if HAVE_SUN
   XSync(dp, 0);
   /* needed to get the numbers drawn at all */
 #endif
