@@ -3,8 +3,6 @@
  * originally intended as a re-implementation of my much-missed dpysnd -- the Foonly/SAIL/E/Mus10/Grnlib sound editor from ca 1983.
  */
 
-/* SOMEDAY: use emacs as the listener via the xembed protocol? (this connection is not quite ready) */
-
 #include "snd.h"
 
 snd_state *ss = NULL;
@@ -29,9 +27,6 @@ static bool ignore_mus_error(int type, char *msg)
 
 void mus_error_to_snd(int type, char *msg)
 {
-  /* it's possible to get here outside any catch, and in Guile a throw in that case
-   *   kills the main program!
-   */
   if (!ss)
     {
       fprintf(stderr, "%s", msg);
@@ -42,22 +37,18 @@ void mus_error_to_snd(int type, char *msg)
 
   if (!(ignore_mus_error(type, msg)))
     {
-      if (ss->catch_exists)
-	{
-	  if (msg == NULL)
-	    XEN_ERROR(XEN_ERROR_TYPE("mus-error"),
-		      XEN_LIST_1(C_TO_XEN_STRING((char *)mus_error_type_to_string(type))));
-	  else XEN_ERROR(XEN_ERROR_TYPE("mus-error"),
-			 XEN_LIST_1(C_TO_XEN_STRING(msg)));
-	}
-      else
-	{
-	  snd_error("%s: %s", mus_error_type_to_string(type), msg);
+#if HAVE_EXTENSION_LANGUAGE
+      if (msg == NULL)
+	XEN_ERROR(XEN_ERROR_TYPE("mus-error"),
+		  XEN_LIST_1(C_TO_XEN_STRING((char *)mus_error_type_to_string(type))));
+      else XEN_ERROR(XEN_ERROR_TYPE("mus-error"),
+		     XEN_LIST_1(C_TO_XEN_STRING(msg)));
+#endif
+      snd_error("%s: %s", mus_error_type_to_string(type), msg);
 #if HAVE_SETJMP_H
-	  ss->jump_ok = true;
-	  top_level_catch(1); /* sigh -- try to keep going */
+      ss->jump_ok = true;
+      top_level_catch(1); /* sigh -- try to keep going */
 #endif
-	}
     }
 }
 
@@ -224,6 +215,8 @@ void snd_set_global_defaults(bool need_cleanup)
   ss->Show_Axes = DEFAULT_SHOW_AXES;
   ss->Show_Indices = DEFAULT_SHOW_INDICES;
   ss->Show_Backtrace = DEFAULT_SHOW_BACKTRACE;
+  ss->With_Inset_Graph = DEFAULT_WITH_INSET_GRAPH;
+  ss->With_Pointer_Focus = DEFAULT_WITH_POINTER_FOCUS;
 
   ss->Listener_Prompt = mus_strdup(DEFAULT_LISTENER_PROMPT);
   ss->listener_prompt_length = mus_strlen(ss->Listener_Prompt);
@@ -296,6 +289,10 @@ void snd_set_global_defaults(bool need_cleanup)
     ss->Save_State_File = mus_strdup(DEFAULT_SAVE_STATE_FILE); 
   else ss->Save_State_File = NULL;
 
+  if (DEFAULT_PEAK_ENV_DIR != (char *)NULL) 
+    ss->Peak_Env_Dir = mus_strdup(DEFAULT_PEAK_ENV_DIR); 
+  else ss->Peak_Env_Dir = NULL;
+  
   ss->Enved_Base = DEFAULT_ENVED_BASE;
   ss->Enved_Power = DEFAULT_ENVED_POWER;
   ss->Enved_Wave_p = DEFAULT_ENVED_WAVE_P;
@@ -354,7 +351,7 @@ static void snd_sigusr1(int ignored)
   XEN_ERROR(XEN_ERROR_TYPE("snd-top-level"), XEN_EMPTY_LIST);
 }
 
-#if HAVE_S7
+#if HAVE_SCHEME
 static void jump_to_top_level(void)
 {
   top_level_catch(1);
@@ -385,13 +382,12 @@ static void handle_sigquit(int ignored)
 static void snd_gsl_error(const char *reason, const char *file, int line, int gsl_errno)
 {
   XEN_ERROR(XEN_ERROR_TYPE("gsl-error"),
-	    XEN_LIST_3(C_TO_XEN_STRING("GSL"),
-		       C_TO_XEN_STRING("~A, ~A in ~A line ~A, gsl err: ~A"),
-		       XEN_LIST_5(C_TO_XEN_STRING(gsl_strerror(gsl_errno)),
-				  C_TO_XEN_STRING(reason),
-				  C_TO_XEN_STRING(file),
-				  C_TO_XEN_INT(line),
-				  C_TO_XEN_INT(gsl_errno))));
+	    XEN_LIST_6(C_TO_XEN_STRING("GSL: ~A, ~A in ~A line ~A, gsl err: ~A"),
+		       C_TO_XEN_STRING(gsl_strerror(gsl_errno)),
+		       C_TO_XEN_STRING(reason),
+		       C_TO_XEN_STRING(file),
+		       C_TO_XEN_INT(line),
+		       C_TO_XEN_INT(gsl_errno)));
 }
 #endif
 
@@ -399,11 +395,7 @@ static void snd_gsl_error(const char *reason, const char *file, int line, int gs
 #if SND_AS_WIDGET
   snd_state *snd_main(int argc, char **argv)
 #else
-  #if HAVE_GUILE
-    static void snd_main(void *closure, int argc, char **argv)
-  #else
-    int main(int argc, char **argv)
-  #endif
+  int main(int argc, char **argv)
 #endif
 {
   int i;
@@ -416,23 +408,6 @@ static void snd_gsl_error(const char *reason, const char *file, int line, int gs
   gsl_set_error_handler(snd_gsl_error);
 #endif
 
-#if ENABLE_NLS && HAVE_GETTEXT && defined(LOCALE_DIR)
-  /* both flags needed to avoid idiotic confusion on the Sun */
-  #if HAVE_SETLOCALE
-    setlocale (LC_ALL, "");
-  #endif
-  bindtextdomain(SND_PACKAGE, LOCALE_DIR);
-  textdomain (SND_PACKAGE);
-  /*
-    (bindtextdomain "snd" "/usr/local/share/locale")
-    (textdomain "snd")
-    (define _ gettext)
-    (display (_ "no selection"))
-
-    but that is limited to Snd's messages
-  */
-#endif
-
   ss = (snd_state *)calloc(1, sizeof(snd_state)); /* not calloc! */
   ss->fam_ok = false;
   ss->cg_seen = false;
@@ -441,7 +416,7 @@ static void snd_gsl_error(const char *reason, const char *file, int line, int gs
   mus_sound_initialize(); /* has to precede version check (mus_audio_moniker needs to be setup in Alsa/Oss) */
   xen_initialize();
 
-#if HAVE_S7 && HAVE_SETJMP_H
+#if HAVE_SCHEME && HAVE_SETJMP_H
   s7_set_error_exiter(s7, jump_to_top_level);
 #endif
 
@@ -465,6 +440,7 @@ static void snd_gsl_error(const char *reason, const char *file, int line, int gs
 
   initialize_format_lists();
   snd_set_global_defaults(false);
+
 #if MUS_DEBUGGING
   ss->Trap_Segfault = false;
 #else
@@ -489,7 +465,6 @@ static void snd_gsl_error(const char *reason, const char *file, int line, int gs
   ss->print_choice = PRINT_SND;
   ss->graph_hook_active = false;
   ss->lisp_graph_hook_active = false;
-  ss->error_lock = false;
   ss->exiting = false;
   ss->deferred_regions = 0;
   ss->fam_connection = NULL;
@@ -501,11 +476,6 @@ static void snd_gsl_error(const char *reason, const char *file, int line, int gs
   ss->xen_error_handler = NULL;
   ss->update_sound_channel_style = NOT_A_CHANNEL_STYLE;
 
-#if USE_NO_GUI || HAVE_RUBY || HAVE_FORTH || HAVE_S7
-  ss->catch_exists = 1; /* scm_shell for USE_NO_GUI case */
-#else
-  ss->catch_exists = 0;
-#endif
 #if HAVE_GL && MUS_WITH_GL2PS
   ss->gl_printing = false;
 #endif
@@ -522,7 +492,7 @@ static void snd_gsl_error(const char *reason, const char *file, int line, int gs
   signal(SIGUSR1, snd_sigusr1);
 #endif
 
-#if HAVE_S7 && defined(SIGQUIT)
+#if HAVE_SCHEME && defined(SIGQUIT)
   sigaction(SIGQUIT, NULL, &old_act);
   if (old_act.sa_handler != SIG_IGN)
     {
@@ -532,43 +502,13 @@ static void snd_gsl_error(const char *reason, const char *file, int line, int gs
     }
 #endif
 
-#ifdef SND_AS_PD_EXTERNAL
-  return;
+#ifdef SND_AS_WIDGET
+  return(ss); 
 #else
-  #ifdef SND_AS_WIDGET
-    return(ss); 
-  #else
-    snd_doit(argc, argv);
-    #if (!HAVE_GUILE)
-      return(0);
-    #endif
-  #endif
-#endif
-}
-
-
-#ifndef SND_AS_WIDGET
-  #ifndef SND_AS_PD_EXTERNAL
-    #if HAVE_GUILE
-    int main(int argc, char *argv[])
-     {
-       scm_boot_guile(argc, argv, snd_main, 0);
-       /* anything after this call will not be executed */
-       return(0);
-     }
-    #endif
-  #endif
-#endif
-
-
-#ifdef SND_AS_PD_EXTERNAL
-int snd_pd_main(void)
-{
-  char *argv[] = {"pd", "-noglob", "-noinit"};
-  snd_main(NULL, 3, argv);
+  snd_doit(argc, argv);
   return(0);
-}
 #endif
+}
 
 
 void g_init_base(void)
