@@ -13,54 +13,12 @@
 #define S_mus_alsa_device               "mus-alsa-device"
 #define S_mus_alsa_playback_device      "mus-alsa-playback-device"
 #define S_mus_alsa_squelch_warning      "mus-alsa-squelch-warning"
-#define S_mus_audio_adat_in             "mus-audio-adat-in"
-#define S_mus_audio_adat_out            "mus-audio-adat-out"
-#define S_mus_audio_aes_in              "mus-audio-aes-in"
-#define S_mus_audio_aes_out             "mus-audio-aes-out"
-#define S_mus_audio_amp                 "mus-audio-amp"
-#define S_mus_audio_aux_input           "mus-audio-aux-input"
-#define S_mus_audio_aux_output          "mus-audio-aux-output"
-#define S_mus_audio_bass                "mus-audio-bass"
-#define S_mus_audio_cd                  "mus-audio-cd"
-#define S_mus_audio_channel             "mus-audio-channel"
 #define S_mus_audio_close               "mus-audio-close"
-#define S_mus_audio_dac_filter          "mus-audio-dac-filter"
-#define S_mus_audio_dac_out             "mus-audio-dac-out"
 #define S_mus_audio_default             "mus-audio-default"
-#define S_mus_audio_digital_in          "mus-audio-digital-in"
-#define S_mus_audio_digital_out         "mus-audio-digital-out"
-#define S_mus_audio_direction           "mus-audio-direction"
-#define S_mus_audio_duplex_default      "mus-audio-duplex-default"
-#define S_mus_audio_format              "mus-audio-format"
-#define S_mus_audio_igain               "mus-audio-igain"
-#define S_mus_audio_imix                "mus-audio-imix"
-#define S_mus_audio_line                "mus-audio-line"
-#define S_mus_audio_line1               "mus-audio-line1"
-#define S_mus_audio_line2               "mus-audio-line2"
-#define S_mus_audio_line3               "mus-audio-line3"
-#define S_mus_audio_line_in             "mus-audio-line-in"
-#define S_mus_audio_line_out            "mus-audio-line-out"
-#define S_mus_audio_microphone          "mus-audio-microphone"
-#define S_mus_audio_mixer               "mus-audio-mixer"
-#define S_mus_audio_mixer_read          "mus-audio-mixer-read"
-#define S_mus_audio_mixer_write         "mus-audio-mixer-write"
-#define S_mus_audio_ogain               "mus-audio-ogain"
+#define S_mus_audio_describe            "mus-audio-describe"
 #define S_mus_audio_open_input          "mus-audio-open-input"
 #define S_mus_audio_open_output         "mus-audio-open-output"
-#define S_mus_audio_pcm                 "mus-audio-pcm"
-#define S_mus_audio_pcm2                "mus-audio-pcm2"
-#define S_mus_audio_port                "mus-audio-port"
 #define S_mus_audio_read                "mus-audio-read"
-#define S_mus_audio_reclev              "mus-audio-reclev"
-#define S_mus_audio_report              "mus-audio-report"
-#define S_mus_audio_samples_per_channel "mus-audio-samples-per-channel"
-#define S_mus_audio_spdif_in            "mus-audio-spdif-in"
-#define S_mus_audio_spdif_out           "mus-audio-spdif-out"
-#define S_mus_audio_speakers            "mus-audio-speakers"
-#define S_mus_audio_srate               "mus-audio-srate"
-#define S_mus_audio_synth               "mus-audio-synth"
-#define S_mus_audio_systems             "mus-audio-systems"
-#define S_mus_audio_treble              "mus-audio-treble"
 #define S_mus_audio_write               "mus-audio-write"
 #define S_mus_b24int                    "mus-b24int"
 #define S_mus_bdouble                   "mus-bdouble"
@@ -96,7 +54,6 @@
 #define S_mus_max_malloc                "mus-max-malloc"
 #define S_mus_max_table_size            "mus-max-table-size"
 #define S_mus_mulaw                     "mus-mulaw"
-#define S_mus_netbsd_set_outputs        "mus-netbsd-set-outputs"
 #define S_mus_next                      "mus-next"
 #define S_mus_nist                      "mus-nist"
 #define S_mus_oss_set_buffers           "mus-oss-set-buffers"
@@ -134,7 +91,6 @@
 #define S_mus_sound_write               "mus-sound-write"
 #define S_mus_sound_write_date          "mus-sound-write-date"
 #define S_mus_soundfont                 "mus-soundfont"
-#define S_mus_sun_set_outputs           "mus-sun-set-outputs"
 #define S_mus_svx                       "mus-svx"
 #define S_mus_ubshort                   "mus-ubshort"
 #define S_mus_ubyte                     "mus-ubyte"
