@@ -2,8 +2,6 @@
 
 (provide 'sndlib-ws.scm)
 
-(use-modules (ice-9 optargs) (ice-9 format))
-
 (define *clm-srate* 44100)
 (define *clm-file-name* "test.snd")
 (define *clm-channels* 1)
@@ -74,28 +72,28 @@
 ;;; -------- with-sound --------
 
 (define* (with-sound-helper thunk 
-			    :key (srate *clm-srate*) 
-			          (output *clm-file-name*) 
-				  (channels *clm-channels*)
-				  (header-type *clm-header-type*)
-				  (data-format *clm-data-format*)
-				  (comment #f)
-				  (verbose *clm-verbose*)
-				  (reverb *clm-reverb*)
-				  (revfile "test.rev")
-				  (reverb-data *clm-reverb-data*)
-				  (reverb-channels *clm-reverb-channels*)
-				  (continue-old-file #f)
-				  (statistics *clm-statistics*)
-				  (scaled-to #f)
-				  (play *clm-play*)
-				  (clipped 'unset)
-				  (notehook *clm-notehook*)               ; (with-sound (:notehook (lambda args (display args))) (fm-violin 0 1 440 .1))
-				  (scaled-by #f)
-				  (ignore-output #f)
-				  (thread-output #f)
-				  (thread-reverb #f)
-				  (output-safety *clm-output-safety*))
+			    (srate *clm-srate*) 
+			    (output *clm-file-name*) 
+			    (channels *clm-channels*)
+			    (header-type *clm-header-type*)
+			    (data-format *clm-data-format*)
+			    (comment #f)
+			    (verbose *clm-verbose*)
+			    (reverb *clm-reverb*)
+			    (revfile "test.rev")
+			    (reverb-data *clm-reverb-data*)
+			    (reverb-channels *clm-reverb-channels*)
+			    (continue-old-file #f)
+			    (statistics *clm-statistics*)
+			    (scaled-to #f)
+			    (scaled-by #f)
+			    (play *clm-play*)
+			    (clipped 'unset)
+			    (notehook *clm-notehook*)               ; (with-sound (:notehook (lambda args (display args))) (fm-violin 0 1 440 .1))
+			    (ignore-output #f)
+			    (thread-output #f)
+			    (thread-reverb #f)
+			    (output-safety *clm-output-safety*))
   "with-sound-helper is the business portion of the with-sound macro"
   (let* ((old-srate (mus-srate))
 	 (old-*output* *output*)
@@ -103,8 +101,11 @@
 	 (in-debugger #f)
 	 (old-notehook *clm-notehook*)
 	 (old-verbose *clm-verbose*)
-	 (output-1 output)                    ; protect during nesting
 	 (output-to-file (string? output))
+	 (output-1 (if (and output-to-file
+			    (or scaled-to scaled-by))
+		       (string-append output ".temp") 
+		       output))                    ; protect during nesting
 	 (reverb-1 revfile)
 	 (reverb-to-file (and reverb (string? revfile))))
 
@@ -145,7 +146,8 @@
 			 (if (file-exists? output-1) 
 			     (delete-file output-1))
 			 (set! *output* (make-sample->file output-1 channels data-format header-type comment))))
-		   (set! (mus-safety *output*) output-safety))
+		   (if *output*
+		       (set! (mus-safety *output*) output-safety)))
 		 (begin
 		   (if (not continue-old-file)
 		       (if (vct? output-1)
@@ -163,7 +165,8 @@
 			     (if (file-exists? reverb-1) 
 				 (delete-file reverb-1))
 			     (set! *reverb* (make-sample->file reverb-1 reverb-channels data-format header-type))))
-		       (set! (mus-safety *reverb*) output-safety))
+		       (if *reverb*
+			   (set! (mus-safety *reverb*) output-safety)))
 		     (begin
 		       (if (not continue-old-file)
 			   (if (vct? reverb-1)
@@ -225,56 +228,67 @@
 	     (if output-to-file
 		 (mus-close *output*)))
 
-	 (let ((snd-output #f)
-	       (cur-sync #f))
-	   (if statistics
-	       (begin
-		 (set! cycles (exact->inexact (/ (- (get-internal-real-time) start) internal-time-units-per-second)))
-		 (display (format #f "~%;~A:~%  maxamp~A:~{ ~,4F~}~%~A  compute time: ~,3F~%"
-				  (if output-to-file
-				      output-1
-				      (if (vct? output-1) "vct" 
-					  (if (sound-data? output-1) "sound-data"
-					      (if (procedure? output-1) "function" 
-						  "flush"))))
-				  (if (or scaled-to scaled-by) 
-				      " (before scaling)" 
-				      "")
-				  (if output-to-file
-				      (let ((lst (mus-sound-maxamp output-1)))
-					(do ((i 0 (+ i 2)))
-					    ((>= i (length lst)))
-					  (list-set! lst i (/ (list-ref lst i) (mus-srate))))
-					lst)
-				      (if (vct? output-1)
-					  (list (vct-peak output-1))
-					  (if (sound-data? output-1)
-					      (sound-data-maxamp output-1)
-					      0.0)))
-				  (if revmax (format #f "  rev max: ~,4F~%" revmax) "")
-				  cycles))))
+	 (if statistics 
+	     (begin
+	       (set! cycles (exact->inexact (/ (- (get-internal-real-time) start) internal-time-units-per-second)))
+	       (display (format #f "~%;~A:~%  maxamp~A:~{ ~,4F~}~%~A  compute time: ~,3F~%"
+				(if output-to-file
+				    (if (or scaled-to scaled-by)
+					(substring output-1 0 (- (string-length output-1) 5))
+					output-1)
+				    (if (vct? output-1) "vct" 
+					(if (sound-data? output-1) "sound-data"
+					    (if (procedure? output-1) "function" 
+						"flush"))))
+				(if (or scaled-to scaled-by) 
+				    " (before scaling)" 
+				    "")
+				(if output-to-file
+				    (let ((lst (mus-sound-maxamp output-1)))
+				      (do ((i 0 (+ i 2)))
+					  ((>= i (length lst)))
+					(list-set! lst i (/ (list-ref lst i) (mus-srate))))
+				      lst)
+				    (if (vct? output-1)
+					(list (vct-peak output-1))
+					(if (sound-data? output-1)
+					    (sound-data-maxamp output-1)
+					    0.0)))
+				(if revmax (format #f "  rev max: ~,4F~%" revmax) "")
+				cycles))))
 
-	   (if (or scaled-to scaled-by)
-	       (if output-to-file
-		   ;; someday scale the output
-		   (display "can't scale output yet")
-		   (if (vct? output-1)
-		       (if scaled-to
-			   (let ((pk (vct-peak output-1)))
-			     (if (> pk 0.0)
-				 (vct-scale! output-1 (/ scaled-to pk))))
-			   (vct-scale! output-1 scaled-by))
-		       (if (sound-data? output-1)
-			   (if scaled-to
-			       (let ((pk (sound-data-peak output-1)))
-				 (if (> pk 0.0)
-				     (sound-data-scale! output-1 (/ scaled-to pk))))
-			       (sound-data-scale! output-1 scaled-by))))))
+	 (if (or scaled-to scaled-by)
+	     (if output-to-file
+		 (let ((scaling
+			(or scaled-by
+			    (let* ((mx-lst (mus-sound-maxamp output-1))
+				   (mx (if (not (null? mx-lst)) (cadr mx-lst) 1.0)))
+			      (do ((i 1 (+ i 2)))
+				  ((>= i (length mx-lst)) (/ scaled-to mx))
+				(set! mx (max mx (list-ref mx-lst i)))))))
+		       (out-file (substring output-1 0 (- (string-length output-1) 5))))
+		   (mus-sound-close-output (mus-sound-open-output out-file srate channels data-format header-type) 0)
+		   (mus-mix out-file output-1 0 (mus-sound-frames output-1) 0 (make-scalar-mixer channels scaling))
+		   (delete-file output-1)
+		   (set! output-1 (substring output-1 0 (- (string-length output-1) 5))))
 
-	   (if (and *clm-player* play output-to-file)
-	       (*clm-player* output-1)))
+		 (if (vct? output-1)
+		     (if scaled-to
+			 (let ((pk (vct-peak output-1)))
+			   (if (> pk 0.0)
+			       (vct-scale! output-1 (/ scaled-to pk))))
+			 (vct-scale! output-1 scaled-by))
+		     (if (sound-data? output-1)
+			 (if scaled-to
+			     (let ((pk (sound-data-peak output-1)))
+			       (if (> pk 0.0)
+				   (sound-data-scale! output-1 (/ scaled-to pk))))
+			     (sound-data-scale! output-1 scaled-by))))))
 
-	 output-1))
+	 (if (and *clm-player* play output-to-file)
+	     (*clm-player* output-1)))
+
+       output-1)
 
      (lambda () 
        (set! *clm-verbose* old-verbose)
@@ -307,7 +321,7 @@
      ;; with-sound but using tempnam for output (can be over-ridden by explicit :output)
      (dynamic-wind
 	 (lambda () 
-	   (set! *clm-file-name* (snd-tempnam)))
+	   (set! *clm-file-name* (tmpnam)))
 	 (lambda ()
 	   (with-sound-helper (lambda () ,@body) ,@args)) ; dynamic-wind returns this as its result
 	 (lambda ()
@@ -315,8 +329,6 @@
 
 
 ;;; -------- clm-load --------
-;;;
-;;; CM wants this to be a function so that it can use apply
 
 (define (clm-load file . args) 
   "(clm-load file . args) loads 'file' in the context of with-sound"
@@ -349,7 +361,7 @@
 ;;; -------- Common Music --------
 
 (define* (init-with-sound
-	  :key (srate *clm-srate*) 
+	  (srate *clm-srate*) 
 	  (output *clm-file-name*) 
 	  (channels *clm-channels*)
 	  (header-type *clm-header-type*)
@@ -459,91 +471,12 @@ finish-with-sound to complete the process."
      (list-set! w 9 val))))
 
 
-
-
-;;; -------- def-optkey-fun --------
-;;;
-;;; this is a translation of CLM's def-optkey-fun
-
-(defmacro def-optkey-fun (decls . body)
-  (let ((func-name (car decls))
-	(func-args (cdr decls)))
-    (if (null? func-args)
-	`(define (,func-name) ,@body)
-	(let ((args (map (lambda (arg)
-			   (symbol->keyword (if (list? arg) (car arg) arg)))
-			 func-args))
-	      (key-name (string->symbol (string-append (symbol->string func-name) "-1"))))
-	  (if (= (length func-args) 1)
-	      `(begin
-		 (define* (,key-name :key ,@func-args) ,@body)
-		 (define* (,func-name :rest passed-args)
-		   (if (or (null? passed-args)
-			   (keyword? (car passed-args)))
-		       (apply ,key-name passed-args)
-		       (apply ,key-name ,(car args) passed-args))))
-	      `(begin
-		 (define* (,key-name :key ,@func-args) ,@body)
-		 (define* (,func-name :rest passed-args)
-		   (if (or (null? passed-args)
-			   (keyword? (car passed-args)))
-		       (apply ,key-name passed-args)
-		       (let ((arglen (length passed-args)))
-			 (if (or (= arglen 1) 
-				 (and (> arglen 2) 
-				      (keyword? (cadr passed-args))))
-			     (apply ,key-name ,(car args) (car passed-args) (cdr passed-args))
-			     (if (or (= arglen 2) 
-				     (and (> arglen 3) 
-					  (keyword? (caddr passed-args))))
-				 (apply ,key-name 
-					,(car args) (car passed-args) 
-					,(cadr args) (cadr passed-args) 
-					(cddr passed-args))
-				 (let ((allargs (call-with-exit
-						 (lambda (break)
-						   (let ((arglist '())
-							 (pa passed-args)
-							 (na ',args))
-						     (do ((k 0 (+ k 1)))
-							 ((= k arglen) arglist)
-						       (if (keyword? (car pa))
-							   (break (append arglist pa))
-							   (begin
-							     (set! arglist (append arglist (list (car na) (car pa))))
-							     (set! pa (cdr pa))
-							     (set! na (cdr na))))))))))
-				   (apply ,key-name allargs)))))))))))))
-
-(defmacro def-optkey-instrument (args . body)
-  (let* ((name (car args))
-	 (targs (cdr args))
-	 (utargs (let ((arg-names '()))
-		   (for-each
-		    (lambda (a)
-		      (if (not (keyword? a))
-			  (if (symbol? a)
-			      (set! arg-names (cons a arg-names))
-			      (set! arg-names (cons (car a) arg-names)))))
-		    targs)
-		   (reverse arg-names))))
-  `(begin 
-     (def-optkey-fun (,name ,@targs)
-       (if *clm-notehook*
-	   (*clm-notehook* (symbol->string ',name) ,@utargs))
-       ((lambda () ; for inner defines, if any
-	  ,@body)))
-     ,@(if *definstrument-hook*
-           (list (*definstrument-hook* name targs))
-           (list)))))
-
-
 (define ->frequency
   (let ((main-pitch (/ 440.0 (expt 2.0 (/ 57 12)))) ; a4 = 440Hz is pitch 57 in our numbering
 	(last-octave 0)                             ; octave number can be omitted
 	(ratios (vector 1.0 256/243 9/8 32/27 81/64 4/3 1024/729 3/2 128/81 27/16 16/9 243/128 2.0)))
-    (lambda* (pitch :optional pythagorean)          ; pitch can be pitch name or actual frequency
-      "(->frequency pitch :optional pythagorean) returns the frequency (Hz) of the 'pitch', a CLM/CM style note name as a \
+    (lambda* (pitch pythagorean)          ; pitch can be pitch name or actual frequency
+      "(->frequency pitch pythagorean) returns the frequency (Hz) of the 'pitch', a CLM/CM style note name as a \
 symbol: 'e4 for example.  If 'pythagorean', the frequency calculation uses small-integer ratios, rather than equal-tempered tuning."
       (if (symbol? pitch)
 	  (let* ((name (string-downcase (symbol->string pitch)))
@@ -566,24 +499,19 @@ symbol: 'e4 for example.  If 'pythagorean', the frequency calculation uses small
 		 (et-pitch (+ base-pitch (* 12 octave))))
 	    (set! last-octave octave)
 	    (if pythagorean
-		(* main-pitch (expt 2 octave) (vector-ref ratios base-pitch))
+		(* main-pitch (expt 2 octave) (ratios base-pitch))
 		(* main-pitch (expt 2.0 (/ et-pitch 12)))))
 	  pitch))))
 
 
 (define (->sample beg)
   "(->sample time-in-seconds) -> time-in-samples"
-  (inexact->exact (round (* (if (not (null? (sounds))) (srate) (mus-srate)) beg))))
+  (round (* (if (not (null? (sounds))) (srate) (mus-srate)) beg)))
 
 
 
 ;;; -------- def-clm-struct --------
 
-(define (snd-error-1 .args)
-  (if (defined? 'snd-error)
-      (apply snd-error args)
-      (apply display args)))
-
 ;;;  :(def-clm-struct (osc :make-wrapper (lambda (gen) (set! (osc-freq gen) (hz->radians (osc-freq gen))) gen)) freq phase)
 ;;;  #<unspecified>
 ;;;  :(define hi (make-osc 440.0 0.0))
@@ -620,7 +548,7 @@ symbol: 'e4 for example.  If 'pythagorean', the frequency calculation uses small
 			   fields))
 	 (field-types (map (lambda (n)
 			     (if (and (list? n) (cadr n) (eq? (cadr n) :type)) 
-				 (snd-error-1 (format #f ":type indication for def-clm-struct (~A) field (~A) should be after the default value" name n)))
+				 (error 'wrong-type-arg ":type indication for def-clm-struct (~A) field (~A) should be after the default value" name n))
 			     (if (and (list? n)
 				      (= (length n) 4)
 				      (eq? (list-ref n 2) :type))
@@ -651,13 +579,13 @@ symbol: 'e4 for example.  If 'pythagorean', the frequency calculation uses small
 	 (lambda ()
 	   "clm struct local method list accessor"
 	   ,methods))
-       (def-optkey-fun (,(string->symbol (string-append "make-" sname))
-		        ,@(map (lambda (n)
-				(if (and (list? n)
-					 (>= (length n) 2))
-				    (list (car n) (cadr n))
-				    (list n 0.0)))
-			      fields))
+       (define* (,(string->symbol (string-append "make-" sname))
+		 ,@(map (lambda (n)
+			  (if (and (list? n)
+				   (>= (length n) 2))
+			      (list (car n) (cadr n))
+			      (list n 0.0)))
+			fields))
 	 (,wrapper (if (list? ,methods)
 		       (list ',(string->symbol sname)
 			     ,@(map string->symbol field-names)
@@ -688,7 +616,6 @@ symbol: 'e4 for example.  If 'pythagorean', the frequency calculation uses small
 
 (defmacro with-threaded-sound (args . body)
   (if (and (provided? 'threads)
-	   (provided? 's7)
 	   (not (= (optimization) 0)))
       (let ((split 
 	     (lambda (l n k)
@@ -785,10 +712,13 @@ symbol: 'e4 for example.  If 'pythagorean', the frequency calculation uses small
 
 ;;; --------------------------------------------------------------------------------
 ;;;
-;;; generics from Snd that are used in some instruments
-;;;   these replacements assume Snd types are not present
+;;; functions from Snd that are used in some instruments
+;;;   these replacements assume that the Snd functions are not present
 
-(define file-name mus-expand-filename)
+(define (file-name name) 
+  (if (string? name) 
+      (mus-expand-filename name) 
+      (mus-file-name name)))
 
 (define srate mus-sound-srate)
 
@@ -803,3 +733,11 @@ symbol: 'e4 for example.  If 'pythagorean', the frequency calculation uses small
   (if (string? obj)
       (mus-sound-frames obj)
       (length obj)))
+
+
+(define snd-print display)
+(define snd-warning display)
+(define snd-display display)
+(define (snd-error str) (error 'mus-error str))
+(define snd-tempnam tmpnam)
+
