@@ -16,7 +16,6 @@
   #endif
   #include <string.h>
 #endif
-#include <errno.h>
 
 #if MUS_MAC_OSX
   #define BUFFER_SIZE 256
@@ -59,8 +58,6 @@ static void set_volume(mus_sample_t **buf, int chans, int length, double volume)
       buf[ch][n] *= volume; 
 }
 
-/* special case multicard quad code split out for clarity (it could be folded into the main branches) */
-
 /* 22-Nov-00:  moved alsa support to separate block */
 /* 8-Apr-04:   added start/end (seconds-based) args */
 /* 2-Nov-05:   added -volume arg */
@@ -72,10 +69,8 @@ static int main_not_alsa(int argc, char *argv[])
   mus_long_t frames, m;
   mus_sample_t **bufs;
   OutSample *obuf;
-  int use_multi_card_code = 0, use_volume = 0;
+  int use_volume = 0;
   int afd0, afd1, buffer_size = BUFFER_SIZE, curframes, sample_size, out_chans, outbytes;
-  mus_sample_t **qbufs;
-  short *obuf0, *obuf1;
   char *name = NULL;
   mus_long_t start = 0, end = 0;
   double begin_time = 0.0, end_time = 0.0, volume = 1.0;
@@ -85,7 +80,7 @@ static int main_not_alsa(int argc, char *argv[])
     {
       if (strcmp(argv[i], "-describe") == 0) 
 	{
-	  mus_audio_describe(); 
+	  fprintf(stdout, "%s", mus_audio_describe()); 
 	  exit(0);
 	}
       else
@@ -165,20 +160,15 @@ static int main_not_alsa(int argc, char *argv[])
       chans = mus_sound_chans(name);
       if (chans > 2)
 	{
-	  float val[8];
-	  mus_audio_mixer_read(MUS_AUDIO_DEFAULT, MUS_AUDIO_CHANNEL, 0, val);
-	  if (val[0] < chans)
+	  int available_chans;
+	  available_chans = mus_audio_device_channels(MUS_AUDIO_DEFAULT);
+	  if (available_chans < chans)
 	    {
-	      if (mus_audio_systems() > 1)
-		use_multi_card_code = 1;
-	      /* I suppose we could count up all the channels here */
-	      else
-		{
-		  fprintf(stderr, "%s has %d channels, but we can only handle %d\n", name, chans, (int)(val[0]));
-		  exit(1);
-		}
+	      fprintf(stderr, "%s has %d channels, but we can only handle %d\n", name, chans, available_chans);
+	      exit(1);
 	    }
 	}
+
       out_chans = chans;
       srate = mus_sound_srate(name);
       frames = mus_sound_frames(name);
@@ -191,122 +181,66 @@ static int main_not_alsa(int argc, char *argv[])
       else end = frames;
       if ((end - start) < frames)
 	frames = end - start;
-      if (!use_multi_card_code)
+
+      bufs = (mus_sample_t **)calloc(chans, sizeof(mus_sample_t *));
+      for (i = 0; i < chans; i++) bufs[i] = (mus_sample_t *)calloc(buffer_size, sizeof(mus_sample_t));
+      obuf = (OutSample *)calloc(buffer_size * out_chans, sizeof(OutSample));
+      outbytes = buffer_size * out_chans * sample_size;
+      for (m = 0; m < frames; m += buffer_size)
 	{
-	  bufs = (mus_sample_t **)calloc(chans, sizeof(mus_sample_t *));
-	  for (i = 0; i < chans; i++) bufs[i] = (mus_sample_t *)calloc(buffer_size, sizeof(mus_sample_t));
-	  obuf = (OutSample *)calloc(buffer_size * out_chans, sizeof(OutSample));
-	  outbytes = buffer_size * out_chans * sample_size;
-	  for (m = 0; m < frames; m += buffer_size)
+	  if ((m + buffer_size) <= frames)
+	    curframes = buffer_size;
+	  else curframes = frames - m;
+	  mus_file_read(fd, 0, curframes - 1, chans, bufs); 
+	  /* some systems are happier if we read the file before opening the dac */
+	  /* at this point the data is in separate arrays of mus_sample_t's */
+	  if (use_volume) 
+	    set_volume(bufs, chans, curframes, volume); 
+	  if (chans == 1)
 	    {
-	      if ((m + buffer_size) <= frames)
-		curframes = buffer_size;
-	      else curframes = frames - m;
-	      mus_file_read(fd, 0, curframes - 1, chans, bufs); 
-	      /* some systems are happier if we read the file before opening the dac */
-	      /* at this point the data is in separate arrays of mus_sample_t's */
-	      if (use_volume) 
-		set_volume(bufs, chans, curframes, volume); 
-	      if (chans == 1)
+	      for (k = 0; k < curframes; k++) 
+		obuf[k] = MUS_CONVERT(bufs[0][k]);
+	    }
+	  else
+	    {
+	      if (chans == 2)
 		{
-		  for (k = 0; k < curframes; k++) 
-		    obuf[k] = MUS_CONVERT(bufs[0][k]);
+		  for (k = 0, n = 0; k < curframes; k++, n += 2) 
+		    {
+		      obuf[n] = MUS_CONVERT(bufs[0][k]); 
+		      obuf[n + 1] = MUS_CONVERT(bufs[1][k]);
+		    }
 		}
 	      else
 		{
-		  if (chans == 2)
+		  for (k = 0, j = 0; k < curframes; k++, j += chans)
 		    {
-		      for (k = 0, n = 0; k < curframes; k++, n += 2) 
-			{
-			  obuf[n] = MUS_CONVERT(bufs[0][k]); 
-			  obuf[n + 1] = MUS_CONVERT(bufs[1][k]);
-			}
-		    }
-		  else
-		    {
-		      for (k = 0, j = 0; k < curframes; k++, j += chans)
-			{
-			  for (n = 0; n < chans; n++) 
-			    obuf[j + n] = MUS_CONVERT(bufs[n][k]);
-			}
+		      for (n = 0; n < chans; n++) 
+			obuf[j + n] = MUS_CONVERT(bufs[n][k]);
 		    }
 		}
+	    }
 #if MUS_MAC_OSX
-	      if (include_mutate == 1)
-		mus_audio_output_properties_mutable(mutate);
+	  if (include_mutate == 1)
+	    mus_audio_output_properties_mutable(mutate);
 #endif
-	      if (afd == -1)
-		{
-#if defined(MUS_LINUX) && defined(PPC)
-		  afd = mus_audio_open_output(MUS_AUDIO_DEFAULT, srate, chans, MUS_AUDIO_COMPATIBLE_FORMAT, 0);
-#else
-		  afd = mus_audio_open_output(MUS_AUDIO_DEFAULT, srate, out_chans, MUS_AUDIO_COMPATIBLE_FORMAT, outbytes);
-#endif
-		  if (afd == -1) break;
-		}
-	      outbytes = curframes * out_chans * sample_size;
-	      mus_audio_write(afd, (char *)obuf, outbytes);
-	    }
-	  if (afd != -1) mus_audio_close(afd);
-	  mus_sound_close_input(fd);
-	  for (i = 0; i < chans; i++) free(bufs[i]);
-	  free(bufs);
-	  free(obuf);
-	}
-      else
-	{
-	  /* code is essentially the same as above, but since this is supposed
-	   *   to be a working example of sndlib, I didn't want the basic stuff
-	   *   to be complicated by one special case.
-	   *
-	   * in my test case, I was using a Sound Blaster and an Ensoniq clone.
-	   * they had slightly different start-up latencies (not really audible),
-	   * and the Ensoniq's dac was running ca. 1 sample per second faster than
-	   * the SB's, so by 5 minutes into a sound, the stereo pairs had drifted
-	   * .01 seconds apart -- this is probably acceptable in many cases.
-	   * In a second test, with two Ensoniq's in one machine, they started
-	   * together and drifted apart at about 1 sample per 8 seconds -- about
-	   * .001 secs apart after 5 minutes.  ("Ensoniq" was SoundWave Pro PCI
-	   * from SIIG Inc -- some sort of clone.)
-	   */
-	  buffer_size = 256;   /* 128 probably better */
-	  outbytes = buffer_size * 2 * 2; 
-	  qbufs = (mus_sample_t **)calloc(chans, sizeof(mus_sample_t *));
-	  for (i = 0; i < chans; i++) qbufs[i] = (mus_sample_t *)calloc(buffer_size, sizeof(mus_sample_t));
-	  obuf0 = (short *)calloc(buffer_size * 2, sizeof(short));
-	  obuf1 = (short *)calloc(buffer_size * 2, sizeof(short));
-	  for (m = 0; m < frames; m += buffer_size)
+	  if (afd == -1)
 	    {
-	      if ((m + buffer_size) <= frames)
-		curframes = buffer_size;
-	      else curframes = frames - m;
-	      mus_file_read(fd, 0, curframes - 1, chans, qbufs); 
-	      if (use_volume) 
-		set_volume(qbufs, chans, curframes, volume); 
-	      for (k = 0, n = 0; k < buffer_size; k++, n += 2) 
-		{
-		  obuf0[n] = MUS_SAMPLE_TO_SHORT(qbufs[0][k]); 
-		  obuf0[n + 1] = MUS_SAMPLE_TO_SHORT(qbufs[1][k]);
-		  obuf1[n] = MUS_SAMPLE_TO_SHORT(qbufs[2][k]); 
-		  obuf1[n + 1] = MUS_SAMPLE_TO_SHORT(qbufs[3][k]);
-		}
-	      if (afd0 == -1)
-		{
-		  afd0 = mus_audio_open_output(MUS_AUDIO_PACK_SYSTEM(0) | MUS_AUDIO_DEFAULT, srate, 2, MUS_AUDIO_COMPATIBLE_FORMAT, outbytes);
-		  afd1 = mus_audio_open_output(MUS_AUDIO_PACK_SYSTEM(1) | MUS_AUDIO_DEFAULT, srate, 2, MUS_AUDIO_COMPATIBLE_FORMAT, outbytes);
-		  if ((afd0 == -1) || (afd1 == -1)) break;
-		}
-	      mus_audio_write(afd0, (char *)obuf0, outbytes);
-	      mus_audio_write(afd1, (char *)obuf1, outbytes);
+#if defined(MUS_LINUX) && defined(PPC)
+	      afd = mus_audio_open_output(MUS_AUDIO_DEFAULT, srate, chans, MUS_AUDIO_COMPATIBLE_FORMAT, 0);
+#else
+	      afd = mus_audio_open_output(MUS_AUDIO_DEFAULT, srate, out_chans, MUS_AUDIO_COMPATIBLE_FORMAT, outbytes);
+#endif
+	      if (afd == -1) break;
 	    }
-	  mus_audio_close(afd0);
-	  mus_audio_close(afd1);
-	  mus_sound_close_input(fd);
-	  for (i = 0; i < chans; i++) free(qbufs[i]);
-	  free(qbufs);
-	  free(obuf0);
-	  free(obuf1);
+	  outbytes = curframes * out_chans * sample_size;
+	  mus_audio_write(afd, (char *)obuf, outbytes);
 	}
+      if (afd != -1) mus_audio_close(afd);
+      mus_sound_close_input(fd);
+      for (i = 0; i < chans; i++) free(bufs[i]);
+      free(bufs);
+      free(obuf);
     }
   return(0);
 }
@@ -319,6 +253,11 @@ static int main_not_alsa(int argc, char *argv[])
 
 static int use_one_device = 1;
 
+void mus_audio_alsa_channel_info(int dev, int *info);
+int mus_audio_alsa_samples_per_channel(int dev);
+void mus_audio_alsa_device_list(int sys, int size, int *val);
+int mus_audio_alsa_device_direction(int dev);
+
 #define MAX_SLOTS 64
 
 static int main_alsa(int argc, char *argv[])
@@ -328,7 +267,7 @@ static int main_alsa(int argc, char *argv[])
   mus_sample_t **read_bufs;
   int afd[MAX_SLOTS];
   short *out_buf[MAX_SLOTS];
-  float val[MAX_SLOTS];
+  int val[MAX_SLOTS];
   int afd0, afd1;
   char *name = NULL;
   int base, curframes;
@@ -355,7 +294,7 @@ static int main_alsa(int argc, char *argv[])
     {
       if (strcmp(argv[i], "-describe") == 0)
 	{
-	  mus_audio_describe(); 
+	  fprintf(stdout, "%s", mus_audio_describe()); 
 	  exit(0);
 	}
       else 
@@ -411,7 +350,7 @@ static int main_alsa(int argc, char *argv[])
   if (fd != -1)
     {
       /* try to select proper device */
-      float dir;
+      int dir = 0;
       int cards, card;
       int sysdev, devs, dev, d, i, im;
       int first_samples_per_chan = -1;
@@ -435,31 +374,34 @@ static int main_alsa(int argc, char *argv[])
       for (card = 0; card < cards; card++) 
 	{
 	  /* get the list of all available devices */
-	  mus_audio_mixer_read(MUS_AUDIO_PACK_SYSTEM(card), MUS_AUDIO_PORT, MAX_SLOTS, val);
-	  devs = (int)(val[0]);
+	  mus_audio_alsa_device_list(MUS_AUDIO_PACK_SYSTEM(card), MAX_SLOTS, val);
+	  devs = val[0];
 	  for (d = 0; d < devs; d++) 
 	    {
-	      dev = (int)(val[d + 1]);
+	      dev = val[d + 1];
 	      sysdev = MUS_AUDIO_PACK_SYSTEM(card)|dev;
-	      mus_audio_mixer_read(sysdev, MUS_AUDIO_DIRECTION, 0, &dir);
+	      dir = mus_audio_alsa_device_direction(sysdev);
+
 	      /* only consider output devices */
-	      if ((int)dir == 0) 
+	      if (dir == 0) 
 		{
-		  float ch[4];
+		  int ch[4];
 		  /* get the number of channels the device supports */
-		  mus_audio_mixer_read(sysdev, MUS_AUDIO_CHANNEL, 4, ch);
-		  available_chans[i] = (int)(ch[0]);
-		  if ((int)ch[2] != 0) /* alsa also sets min and max channels */
+		  mus_audio_alsa_channel_info(sysdev, ch);
+		  available_chans[i] = ch[0];
+		  if (ch[2] != 0) /* alsa also sets min and max channels */
 		    {
-		      min_chans[i] = (int)(ch[1]);
-		      max_chans[i] = (int)(ch[2]);
+		      min_chans[i] = ch[1];
+		      max_chans[i] = ch[2];
 		    }
 		  if (max_chans[i] > max_chans[im]) im = i;
+
 		  /* find out what format we can use with the device */
 		  out_format[i] = mus_audio_compatible_format(sysdev);
+
 		  /* find out what buffer size the device wants */
-		  mus_audio_mixer_read(sysdev, MUS_AUDIO_SAMPLES_PER_CHANNEL, 2, ch);
-		  samples_per_chan = (int)ch[0];
+		  samples_per_chan = mus_audio_alsa_samples_per_channel(sysdev);
+
 		  /* skip device if it has different buffer size, all must match */
 		  if (first_samples_per_chan == -1) 
 		    first_samples_per_chan = samples_per_chan;
