@@ -175,7 +175,7 @@
 		 (char=? (string-ref name i) #\*))
 	     (return (substring name 0 i))))))))
 
-(define* (parse-args args :optional x)
+(define* (parse-args args x)
   (let ((data '())
 	(sp -1)
 	(type #f)
@@ -351,7 +351,7 @@
 		    (hey "XL_TYPE_PTR(GLXContext, GLXContext)~%")
 		    ))))))
 
-(define* (CFNC data :optional spec spec-name)
+(define* (CFNC data spec spec-name)
   (let ((name (cadr-str data))
 	(args (caddr-str data)))
     (if (assoc name names)
@@ -365,14 +365,14 @@
 		(set! funcs (cons (list name type strs args) funcs)))
 	    (set! names (cons (cons name 'fnc) names)))))))
 
-(define* (CINT name :optional type)
+(define* (CINT name type)
   (if (assoc name names)
       (display (format #f "~A CINT~%" name))
       (begin
 	(set! ints (cons name ints))
 	(set! names (cons (cons name 'int) names)))))
 
-(define* (CFNC-X data :optional spec spec-name)
+(define* (CFNC-X data spec spec-name)
   (let ((name (cadr-str data))
 	(args (caddr-str data)))
     (if (assoc name names)
@@ -386,7 +386,7 @@
 		(set! x-funcs (cons (list name type strs args) x-funcs)))
 	    (set! names (cons (cons name 'fnc) names)))))))
 
-(define* (CINT-X name :optional type)
+(define* (CINT-X name type)
   (if (assoc name names)
       (display (format #f "~A CINT-X~%" name))
       (begin
@@ -407,7 +407,7 @@
 (load "gldata.scm")
 
 ;;; ---------------------------------------- write output file ----------------------------------------
-(hey "/* gl.c: s7, Guile, Ruby, and Forth bindings for GL, GLU~%")
+(hey "/* gl.c: s7, Ruby, and Forth bindings for GL, GLU~%")
 (hey " *   generated automatically from makegl.scm and gldata.scm~%")
 (hey " *   needs xen.h~%")
 (hey " *~%")
@@ -416,6 +416,9 @@
 (hey " * 'gl is added to *features*~%")
 (hey " *~%")
 (hey " * HISTORY:~%")
+(hey " *     --------~%")
+(hey " *     16-Dec-09: removed Guile support.~%")
+(hey " *     --------~%")
 (hey " *     17-Oct-08: removed gtkglext bindings.~%")
 (hey " *     --------~%")
 (hey " *     30-Mar-06: check for glu.h, omit GLU_* if necessary.  Add Forth support.~%")
@@ -574,8 +577,7 @@
 	  (arg-start 0)
 	  (line-len 0)
 	  (line-max 120)
-	  (protect-arglist #f)
-	  (max-args 10)) ; libguile/gsubr.h:#define SCM_GSUBR_MAX 10
+	  (max-args 10)) 
 
      (define (hey-start)
        ;; start of checked line
@@ -614,8 +616,7 @@
 	 (heyc "void")
 	 (if (>= (length args) max-args)
 	     (begin
-	       (heyc "XEN arglist")
-	       (set! protect-arglist #t))
+	       (heyc "XEN arglist"))
 	     (let ((previous-arg #f))
 	       (for-each 
 		(lambda (arg)
@@ -726,9 +727,7 @@
 		   (hey "      result = XEN_CONS(C_TO_XEN_~A(~A[i]), result);~%" 
 			(no-stars (deref-type (list-ref args (- (length args) 1))))
 			(deref-name (list-ref args (- (length args) 1))))
-		   (if protect-arglist
-		       (hey "    return(xen_return_first(result, arglist));~%")
-		       (hey "    return(result);~%"))
+		   (hey "    return(result);~%")
 		   (hey "  }~%"))
 		 (begin
 		   (hey "  return(XEN_LIST_~D(" (+ refargs (if using-result 1 0)))
@@ -746,9 +745,7 @@
 	   (if (string=? return-type "void")
 	       (begin
 		 (hey ");~%")
-		 (if protect-arglist
-		     (hey "  return(xen_return_first(XEN_FALSE, arglist));~%")
-		     (hey "  return(XEN_FALSE);~%")))
+		 (hey "  return(XEN_FALSE);~%"))
 	       (hey ")));~%")))
        )
 
@@ -862,7 +859,7 @@
 (hey "/* ---------------------------------------- constants ---------------------------------------- */~%~%")
 (hey "static void define_integers(void)~%")
 (hey "{~%~%")
-(hey "#if HAVE_S7~%")
+(hey "#if HAVE_SCHEME~%")
 (hey "#define DEFINE_INTEGER(Name) s7_define_constant(s7, XL_PRE #Name XL_POST, C_TO_XEN_INT(Name))~%")
 (hey "#else~%")
 (hey "#define DEFINE_INTEGER(Name) XEN_DEFINE(XL_PRE #Name XL_POST, C_TO_XEN_INT(Name))~%")
