@@ -1,9 +1,3 @@
-#!/usr/bin/guile -s
-!#
-
-(use-modules (ice-9 format))
-(if (not (defined? 'read-line)) (use-modules (ice-9 rdelim)))
-
 (with-output-to-file
     "test.scm"
   (lambda ()
@@ -18,6 +12,6 @@
 		  (let ((ch (string-ref line i)))
 		    (if (not (char=? ch (integer->char #o015)))
 			(display (format #f "~C" ch)))))
-		(loop (read-line file 'concat)))))))))
+		(loop (read-line file)))))))))
 
 
