@@ -1,10 +1,7 @@
 ;;; with-sound and friends
 
-(use-modules (ice-9 optargs) (ice-9 format))
 (provide 'snd-ws.scm)
 
-(if (not (provided? 'snd-extensions.scm)) (load-from-path "extensions.scm")) ; we need sound-property in with-mixed-sound
-
 (defmacro ws-interrupt? ()
   `(if (c-g?) 
        (throw 'with-sound-interrupt)))
@@ -13,32 +10,33 @@
 
 ;;; -------- with-sound defaults --------
 
-(define *clm-srate* (default-output-srate))
-(define *clm-file-name* "test.snd")
-(define *clm-channels* (default-output-chans))
-(define *clm-data-format* (default-output-data-format))
-(define *clm-header-type* (default-output-header-type))
-(define *clm-verbose* #f)
-(define *clm-play* #f)
-(define *clm-statistics* #f)
-(define *clm-reverb* #f)
-(define *clm-reverb-channels* 1)
-(define *clm-reverb-data* '())
-(define *clm-table-size* 512)
-(define *clm-file-buffer-size* 65536)
-(define *clm-locsig-type* mus-interp-linear)
-(define *clm-clipped* #t)
+(define *clm-srate*             (default-output-srate))
+(define *clm-file-name*         "test.snd")
+(define *clm-channels*          (default-output-chans))
+(define *clm-data-format*       (default-output-data-format))
+(define *clm-header-type*       (default-output-header-type))
+(define *clm-verbose*           #f)
+(define *clm-play*              #f)
+(define *clm-statistics*        #f)
+(define *clm-reverb*            #f)
+(define *clm-reverb-channels*   1)
+(define *clm-reverb-data*       '())
+(define *clm-table-size*        512)
+(define *clm-file-buffer-size*  65536)
+(define *clm-locsig-type*       mus-interp-linear)
+(define *clm-clipped*           #t)
 (define *clm-array-print-length* (print-length))
-(define *clm-player* #f)          ; default is play-and-wait (takes index of newly created sound, not the sound's file name)
-(define *clm-notehook* #f)
-(define *clm-with-sound-depth* 0) ; for CM, not otherwise used
+(define *clm-player*            #f)
+(define *clm-notehook*          #f)
+(define *clm-with-sound-depth*  0)           ; for CM, not otherwise used
 (define *clm-default-frequency* 0.0)
-(define *clm-safety* 0)           ; obsolete
-(define *clm-delete-reverb* #f)   ; should with-sound clean up reverb stream
-(define *clm-threads* 4)
-(define *clm-output-safety* 0)    ; if 1, assume output buffers will not need to be flushed except at the very end
+(define *clm-safety*            0)           ; obsolete
+(define *clm-delete-reverb*     #f)          ; should with-sound clean up reverb stream
+(define *clm-threads*           4)
+(define *clm-output-safety*     0)           ; if 1, assume output buffers will not need to be flushed except at the very end
 
-(define *to-snd* #t)
+(define *to-snd*                #t)
+(define *default-player* (lambda (s) (play s :wait #t))) ; we need to perserve "play" because it is used as a keyword argument in with-sound
 
 
 (define (times->samples beg dur) 
@@ -84,29 +82,29 @@
 ;;; -------- with-sound --------
 
 (define* (with-sound-helper thunk 
-			    :key (srate *clm-srate*) 
-			          (output *clm-file-name*) 
-				  (channels *clm-channels*)
-				  (header-type *clm-header-type*)
-				  (data-format *clm-data-format*)
-				  (comment #f)
-				  (verbose *clm-verbose*)
-				  (reverb *clm-reverb*)
-				  (revfile "test.rev")
-				  (reverb-data *clm-reverb-data*)
-				  (reverb-channels *clm-reverb-channels*)
-				  (continue-old-file #f)
-				  (statistics *clm-statistics*)
-				  (scaled-to #f)
-				  (play *clm-play*)
-				  (to-snd *to-snd*)
-				  (clipped 'unset)
-				  (notehook *clm-notehook*)               ; (with-sound (:notehook (lambda args (display args))) (fm-violin 0 1 440 .1))
-				  (scaled-by #f)
-				  (ignore-output #f)
-				  (thread-output #f)
-				  (thread-reverb #f)
-				  (output-safety *clm-output-safety*))
+			    (srate *clm-srate*) 
+			    (output *clm-file-name*) 
+			    (channels *clm-channels*)
+			    (header-type *clm-header-type*)
+			    (data-format *clm-data-format*)
+			    (comment #f)
+			    (verbose *clm-verbose*)
+			    (reverb *clm-reverb*)
+			    (revfile "test.rev")
+			    (reverb-data *clm-reverb-data*)
+			    (reverb-channels *clm-reverb-channels*)
+			    (continue-old-file #f)
+			    (statistics *clm-statistics*)
+			    (scaled-to #f)
+			    (play *clm-play*)
+			    (to-snd *to-snd*)
+			    (clipped 'unset)
+			    (notehook *clm-notehook*)               ; (with-sound (:notehook (lambda args (display args))) (fm-violin 0 1 440 .1))
+			    (scaled-by #f)
+			    (ignore-output #f)
+			    (thread-output #f)
+			    (thread-reverb #f)
+			    (output-safety *clm-output-safety*))
   "with-sound-helper is the business portion of the with-sound macro"
   (let* ((old-srate (mus-srate))
 	 (old-*output* *output*)
@@ -160,10 +158,10 @@
 			 (if (file-exists? output-1) 
 			     (delete-file output-1))
 			 (set! *output* (make-sample->file output-1 channels data-format header-type comment))))
-		   (set! (mus-safety *output*) output-safety))
+		   (if *output*
+		       (set! (mus-safety *output*) output-safety)))
 		 (begin
 		   (if (not continue-old-file)
-		       ;; if s7 we could just use fill! here (and below)
 		       (if (or (vct? output-1)
 			       (sound-data? output-1)
 			       (vector? output-1))
@@ -179,7 +177,8 @@
 			     (if (file-exists? reverb-1) 
 				 (delete-file reverb-1))
 			     (set! *reverb* (make-sample->file reverb-1 reverb-channels data-format header-type))))
-		       (set! (mus-safety *reverb*) output-safety))
+		       (if *reverb*
+			   (set! (mus-safety *reverb*) output-safety)))
 		     (begin
 		       (if (not continue-old-file)
 			   (if (or (vct? reverb-1)
@@ -245,7 +244,7 @@
 		   (begin
 		     (if reverb-to-file
 			 (set! *reverb* (make-file->sample reverb-1)))
-		     (apply reverb reverb-data)
+		     (apply reverb reverb-data)                                   ; here is the reverb call(!)
 		     (if reverb-to-file
 			 (mus-close *reverb*))
 		     (if (and reverb-to-file *clm-delete-reverb*)
@@ -259,7 +258,7 @@
 	 (let ((snd-output #f)
 	       (cur-sync #f))
 	   (if statistics
-	       (set! cycles (exact->inexact (/ (- (get-internal-real-time) start) internal-time-units-per-second))))
+	       (set! cycles (/ (* 1.0 (- (get-internal-real-time) start)) internal-time-units-per-second)))
 
 	   (if (and to-snd output-to-file)
 	       (let* ((cur (find-sound output-1)))
@@ -337,18 +336,18 @@
 				     (if (> pk 0.0)
 					 (let ((scl (/ scaled-to pk)))
 					   (do ((i 0 (+ i 1)))
-					       ((= i (vector-length output-1)))
-					     (vector-set! output-1 i (* scl (vector-ref output-1 i)))))))
+					       ((= i (length output-1)))
+					     (set! (output-1 i) (* scl (output-1 i)))))))
 				   (do ((i 0 (+ i 1)))
-				       ((= i (vector-length output-1)))
-				     (vector-set! output-1 i (* scaled-by (vector-ref output-1 i))))))))))
+				       ((= i (length output-1)))
+				     (set! (output-1 i) (* scaled-by (output-1 i))))))))))
 
 	   (if (and play output-to-file)
 	       (if to-snd
 		   (if *clm-player*
 		       (*clm-player* snd-output)
-		       (play-and-wait 0 snd-output))
-		   (play output-1)))
+		       (*default-player* snd-output))
+		   (*default-player* output-1))) ; this was (play output-1) which could not have worked?!
 
 	   (if (and to-snd output-to-file)
 	       (begin
@@ -397,7 +396,6 @@
 
 (defmacro with-threaded-sound (args . body)
   (if (and (provided? 'snd-threads)
-	   (provided? 's7)
 	   (not (= (optimization) 0)))
       (let ((split 
 	     (lambda (l n k)
@@ -512,8 +510,6 @@
 
 
 ;;; -------- clm-load --------
-;;;
-;;; CM wants this to be a function so that it can use apply
 
 (define (clm-load file . args) 
   "(clm-load file . args) loads 'file' in the context of with-sound"
@@ -566,7 +562,7 @@
 			  (report-in-minibuffer (format #f "mix ~A: ~A" 
 						      id (or (and info
 								  (cadddr info))
-							     (exact->inexact (/ (mix-position id) (srate outsnd))))))
+							     (/ (mix-position id) (* 1.0 (srate outsnd))))))
 			  #t))) ; #t -> don't print the mix id in the minibuffer
 
 	   (dynamic-wind
@@ -579,7 +575,7 @@
 	       (lambda ()
 		 (for-each
 		  (lambda (note)
-		    (let* ((snd (with-temp-sound (,@args :ignore-output #t :clipped #f) (eval (append (list (car note) 0.0) (cddr note)) (current-module))))
+		    (let* ((snd (with-temp-sound (,@args :ignore-output #t :clipped #f) (eval (append (list (car note) 0.0) (cddr note)) (current-environment))))
 			   ;; I can't immediately find a way around the "eval" 
 			   (beg (floor (* (srate outsnd) (cadr note))))
 			   ;; can't use seconds->samples here because the global mus-srate value might not match the local one
@@ -616,7 +612,7 @@
 ;(with-mixed-sound (:channels 2) (fm-violin 0 .1 440 .1 :degree 0) (fm-violin 1 .1 660 .1 :degree 45))
 
 
-(define* (with-mixed-sound->notelist :optional (output-file "temp.scm") snd)
+(define* (with-mixed-sound->notelist (output-file "temp.scm") snd)
   (let* ((outsnd (or snd (selected-sound) (car (sounds))))
 	 (mix-info (sound-property 'with-mixed-sound-info outsnd)))
     (if (not mix-info)
@@ -632,8 +628,8 @@
 		     (if (not (= (cadr info) (mix-position id)))
 			 (display (format #f "  (~A ~,3F~{ ~A~})~%"
 					  (car call) 
-					  (exact->inexact (/ (mix-position id) (srate snd)))
-					  (cddr call)) 
+					  (/ (mix-position id) (* 1.0 (srate snd)))
+					  (cddr call))
 				  oput)
 			 (display (format #f "  ~A~%" call) oput)))
 		   (report-in-minibuffer "can't find note associated with mix ~A" id))))
@@ -713,7 +709,7 @@
 ;;; -------- Common Music --------
 
 (define* (init-with-sound
-	  :key (srate *clm-srate*) 
+	  (srate *clm-srate*) 
 	  (output *clm-file-name*) 
 	  (channels *clm-channels*)
 	  (header-type *clm-header-type*)
@@ -830,7 +826,7 @@ finish-with-sound to complete the process."
 			   (if scaled-by
 			       (scale-by scaled-by snd-output)))
 		       (save-sound snd-output)))
-	      (if play (play-and-wait 0 snd-output))
+	      (if play (*default-player* snd-output))
 	      (update-time-graph snd-output)))
 	(set! (mus-srate) old-srate)
 	output)
@@ -853,17 +849,12 @@ finish-with-sound to complete the process."
   "(ws-save-state filename) is an after-save-state-hook function that saves the current with-sound global settings"
 
   (define (open-appending filename)
-    (if (provided? 'snd-guile)
-	(open filename (logior O_RDWR O_APPEND))
-	(open-output-file filename "a")))
+    (open-output-file filename "a"))
 
   (define (close-appending fd)
-    (if (provided? 'snd-guile)
-	(close fd)
-	(close-output-port fd)))
+    (close-output-port fd))
 
   (let ((fd (open-appending filename)))
-    ;; open in Guile throws 'system-error (I think) if anything goes wrong
     ;; fd is a Scheme port at this point (not an integer), so we can use format etc
     ;; should the save-state file load this file if it hasn't been loaded? (what path?)
     (format fd "~%~%;;; from ws.scm~%")
@@ -879,39 +870,14 @@ finish-with-sound to complete the process."
 (add-hook! after-save-state-hook ws-save-state)
 
 
-;;; -------- def-optkey-instrument --------
-
-(defmacro def-optkey-instrument (args . body)
-  (let* ((name (car args))
-	 (targs (cdr args))
-	 (utargs (let ((arg-names '()))
-		   (for-each
-		    (lambda (a)
-		      (if (not (keyword? a))
-			  (if (symbol? a)
-			      (set! arg-names (cons a arg-names))
-			      (set! arg-names (cons (car a) arg-names)))))
-		    targs)
-		   (reverse arg-names))))
-  `(begin 
-     (def-optkey-fun (,name ,@targs)
-       (if *clm-notehook*
-	   (*clm-notehook* (symbol->string ',name) ,@utargs))
-       ((lambda () ; for inner defines, if any
-	  ,@body)))
-     ,@(if *definstrument-hook*
-           (list (*definstrument-hook* name targs))
-           (list)))))
-
-
 ;;; -------- ->frequency --------
 
 (define ->frequency
   (let ((main-pitch (/ 440.0 (expt 2.0 (/ 57 12)))) ; a4 = 440Hz is pitch 57 in our numbering
 	(last-octave 0)                             ; octave number can be omitted
 	(ratios (vector 1.0 256/243 9/8 32/27 81/64 4/3 1024/729 3/2 128/81 27/16 16/9 243/128 2.0)))
-    (lambda* (pitch :optional pythagorean)          ; pitch can be pitch name or actual frequency
-      "(->frequency pitch :optional pythagorean) returns the frequency (Hz) of the 'pitch', a CLM/CM style note name as a \
+    (lambda* (pitch pythagorean)          ; pitch can be pitch name or actual frequency
+      "(->frequency pitch pythagorean) returns the frequency (Hz) of the 'pitch', a CLM/CM style note name as a \
 symbol: 'e4 for example.  If 'pythagorean', the frequency calculation uses small-integer ratios, rather than equal-tempered tuning."
       (if (symbol? pitch)
 	  (let* ((name (string-downcase (symbol->string pitch)))
@@ -934,7 +900,7 @@ symbol: 'e4 for example.  If 'pythagorean', the frequency calculation uses small
 		 (et-pitch (+ base-pitch (* 12 octave))))
 	    (set! last-octave octave)
 	    (if pythagorean
-		(* main-pitch (expt 2 octave) (vector-ref ratios base-pitch))
+		(* main-pitch (expt 2 octave) (ratios base-pitch))
 		(* main-pitch (expt 2.0 (/ et-pitch 12)))))
 	  pitch))))
 
@@ -993,7 +959,7 @@ symbol: 'e4 for example.  If 'pythagorean', the frequency calculation uses small
 				 (if (and (list? n)
 					  (= (length n) 2))
 				     (if (number? (cadr n))
-					 (if (exact? (cadr n))
+					 (if (rational? (cadr n))
 					     'int
 					     'float)
 					 (if (string? (cadr n))
@@ -1016,7 +982,7 @@ symbol: 'e4 for example.  If 'pythagorean', the frequency calculation uses small
 	 (lambda ()
 	   "clm struct local method list accessor"
 	   ,methods))
-       (def-optkey-fun (,(string->symbol (string-append "make-" sname))
+       (define* (,(string->symbol (string-append "make-" sname))
 		        ,@(map (lambda (n)
 				(if (and (list? n)
 					 (>= (length n) 2))
@@ -1077,7 +1043,6 @@ symbol: 'e4 for example.  If 'pythagorean', the frequency calculation uses small
 (define (with-threaded-channels snd func)
   (let ((chns (channels snd)))
     (if (and (provided? 'snd-threads)
-	     (provided? 's7)
 	     (> chns 1))
 	
 	(dynamic-wind
@@ -1110,3 +1075,69 @@ symbol: 'e4 for example.  If 'pythagorean', the frequency calculation uses small
 	    ((= chn chns))
 	  (func snd chn)))))
 
+
+;;; -------- *clm-search-list*
+
+;;; PERHAPS: doc/test *clm-search-list*, and use to choose input/output loc?
+
+(define *clm-search-list* (list "."))
+
+(define (clm-find-file name)
+  (if (file-exists? name)
+      name
+      (call-with-exit
+       (lambda (return)
+	 (for-each
+	  (lambda (path)
+	    (let ((len (string-length path)))
+	      (if (> len 0)
+		  (let ((new-name (string-append path (if (not (char=? (path (- len 1)) #\/)) "/" "") name)))
+		    (if (file-exists? new-name)
+			(return new-name))))))
+	  *clm-search-list*)
+	 #f))))
+
+#|
+(with-sound ()
+  (let ((fd (make-file->sample "oboe.snd"))
+	(len (mus-sound-frames "oboe.snd")))
+    (run
+     (lambda ()
+       (do ((i 0 (+ i 1)))
+	   ((= i len))
+	 (outa i (* .5 (file->sample fd i 0))))))))
+|#
+
+
+(define (mix-notelists . notelists)
+  ;; assume the 2nd parameter is the begin time in seconds (the 1st is the instrument name)
+  (sort! 
+   (apply append notelists)
+   (lambda (note1 note2)
+     (< (cadr note1) (cadr note2)))))
+
+#|
+(mix-notelists '((fm-violin 0 1 440 .1)
+		 (fm-violin 1 1 550 .1))
+	       '((bird 0 .1 )
+		 (bird .2 .1)
+		 (bird 1.2 .3)
+		 (bird .5 .5)))
+((bird 0 0.1) (fm-violin 0 1 440 0.1) (bird 0.2 0.1) (bird 0.5 0.5) (fm-violin 1 1 550 0.1) (bird 1.2 0.3))
+|#
+
+
+(define* (with-simple-sound-helper thunk (output "test.snd") (channels 1) (srate 44100) (data-format mus-lfloat) (header-type mus-next))
+  (let ((old-output *output*))
+    (dynamic-wind
+	(lambda ()
+	  (set! *output* (make-sample->file output channels data-format header-type "with-simple-sound output")))
+	(lambda ()
+	  (thunk)
+	  output)
+	(lambda ()
+	  (mus-close *output*)
+	  (set! *output* old-output)))))
+
+(defmacro with-simple-sound (args . body)
+  `(with-simple-sound-helper (lambda () ,@body) ,@args))
