@@ -3,7 +3,6 @@
 ;;; (xe-create-enved name parent args axis-bounds) -> new envelope editor (returned value is list)
 ;;; (xe-envelope editor) -> current envelope (settable)
 
-(use-modules (ice-9 common-list) (ice-9 format))
 (provide 'snd-xm-enved.scm)
 
 
@@ -262,29 +261,33 @@
 	(g_signal_connect_closure_by_id (GPOINTER drawer)
 					(g_signal_lookup "button_press_event" (G_OBJECT_TYPE (GTK_OBJECT drawer)))
 					0 (g_cclosure_new (lambda (w e d) 
-							    (let ((ev (GDK_EVENT_BUTTON e)))
-							      (xe-mouse-press editor (.x ev) (.y ev)))
+							    (let* ((ev (GDK_EVENT_BUTTON e))
+								   (coords (gdk_event_get_coords ev))
+								   (x (cadr coords))
+								   (y (caddr coords)))
+							      (xe-mouse-press editor x y))
 							    #f)
 							  #f #f) 
 					#f)
 	(g_signal_connect_closure_by_id (GPOINTER drawer)
 					(g_signal_lookup "button_release_event" (G_OBJECT_TYPE (GTK_OBJECT drawer)))
 					0 (g_cclosure_new (lambda (w e d) 
-							    (let ((ev (GDK_EVENT_BUTTON e)))
-							      (xe-mouse-release editor (.x ev) (.y ev)))
+							    (let* ((ev (GDK_EVENT_BUTTON e))
+								   (coords (gdk_event_get_coords ev))
+								   (x (cadr coords))
+								   (y (caddr coords)))
+							      (xe-mouse-release editor x y))
 							    #f)
 							  #f #f)
 					#f)
 	(g_signal_connect_closure_by_id (GPOINTER drawer)
 					(g_signal_lookup "motion_notify_event" (G_OBJECT_TYPE (GTK_OBJECT drawer)))
 					0 (g_cclosure_new (lambda (w e d) 
-							    (let ((ev (GDK_EVENT_MOTION e)))
-							      (if (= (.is_hint ev) 1)
-								  (let ((xy (gdk_window_get_pointer (.window ev))))
-								    (if (not (= (logand (cadddr xy) GDK_BUTTON1_MASK) 0))
-									(xe-mouse-drag editor (cadr xy) (caddr xy))))
-								  (if (not (= (logand (.state ev) GDK_BUTTON1_MASK) 0))
-								      (xe-mouse-drag editor (.x ev) (.y ev)))))
+							    (let* ((ev (GDK_EVENT_MOTION e))
+								   (coords (gdk_event_get_coords ev))
+								   (x (cadr coords))
+								   (y (caddr coords)))
+							      (xe-mouse-drag editor x y))
 							    #f)
 							  #f #f)
 					#f)
@@ -336,20 +339,18 @@
 		px0
 		(min px1
 		     (max px0
-			  (inexact->exact
-			   (floor (+ px0 (* (- px1 px0)
-				     (/ (- x ix0)
-					(- ix1 ix0))))))))))
+			  (floor (+ px0 (* (- px1 px0)
+					   (/ (- x ix0)
+					      (- ix1 ix0)))))))))
 	  
 	  (define (xe-grfy drawer y)
 	    (if (= py0 py1)
 		py0
 		(min py0 ; grows downward so y1 < y0
 		     (max py1
-			  (inexact->exact
-			   (floor (+ py1 (* (- py0 py1)
-				     (/ (- y iy1)
-					(- iy0 iy1))))))))))
+			  (floor (+ py1 (* (- py0 py1)
+					   (/ (- y iy1)
+					      (- iy0 iy1)))))))))
 
 	  (if (> py0 py1)
 	      (begin
