@@ -63,8 +63,8 @@ an envelope (normally a ramp from 0 to 1) which sets where we are in the zipping
 		    (set! (zdata-cursamples zp) frame-samples)
 		    (do ((k 0 (+ 1 k)))
 			((= k frame-samples))
-		      (vct-set! frame1 k (read-sample input1))
-		      (vct-set! frame2 k (read-sample input2)))
+		      (set! (frame1 k) (read-sample input1))
+		      (set! (frame2 k) (read-sample input2)))
 		    ;; now resample each dependent on location in ramp (samp1 and samp2 are increments)
 		    (vct-fill! (zdata-frame0 zp) 0.0)
 		    (let ((start-ctr 0.0)
@@ -73,8 +73,8 @@ an envelope (normally a ramp from 0 to 1) which sets where we are in the zipping
 		      (do ((k 0 (+ 1 k)))
 			  ((= k chunk-len))
 			(let* ((ictr (floor start-ctr))
-			       (y0 (vct-ref frame2 ictr))
-			       (y1 (vct-ref frame2 (+ ictr 1))))
+			       (y0 (frame2 ictr))
+			       (y1 (frame2 (+ ictr 1))))
 			  (vct-set! (zdata-frame0 zp) k (+ y0 (* (- y1 y0) (- start-ctr ictr))))
 			  (set! start-ctr (+ start-ctr samp2)))))
 		    (let ((start-ctr 0.0)
@@ -82,11 +82,11 @@ an envelope (normally a ramp from 0 to 1) which sets where we are in the zipping
 		      (do ((k chunk-len (+ 1 k)))
 			  ((= k frame-samples))
 			(let* ((ictr (floor start-ctr))
-			       (y0 (vct-ref frame1 ictr))
-			       (y1 (vct-ref frame1 (+ ictr 1))))
+			       (y0 (frame1 ictr))
+			       (y1 (frame1 (+ ictr 1))))
 			  (vct-set! (zdata-frame0 zp) k (+ y0 (* (- y1 y0) (- start-ctr ictr))))
 			  (set! start-ctr (+ start-ctr samp1)))))))
-	      (let ((result (vct-ref (zdata-frame0 zp) (zdata-frame-loc zp))))
+	      (let ((result ((zdata-frame0 zp) (zdata-frame-loc zp))))
 		(set! (zdata-frame-loc zp) (+ (zdata-frame-loc zp) 1))
 		result))))))
 
@@ -111,10 +111,10 @@ an envelope (normally a ramp from 0 to 1) which sets where we are in the zipping
 (define (ramp-test)
   (let ((data (make-vct 10000)))
     (new-sound "new-0.snd")
-    (do ((i 0 (+ 1 i))) ((= i 10000)) (vct-set! data i (* i .0001)))
+    (do ((i 0 (+ 1 i))) ((= i 10000)) (set! (data i) (* i .0001)))
     (vct->channel data 0 10000 0)
     (new-sound "new-1.snd")
-    (do ((i 0 (+ 1 i))) ((= i 10000)) (vct-set! data i (- 1.0 (* i .0001))))
+    (do ((i 0 (+ 1 i))) ((= i 10000)) (set! (data i) (- 1.0 (* i .0001))))
     (vct->channel data 0 10000 1)
     (let* ((dur (frames))
 	   (zp (make-zipper (make-env '(0 0 1 1) :length dur)
